=== modified file 'apt-inst/deb/dpkgdb.cc'
--- apt-inst/deb/dpkgdb.cc	2010-02-18 22:07:23 +0000
+++ apt-inst/deb/dpkgdb.cc	2010-06-10 14:02:22 +0000
@@ -142,7 +142,7 @@
       CacheMap = 0;
    }
    
-   if (pkgMakeOnlyStatusCache(Progress,&CacheMap) == false)
+   if (pkgCacheGenerator::MakeOnlyStatusCache(&Progress,&CacheMap) == false)
       return false;
    Cache->DropProgress();
    

=== modified file 'apt-pkg/acquire-item.cc'
--- apt-pkg/acquire-item.cc	2010-05-25 16:01:42 +0000
+++ apt-pkg/acquire-item.cc	2010-06-10 14:02:22 +0000
@@ -33,6 +33,7 @@
 #include <string>
 #include <sstream>
 #include <stdio.h>
+#include <ctime>
 									/*}}}*/
 
 using namespace std;
@@ -64,6 +65,7 @@
 {
    Status = StatIdle;
    ErrorText = LookupTag(Message,"Message");
+   UsedMirror =  LookupTag(Message,"UsedMirror");
    if (QueueCounter <= 1)
    {
       /* This indicates that the file is not available right now but might
@@ -76,10 +78,17 @@
 	 Dequeue();
 	 return;
       }
-      
+
       Status = StatError;
       Dequeue();
    }   
+
+   // report mirror failure back to LP if we actually use a mirror
+   string FailReason = LookupTag(Message, "FailReason");
+   if(FailReason.size() != 0)
+      ReportMirrorFailure(FailReason);
+   else
+      ReportMirrorFailure(ErrorText);
 }
 									/*}}}*/
 // Acquire::Item::Start - Item has begun to download			/*{{{*/
@@ -101,7 +110,7 @@
 {
    // We just downloaded something..
    string FileName = LookupTag(Message,"Filename");
-   // we only inform the Log class if it was actually not a local thing
+   UsedMirror =  LookupTag(Message,"UsedMirror");
    if (Complete == false && !Local && FileName == DestFile)
    {
       if (Owner->Log != 0)
@@ -110,7 +119,6 @@
 
    if (FileSize == 0)
       FileSize= Size;
-   
    Status = StatDone;
    ErrorText = string();
    Owner->Dequeue(this);
@@ -132,6 +140,50 @@
    }   
 }
 									/*}}}*/
+// Acquire::Item::ReportMirrorFailure					/*{{{*/
+// ---------------------------------------------------------------------
+void pkgAcquire::Item::ReportMirrorFailure(string FailCode)
+{
+   // we only act if a mirror was used at all
+   if(UsedMirror.empty())
+      return;
+#if 0
+   std::cerr << "\nReportMirrorFailure: " 
+	     << UsedMirror
+	     << " Uri: " << DescURI()
+	     << " FailCode: " 
+	     << FailCode << std::endl;
+#endif
+   const char *Args[40];
+   unsigned int i = 0;
+   string report = _config->Find("Methods::Mirror::ProblemReporting", 
+				 "/usr/lib/apt/apt-report-mirror-failure");
+   if(!FileExists(report))
+      return;
+   Args[i++] = report.c_str();
+   Args[i++] = UsedMirror.c_str();
+   Args[i++] = DescURI().c_str();
+   Args[i++] = FailCode.c_str();
+   Args[i++] = NULL;
+   pid_t pid = ExecFork();
+   if(pid < 0) 
+   {
+      _error->Error("ReportMirrorFailure Fork failed");
+      return;
+   }
+   else if(pid == 0) 
+   {
+      execvp(Args[0], (char**)Args);
+      std::cerr << "Could not exec " << Args[0] << std::endl;
+      _exit(100);
+   }
+   if(!ExecWait(pid, "report-mirror-failure")) 
+   {
+      _error->Warning("Couldn't report problem to '%s'",
+		      _config->Find("Methods::Mirror::ProblemReporting").c_str());
+   }
+}
+									/*}}}*/
 // AcqDiffIndex::AcqDiffIndex - Constructor				/*{{{*/
 // ---------------------------------------------------------------------
 /* Get the DiffIndex file first and see if there are patches availabe 
@@ -624,7 +676,6 @@
    struct stat Buf;
    if (stat(Final.c_str(),&Buf) != 0)
       return "\nIndex-File: true";
-   
    return "\nIndex-File: true\nLast-Modified: " + TimeRFC1123(Buf.st_mtime);
 }
 									/*}}}*/
@@ -692,6 +743,7 @@
          Status = StatAuthError;
          ErrorText = _("Hash Sum mismatch");
          Rename(DestFile,DestFile + ".FAILED");
+	 ReportMirrorFailure("HashChecksumFailure");
          return;
       }
       // Done, move it into position
@@ -780,6 +832,19 @@
 {
 }
 									/*}}}*/
+// AcqIndexTrans::Custom600Headers - Insert custom request headers	/*{{{*/
+// ---------------------------------------------------------------------
+string pkgAcqIndexTrans::Custom600Headers()
+{
+   string Final = _config->FindDir("Dir::State::lists");
+   Final += URItoFileName(RealURI);
+
+   struct stat Buf;
+   if (stat(Final.c_str(),&Buf) != 0)
+      return "\nFail-Ignore: true";
+   return "\nFail-Ignore: true\nLast-Modified: " + TimeRFC1123(Buf.st_mtime);
+}
+									/*}}}*/
 // AcqIndexTrans::Failed - Silence failure messages for missing files	/*{{{*/
 // ---------------------------------------------------------------------
 /* */
@@ -882,8 +947,9 @@
       Rename(LastGoodSig, DestFile);
 
    // queue a pkgAcqMetaIndex to be verified against the sig we just retrieved
-   new pkgAcqMetaIndex(Owner, MetaIndexURI, MetaIndexURIDesc, MetaIndexShortDesc,
-		       DestFile, IndexTargets, MetaIndexParser);
+   new pkgAcqMetaIndex(Owner, MetaIndexURI, MetaIndexURIDesc, 
+		       MetaIndexShortDesc,  DestFile, IndexTargets, 
+		       MetaIndexParser);
 
 }
 									/*}}}*/
@@ -896,7 +962,7 @@
    {
       Item::Failed(Message,Cnf);
       // move the sigfile back on transient network failures 
-      if(FileExists(DestFile))
+      if(FileExists(LastGoodSig))
  	 Rename(LastGoodSig,Final);
 
       // set the status back to , Item::Failed likes to reset it
@@ -971,6 +1037,15 @@
    if (AuthPass == true)
    {
       AuthDone(Message);
+
+      // all cool, move Release file into place
+      Complete = true;
+
+      string FinalFile = _config->FindDir("Dir::State::lists");
+      FinalFile += URItoFileName(RealURI);
+      Rename(DestFile,FinalFile);
+      chmod(FinalFile.c_str(),0644);
+      DestFile = FinalFile;
    }
    else
    {
@@ -1022,22 +1097,15 @@
       return;
    }
 
-   // see if the download was a IMSHit
+   // make sure to verify against the right file on I-M-S hit
    IMSHit = StringToBool(LookupTag(Message,"IMS-Hit"),false);
+   if(IMSHit)
+   {
+      string FinalFile = _config->FindDir("Dir::State::lists");
+      FinalFile += URItoFileName(RealURI);
+      DestFile = FinalFile;
+   }
    Complete = true;
-
-   string FinalFile = _config->FindDir("Dir::State::lists");
-   FinalFile += URItoFileName(RealURI);
-
-   // If we get a IMS hit we can remove the empty file in partial
-   // othersie we move the file in place
-   if (IMSHit)
-      unlink(DestFile.c_str());
-   else
-      Rename(DestFile,FinalFile);
-
-   chmod(FinalFile.c_str(),0644);
-   DestFile = FinalFile;
 }
 									/*}}}*/
 void pkgAcqMetaIndex::AuthDone(string Message)				/*{{{*/
@@ -1067,7 +1135,6 @@
    QueueIndexes(true);
 
    // Done, move signature file into position
-
    string VerifiedSigFile = _config->FindDir("Dir::State::lists") +
       URItoFileName(RealURI) + ".gpg";
    Rename(SigFile,VerifiedSigFile);
@@ -1105,13 +1172,16 @@
             return;
          }
       }
-      
-      // Queue Packages file (either diff or full packages files, depending
-      // on the users option)
-      if(_config->FindB("Acquire::PDiffs",true) == true) 
+
+      /* Queue Packages file (either diff or full packages files, depending
+         on the users option) - we also check if the PDiff Index file is listed
+         in the Meta-Index file. Ideal would be if pkgAcqDiffIndex would test this
+         instead, but passing the required info to it is to much hassle */
+      if(_config->FindB("Acquire::PDiffs",true) == true && (verify == false ||
+	  MetaIndexParser->Exists(string((*Target)->MetaKey).append(".diff/Index")) == true))
 	 new pkgAcqDiffIndex(Owner, (*Target)->URI, (*Target)->Description,
 			     (*Target)->ShortDesc, ExpectedIndexHash);
-      else 
+      else
 	 new pkgAcqIndex(Owner, (*Target)->URI, (*Target)->Description,
 			    (*Target)->ShortDesc, ExpectedIndexHash);
    }
@@ -1177,6 +1247,17 @@
       Transformed = "";
    }
 
+   if (_config->FindB("Acquire::Check-Valid-Until", true) == true &&
+       MetaIndexParser->GetValidUntil() > 0) {
+      time_t const invalid_since = time(NULL) - MetaIndexParser->GetValidUntil();
+      if (invalid_since > 0)
+	 // TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+	 // the time since then the file is invalid - formated in the same way as in
+	 // the download progress display (e.g. 7d 3h 42min 1s)
+	 return _error->Error(_("Release file expired, ignoring %s (invalid since %s)"),
+	                      RealURI.c_str(), TimeToStr(invalid_since).c_str());
+   }
+
    if (_config->FindB("Debug::pkgAcquire::Auth", false)) 
    {
       std::cerr << "Got Codename: " << MetaIndexParser->GetDist() << std::endl;
@@ -1194,7 +1275,7 @@
 //       return false;
       if (!Transformed.empty())
       {
-         _error->Warning("Conflicting distribution: %s (expected %s but got %s)",
+         _error->Warning(_("Conflicting distribution: %s (expected %s but got %s)"),
                          Desc.Description.c_str(),
                          Transformed.c_str(),
                          MetaIndexParser->GetDist().c_str());
@@ -1211,30 +1292,30 @@
 {
    if (AuthPass == true)
    {
-      // if we fail the authentication but got the file via a IMS-Hit 
-      // this means that the file wasn't downloaded and that it might be
-      // just stale (server problem, proxy etc). we delete what we have
-      // queue it again without i-m-s 
-      // alternatively we could just unlink the file and let the user try again
-      if (IMSHit)
+      // gpgv method failed, if we have a good signature 
+      string LastGoodSigFile = _config->FindDir("Dir::State::lists") +
+	 "partial/" + URItoFileName(RealURI) + ".gpg.reverify";
+      if(FileExists(LastGoodSigFile))
       {
-	 Complete = false;
-	 Local = false;
-	 AuthPass = false;
-	 unlink(DestFile.c_str());
-
-	 DestFile = _config->FindDir("Dir::State::lists") + "partial/";
-	 DestFile += URItoFileName(RealURI);
-	 Desc.URI = RealURI;
-	 QueueURI(Desc);
+	 string VerifiedSigFile = _config->FindDir("Dir::State::lists") +
+	    URItoFileName(RealURI) + ".gpg";
+	 Rename(LastGoodSigFile,VerifiedSigFile);
+	 Status = StatTransientNetworkError;
+	 _error->Warning(_("A error occurred during the signature "
+			   "verification. The repository is not updated "
+			   "and the previous index files will be used."
+			   "GPG error: %s: %s\n"),
+			 Desc.Description.c_str(),
+			 LookupTag(Message,"Message").c_str());
+	 RunScripts("APT::Update::Auth-Failure");
 	 return;
+      } else {
+	 _error->Warning(_("GPG error: %s: %s"),
+			 Desc.Description.c_str(),
+			 LookupTag(Message,"Message").c_str());
       }
-
       // gpgv method failed 
-      _error->Warning("GPG error: %s: %s",
-                      Desc.Description.c_str(),
-                      LookupTag(Message,"Message").c_str());
-
+      ReportMirrorFailure("GPGFailure");
    }
 
    // No Release file was present, or verification failed, so fall

=== modified file 'apt-pkg/acquire-item.h'
--- apt-pkg/acquire-item.h	2010-05-06 09:32:54 +0000
+++ apt-pkg/acquire-item.h	2010-06-10 14:02:22 +0000
@@ -112,10 +112,10 @@
    string ErrorText;
 
    /** \brief The size of the object to fetch. */
-   unsigned long FileSize;
+   unsigned long long FileSize;
 
    /** \brief How much of the object was already fetched. */
-   unsigned long PartialSize;
+   unsigned long long PartialSize;
 
    /** \brief If not \b NULL, contains the name of a subprocess that
     *  is operating on this object (for instance, "gzip" or "gpgv").
@@ -143,6 +143,7 @@
     *  download progress indicator's overall statistics.
     */
    bool Local;
+   string UsedMirror;
 
    /** \brief The number of fetch queues into which this item has been
     *  inserted.
@@ -243,6 +244,17 @@
 
    /** \return \b true if this object is being fetched from a trusted source. */
    virtual bool IsTrusted() {return false;};
+   
+   // report mirror problems
+   /** \brief Report mirror problem
+    * 
+    *  This allows reporting mirror failures back to a centralized
+    *  server. The apt-report-mirror-failure script is called for this
+    * 
+    *  \param FailCode A short failure string that is send
+    */
+   void ReportMirrorFailure(string FailCode);
+
 
    /** \brief Initialize an item.
     *
@@ -551,7 +563,8 @@
     *  fallback is ".gz" or none.
     */
    pkgAcqIndex(pkgAcquire *Owner,string URI,string URIDesc,
-	       string ShortDesc, HashString ExpectedHash, string compressExt="");
+	       string ShortDesc, HashString ExpectedHash, 
+	       string compressExt="");
 };
 									/*}}}*/
 /** \brief An acquire item that is responsible for fetching a		{{{
@@ -566,6 +579,7 @@
    public:
   
    virtual void Failed(string Message,pkgAcquire::MethodConfig *Cnf);
+   virtual string Custom600Headers();
 
    /** \brief Create a pkgAcqIndexTrans.
     *
@@ -614,7 +628,6 @@
    /** \brief The last good signature file */
    string LastGoodSig;
 
-
    /** \brief The fetch request that is currently being processed. */
    pkgAcquire::ItemDesc Desc;
 

=== modified file 'apt-pkg/acquire-method.cc'
--- apt-pkg/acquire-method.cc	2010-02-18 22:07:23 +0000
+++ apt-pkg/acquire-method.cc	2010-06-10 14:02:22 +0000
@@ -96,12 +96,11 @@
    }
    
    char S[1024];
+   char *End = S;
    if (Queue != 0)
    {
-      snprintf(S,sizeof(S)-50,"400 URI Failure\nURI: %s\n"
-	       "Message: %s %s\n",Queue->Uri.c_str(),Err.c_str(),
-	       FailExtra.c_str());
-
+      End += snprintf(S,sizeof(S)-50,"400 URI Failure\nURI: %s\n"
+		      "Message: %s %s\n",Queue->Uri.c_str(), Err.c_str(), IP.c_str());
       // Dequeue
       FetchItem *Tmp = Queue;
       Queue = Queue->Next;
@@ -110,10 +109,14 @@
 	 QueueBack = Queue;
    }
    else
-      snprintf(S,sizeof(S)-50,"400 URI Failure\nURI: <UNKNOWN>\n"
-	       "Message: %s %s\n",Err.c_str(),
-	       FailExtra.c_str());
-      
+   {
+      End += snprintf(S,sizeof(S)-50,"400 URI Failure\nURI: <UNKNOWN>\n"
+		      "Message: %s\n",Err.c_str());
+   }
+   if(FailReason.empty() == false)
+      End += snprintf(End,sizeof(S)-50 - (End - S),"FailReason: %s\n",FailReason.c_str());
+   if (UsedMirror.empty() == false)
+      End += snprintf(End,sizeof(S)-50 - (End - S),"UsedMirror: %s\n",UsedMirror.c_str());
    // Set the transient flag 
    if (Transient == true)
       strcat(S,"Transient-Failure: true\n\n");
@@ -184,6 +187,8 @@
       End += snprintf(End,sizeof(S)-50 - (End - S),"SHA1-Hash: %s\n",Res.SHA1Sum.c_str());
    if (Res.SHA256Sum.empty() == false)
       End += snprintf(End,sizeof(S)-50 - (End - S),"SHA256-Hash: %s\n",Res.SHA256Sum.c_str());
+   if (UsedMirror.empty() == false)
+      End += snprintf(End,sizeof(S)-50 - (End - S),"UsedMirror: %s\n",UsedMirror.c_str());
    if (Res.GPGVOutput.size() > 0)
       End += snprintf(End,sizeof(S)-50 - (End - S),"GPGVOutput:\n");     
    for (vector<string>::iterator I = Res.GPGVOutput.begin();
@@ -373,9 +378,10 @@
 	    
 	    Tmp->Uri = LookupTag(Message,"URI");
 	    Tmp->DestFile = LookupTag(Message,"FileName");
-	    if (StrToTime(LookupTag(Message,"Last-Modified"),Tmp->LastModified) == false)
+	    if (RFC1123StrToTime(LookupTag(Message,"Last-Modified").c_str(),Tmp->LastModified) == false)
 	       Tmp->LastModified = 0;
 	    Tmp->IndexFile = StringToBool(LookupTag(Message,"Index-File"),false);
+	    Tmp->FailIgnore = StringToBool(LookupTag(Message,"Fail-Ignore"),false);
 	    Tmp->Next = 0;
 	    
 	    // Append it to the list

=== modified file 'apt-pkg/acquire-method.h'
--- apt-pkg/acquire-method.h	2010-02-18 22:07:23 +0000
+++ apt-pkg/acquire-method.h	2010-06-10 14:02:22 +0000
@@ -37,6 +37,7 @@
       string DestFile;
       time_t LastModified;
       bool IndexFile;
+      bool FailIgnore;
    };
    
    struct FetchResult
@@ -59,7 +60,9 @@
    vector<string> Messages;
    FetchItem *Queue;
    FetchItem *QueueBack;
-   string FailExtra;
+   string FailReason;
+   string UsedMirror;
+   string IP;
    
    // Handlers for messages
    virtual bool Configuration(string Message);
@@ -68,14 +71,14 @@
    // Outgoing messages
    void Fail(bool Transient = false);
    inline void Fail(const char *Why, bool Transient = false) {Fail(string(Why),Transient);};
-   void Fail(string Why, bool Transient = false);
-   void URIStart(FetchResult &Res);
-   void URIDone(FetchResult &Res,FetchResult *Alt = 0);
+   virtual void Fail(string Why, bool Transient = false);
+   virtual void URIStart(FetchResult &Res);
+   virtual void URIDone(FetchResult &Res,FetchResult *Alt = 0);
+
    bool MediaFail(string Required,string Drive);
    virtual void Exit() {};
 
    public:
-
    enum CnfFlags {SingleInstance = (1<<0),
                   Pipeline = (1<<1), SendConfig = (1<<2),
                   LocalOnly = (1<<3), NeedsCleanup = (1<<4), 
@@ -87,7 +90,8 @@
    void Redirect(const string &NewURI);
  
    int Run(bool Single = false);
-   inline void SetFailExtraMsg(string Msg) {FailExtra = Msg;};
+   inline void SetFailReason(string Msg) {FailReason = Msg;};
+   inline void SetIP(string aIP) {IP = aIP;};
    
    pkgAcqMethod(const char *Ver,unsigned long Flags = 0);
    virtual ~pkgAcqMethod() {};

=== modified file 'apt-pkg/acquire.cc'
--- apt-pkg/acquire.cc	2010-05-06 09:32:54 +0000
+++ apt-pkg/acquire.cc	2010-06-10 14:02:22 +0000
@@ -506,9 +506,9 @@
 // Acquire::TotalNeeded - Number of bytes to fetch			/*{{{*/
 // ---------------------------------------------------------------------
 /* This is the total number of bytes needed */
-double pkgAcquire::TotalNeeded()
+unsigned long long pkgAcquire::TotalNeeded()
 {
-   double Total = 0;
+   unsigned long long Total = 0;
    for (ItemCIterator I = ItemsBegin(); I != ItemsEnd(); I++)
       Total += (*I)->FileSize;
    return Total;
@@ -517,9 +517,9 @@
 // Acquire::FetchNeeded - Number of bytes needed to get			/*{{{*/
 // ---------------------------------------------------------------------
 /* This is the number of bytes that is not local */
-double pkgAcquire::FetchNeeded()
+unsigned long long pkgAcquire::FetchNeeded()
 {
-   double Total = 0;
+   unsigned long long Total = 0;
    for (ItemCIterator I = ItemsBegin(); I != ItemsEnd(); I++)
       if ((*I)->Local == false)
 	 Total += (*I)->FileSize;
@@ -529,9 +529,9 @@
 // Acquire::PartialPresent - Number of partial bytes we already have	/*{{{*/
 // ---------------------------------------------------------------------
 /* This is the number of bytes that is not local */
-double pkgAcquire::PartialPresent()
+unsigned long long pkgAcquire::PartialPresent()
 {
-  double Total = 0;
+  unsigned long long Total = 0;
    for (ItemCIterator I = ItemsBegin(); I != ItemsEnd(); I++)
       if ((*I)->Local == false)
 	 Total += (*I)->PartialSize;

=== modified file 'apt-pkg/acquire.h'
--- apt-pkg/acquire.h	2010-05-06 09:32:54 +0000
+++ apt-pkg/acquire.h	2010-06-10 14:02:22 +0000
@@ -323,17 +323,17 @@
    /** \return the total size in bytes of all the items included in
     *  this download.
     */
-   double TotalNeeded();
+   unsigned long long TotalNeeded();
 
    /** \return the size in bytes of all non-local items included in
     *  this download.
     */
-   double FetchNeeded();
+   unsigned long long FetchNeeded();
 
    /** \return the amount of data to be fetched that is already
     *  present on the filesystem.
     */
-   double PartialPresent();
+   unsigned long long PartialPresent();
 
    /** \brief Delayed constructor
     *

=== modified file 'apt-pkg/algorithms.cc'
--- apt-pkg/algorithms.cc	2010-05-06 09:32:54 +0000
+++ apt-pkg/algorithms.cc	2010-06-10 14:02:22 +0000
@@ -1184,8 +1184,7 @@
       return _error->Error(_("Unable to correct problems, you have held broken packages."));
    }
    
-   // set the auto-flags (mvo: I'm not sure if we _really_ need this, but
-   // I didn't managed 
+   // set the auto-flags (mvo: I'm not sure if we _really_ need this)
    pkgCache::PkgIterator I = Cache.PkgBegin();
    for (;I.end() != true; I++) {
       if (Cache[I].NewInstall() && !(Flags[I->ID] & PreInstalled)) {

=== modified file 'apt-pkg/aptconfiguration.cc'
--- apt-pkg/aptconfiguration.cc	2010-04-01 17:30:43 +0000
+++ apt-pkg/aptconfiguration.cc	2010-06-10 14:02:22 +0000
@@ -327,11 +327,24 @@
 	if (likely(Cached == true) && archs.empty() == false)
 		return archs;
 
+	archs = _config->FindVector("APT::Architectures");
 	string const arch = _config->Find("APT::Architecture");
-	archs = _config->FindVector("APT::Architectures");
+	if (unlikely(arch.empty() == true))
+		return archs;
+
 	if (archs.empty() == true ||
 	    std::find(archs.begin(), archs.end(), arch) == archs.end())
 		archs.push_back(arch);
+
+	// erase duplicates and empty strings
+	for (std::vector<string>::reverse_iterator a = archs.rbegin();
+	     a != archs.rend(); ++a) {
+		if (a->empty() == true || std::find(a + 1, archs.rend(), *a) != archs.rend())
+			archs.erase(a.base()-1);
+		if (a == archs.rend())
+			break;
+	}
+
 	return archs;
 }
 									/*}}}*/

=== modified file 'apt-pkg/cachefile.cc'
--- apt-pkg/cachefile.cc	2010-02-18 22:07:23 +0000
+++ apt-pkg/cachefile.cc	2010-06-10 14:02:22 +0000
@@ -27,7 +27,8 @@
 // CacheFile::CacheFile - Constructor					/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-pkgCacheFile::pkgCacheFile() : Map(0), Cache(0), DCache(0), Policy(0)
+pkgCacheFile::pkgCacheFile() : Map(NULL), Cache(NULL), DCache(NULL),
+				Policy(NULL), SrcList(NULL)
 {
 }
 									/*}}}*/
@@ -38,16 +39,30 @@
 {
    delete DCache;
    delete Policy;
+   delete SrcList;
    delete Cache;
    delete Map;
    _system->UnLock(true);
-}   
+}
 									/*}}}*/
 // CacheFile::BuildCaches - Open and build the cache files		/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-bool pkgCacheFile::BuildCaches(OpProgress &Progress,bool WithLock)
+bool pkgCacheFile::BuildCaches(OpProgress *Progress, bool WithLock)
 {
+   if (Cache != NULL)
+      return true;
+
+   if (_config->FindB("pkgCacheFile::Generate", true) == false)
+   {
+      Map = new MMap(*new FileFd(_config->FindFile("Dir::Cache::pkgcache"),
+		     FileFd::ReadOnly),MMap::Public|MMap::ReadOnly);
+      Cache = new pkgCache(Map);
+      if (_error->PendingError() == true)
+         return false;
+      return true;
+   }
+
    const bool ErrorWasEmpty = _error->empty();
    if (WithLock == true)
       if (_system->Lock() == false)
@@ -58,15 +73,13 @@
       
    if (_error->PendingError() == true)
       return false;
-   
-   // Read the source list
-   pkgSourceList List;
-   if (List.ReadMainList() == false)
-      return _error->Error(_("The list of sources could not be read."));
+
+   BuildSourceList(Progress);
 
    // Read the caches
-   bool Res = pkgMakeStatusCache(List,Progress,&Map,!WithLock);
-   Progress.Done();
+   bool Res = pkgCacheGenerator::MakeStatusCache(*SrcList,Progress,&Map,!WithLock);
+   if (Progress != NULL)
+      Progress->Done();
    if (Res == false)
       return _error->Error(_("The package lists or status file could not be parsed or opened."));
 
@@ -80,29 +93,70 @@
    return true;
 }
 									/*}}}*/
-// CacheFile::Open - Open the cache files, creating if necessary	/*{{{*/
-// ---------------------------------------------------------------------
-/* */
-bool pkgCacheFile::Open(OpProgress &Progress,bool WithLock)
-{
-   if (BuildCaches(Progress,WithLock) == false)
-      return false;
-   
-   // The policy engine
+// CacheFile::BuildSourceList - Open and build all relevant sources.list/*{{{*/
+// ---------------------------------------------------------------------
+/* */
+bool pkgCacheFile::BuildSourceList(OpProgress *Progress)
+{
+   if (SrcList != NULL)
+      return true;
+
+   SrcList = new pkgSourceList();
+   if (SrcList->ReadMainList() == false)
+      return _error->Error(_("The list of sources could not be read."));
+   return true;
+}
+									/*}}}*/
+// CacheFile::BuildPolicy - Open and build all relevant preferences	/*{{{*/
+// ---------------------------------------------------------------------
+/* */
+bool pkgCacheFile::BuildPolicy(OpProgress *Progress)
+{
+   if (Policy != NULL)
+      return true;
+
    Policy = new pkgPolicy(Cache);
    if (_error->PendingError() == true)
       return false;
 
    if (ReadPinFile(*Policy) == false || ReadPinDir(*Policy) == false)
       return false;
-   
-   // Create the dependency cache
+
+   return true;
+}
+									/*}}}*/
+// CacheFile::BuildDepCache - Open and build the dependency cache	/*{{{*/
+// ---------------------------------------------------------------------
+/* */
+bool pkgCacheFile::BuildDepCache(OpProgress *Progress)
+{
+   if (DCache != NULL)
+      return true;
+
    DCache = new pkgDepCache(Cache,Policy);
    if (_error->PendingError() == true)
       return false;
-   
-   DCache->Init(&Progress);
-   Progress.Done();
+
+   DCache->Init(Progress);
+   return true;
+}
+									/*}}}*/
+// CacheFile::Open - Open the cache files, creating if necessary	/*{{{*/
+// ---------------------------------------------------------------------
+/* */
+bool pkgCacheFile::Open(OpProgress *Progress, bool WithLock)
+{
+   if (BuildCaches(Progress,WithLock) == false)
+      return false;
+
+   if (BuildPolicy(Progress) == false)
+      return false;
+
+   if (BuildDepCache(Progress) == false)
+      return false;
+
+   if (Progress != NULL)
+      Progress->Done();
    if (_error->PendingError() == true)
       return false;
    
@@ -117,12 +171,14 @@
    delete DCache;
    delete Policy;
    delete Cache;
+   delete SrcList;
    delete Map;
    _system->UnLock(true);
 
-   Map = 0;
-   DCache = 0;
-   Policy = 0;
-   Cache = 0;
+   Map = NULL;
+   DCache = NULL;
+   Policy = NULL;
+   Cache = NULL;
+   SrcList = NULL;
 }
 									/*}}}*/

=== modified file 'apt-pkg/cachefile.h'
--- apt-pkg/cachefile.h	2008-05-28 15:19:12 +0000
+++ apt-pkg/cachefile.h	2010-06-10 14:02:22 +0000
@@ -23,6 +23,7 @@
 #include <apt-pkg/sourcelist.h>
 
 class pkgPolicy;
+class pkgSourceList;
 class pkgCacheFile
 {
    protected:
@@ -30,27 +31,42 @@
    MMap *Map;
    pkgCache *Cache;
    pkgDepCache *DCache;
-   
+   pkgPolicy *Policy;
+   pkgSourceList *SrcList;
+
    public:
 
-   pkgPolicy *Policy;
-      
    // We look pretty much exactly like a pointer to a dep cache
    inline operator pkgCache &() {return *Cache;};
    inline operator pkgCache *() {return Cache;};
    inline operator pkgDepCache &() {return *DCache;};
    inline operator pkgDepCache *() {return DCache;};
+   inline operator pkgPolicy &() {return *Policy;};
+   inline operator pkgPolicy *() {return Policy;};
+   inline operator pkgSourceList &() {return *SrcList;};
+   inline operator pkgSourceList *() {return SrcList;};
    inline pkgDepCache *operator ->() {return DCache;};
    inline pkgDepCache &operator *() {return *DCache;};
    inline pkgDepCache::StateCache &operator [](pkgCache::PkgIterator const &I) {return (*DCache)[I];};
    inline unsigned char &operator [](pkgCache::DepIterator const &I) {return (*DCache)[I];};
 
-   bool BuildCaches(OpProgress &Progress,bool WithLock = true);
-   bool Open(OpProgress &Progress,bool WithLock = true);
+   bool BuildCaches(OpProgress *Progress = NULL,bool WithLock = true);
+   __deprecated bool BuildCaches(OpProgress &Progress,bool const &WithLock = true) { return BuildCaches(&Progress, WithLock); };
+   bool BuildSourceList(OpProgress *Progress = NULL);
+   bool BuildPolicy(OpProgress *Progress = NULL);
+   bool BuildDepCache(OpProgress *Progress = NULL);
+   bool Open(OpProgress *Progress = NULL, bool WithLock = true);
+   inline bool ReadOnlyOpen(OpProgress *Progress = NULL) { return Open(Progress, false); };
+   __deprecated bool Open(OpProgress &Progress,bool const &WithLock = true) { return Open(&Progress, WithLock); };
    void Close();
-   
+
+   inline pkgCache* GetPkgCache() { BuildCaches(NULL, false); return Cache; };
+   inline pkgDepCache* GetDepCache() { BuildDepCache(); return DCache; };
+   inline pkgPolicy* GetPolicy() { BuildPolicy(); return Policy; };
+   inline pkgSourceList* GetSourceList() { BuildSourceList(); return SrcList; };
+
    pkgCacheFile();
-   ~pkgCacheFile();
+   virtual ~pkgCacheFile();
 };
 
 #endif

=== modified file 'apt-pkg/cacheiterators.h'
--- apt-pkg/cacheiterators.h	2010-04-01 17:30:43 +0000
+++ apt-pkg/cacheiterators.h	2010-06-10 14:02:22 +0000
@@ -29,10 +29,12 @@
 									/*}}}*/
 #ifndef PKGLIB_CACHEITERATORS_H
 #define PKGLIB_CACHEITERATORS_H
+#include<iterator>
 // abstract Iterator template						/*{{{*/
 /* This template provides the very basic iterator methods we
    need to have for doing some walk-over-the-cache magic */
-template<typename Str, typename Itr> class pkgCache::Iterator {
+template<typename Str, typename Itr> class pkgCache::Iterator :
+			public std::iterator<std::forward_iterator_tag, Str> {
 	protected:
 	Str *S;
 	pkgCache *Owner;
@@ -64,7 +66,7 @@
 	inline operator Str const *() const {return S == OwnerPointer() ? 0 : S;};
 	inline Str &operator *() {return *S;};
 	inline Str const &operator *() const {return *S;};
-	inline pkgCache *Cache() {return Owner;};
+	inline pkgCache *Cache() const {return Owner;};
 
 	// Mixed stuff
 	inline void operator =(const Itr &B) {S = B.S; Owner = B.Owner;};
@@ -102,6 +104,11 @@
 	inline const char *Name() const {return S->Name == 0?0:Owner->StrP + S->Name;};
 	inline PkgIterator PackageList() const;
 	PkgIterator FindPkg(string Arch = "any");
+	/** \brief find the package with the "best" architecture
+
+	    The best architecture is either the "native" or the first
+	    in the list of Architectures which is not an end-Pointer */
+	PkgIterator FindPreferredPkg();
 	PkgIterator NextPkg(PkgIterator const &Pkg);
 
 	// Constructors
@@ -198,8 +205,8 @@
 	inline PrvIterator ProvidesList() const;
 	inline VerFileIterator FileList() const;
 	bool Downloadable() const;
-	inline const char *PriorityType() {return Owner->Priority(S->Priority);};
-	string RelStr();
+	inline const char *PriorityType() const {return Owner->Priority(S->Priority);};
+	string RelStr() const;
 
 	bool Automatic() const;
 	bool Pseudo() const;

=== added file 'apt-pkg/cacheset.cc'
--- apt-pkg/cacheset.cc	1970-01-01 00:00:00 +0000
+++ apt-pkg/cacheset.cc	2010-06-10 14:02:22 +0000
@@ -0,0 +1,280 @@
+// -*- mode: cpp; mode: fold -*-
+// Description								/*{{{*/
+/* ######################################################################
+
+   Simple wrapper around a std::set to provide a similar interface to
+   a set of cache structures as to the complete set of all structures
+   in the pkgCache. Currently only Package is supported.
+
+   ##################################################################### */
+									/*}}}*/
+// Include Files							/*{{{*/
+#include <apt-pkg/aptconfiguration.h>
+#include <apt-pkg/error.h>
+#include <apt-pkg/cacheset.h>
+#include <apt-pkg/strutl.h>
+#include <apt-pkg/versionmatch.h>
+
+#include <apti18n.h>
+
+#include <vector>
+
+#include <regex.h>
+									/*}}}*/
+namespace APT {
+// FromRegEx - Return all packages in the cache matching a pattern	/*{{{*/
+PackageSet PackageSet::FromRegEx(pkgCacheFile &Cache, std::string pattern, std::ostream &out) {
+	PackageSet pkgset;
+	std::string arch = "native";
+	static const char * const isregex = ".?+*|[^$";
+
+	if (pattern.find_first_of(isregex) == std::string::npos)
+		return pkgset;
+
+	size_t archfound = pattern.find_last_of(':');
+	if (archfound != std::string::npos) {
+		arch = pattern.substr(archfound+1);
+		if (arch.find_first_of(isregex) == std::string::npos)
+			pattern.erase(archfound);
+		else
+			arch = "native";
+	}
+
+	regex_t Pattern;
+	int Res;
+	if ((Res = regcomp(&Pattern, pattern.c_str() , REG_EXTENDED | REG_ICASE | REG_NOSUB)) != 0) {
+		char Error[300];
+		regerror(Res, &Pattern, Error, sizeof(Error));
+		_error->Error(_("Regex compilation error - %s"), Error);
+		return pkgset;
+	}
+
+	for (pkgCache::GrpIterator Grp = Cache.GetPkgCache()->GrpBegin(); Grp.end() == false; ++Grp)
+	{
+		if (regexec(&Pattern, Grp.Name(), 0, 0, 0) != 0)
+			continue;
+		pkgCache::PkgIterator Pkg = Grp.FindPkg(arch);
+		if (Pkg.end() == true) {
+			if (archfound == std::string::npos) {
+				std::vector<std::string> archs = APT::Configuration::getArchitectures();
+				for (std::vector<std::string>::const_iterator a = archs.begin();
+				     a != archs.end() && Pkg.end() != true; ++a)
+					Pkg = Grp.FindPkg(*a);
+			}
+			if (Pkg.end() == true)
+				continue;
+		}
+
+		ioprintf(out, _("Note, selecting %s for regex '%s'\n"),
+			 Pkg.FullName(true).c_str(), pattern.c_str());
+
+		pkgset.insert(Pkg);
+	}
+
+	regfree(&Pattern);
+
+	return pkgset;
+}
+									/*}}}*/
+// GroupedFromCommandLine - Return all versions specified on commandline/*{{{*/
+std::map<unsigned short, PackageSet> PackageSet::GroupedFromCommandLine(
+		pkgCacheFile &Cache, const char **cmdline,
+		std::list<PackageSet::Modifier> const &mods,
+		unsigned short const &fallback, std::ostream &out) {
+	std::map<unsigned short, PackageSet> pkgsets;
+	for (const char **I = cmdline; *I != 0; ++I) {
+		unsigned short modID = fallback;
+		std::string str = *I;
+		for (std::list<PackageSet::Modifier>::const_iterator mod = mods.begin();
+		     mod != mods.end(); ++mod) {
+			size_t const alength = strlen(mod->Alias);
+			switch(mod->Pos) {
+			case PackageSet::Modifier::POSTFIX:
+				if (str.compare(str.length() - alength, alength,
+				    mod->Alias, 0, alength) != 0)
+					continue;
+				str.erase(str.length() - alength);
+				modID = mod->ID;
+				break;
+			case PackageSet::Modifier::PREFIX:
+				continue;
+			case PackageSet::Modifier::NONE:
+				continue;
+			}
+			break;
+		}
+		PackageSet pset = PackageSet::FromString(Cache, str, out);
+		pkgsets[modID].insert(pset.begin(), pset.end());
+	}
+	return pkgsets;
+}
+									/*}}}*/
+// FromCommandLine - Return all packages specified on commandline	/*{{{*/
+PackageSet PackageSet::FromCommandLine(pkgCacheFile &Cache, const char **cmdline, std::ostream &out) {
+	PackageSet pkgset;
+	for (const char **I = cmdline; *I != 0; ++I) {
+		PackageSet pset = FromString(Cache, *I, out);
+		pkgset.insert(pset.begin(), pset.end());
+	}
+	return pkgset;
+}
+									/*}}}*/
+// FromString - Return all packages matching a specific string		/*{{{*/
+PackageSet PackageSet::FromString(pkgCacheFile &Cache, std::string const &str, std::ostream &out) {
+	std::string pkg = str;
+	size_t archfound = pkg.find_last_of(':');
+	std::string arch;
+	if (archfound != std::string::npos) {
+		arch = pkg.substr(archfound+1);
+		pkg.erase(archfound);
+	}
+
+	pkgCache::PkgIterator Pkg;
+	if (arch.empty() == true) {
+		pkgCache::GrpIterator Grp = Cache.GetPkgCache()->FindGrp(pkg);
+		if (Grp.end() == false)
+			Pkg = Grp.FindPreferredPkg();
+	} else
+		Pkg = Cache.GetPkgCache()->FindPkg(pkg, arch);
+
+	if (Pkg.end() == false) {
+		PackageSet pkgset;
+		pkgset.insert(Pkg);
+		return pkgset;
+	}
+	PackageSet regex = FromRegEx(Cache, str, out);
+	if (regex.empty() == true)
+		_error->Warning(_("Unable to locate package %s"), str.c_str());
+	return regex;
+}
+									/*}}}*/
+// FromCommandLine - Return all versions specified on commandline	/*{{{*/
+APT::VersionSet VersionSet::FromCommandLine(pkgCacheFile &Cache, const char **cmdline,
+		APT::VersionSet::Version const &fallback, std::ostream &out) {
+	VersionSet verset;
+	for (const char **I = cmdline; *I != 0; ++I) {
+		std::string pkg = *I;
+		std::string ver;
+		bool verIsRel = false;
+		size_t const vertag = pkg.find_last_of("/=");
+		if (vertag != string::npos) {
+			ver = pkg.substr(vertag+1);
+			verIsRel = (pkg[vertag] == '/');
+			pkg.erase(vertag);
+		}
+		PackageSet pkgset = PackageSet::FromString(Cache, pkg.c_str(), out);
+		for (PackageSet::const_iterator P = pkgset.begin();
+		     P != pkgset.end(); ++P) {
+			if (vertag == string::npos) {
+				AddSelectedVersion(Cache, verset, P, fallback);
+				continue;
+			}
+			pkgCache::VerIterator V;
+			if (ver == "installed")
+				V = getInstalledVer(Cache, P);
+			else if (ver == "candidate")
+				V = getCandidateVer(Cache, P);
+			else {
+				pkgVersionMatch Match(ver, (verIsRel == true ? pkgVersionMatch::Release :
+						pkgVersionMatch::Version));
+				V = Match.Find(P);
+				if (V.end() == true) {
+					if (verIsRel == true)
+						_error->Error(_("Release '%s' for '%s' was not found"),
+								ver.c_str(), P.FullName(true).c_str());
+					else
+						_error->Error(_("Version '%s' for '%s' was not found"),
+								ver.c_str(), P.FullName(true).c_str());
+					continue;
+				}
+			}
+			if (V.end() == true)
+				continue;
+			if (ver == V.VerStr())
+				ioprintf(out, _("Selected version '%s' (%s) for '%s'\n"),
+					 V.VerStr(), V.RelStr().c_str(), P.FullName(true).c_str());
+			verset.insert(V);
+		}
+	}
+	return verset;
+}
+									/*}}}*/
+// AddSelectedVersion - add version from package based on fallback	/*{{{*/
+bool VersionSet::AddSelectedVersion(pkgCacheFile &Cache, VersionSet &verset,
+		pkgCache::PkgIterator const &P, VersionSet::Version const &fallback,
+		bool const &AllowError) {
+	pkgCache::VerIterator V;
+	switch(fallback) {
+	case VersionSet::ALL:
+		if (P->VersionList != 0)
+			for (V = P.VersionList(); V.end() != true; ++V)
+				verset.insert(V);
+		else if (AllowError == false)
+			return _error->Error(_("Can't select versions from package '%s' as it purely virtual"), P.FullName(true).c_str());
+		else
+			return false;
+		break;
+	case VersionSet::CANDANDINST:
+		verset.insert(getInstalledVer(Cache, P, AllowError));
+		verset.insert(getCandidateVer(Cache, P, AllowError));
+		break;
+	case VersionSet::CANDIDATE:
+		verset.insert(getCandidateVer(Cache, P, AllowError));
+		break;
+	case VersionSet::INSTALLED:
+		verset.insert(getInstalledVer(Cache, P, AllowError));
+		break;
+	case VersionSet::CANDINST:
+		V = getCandidateVer(Cache, P, true);
+		if (V.end() == true)
+			V = getInstalledVer(Cache, P, true);
+		if (V.end() == false)
+			verset.insert(V);
+		else if (AllowError == false)
+			return _error->Error(_("Can't select installed nor candidate version from package '%s' as it has neither of them"), P.FullName(true).c_str());
+		else
+			return false;
+		break;
+	case VersionSet::INSTCAND:
+		V = getInstalledVer(Cache, P, true);
+		if (V.end() == true)
+			V = getCandidateVer(Cache, P, true);
+		if (V.end() == false)
+			verset.insert(V);
+		else if (AllowError == false)
+			return _error->Error(_("Can't select installed nor candidate version from package '%s' as it has neither of them"), P.FullName(true).c_str());
+		else
+			return false;
+		break;
+	case VersionSet::NEWEST:
+		if (P->VersionList != 0)
+			verset.insert(P.VersionList());
+		else if (AllowError == false)
+			return _error->Error(_("Can't select newest version from package '%s' as it is purely virtual"), P.FullName(true).c_str());
+		else
+			return false;
+		break;
+	}
+	return true;
+}
+									/*}}}*/
+// getCandidateVer - Returns the candidate version of the given package	/*{{{*/
+pkgCache::VerIterator VersionSet::getCandidateVer(pkgCacheFile &Cache,
+		pkgCache::PkgIterator const &Pkg, bool const &AllowError) {
+	if (unlikely(Cache.BuildDepCache() == false))
+		return pkgCache::VerIterator(*Cache);
+	pkgCache::VerIterator Cand = Cache[Pkg].CandidateVerIter(Cache);
+	if (AllowError == false && Cand.end() == true)
+		_error->Error(_("Can't select candidate version from package %s as it has no candidate"), Pkg.FullName(true).c_str());
+	return Cand;
+}
+									/*}}}*/
+// getInstalledVer - Returns the installed version of the given package	/*{{{*/
+pkgCache::VerIterator VersionSet::getInstalledVer(pkgCacheFile &Cache,
+		pkgCache::PkgIterator const &Pkg, bool const &AllowError) {
+	if (AllowError == false && Pkg->CurrentVer == 0)
+		_error->Error(_("Can't select installed version from package %s as it is not installed"), Pkg.FullName(true).c_str());
+	return Pkg.CurrentVer();
+}
+									/*}}}*/
+}

=== added file 'apt-pkg/cacheset.h'
--- apt-pkg/cacheset.h	1970-01-01 00:00:00 +0000
+++ apt-pkg/cacheset.h	2010-06-10 14:02:22 +0000
@@ -0,0 +1,239 @@
+// -*- mode: cpp; mode: fold -*-
+// Description								/*{{{*/
+/** \file cacheset.h
+   Wrappers around std::set to have set::iterators which behave
+   similar to the Iterators of the cache structures.
+
+   Provides also a few helper methods which work with these sets */
+									/*}}}*/
+#ifndef APT_CACHESET_H
+#define APT_CACHESET_H
+// Include Files							/*{{{*/
+#include <iostream>
+#include <fstream>
+#include <list>
+#include <map>
+#include <set>
+#include <string>
+
+#include <apt-pkg/cachefile.h>
+#include <apt-pkg/pkgcache.h>
+									/*}}}*/
+namespace APT {
+class PackageSet : public std::set<pkgCache::PkgIterator> {		/*{{{*/
+/** \class APT::PackageSet
+
+    Simple wrapper around a std::set to provide a similar interface to
+    a set of packages as to the complete set of all packages in the
+    pkgCache. */
+public:									/*{{{*/
+	/** \brief smell like a pkgCache::PkgIterator */
+	class const_iterator : public std::set<pkgCache::PkgIterator>::const_iterator {
+	public:
+		const_iterator(std::set<pkgCache::PkgIterator>::const_iterator x) :
+			 std::set<pkgCache::PkgIterator>::const_iterator(x) {}
+
+		operator pkgCache::PkgIterator(void) { return **this; }
+
+		inline const char *Name() const {return (**this).Name(); }
+		inline std::string FullName(bool const &Pretty) const { return (**this).FullName(Pretty); }
+		inline std::string FullName() const { return (**this).FullName(); }
+		inline const char *Section() const {return (**this).Section(); }
+		inline bool Purge() const {return (**this).Purge(); }
+		inline const char *Arch() const {return (**this).Arch(); }
+		inline pkgCache::GrpIterator Group() const { return (**this).Group(); }
+		inline pkgCache::VerIterator VersionList() const { return (**this).VersionList(); }
+		inline pkgCache::VerIterator CurrentVer() const { return (**this).CurrentVer(); }
+		inline pkgCache::DepIterator RevDependsList() const { return (**this).RevDependsList(); }
+		inline pkgCache::PrvIterator ProvidesList() const { return (**this).ProvidesList(); }
+		inline pkgCache::PkgIterator::OkState State() const { return (**this).State(); }
+		inline const char *CandVersion() const { return (**this).CandVersion(); }
+		inline const char *CurVersion() const { return (**this).CurVersion(); }
+		inline pkgCache *Cache() const { return (**this).Cache(); };
+		inline unsigned long Index() const {return (**this).Index();};
+		// we have only valid iterators here
+		inline bool end() const { return false; };
+
+		friend std::ostream& operator<<(std::ostream& out, const_iterator i) { return operator<<(out, (*i)); }
+
+		inline pkgCache::Package const * operator->() const {
+			return &***this;
+		};
+	};
+	// 103. set::iterator is required to be modifiable, but this allows modification of keys
+	typedef APT::PackageSet::const_iterator iterator;
+
+	using std::set<pkgCache::PkgIterator>::insert;
+	inline void insert(pkgCache::PkgIterator const &P) { if (P.end() == false) std::set<pkgCache::PkgIterator>::insert(P); };
+
+	/** \brief returns all packages in the cache whose name matchs a given pattern
+
+	    A simple helper responsible for executing a regular expression on all
+	    package names in the cache. Optional it prints a a notice about the
+	    packages chosen cause of the given package.
+	    \param Cache the packages are in
+	    \param pattern regular expression for package names
+	    \param out stream to print the notice to */
+	static APT::PackageSet FromRegEx(pkgCacheFile &Cache, std::string pattern, std::ostream &out);
+	static APT::PackageSet FromRegEx(pkgCacheFile &Cache, std::string const &pattern) {
+		std::ostream out (std::ofstream("/dev/null").rdbuf());
+		return APT::PackageSet::FromRegEx(Cache, pattern, out);
+	}
+
+	/** \brief returns all packages specified by a string
+
+	    \param Cache the packages are in
+	    \param string String the package name(s) should be extracted from
+	    \param out stream to print various notices to */
+	static APT::PackageSet FromString(pkgCacheFile &Cache, std::string const &string, std::ostream &out);
+	static APT::PackageSet FromString(pkgCacheFile &Cache, std::string const &string) {
+		std::ostream out (std::ofstream("/dev/null").rdbuf());
+		return APT::PackageSet::FromString(Cache, string, out);
+	}
+
+	/** \brief returns all packages specified on the commandline
+
+	    Get all package names from the commandline and executes regex's if needed.
+	    No special package command is supported, just plain names.
+	    \param Cache the packages are in
+	    \param cmdline Command line the package names should be extracted from
+	    \param out stream to print various notices to */
+	static APT::PackageSet FromCommandLine(pkgCacheFile &Cache, const char **cmdline, std::ostream &out);
+	static APT::PackageSet FromCommandLine(pkgCacheFile &Cache, const char **cmdline) {
+		std::ostream out (std::ofstream("/dev/null").rdbuf());
+		return APT::PackageSet::FromCommandLine(Cache, cmdline, out);
+	}
+
+	struct Modifier {
+		enum Position { NONE, PREFIX, POSTFIX };
+		unsigned short ID;
+		const char * const Alias;
+		Position Pos;
+		Modifier (unsigned short const &id, const char * const alias, Position const &pos) : ID(id), Alias(alias), Pos(pos) {};
+	};
+
+	static std::map<unsigned short, PackageSet> GroupedFromCommandLine(
+		pkgCacheFile &Cache, const char **cmdline,
+		std::list<PackageSet::Modifier> const &mods,
+		unsigned short const &fallback, std::ostream &out);
+	static std::map<unsigned short, PackageSet> GroupedFromCommandLine(
+		pkgCacheFile &Cache, const char **cmdline,
+		std::list<PackageSet::Modifier> const &mods,
+		unsigned short const &fallback) {
+		std::ostream out (std::ofstream("/dev/null").rdbuf());
+		return APT::PackageSet::GroupedFromCommandLine(Cache, cmdline,
+				mods, fallback, out);
+	}
+									/*}}}*/
+};									/*}}}*/
+class VersionSet : public std::set<pkgCache::VerIterator> {		/*{{{*/
+/** \class APT::VersionSet
+
+    Simple wrapper around a std::set to provide a similar interface to
+    a set of versions as to the complete set of all versions in the
+    pkgCache. */
+public:									/*{{{*/
+	/** \brief smell like a pkgCache::VerIterator */
+	class const_iterator : public std::set<pkgCache::VerIterator>::const_iterator {
+	public:
+		const_iterator(std::set<pkgCache::VerIterator>::const_iterator x) :
+			 std::set<pkgCache::VerIterator>::const_iterator(x) {}
+
+		operator pkgCache::VerIterator(void) { return **this; }
+
+		inline pkgCache *Cache() const { return (**this).Cache(); };
+		inline unsigned long Index() const {return (**this).Index();};
+		// we have only valid iterators here
+		inline bool end() const { return false; };
+
+		inline pkgCache::Version const * operator->() const {
+			return &***this;
+		};
+
+		inline int CompareVer(const pkgCache::VerIterator &B) const { return (**this).CompareVer(B); };
+		inline const char *VerStr() const { return (**this).VerStr(); };
+		inline const char *Section() const { return (**this).Section(); };
+		inline const char *Arch() const { return (**this).Arch(); };
+		inline const char *Arch(bool const pseudo) const { return (**this).Arch(pseudo); };
+		inline pkgCache::PkgIterator ParentPkg() const { return (**this).ParentPkg(); };
+		inline pkgCache::DescIterator DescriptionList() const { return (**this).DescriptionList(); };
+		inline pkgCache::DescIterator TranslatedDescription() const { return (**this).TranslatedDescription(); };
+		inline pkgCache::DepIterator DependsList() const { return (**this).DependsList(); };
+		inline pkgCache::PrvIterator ProvidesList() const { return (**this).ProvidesList(); };
+		inline pkgCache::VerFileIterator FileList() const { return (**this).FileList(); };
+		inline bool Downloadable() const { return (**this).Downloadable(); };
+		inline const char *PriorityType() const { return (**this).PriorityType(); };
+		inline string RelStr() const { return (**this).RelStr(); };
+		inline bool Automatic() const { return (**this).Automatic(); };
+		inline bool Pseudo() const { return (**this).Pseudo(); };
+		inline pkgCache::VerFileIterator NewestFile() const { return (**this).NewestFile(); };
+	};
+	// 103. set::iterator is required to be modifiable, but this allows modification of keys
+	typedef APT::VersionSet::const_iterator iterator;
+
+	using std::set<pkgCache::VerIterator>::insert;
+	inline void insert(pkgCache::VerIterator const &V) { if (V.end() == false) std::set<pkgCache::VerIterator>::insert(V); };
+
+	/** \brief specifies which version(s) will be returned if non is given */
+	enum Version {
+		/** All versions */
+		ALL,
+		/** Candidate and installed version */
+		CANDANDINST,
+		/** Candidate version */
+		CANDIDATE,
+		/** Installed version */
+		INSTALLED,
+		/** Candidate or if non installed version */
+		CANDINST,
+		/** Installed or if non candidate version */
+		INSTCAND,
+		/** Newest version */
+		NEWEST
+	};
+
+	/** \brief returns all versions specified on the commandline
+
+	    Get all versions from the commandline, uses given default version if
+	    non specifically requested  and executes regex's if needed on names.
+	    \param Cache the packages and versions are in
+	    \param cmdline Command line the versions should be extracted from
+	    \param out stream to print various notices to */
+	static APT::VersionSet FromCommandLine(pkgCacheFile &Cache, const char **cmdline,
+			APT::VersionSet::Version const &fallback, std::ostream &out);
+	static APT::VersionSet FromCommandLine(pkgCacheFile &Cache, const char **cmdline,
+			APT::VersionSet::Version const &fallback) {
+		std::ostream out (std::ofstream("/dev/null").rdbuf());
+		return APT::VersionSet::FromCommandLine(Cache, cmdline, fallback, out);
+	}
+	static APT::VersionSet FromCommandLine(pkgCacheFile &Cache, const char **cmdline) {
+		return APT::VersionSet::FromCommandLine(Cache, cmdline, CANDINST);
+	}
+									/*}}}*/
+protected:								/*{{{*/
+
+	/** \brief returns the candidate version of the package
+
+	    \param Cache to be used to query for information
+	    \param Pkg we want the candidate version from this package
+	    \param AllowError add an error to the stack if not */
+	static pkgCache::VerIterator getCandidateVer(pkgCacheFile &Cache,
+		pkgCache::PkgIterator const &Pkg, bool const &AllowError = false);
+
+	/** \brief returns the installed version of the package
+
+	    \param Cache to be used to query for information
+	    \param Pkg we want the installed version from this package
+	    \param AllowError add an error to the stack if not */
+	static pkgCache::VerIterator getInstalledVer(pkgCacheFile &Cache,
+		pkgCache::PkgIterator const &Pkg, bool const &AllowError = false);
+
+
+	static bool AddSelectedVersion(pkgCacheFile &Cache, VersionSet &verset,
+		pkgCache::PkgIterator const &P, VersionSet::Version const &fallback,
+		bool const &AllowError = false);
+
+									/*}}}*/
+};									/*}}}*/
+}
+#endif

=== modified file 'apt-pkg/contrib/cmndline.cc'
--- apt-pkg/contrib/cmndline.cc	2010-04-01 17:30:43 +0000
+++ apt-pkg/contrib/cmndline.cc	2010-06-10 14:02:22 +0000
@@ -360,11 +360,11 @@
    than nothing after all. */
 void CommandLine::SaveInConfig(unsigned int const &argc, char const * const * const argv)
 {
-   char cmdline[300];
+   char cmdline[100 + argc * 50];
    unsigned int length = 0;
    bool lastWasOption = false;
    bool closeQuote = false;
-   for (unsigned int i = 0; i < argc; ++i, ++length)
+   for (unsigned int i = 0; i < argc && length < sizeof(cmdline); ++i, ++length)
    {
       for (unsigned int j = 0; argv[i][j] != '\0' && length < sizeof(cmdline)-1; ++j, ++length)
       {

=== modified file 'apt-pkg/contrib/strutl.cc'
--- apt-pkg/contrib/strutl.cc	2010-04-01 17:30:43 +0000
+++ apt-pkg/contrib/strutl.cc	2010-06-10 14:02:22 +0000
@@ -827,34 +827,70 @@
    }   
 }
 									/*}}}*/
-// timegm - Internal timegm function if gnu is not available		/*{{{*/
+// timegm - Internal timegm if the gnu version is not available		/*{{{*/
 // ---------------------------------------------------------------------
-/* Ripped this evil little function from wget - I prefer the use of 
-   GNU timegm if possible as this technique will have interesting problems
-   with leap seconds, timezones and other.
-   
-   Converts struct tm to time_t, assuming the data in tm is UTC rather
+/* Converts struct tm to time_t, assuming the data in tm is UTC rather
    than local timezone (mktime assumes the latter).
-   
-   Contributed by Roger Beeman <beeman@cisco.com>, with the help of
-   Mark Baushke <mdb@cisco.com> and the rest of the Gurus at CISCO. */
-
-/* Turned it into an autoconf check, because GNU is not the only thing which
-   can provide timegm. -- 2002-09-22, Joel Baker */
-
-#ifndef HAVE_TIMEGM // Now with autoconf!
+
+   This function is a nonstandard GNU extension that is also present on
+   the BSDs and maybe other systems. For others we follow the advice of
+   the manpage of timegm and use his portable replacement. */
+#ifndef HAVE_TIMEGM
 static time_t timegm(struct tm *t)
 {
-   time_t tl, tb;
-   
-   tl = mktime (t);
-   if (tl == -1)
-      return -1;
-   tb = mktime (gmtime (&tl));
-   return (tl <= tb ? (tl + (tl - tb)) : (tl - (tb - tl)));
+   char *tz = getenv("TZ");
+   setenv("TZ", "", 1);
+   tzset();
+   time_t ret = mktime(t);
+   if (tz)
+      setenv("TZ", tz, 1);
+   else
+      unsetenv("TZ");
+   tzset();
+   return ret;
 }
 #endif
 									/*}}}*/
+// FullDateToTime - Converts a HTTP1.1 full date strings into a time_t	/*{{{*/
+// ---------------------------------------------------------------------
+/* tries to parses a full date as specified in RFC2616 Section 3.3.1
+   with one exception: All timezones (%Z) are accepted but the protocol
+   says that it MUST be GMT, but this one is equal to UTC which we will
+   encounter from time to time (e.g. in Release files) so we accept all
+   here and just assume it is GMT (or UTC) later on */
+bool RFC1123StrToTime(const char* const str,time_t &time)
+{
+   struct tm Tm;
+   setlocale (LC_ALL,"C");
+   bool const invalid =
+   // Sun, 06 Nov 1994 08:49:37 GMT  ; RFC 822, updated by RFC 1123
+      (strptime(str, "%a, %d %b %Y %H:%M:%S %Z", &Tm) == NULL &&
+   // Sunday, 06-Nov-94 08:49:37 GMT ; RFC 850, obsoleted by RFC 1036
+       strptime(str, "%A, %d-%b-%y %H:%M:%S %Z", &Tm) == NULL &&
+   // Sun Nov  6 08:49:37 1994       ; ANSI C's asctime() format
+       strptime(str, "%a %b %d %H:%M:%S %Y", &Tm) == NULL);
+   setlocale (LC_ALL,"");
+   if (invalid == true)
+      return false;
+
+   time = timegm(&Tm);
+   return true;
+}
+									/*}}}*/
+// FTPMDTMStrToTime - Converts a ftp modification date into a time_t	/*{{{*/
+// ---------------------------------------------------------------------
+/* */
+bool FTPMDTMStrToTime(const char* const str,time_t &time)
+{
+   struct tm Tm;
+   // MDTM includes no whitespaces but recommend and ignored by strptime
+   if (strptime(str, "%Y %m %d %H %M %S", &Tm) == NULL)
+      return false;
+
+   time = timegm(&Tm);
+   return true;
+}
+									/*}}}*/
 // StrToTime - Converts a string into a time_t				/*{{{*/
 // ---------------------------------------------------------------------
 /* This handles all 3 populare time formats including RFC 1123, RFC 1036

=== modified file 'apt-pkg/contrib/strutl.h'
--- apt-pkg/contrib/strutl.h	2010-04-01 17:30:43 +0000
+++ apt-pkg/contrib/strutl.h	2010-06-10 14:02:22 +0000
@@ -45,7 +45,9 @@
 string OutputInDepth(const unsigned long Depth, const char* Separator="  ");
 string URItoFileName(const string &URI);
 string TimeRFC1123(time_t Date);
-bool StrToTime(const string &Val,time_t &Result);
+bool RFC1123StrToTime(const char* const str,time_t &time) __must_check;
+bool FTPMDTMStrToTime(const char* const str,time_t &time) __must_check;
+__deprecated bool StrToTime(const string &Val,time_t &Result);
 string LookupTag(const string &Message,const char *Tag,const char *Default = 0);
 int StringToBool(const string &Text,int Default = -1);
 bool ReadMessages(int Fd, vector<string> &List);

=== modified file 'apt-pkg/deb/debindexfile.cc'
--- apt-pkg/deb/debindexfile.cc	2010-04-01 17:30:43 +0000
+++ apt-pkg/deb/debindexfile.cc	2010-06-10 14:02:22 +0000
@@ -262,15 +262,15 @@
 // PackagesIndex::Merge - Load the index file into a cache		/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-bool debPackagesIndex::Merge(pkgCacheGenerator &Gen,OpProgress &Prog) const
+bool debPackagesIndex::Merge(pkgCacheGenerator &Gen,OpProgress *Prog) const
 {
    string PackageFile = IndexFile("Packages");
    FileFd Pkg(PackageFile,FileFd::ReadOnly);
    debListParser Parser(&Pkg, Architecture);
    if (_error->PendingError() == true)
       return _error->Error("Problem opening %s",PackageFile.c_str());
-   
-   Prog.SubProgress(0,Info("Packages"));
+   if (Prog != NULL)
+      Prog->SubProgress(0,Info("Packages"));
    ::URI Tmp(URI);
    if (Gen.SelectFile(PackageFile,Tmp.Host,*this) == false)
       return _error->Error("Problem with SelectFile %s",PackageFile.c_str());
@@ -445,7 +445,7 @@
 // TranslationsIndex::Merge - Load the index file into a cache		/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-bool debTranslationsIndex::Merge(pkgCacheGenerator &Gen,OpProgress &Prog) const
+bool debTranslationsIndex::Merge(pkgCacheGenerator &Gen,OpProgress *Prog) const
 {
    // Check the translation file, if in use
    string TranslationFile = IndexFile(Language);
@@ -456,7 +456,8 @@
      if (_error->PendingError() == true)
        return false;
      
-     Prog.SubProgress(0, Info(TranslationFile.c_str()));
+     if (Prog != NULL)
+	Prog->SubProgress(0, Info(TranslationFile.c_str()));
      if (Gen.SelectFile(TranslationFile,string(),*this) == false)
        return _error->Error("Problem with SelectFile %s",TranslationFile.c_str());
 
@@ -529,7 +530,7 @@
 // StatusIndex::Merge - Load the index file into a cache		/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-bool debStatusIndex::Merge(pkgCacheGenerator &Gen,OpProgress &Prog) const
+bool debStatusIndex::Merge(pkgCacheGenerator &Gen,OpProgress *Prog) const
 {
    FileFd Pkg(File,FileFd::ReadOnly);
    if (_error->PendingError() == true)
@@ -537,8 +538,9 @@
    debListParser Parser(&Pkg);
    if (_error->PendingError() == true)
       return false;
-   
-   Prog.SubProgress(0,File);
+
+   if (Prog != NULL)
+      Prog->SubProgress(0,File);
    if (Gen.SelectFile(File,string(),*this,pkgCache::Flag::NotSource) == false)
       return _error->Error("Problem with SelectFile %s",File.c_str());
 

=== modified file 'apt-pkg/deb/debindexfile.h'
--- apt-pkg/deb/debindexfile.h	2010-04-01 17:30:43 +0000
+++ apt-pkg/deb/debindexfile.h	2010-06-10 14:02:22 +0000
@@ -35,7 +35,7 @@
    virtual bool Exists() const;
    virtual bool HasPackages() const {return true;};
    virtual unsigned long Size() const;
-   virtual bool Merge(pkgCacheGenerator &Gen,OpProgress &Prog) const;
+   virtual bool Merge(pkgCacheGenerator &Gen,OpProgress *Prog) const;
    virtual pkgCache::PkgFileIterator FindInCache(pkgCache &Cache) const;
 
    debStatusIndex(string File);
@@ -67,7 +67,7 @@
    virtual bool Exists() const;
    virtual bool HasPackages() const {return true;};
    virtual unsigned long Size() const;
-   virtual bool Merge(pkgCacheGenerator &Gen,OpProgress &Prog) const;
+   virtual bool Merge(pkgCacheGenerator &Gen,OpProgress *Prog) const;
    virtual pkgCache::PkgFileIterator FindInCache(pkgCache &Cache) const;
 
    debPackagesIndex(string const &URI, string const &Dist, string const &Section,
@@ -99,7 +99,7 @@
    virtual bool Exists() const;
    virtual bool HasPackages() const;
    virtual unsigned long Size() const;
-   virtual bool Merge(pkgCacheGenerator &Gen,OpProgress &Prog) const;
+   virtual bool Merge(pkgCacheGenerator &Gen,OpProgress *Prog) const;
    virtual pkgCache::PkgFileIterator FindInCache(pkgCache &Cache) const;
 
    debTranslationsIndex(string URI,string Dist,string Section, char const * const Language);

=== modified file 'apt-pkg/deb/deblistparser.cc'
--- apt-pkg/deb/deblistparser.cc	2010-04-01 17:30:43 +0000
+++ apt-pkg/deb/deblistparser.cc	2010-06-10 14:02:22 +0000
@@ -133,10 +133,9 @@
    }
 
    // Archive Size
-   Ver->Size = (unsigned)Section.FindI("Size");
-   
+   Ver->Size = Section.FindULL("Size");
    // Unpacked Size (in K)
-   Ver->InstalledSize = (unsigned)Section.FindI("Installed-Size");
+   Ver->InstalledSize = Section.FindULL("Installed-Size");
    Ver->InstalledSize *= 1024;
 
    // Priority

=== modified file 'apt-pkg/deb/debsystem.cc'
--- apt-pkg/deb/debsystem.cc	2010-02-18 22:07:23 +0000
+++ apt-pkg/deb/debsystem.cc	2010-06-10 14:02:22 +0000
@@ -18,7 +18,6 @@
 #include <apt-pkg/error.h>
 #include <apt-pkg/fileutl.h>
 #include <apti18n.h>
-    
 #include <sys/types.h>
 #include <unistd.h>
 #include <dirent.h>
@@ -79,8 +78,15 @@
    {
       close(LockFD);
       LockFD = -1;
+      const char *cmd;
+      if (getenv("SUDO_USER") != NULL)
+	 cmd = "sudo dpkg --configure -a";
+      else
+	 cmd = "dpkg --configure -a";
+      // TRANSLATORS: the %s contains the recovery command, usually
+      //              dpkg --configure -a
       return _error->Error(_("dpkg was interrupted, you must manually "
-                             "run 'dpkg --configure -a' to correct the problem. "));
+                             "run '%s' to correct the problem. "), cmd);
    }
 
 	 LockCount++;
@@ -158,7 +164,7 @@
    /* These really should be jammed into a generic 'Local Database' engine
       which is yet to be determined. The functions in pkgcachegen should
       be the only users of these */
-   Cnf.CndSet("Dir::State::userstatus","status.user"); // Defunct
+   Cnf.CndSet("Dir::State::extended_states", Cnf.FindDir("Dir::State").append("extended_states"));
    Cnf.CndSet("Dir::State::status","/var/lib/dpkg/status");
    Cnf.CndSet("Dir::Bin::dpkg","/usr/bin/dpkg");
 

=== modified file 'apt-pkg/deb/dpkgpm.cc'
--- apt-pkg/deb/dpkgpm.cc	2010-05-25 16:01:42 +0000
+++ apt-pkg/deb/dpkgpm.cc	2010-06-10 14:02:22 +0000
@@ -12,6 +12,7 @@
 #include <apt-pkg/error.h>
 #include <apt-pkg/configuration.h>
 #include <apt-pkg/depcache.h>
+#include <apt-pkg/pkgrecords.h>
 #include <apt-pkg/strutl.h>
 #include <apti18n.h>
 #include <apt-pkg/fileutl.h>
@@ -20,10 +21,12 @@
 #include <stdlib.h>
 #include <fcntl.h>
 #include <sys/select.h>
+#include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <signal.h>
 #include <errno.h>
+#include <string.h>
 #include <stdio.h>
 #include <string.h>
 #include <algorithm>
@@ -354,7 +357,6 @@
 
    return true;
 }
-
 									/*}}}*/
 // DPkgPM::DoStdin - Read stdin and pass to slave pty			/*{{{*/
 // ---------------------------------------------------------------------
@@ -425,7 +427,7 @@
       'processing: trigproc: trigger'
 	    
    */
-   char* list[5];
+   char* list[6];
    //        dpkg sends multiline error messages sometimes (see
    //        #374195 for a example. we should support this by
    //        either patching dpkg to not send multiline over the
@@ -470,12 +472,20 @@
 	 std::clog << "send: '" << status.str() << "'" << endl;
 
       if (strncmp(action, "disappear", strlen("disappear")) == 0)
-	 disappearedPkgs.insert(string(pkg_or_trigger));
+	 handleDisappearAction(pkg_or_trigger);
       return;
    }
 
    if(strncmp(action,"error",strlen("error")) == 0)
    {
+      // urgs, sometime has ":" in its error string so that we
+      // end up with the error message split between list[3]
+      // and list[4], e.g. the message: 
+      // "failed in buffer_write(fd) (10, ret=-1): backend dpkg-deb ..."
+      // concat them again
+      if( list[4] != NULL )
+	 list[3][strlen(list[3])] = ':';
+
       status << "pmerror:" << list[1]
 	     << ":"  << (PackagesDone/float(PackagesTotal)*100.0) 
 	     << ":" << list[3]
@@ -484,6 +494,8 @@
 	 write(OutStatusFd, status.str().c_str(), status.str().size());
       if (Debug == true)
 	 std::clog << "send: '" << status.str() << "'" << endl;
+      pkgFailures++;
+      WriteApportReport(list[1], list[3]);
       return;
    }
    else if(strncmp(action,"conffile",strlen("conffile")) == 0)
@@ -530,6 +542,51 @@
 		<< " action: " << action << endl;
 }
 									/*}}}*/
+// DPkgPM::handleDisappearAction					/*{{{*/
+void pkgDPkgPM::handleDisappearAction(string const &pkgname)
+{
+   // record the package name for display and stuff later
+   disappearedPkgs.insert(pkgname);
+
+   pkgCache::PkgIterator Pkg = Cache.FindPkg(pkgname);
+   if (unlikely(Pkg.end() == true))
+      return;
+   // the disappeared package was auto-installed - nothing to do
+   if ((Cache[Pkg].Flags & pkgCache::Flag::Auto) == pkgCache::Flag::Auto)
+      return;
+   pkgCache::VerIterator PkgVer = Pkg.CurrentVer();
+   if (unlikely(PkgVer.end() == true))
+      return;
+   /* search in the list of dependencies for (Pre)Depends,
+      check if this dependency has a Replaces on our package
+      and if so transfer the manual installed flag to it */
+   for (pkgCache::DepIterator Dep = PkgVer.DependsList(); Dep.end() != true; ++Dep)
+   {
+      if (Dep->Type != pkgCache::Dep::Depends &&
+	  Dep->Type != pkgCache::Dep::PreDepends)
+	 continue;
+      pkgCache::PkgIterator Tar = Dep.TargetPkg();
+      if (unlikely(Tar.end() == true))
+	 continue;
+      // the package is already marked as manual
+      if ((Cache[Tar].Flags & pkgCache::Flag::Auto) != pkgCache::Flag::Auto)
+	 continue;
+      pkgCache::VerIterator TarVer = Tar.CurrentVer();
+      for (pkgCache::DepIterator Rep = TarVer.DependsList(); Rep.end() != true; ++Rep)
+      {
+	 if (Rep->Type != pkgCache::Dep::Replaces)
+	    continue;
+	 if (Pkg != Rep.TargetPkg())
+	    continue;
+	 // okay, they are strongly connected - transfer manual-bit
+	 if (Debug == true)
+	    std::clog << "transfer manual-bit from disappeared »" << pkgname << "« to »" << Tar.FullName() << "«" << std::endl;
+	 Cache[Tar].Flags &= ~Flag::Auto;
+	 break;
+      }
+   }
+}
+									/*}}}*/
 // DPkgPM::DoDpkgStatusFd						/*{{{*/
 // ---------------------------------------------------------------------
 /*
@@ -568,15 +625,15 @@
 }
 									/*}}}*/
 // DPkgPM::WriteHistoryTag						/*{{{*/
-void pkgDPkgPM::WriteHistoryTag(string tag, string value)
+void pkgDPkgPM::WriteHistoryTag(string const &tag, string value)
 {
-   if (value.size() > 0)
-   {
-      // poor mans rstrip(", ")
-      if (value[value.size()-2] == ',' && value[value.size()-1] == ' ')
-	 value.erase(value.size() - 2, 2);
-      fprintf(history_out, "%s: %s\n", tag.c_str(), value.c_str());
-   }
+   size_t const length = value.length();
+   if (length == 0)
+      return;
+   // poor mans rstrip(", ")
+   if (value[length-2] == ',' && value[length-1] == ' ')
+      value.erase(length - 2, 2);
+   fprintf(history_out, "%s: %s\n", tag.c_str(), value.c_str());
 }									/*}}}*/
 // DPkgPM::OpenLog							/*{{{*/
 bool pkgDPkgPM::OpenLog()
@@ -663,7 +720,22 @@
 
    if(history_out)
    {
-      if (dpkg_error.size() > 0)
+      if (disappearedPkgs.empty() == false)
+      {
+	 string disappear;
+	 for (std::set<std::string>::const_iterator d = disappearedPkgs.begin();
+	      d != disappearedPkgs.end(); ++d)
+	 {
+	    pkgCache::PkgIterator P = Cache.FindPkg(*d);
+	    disappear.append(*d);
+	    if (P.end() == true)
+	       disappear.append(", ");
+	    else
+	       disappear.append(" (").append(Cache[P].CurVersion).append("), ");
+	 }
+	 WriteHistoryTag("Disappeared", disappear);
+      }
+      if (dpkg_error.empty() == false)
 	 fprintf(history_out, "Error: %s\n", dpkg_error.c_str());
       fprintf(history_out, "End-Date: %s\n", timestr);
       fclose(history_out);
@@ -1175,3 +1247,186 @@
    List.erase(List.begin(),List.end());
 }
 									/*}}}*/
+// pkgDpkgPM::WriteApportReport - write out error report pkg failure	/*{{{*/
+// ---------------------------------------------------------------------
+/* */
+void pkgDPkgPM::WriteApportReport(const char *pkgpath, const char *errormsg) 
+{
+   string pkgname, reportfile, srcpkgname, pkgver, arch;
+   string::size_type pos;
+   FILE *report;
+
+   if (_config->FindB("Dpkg::ApportFailureReport", false) == false)
+   {
+      std::clog << "configured to not write apport reports" << std::endl;
+      return;
+   }
+
+   // only report the first errors
+   if(pkgFailures > _config->FindI("APT::Apport::MaxReports", 3))
+   {
+      std::clog << _("No apport report written because MaxReports is reached already") << std::endl;
+      return;
+   }
+
+   // check if its not a follow up error 
+   const char *needle = dgettext("dpkg", "dependency problems - leaving unconfigured");
+   if(strstr(errormsg, needle) != NULL) {
+      std::clog << _("No apport report written because the error message indicates its a followup error from a previous failure.") << std::endl;
+      return;
+   }
+
+   // do not report disk-full failures 
+   if(strstr(errormsg, strerror(ENOSPC)) != NULL) {
+      std::clog << _("No apport report written because the error message indicates a disk full error") << std::endl;
+      return;
+   }
+
+   // do not report out-of-memory failures 
+   if(strstr(errormsg, strerror(ENOMEM)) != NULL) {
+      std::clog << _("No apport report written because the error message indicates a out of memory error") << std::endl;
+      return;
+   }
+
+   // do not report dpkg I/O errors
+   // XXX - this message is localized, but this only matches the English version.  This is better than nothing.
+   if(strstr(errormsg, "short read in buffer_copy (")) {
+      std::clog << _("No apport report written because the error message indicates a dpkg I/O error") << std::endl;
+      return;
+   }
+
+   // get the pkgname and reportfile
+   pkgname = flNotDir(pkgpath);
+   pos = pkgname.find('_');
+   if(pos != string::npos)
+      pkgname = pkgname.substr(0, pos);
+
+   // find the package versin and source package name
+   pkgCache::PkgIterator Pkg = Cache.FindPkg(pkgname);
+   if (Pkg.end() == true)
+      return;
+   pkgCache::VerIterator Ver = Cache.GetCandidateVer(Pkg);
+   if (Ver.end() == true)
+      return;
+   pkgver = Ver.VerStr() == NULL ? "unknown" : Ver.VerStr();
+   pkgRecords Recs(Cache);
+   pkgRecords::Parser &Parse = Recs.Lookup(Ver.FileList());
+   srcpkgname = Parse.SourcePkg();
+   if(srcpkgname.empty())
+      srcpkgname = pkgname;
+
+   // if the file exists already, we check:
+   // - if it was reported already (touched by apport). 
+   //   If not, we do nothing, otherwise
+   //    we overwrite it. This is the same behaviour as apport
+   // - if we have a report with the same pkgversion already
+   //   then we skip it
+   reportfile = flCombine("/var/crash",pkgname+".0.crash");
+   if(FileExists(reportfile))
+   {
+      struct stat buf;
+      char strbuf[255];
+
+      // check atime/mtime
+      stat(reportfile.c_str(), &buf);
+      if(buf.st_mtime > buf.st_atime)
+	 return;
+
+      // check if the existing report is the same version
+      report = fopen(reportfile.c_str(),"r");
+      while(fgets(strbuf, sizeof(strbuf), report) != NULL)
+      {
+	 if(strstr(strbuf,"Package:") == strbuf)
+	 {
+	    char pkgname[255], version[255];
+	    if(sscanf(strbuf, "Package: %s %s", pkgname, version) == 2)
+	       if(strcmp(pkgver.c_str(), version) == 0)
+	       {
+		  fclose(report);
+		  return;
+	       }
+	 }
+      }
+      fclose(report);
+   }
+
+   // now write the report
+   arch = _config->Find("APT::Architecture");
+   report = fopen(reportfile.c_str(),"w");
+   if(report == NULL)
+      return;
+   if(_config->FindB("DPkgPM::InitialReportOnly",false) == true)
+      chmod(reportfile.c_str(), 0);
+   else
+      chmod(reportfile.c_str(), 0600);
+   fprintf(report, "ProblemType: Package\n");
+   fprintf(report, "Architecture: %s\n", arch.c_str());
+   time_t now = time(NULL);
+   fprintf(report, "Date: %s" , ctime(&now));
+   fprintf(report, "Package: %s %s\n", pkgname.c_str(), pkgver.c_str());
+   fprintf(report, "SourcePackage: %s\n", srcpkgname.c_str());
+   fprintf(report, "ErrorMessage:\n %s\n", errormsg);
+
+   // ensure that the log is flushed
+   if(term_out)
+      fflush(term_out);
+
+   // attach terminal log it if we have it
+   string logfile_name = _config->FindFile("Dir::Log::Terminal");
+   if (!logfile_name.empty())
+   {
+      FILE *log = NULL;
+      char buf[1024];
+
+      fprintf(report, "DpkgTerminalLog:\n");
+      log = fopen(logfile_name.c_str(),"r");
+      if(log != NULL)
+      {
+	 while( fgets(buf, sizeof(buf), log) != NULL)
+	    fprintf(report, " %s", buf);
+	 fclose(log);
+      }
+   }
+
+   // log the ordering 
+   const char *ops_str[] = {"Install", "Configure","Remove","Purge"};
+   fprintf(report, "AptOrdering:\n");
+   for (vector<Item>::iterator I = List.begin(); I != List.end(); I++)
+      fprintf(report, " %s: %s\n", (*I).Pkg.Name(), ops_str[(*I).Op]);
+
+   // attach dmesg log (to learn about segfaults)
+   if (FileExists("/bin/dmesg"))
+   {
+      FILE *log = NULL;
+      char buf[1024];
+
+      fprintf(report, "Dmesg:\n");
+      log = popen("/bin/dmesg","r");
+      if(log != NULL)
+      {
+	 while( fgets(buf, sizeof(buf), log) != NULL)
+	    fprintf(report, " %s", buf);
+	 fclose(log);
+      }
+   }
+
+   // attach df -l log (to learn about filesystem status)
+   if (FileExists("/bin/df"))
+   {
+      FILE *log = NULL;
+      char buf[1024];
+
+      fprintf(report, "Df:\n");
+      log = popen("/bin/df -l","r");
+      if(log != NULL)
+      {
+	 while( fgets(buf, sizeof(buf), log) != NULL)
+	    fprintf(report, " %s", buf);
+	 fclose(log);
+      }
+   }
+
+   fclose(report);
+
+}
+									/*}}}*/

=== modified file 'apt-pkg/deb/dpkgpm.h'
--- apt-pkg/deb/dpkgpm.h	2010-02-18 22:07:23 +0000
+++ apt-pkg/deb/dpkgpm.h	2010-06-10 14:02:22 +0000
@@ -32,7 +32,23 @@
    FILE *history_out;
    string dpkg_error;
 
+   /** \brief record the disappear action and handle accordingly
+
+      dpkg let packages disappear then they have no files any longer and
+      nothing depends on them. We need to collect this as dpkg as well as
+      APT doesn't know beforehand that the package will disappear, so the
+      only possible option is to tell the user afterwards about it.
+      To enhance the experience we also try to forward the auto-install
+      flag so the disappear-causer(s) are not autoremoved next time -
+      for the transfer to happen the disappeared version needs to depend
+      on the package the flag should be forwarded to and this package
+      needs to declare a Replaces on the disappeared package.
+      \param pkgname Name of the package that disappeared
+   */
+   void handleDisappearAction(string const &pkgname);
+
    protected:
+   int pkgFailures;
 
    // progress reporting
    struct DpkgState 
@@ -49,6 +65,7 @@
    // the int is the state that is already done (e.g. a package that is
    // going to be install is already in state "half-installed")
    map<string,unsigned int> PackageOpsDone;
+
    // progress reporting
    unsigned int PackagesDone;
    unsigned int PackagesTotal;
@@ -68,7 +85,10 @@
    // Helpers
    bool RunScriptsWithPkgs(const char *Cnf);
    bool SendV2Pkgs(FILE *F);
-   void WriteHistoryTag(string tag, string value);
+   void WriteHistoryTag(string const &tag, string value);
+
+   // apport integration
+   void WriteApportReport(const char *pkgpath, const char *errormsg);
 
    // dpkg log
    bool OpenLog();

=== modified file 'apt-pkg/depcache.cc'
--- apt-pkg/depcache.cc	2010-05-25 16:01:42 +0000
+++ apt-pkg/depcache.cc	2010-06-10 14:02:22 +0000
@@ -165,7 +165,7 @@
 bool pkgDepCache::readStateFile(OpProgress *Prog)			/*{{{*/
 {
    FileFd state_file;
-   string const state = _config->FindDir("Dir::State") + "extended_states";
+   string const state = _config->FindFile("Dir::State::extended_states");
    if(FileExists(state)) {
       state_file.Open(state, FileFd::ReadOnly);
       int const file_size = state_file.Size();
@@ -222,7 +222,7 @@
       std::clog << "pkgDepCache::writeStateFile()" << std::endl;
 
    FileFd StateFile;
-   string const state = _config->FindDir("Dir::State") + "extended_states";
+   string const state = _config->FindFile("Dir::State::extended_states");
 
    // if it does not exist, create a empty one
    if(!FileExists(state)) 
@@ -407,49 +407,118 @@
 									/*}}}*/
 // DepCache::AddSizes - Add the packages sizes to the counters		/*{{{*/
 // ---------------------------------------------------------------------
-/* Call with Mult = -1 to preform the inverse opration */
-void pkgDepCache::AddSizes(const PkgIterator &Pkg,signed long Mult)
-{
-   StateCache &P = PkgState[Pkg->ID];
-   
-   if (Pkg->VersionList == 0)
-      return;
-   
-   if (Pkg.State() == pkgCache::PkgIterator::NeedsConfigure && 
-       P.Keep() == true)
-      return;
-   
-   // Compute the size data
-   if (P.NewInstall() == true)
-   {
-      iUsrSize += (signed)(Mult*P.InstVerIter(*this)->InstalledSize);
-      iDownloadSize += (signed)(Mult*P.InstVerIter(*this)->Size);
-      return;
-   }
-   
-   // Upgrading
-   if (Pkg->CurrentVer != 0 && 
-       (P.InstallVer != (Version *)Pkg.CurrentVer() || 
-	(P.iFlags & ReInstall) == ReInstall) && P.InstallVer != 0)
-   {
-      iUsrSize += (signed)(Mult*((signed)P.InstVerIter(*this)->InstalledSize - 
-			(signed)Pkg.CurrentVer()->InstalledSize));
-      iDownloadSize += (signed)(Mult*P.InstVerIter(*this)->Size);
-      return;
-   }
-   
-   // Reinstall
-   if (Pkg.State() == pkgCache::PkgIterator::NeedsUnpack &&
-       P.Delete() == false)
-   {
-      iDownloadSize += (signed)(Mult*P.InstVerIter(*this)->Size);
-      return;
-   }
-   
-   // Removing
-   if (Pkg->CurrentVer != 0 && P.InstallVer == 0)
-   {
-      iUsrSize -= (signed)(Mult*Pkg.CurrentVer()->InstalledSize);
+/* Call with Mult = -1 to preform the inverse opration
+   The Mult increases the complexity of the calulations here and is unused -
+   or do we really have a usecase for removing the size of a package two
+   times? So let us replace it with a simple bool and be done with it… */
+__deprecated void pkgDepCache::AddSizes(const PkgIterator &Pkg,signed long Mult)
+{
+   StateCache &P = PkgState[Pkg->ID];
+   
+   if (Pkg->VersionList == 0)
+      return;
+   
+   if (Pkg.State() == pkgCache::PkgIterator::NeedsConfigure && 
+       P.Keep() == true)
+      return;
+   
+   // Compute the size data
+   if (P.NewInstall() == true)
+   {
+      iUsrSize += (signed long long)(Mult*P.InstVerIter(*this)->InstalledSize);
+      iDownloadSize += (signed long long)(Mult*P.InstVerIter(*this)->Size);
+      return;
+   }
+   
+   // Upgrading
+   if (Pkg->CurrentVer != 0 && 
+       (P.InstallVer != (Version *)Pkg.CurrentVer() || 
+	(P.iFlags & ReInstall) == ReInstall) && P.InstallVer != 0)
+   {
+      iUsrSize += (signed long long)(Mult*((signed long long)P.InstVerIter(*this)->InstalledSize - 
+			(signed long long)Pkg.CurrentVer()->InstalledSize));
+      iDownloadSize += (signed long long)(Mult*P.InstVerIter(*this)->Size);
+      return;
+   }
+   
+   // Reinstall
+   if (Pkg.State() == pkgCache::PkgIterator::NeedsUnpack &&
+       P.Delete() == false)
+   {
+      iDownloadSize += (signed long long)(Mult*P.InstVerIter(*this)->Size);
+      return;
+   }
+   
+   // Removing
+   if (Pkg->CurrentVer != 0 && P.InstallVer == 0)
+   {
+      iUsrSize -= (signed long long)(Mult*Pkg.CurrentVer()->InstalledSize);
+      return;
+   }   
+}
+									/*}}}*/
+// DepCache::AddSizes - Add the packages sizes to the counters		/*{{{*/
+// ---------------------------------------------------------------------
+/* Call with Inverse = true to preform the inverse opration */
+void pkgDepCache::AddSizes(const PkgIterator &Pkg, bool const &Inverse)
+{
+   StateCache &P = PkgState[Pkg->ID];
+   
+   if (Pkg->VersionList == 0)
+      return;
+   
+   if (Pkg.State() == pkgCache::PkgIterator::NeedsConfigure && 
+       P.Keep() == true)
+      return;
+   
+   // Compute the size data
+   if (P.NewInstall() == true)
+   {
+      if (Inverse == false) {
+	 iUsrSize += P.InstVerIter(*this)->InstalledSize;
+	 iDownloadSize += P.InstVerIter(*this)->Size;
+      } else {
+	 iUsrSize -= P.InstVerIter(*this)->InstalledSize;
+	 iDownloadSize -= P.InstVerIter(*this)->Size;
+      }
+      return;
+   }
+   
+   // Upgrading
+   if (Pkg->CurrentVer != 0 && 
+       (P.InstallVer != (Version *)Pkg.CurrentVer() || 
+	(P.iFlags & ReInstall) == ReInstall) && P.InstallVer != 0)
+   {
+      if (Inverse == false) {
+	 iUsrSize -= Pkg.CurrentVer()->InstalledSize;
+	 iUsrSize += P.InstVerIter(*this)->InstalledSize;
+	 iDownloadSize += P.InstVerIter(*this)->Size;
+      } else {
+	 iUsrSize -= P.InstVerIter(*this)->InstalledSize;
+	 iUsrSize += Pkg.CurrentVer()->InstalledSize;
+	 iDownloadSize -= P.InstVerIter(*this)->Size;
+      }
+      return;
+   }
+   
+   // Reinstall
+   if (Pkg.State() == pkgCache::PkgIterator::NeedsUnpack &&
+       P.Delete() == false)
+   {
+      if (Inverse == false)
+	 iDownloadSize += P.InstVerIter(*this)->Size;
+      else
+	 iDownloadSize -= P.InstVerIter(*this)->Size;
+      return;
+   }
+   
+   // Removing
+   if (Pkg->CurrentVer != 0 && P.InstallVer == 0)
+   {
+      if (Inverse == false)
+	 iUsrSize -= Pkg.CurrentVer()->InstalledSize;
+      else
+	 iUsrSize += Pkg.CurrentVer()->InstalledSize;
       return;
    }   
 }
@@ -806,7 +875,7 @@
 		a bit we increase with a kill, but we should do something more clever… */
       while(recheck.empty() == false)
 	 for (std::set<unsigned long>::const_iterator p = recheck.begin();
-	     p != recheck.end(); ++p) {
+	     p != recheck.end();) {
 	    if (Prog != 0 && Done%20 == 0)
 	       Prog->Progress(Done);
 	    PkgIterator P = PkgIterator(*Cache, Cache->PkgP + *p);
@@ -814,7 +883,7 @@
 	       ++killed;
 	       ++Done;
 	    }
-	    recheck.erase(p);
+	    recheck.erase(p++);
 	 }
 
       /* Okay, we have killed a great amount of pseudopackages -
@@ -849,7 +918,7 @@
 	 unsigned long const G = *g;
 	 recheck.erase(g);
 	 if (unlikely(ReInstallPseudoForGroup(G, recheck) == false))
-	    _error->Warning(_("Internal error, group '%s' has no installable pseudo package"), GrpIterator(*Cache, Cache->GrpP + *g).Name());
+	    _error->Warning(_("Internal error, group '%s' has no installable pseudo package"), GrpIterator(*Cache, Cache->GrpP + G).Name());
       }
    }
 
@@ -1638,8 +1707,11 @@
    {
       if(!(PkgState[p->ID].Flags & Flag::Auto) ||
 	  (p->Flags & Flag::Essential) ||
-	  userFunc.InRootSet(p))
-          
+	  userFunc.InRootSet(p) ||
+	  // be nice even then a required package violates the policy (#583517)
+	  // and do the full mark process also for required packages
+	  (p.CurrentVer().end() != true &&
+	   p.CurrentVer()->Priority == pkgCache::State::Required))
       {
 	 // the package is installed (and set to keep)
 	 if(PkgState[p->ID].Keep() && !p.CurrentVer().end())
@@ -1716,10 +1788,6 @@
 
    // If the version belongs to a Multi-Arch all package
    // we will mark all others in this Group with this version also
-   // Beware: We compare versions here the lazy way: string comparision
-   // this is bad if multiple repositories provide different versions
-   // of the package with an identical version number - but even in this
-   // case the dependencies are likely the same.
    if (ver->MultiArch == pkgCache::Version::All &&
 	strcmp(ver.Arch(true), "all") == 0)
    {
@@ -1731,7 +1799,8 @@
 	 for (VerIterator V = P.VersionList();
 	      V.end() != true; ++V)
 	 {
-	    if (strcmp(VerStr, V.VerStr()) != 0)
+	    if (ver->Hash != V->Hash ||
+		strcmp(VerStr, V.VerStr()) != 0)
 	       continue;
 	    MarkPackage(P, V, follow_recommends, follow_suggests);
 	    break;

=== modified file 'apt-pkg/depcache.h'
--- apt-pkg/depcache.h	2010-05-06 09:32:54 +0000
+++ apt-pkg/depcache.h	2010-06-10 14:02:22 +0000
@@ -286,9 +286,11 @@
    pkgCache *Cache;
    StateCache *PkgState;
    unsigned char *DepState;
-   
-   double iUsrSize;
-   double iDownloadSize;
+
+   /** Stores the space changes after installation */
+   signed long long iUsrSize;
+   /** Stores how much we need to download to get the packages */
+   unsigned long long iDownloadSize;
    unsigned long iInstCount;
    unsigned long iDelCount;
    unsigned long iKeepCount;
@@ -321,8 +323,9 @@
    void Update(PkgIterator const &P);
    
    // Count manipulators
-   void AddSizes(const PkgIterator &Pkg,signed long Mult = 1);
-   inline void RemoveSizes(const PkgIterator &Pkg) {AddSizes(Pkg,-1);};
+   void AddSizes(const PkgIterator &Pkg, bool const &Invert = false);
+   inline void RemoveSizes(const PkgIterator &Pkg) {AddSizes(Pkg, true);};
+   void AddSizes(const PkgIterator &Pkg,signed long Mult) __deprecated;
    void AddStates(const PkgIterator &Pkg,int Add = 1);
    inline void RemoveStates(const PkgIterator &Pkg) {AddStates(Pkg,-1);};
    
@@ -451,8 +454,8 @@
    bool writeStateFile(OpProgress *prog, bool InstalledOnly=true);
    
    // Size queries
-   inline double UsrSize() {return iUsrSize;};
-   inline double DebSize() {return iDownloadSize;};
+   inline signed long long UsrSize() {return iUsrSize;};
+   inline unsigned long long DebSize() {return iDownloadSize;};
    inline unsigned long DelCount() {return iDelCount;};
    inline unsigned long KeepCount() {return iKeepCount;};
    inline unsigned long InstCount() {return iInstCount;};

=== modified file 'apt-pkg/indexcopy.cc'
--- apt-pkg/indexcopy.cc	2010-02-18 22:07:23 +0000
+++ apt-pkg/indexcopy.cc	2010-06-10 14:02:22 +0000
@@ -27,6 +27,8 @@
 #include <sstream>
 #include <unistd.h>
 #include <sys/stat.h>
+#include <sys/types.h>
+#include <fcntl.h>
 #include <stdio.h>
 									/*}}}*/
 
@@ -590,66 +592,34 @@
       indexRecords *MetaIndex = new indexRecords;
       string prefix = *I; 
 
+      string const releasegpg = *I+"Release.gpg";
+      string const release = *I+"Release";
+
       // a Release.gpg without a Release should never happen
-      if(!FileExists(*I+"Release"))
+      if(FileExists(release) == false)
       {
 	 delete MetaIndex;
 	 continue;
       }
 
-
-      // verify the gpg signature of "Release"
-      // gpg --verify "*I+Release.gpg", "*I+Release"
-      const char *Args[400];
-      unsigned int i = 0;
-
-      string gpgvpath = _config->Find("Dir::Bin::gpg", "/usr/bin/gpgv");
-      string pubringpath = _config->Find("Apt::GPGV::TrustedKeyring", "/etc/apt/trusted.gpg");
-      string releasegpg = *I+"Release.gpg";
-      string release = *I+"Release";
-
-      Args[i++] = gpgvpath.c_str();
-      Args[i++] = "--keyring";
-      Args[i++] = pubringpath.c_str();
-      Configuration::Item const *Opts;
-      Opts = _config->Tree("Acquire::gpgv::Options");
-      if (Opts != 0)
-      {
-         Opts = Opts->Child;
-	 for (; Opts != 0; Opts = Opts->Next)
-         {
-            if (Opts->Value.empty() == true)
-               continue;
-            Args[i++] = Opts->Value.c_str();
-	    if(i >= 390) { 
-	       _error->Error("Argument list from Acquire::gpgv::Options too long. Exiting.");
-	       return false;
-	    }
-         }
-      }
-      
-      Args[i++] = releasegpg.c_str();
-      Args[i++] = release.c_str();
-      Args[i++] = NULL;
-      
       pid_t pid = ExecFork();
       if(pid < 0) {
 	 _error->Error("Fork failed");
 	 return false;
       }
-      if(pid == 0) {
-	 execvp(gpgvpath.c_str(), (char**)Args);
-      }
+      if(pid == 0)
+	 RunGPGV(release, releasegpg);
+
       if(!ExecWait(pid, "gpgv")) {
 	 _error->Warning("Signature verification failed for: %s",
-			 string(*I+"Release.gpg").c_str());
+			 releasegpg.c_str());
 	 // something went wrong, don't copy the Release.gpg
 	 // FIXME: delete any existing gpg file?
 	 continue;
       }
 
       // Open the Release file and add it to the MetaIndex
-      if(!MetaIndex->Load(*I+"Release"))
+      if(!MetaIndex->Load(release))
       {
 	 _error->Error("%s",MetaIndex->ErrorText.c_str());
 	 return false;
@@ -679,6 +649,103 @@
    return true;
 }
 									/*}}}*/
+// SigVerify::RunGPGV - returns the command needed for verify		/*{{{*/
+// ---------------------------------------------------------------------
+/* Generating the commandline for calling gpgv is somehow complicated as
+   we need to add multiple keyrings and user supplied options. Also, as
+   the cdrom code currently can not use the gpgv method we have two places
+   these need to be done - so the place for this method is wrong but better
+   than code duplication… */
+bool SigVerify::RunGPGV(std::string const &File, std::string const &FileGPG,
+			int const &statusfd, int fd[2])
+{
+   string const gpgvpath = _config->Find("Dir::Bin::gpg", "/usr/bin/gpgv");
+   // FIXME: remove support for deprecated APT::GPGV setting
+   string const trustedFile = _config->FindFile("Dir::Etc::Trusted",
+		_config->Find("APT::GPGV::TrustedKeyring", "/etc/apt/trusted.gpg").c_str());
+   string const trustedPath = _config->FindDir("Dir::Etc::TrustedParts", "/etc/apt/trusted.gpg.d");
+
+   bool const Debug = _config->FindB("Debug::Acquire::gpgv", false);
+
+   if (Debug == true)
+   {
+      std::clog << "gpgv path: " << gpgvpath << std::endl;
+      std::clog << "Keyring file: " << trustedFile << std::endl;
+      std::clog << "Keyring path: " << trustedPath << std::endl;
+   }
+
+   std::vector<string> keyrings = GetListOfFilesInDir(trustedPath, "gpg", false);
+   if (FileExists(trustedFile) == true)
+      keyrings.push_back(trustedFile);
+
+   std::vector<const char *> Args;
+   Args.reserve(30);
+
+   if (keyrings.empty() == true)
+      return false;
+
+   Args.push_back(gpgvpath.c_str());
+   Args.push_back("--ignore-time-conflict");
+
+   if (statusfd != -1)
+   {
+      Args.push_back("--status-fd");
+      char fd[10];
+      snprintf(fd, sizeof(fd), "%i", statusfd);
+      Args.push_back(fd);
+   }
+
+   for (vector<string>::const_iterator K = keyrings.begin();
+	K != keyrings.end(); ++K)
+   {
+      Args.push_back("--keyring");
+      Args.push_back(K->c_str());
+   }
+
+   Configuration::Item const *Opts;
+   Opts = _config->Tree("Acquire::gpgv::Options");
+   if (Opts != 0)
+   {
+      Opts = Opts->Child;
+      for (; Opts != 0; Opts = Opts->Next)
+      {
+	 if (Opts->Value.empty() == true)
+	    continue;
+	 Args.push_back(Opts->Value.c_str());
+      }
+   }
+
+   Args.push_back(FileGPG.c_str());
+   Args.push_back(File.c_str());
+   Args.push_back(NULL);
+
+   if (Debug == true)
+   {
+      std::clog << "Preparing to exec: " << gpgvpath;
+      for (std::vector<const char *>::const_iterator a = Args.begin(); *a != NULL; ++a)
+	 std::clog << " " << *a;
+      std::clog << std::endl;
+   }
+
+   if (statusfd != -1)
+   {
+      int const nullfd = open("/dev/null", O_RDONLY);
+      close(fd[0]);
+      // Redirect output to /dev/null; we read from the status fd
+      dup2(nullfd, STDOUT_FILENO);
+      dup2(nullfd, STDERR_FILENO);
+      // Redirect the pipe to the status fd (3)
+      dup2(fd[1], statusfd);
+
+      putenv((char *)"LANG=");
+      putenv((char *)"LC_ALL=");
+      putenv((char *)"LC_MESSAGES=");
+   }
+
+   execvp(gpgvpath.c_str(), (char **) &Args[0]);
+   return true;
+}
+									/*}}}*/
 bool TranslationsCopy::CopyTranslations(string CDROM,string Name,	/*{{{*/
 				vector<string> &List, pkgCdromStatus *log)
 {

=== modified file 'apt-pkg/indexcopy.h'
--- apt-pkg/indexcopy.h	2009-07-29 19:16:22 +0000
+++ apt-pkg/indexcopy.h	2010-06-10 14:02:22 +0000
@@ -89,6 +89,15 @@
  public:
    bool CopyAndVerify(string CDROM,string Name,vector<string> &SigList,
 		      vector<string> PkgList,vector<string> SrcList);
+
+   /** \brief generates and run the command to verify a file with gpgv */
+   static bool RunGPGV(std::string const &File, std::string const &FileOut,
+		       int const &statusfd, int fd[2]);
+   inline static bool RunGPGV(std::string const &File, std::string const &FileOut,
+			      int const &statusfd = -1) {
+      int fd[2];
+      return RunGPGV(File, FileOut, statusfd, fd);
+   };
 };
 									/*}}}*/
 

=== modified file 'apt-pkg/indexfile.h'
--- apt-pkg/indexfile.h	2008-05-28 15:19:12 +0000
+++ apt-pkg/indexfile.h	2010-06-10 14:02:22 +0000
@@ -74,8 +74,12 @@
    virtual bool Exists() const = 0;
    virtual bool HasPackages() const = 0;
    virtual unsigned long Size() const = 0;
-   virtual bool Merge(pkgCacheGenerator &/*Gen*/,OpProgress &/*Prog*/) const {return false;};
-   virtual bool MergeFileProvides(pkgCacheGenerator &/*Gen*/,OpProgress &/*Prog*/) const {return true;};
+   virtual bool Merge(pkgCacheGenerator &/*Gen*/,OpProgress* /*Prog*/) const { return false; };
+   __deprecated virtual bool Merge(pkgCacheGenerator &Gen, OpProgress &Prog) const
+      { return Merge(Gen, &Prog); };
+   virtual bool MergeFileProvides(pkgCacheGenerator &/*Gen*/,OpProgress* /*Prog*/) const {return true;};
+   __deprecated virtual bool MergeFileProvides(pkgCacheGenerator &Gen, OpProgress &Prog) const
+      {return MergeFileProvides(Gen, &Prog);};
    virtual pkgCache::PkgFileIterator FindInCache(pkgCache &Cache) const;
 
    static bool TranslationsAvailable();

=== modified file 'apt-pkg/indexrecords.cc'
--- apt-pkg/indexrecords.cc	2010-02-18 22:07:23 +0000
+++ apt-pkg/indexrecords.cc	2010-06-10 14:02:22 +0000
@@ -7,8 +7,11 @@
 #include <apt-pkg/tagfile.h>
 #include <apt-pkg/error.h>
 #include <apt-pkg/strutl.h>
+#include <apt-pkg/configuration.h>
 #include <apti18n.h>
 #include <sys/stat.h>
+#include <clocale>
+
 									/*}}}*/
 string indexRecords::GetDist() const
 {
@@ -26,11 +29,21 @@
    return this->ExpectedDist;
 }
 
+time_t indexRecords::GetValidUntil() const
+{
+   return this->ValidUntil;
+}
+
 const indexRecords::checkSum *indexRecords::Lookup(const string MetaKey)
 {
    return Entries[MetaKey];
 }
 
+bool indexRecords::Exists(string const &MetaKey) const
+{
+   return Entries.count(MetaKey) == 1;
+}
+
 bool indexRecords::Load(const string Filename)				/*{{{*/
 {
    FileFd Fd(Filename, FileFd::ReadOnly);
@@ -80,9 +93,40 @@
    {
       strprintf(ErrorText, _("No Hash entry in Release file %s"), Filename.c_str());
       return false;
-   }  
-
-   string Strdate = Section.FindS("Date"); // FIXME: verify this somehow?
+   }
+
+   string Label = Section.FindS("Label");
+   string StrDate = Section.FindS("Date");
+   string StrValidUntil = Section.FindS("Valid-Until");
+
+   // if we have a Valid-Until header in the Release file, use it as default
+   if (StrValidUntil.empty() == false)
+   {
+      if(RFC1123StrToTime(StrValidUntil.c_str(), ValidUntil) == false)
+      {
+	 strprintf(ErrorText, _("Invalid 'Valid-Until' entry in Release file %s"), Filename.c_str());
+	 return false;
+      }
+   }
+   // get the user settings for this archive and use what expires earlier
+   int MaxAge = _config->FindI("Acquire::Max-ValidTime", 0);
+   if (Label.empty() == true)
+      MaxAge = _config->FindI(string("Acquire::Max-ValidTime::" + Label).c_str(), MaxAge);
+
+   if(MaxAge == 0) // No user settings, use the one from the Release file
+      return true;
+
+   time_t date;
+   if (RFC1123StrToTime(StrDate.c_str(), date) == false)
+   {
+      strprintf(ErrorText, _("Invalid 'Date' entry in Release file %s"), Filename.c_str());
+      return false;
+   }
+   date += 24*60*60*MaxAge;
+
+   if (ValidUntil == 0 || ValidUntil > date)
+      ValidUntil = date;
+
    return true;
 }
 									/*}}}*/
@@ -160,6 +204,6 @@
 }
 
 indexRecords::indexRecords(const string ExpectedDist) :
-   ExpectedDist(ExpectedDist)
+   ExpectedDist(ExpectedDist), ValidUntil(0)
 {
 }

=== modified file 'apt-pkg/indexrecords.h'
--- apt-pkg/indexrecords.h	2010-02-18 22:07:23 +0000
+++ apt-pkg/indexrecords.h	2010-06-10 14:02:22 +0000
@@ -12,6 +12,7 @@
 
 #include <map>
 #include <vector>
+#include <ctime>
 
 class indexRecords
 {
@@ -25,6 +26,8 @@
    string Dist;
    string Suite;
    string ExpectedDist;
+   time_t ValidUntil;
+
    std::map<string,checkSum *> Entries;
 
    public:
@@ -34,10 +37,13 @@
 
    // Lookup function
    virtual const checkSum *Lookup(const string MetaKey);
+   /** \brief tests if a checksum for this file is available */
+   bool Exists(string const &MetaKey) const;
    std::vector<std::string> MetaKeys();
 
    virtual bool Load(string Filename);
    string GetDist() const;
+   time_t GetValidUntil() const;
    virtual bool CheckDist(const string MaybeDist) const;
    string GetExpectedDist() const;
    virtual ~indexRecords(){};

=== modified file 'apt-pkg/init.cc'
--- apt-pkg/init.cc	2010-05-25 16:01:42 +0000
+++ apt-pkg/init.cc	2010-06-10 14:02:22 +0000
@@ -51,6 +51,7 @@
        
    Cnf.Set("Dir::State::lists","lists/");
    Cnf.Set("Dir::State::cdroms","cdroms.list");
+   Cnf.Set("Dir::State::mirrors","mirrors/");
    
    // Cache
    Cnf.Set("Dir::Cache","var/cache/apt/");

=== modified file 'apt-pkg/makefile'
--- apt-pkg/makefile	2010-05-06 09:32:54 +0000
+++ apt-pkg/makefile	2010-06-10 14:02:22 +0000
@@ -35,14 +35,15 @@
 	 srcrecords.cc cachefile.cc versionmatch.cc policy.cc \
 	 pkgsystem.cc indexfile.cc pkgcachegen.cc acquire-item.cc \
 	 indexrecords.cc vendor.cc vendorlist.cc cdrom.cc indexcopy.cc \
-	 aptconfiguration.cc
+	 aptconfiguration.cc cacheset.cc
 HEADERS+= algorithms.h depcache.h pkgcachegen.h cacheiterators.h \
 	  orderlist.h sourcelist.h packagemanager.h tagfile.h \
 	  init.h pkgcache.h version.h progress.h pkgrecords.h \
 	  acquire.h acquire-worker.h acquire-item.h acquire-method.h \
 	  clean.h srcrecords.h cachefile.h versionmatch.h policy.h \
 	  pkgsystem.h indexfile.h metaindex.h indexrecords.h vendor.h \
-          vendorlist.h cdrom.h indexcopy.h aptconfiguration.h
+          vendorlist.h cdrom.h indexcopy.h aptconfiguration.h \
+	  cacheset.h
 
 # Source code for the debian specific components
 # In theory the deb headers do not need to be exported..

=== modified file 'apt-pkg/pkgcache.cc'
--- apt-pkg/pkgcache.cc	2010-05-06 09:32:54 +0000
+++ apt-pkg/pkgcache.cc	2010-06-10 14:02:22 +0000
@@ -343,6 +343,25 @@
 	return PkgIterator(*Owner, 0);
 }
 									/*}}}*/
+// GrpIterator::FindPreferredPkg - Locate the "best" package		/*{{{*/
+// ---------------------------------------------------------------------
+/* Returns an End-Pointer on error, pointer to the package otherwise */
+pkgCache::PkgIterator pkgCache::GrpIterator::FindPreferredPkg() {
+	pkgCache::PkgIterator Pkg = FindPkg("native");
+	if (Pkg.end() == false)
+		return Pkg;
+
+	std::vector<std::string> const archs = APT::Configuration::getArchitectures();
+	for (std::vector<std::string>::const_iterator a = archs.begin();
+	     a != archs.end(); ++a) {
+		Pkg = FindPkg(*a);
+		if (Pkg.end() == false)
+			return Pkg;
+	}
+
+	return PkgIterator(*Owner, 0);
+}
+									/*}}}*/
 // GrpIterator::NextPkg - Locate the next package in the group		/*{{{*/
 // ---------------------------------------------------------------------
 /* Returns an End-Pointer on error, pointer to the package otherwise.
@@ -723,7 +742,7 @@
 // ---------------------------------------------------------------------
 /* This describes the version from a release-centric manner. The output is a 
    list of Label:Version/Archive */
-string pkgCache::VerIterator::RelStr()
+string pkgCache::VerIterator::RelStr() const
 {
    bool First = true;
    string Res;

=== modified file 'apt-pkg/pkgcache.h'
--- apt-pkg/pkgcache.h	2010-05-06 09:32:54 +0000
+++ apt-pkg/pkgcache.h	2010-06-10 14:02:22 +0000
@@ -532,9 +532,9 @@
    /** \brief archive size for this version
 
        For Debian this is the size of the .deb file. */
-   map_ptrloc Size;              // These are the .deb size
+   unsigned long long Size;      // These are the .deb size
    /** \brief uncompressed size for this version */
-   map_ptrloc InstalledSize;
+   unsigned long long InstalledSize;
    /** \brief characteristic value representing this version
 
        No two packages in existence should have the same VerStr

=== modified file 'apt-pkg/pkgcachegen.cc'
--- apt-pkg/pkgcachegen.cc	2010-05-06 09:32:54 +0000
+++ apt-pkg/pkgcachegen.cc	2010-06-10 14:02:22 +0000
@@ -526,7 +526,7 @@
 // CacheGenerator::FinishCache - do various finish operations		/*{{{*/
 // ---------------------------------------------------------------------
 /* This prepares the Cache for delivery */
-bool pkgCacheGenerator::FinishCache(OpProgress &Progress)
+bool pkgCacheGenerator::FinishCache(OpProgress *Progress)
 {
    // FIXME: add progress reporting for this operation
    // Do we have different architectures in your groups ?
@@ -923,7 +923,7 @@
 // ---------------------------------------------------------------------
 /* */
 static bool BuildCache(pkgCacheGenerator &Gen,
-		       OpProgress &Progress,
+		       OpProgress *Progress,
 		       unsigned long &CurrentSize,unsigned long TotalSize,
 		       FileIterator Start, FileIterator End)
 {
@@ -944,7 +944,8 @@
       }
       
       unsigned long Size = (*I)->Size();
-      Progress.OverallProgress(CurrentSize,TotalSize,Size,_("Reading package lists"));
+      if (Progress != NULL)
+	 Progress->OverallProgress(CurrentSize,TotalSize,Size,_("Reading package lists"));
       CurrentSize += Size;
       
       if ((*I)->Merge(Gen,Progress) == false)
@@ -953,13 +954,15 @@
 
    if (Gen.HasFileDeps() == true)
    {
-      Progress.Done();
+      if (Progress != NULL)
+	 Progress->Done();
       TotalSize = ComputeSize(Start, End);
       CurrentSize = 0;
       for (I = Start; I != End; I++)
       {
 	 unsigned long Size = (*I)->Size();
-	 Progress.OverallProgress(CurrentSize,TotalSize,Size,_("Collecting File Provides"));
+	 if (Progress != NULL)
+	    Progress->OverallProgress(CurrentSize,TotalSize,Size,_("Collecting File Provides"));
 	 CurrentSize += Size;
 	 if ((*I)->MergeFileProvides(Gen,Progress) == false)
 	    return false;
@@ -969,7 +972,7 @@
    return true;
 }
 									/*}}}*/
-// MakeStatusCache - Construct the status cache				/*{{{*/
+// CacheGenerator::MakeStatusCache - Construct the status cache		/*{{{*/
 // ---------------------------------------------------------------------
 /* This makes sure that the status cache (the cache that has all 
    index files from the sources list and all local ones) is ready
@@ -977,7 +980,10 @@
    the cache will be stored there. This is pretty much mandetory if you
    are using AllowMem. AllowMem lets the function be run as non-root
    where it builds the cache 'fast' into a memory buffer. */
-bool pkgMakeStatusCache(pkgSourceList &List,OpProgress &Progress,
+__deprecated bool pkgMakeStatusCache(pkgSourceList &List,OpProgress &Progress,
+			MMap **OutMap, bool AllowMem)
+   { return pkgCacheGenerator::MakeStatusCache(List, &Progress, OutMap, AllowMem); }
+bool pkgCacheGenerator::MakeStatusCache(pkgSourceList &List,OpProgress *Progress,
 			MMap **OutMap,bool AllowMem)
 {
    bool const Debug = _config->FindB("Debug::pkgCacheGen", false);
@@ -1028,13 +1034,15 @@
 
    if (Writeable == false && AllowMem == false && CacheFile.empty() == false)
       return _error->Error(_("Unable to write to %s"),flNotFile(CacheFile).c_str());
-   
-   Progress.OverallProgress(0,1,1,_("Reading package lists"));
-   
+
+   if (Progress != NULL)
+      Progress->OverallProgress(0,1,1,_("Reading package lists"));
+
    // Cache is OK, Fin.
    if (CheckValidity(CacheFile,Files.begin(),Files.end(),OutMap) == true)
    {
-      Progress.OverallProgress(1,1,1,_("Reading package lists"));
+      if (Progress != NULL)
+	 Progress->OverallProgress(1,1,1,_("Reading package lists"));
       if (Debug == true)
 	 std::clog << "pkgcache.bin is valid - no need to build anything" << std::endl;
       return true;
@@ -1084,7 +1092,7 @@
       TotalSize = ComputeSize(Files.begin()+EndOfSource,Files.end());
 
       // Build the status cache
-      pkgCacheGenerator Gen(Map.Get(),&Progress);
+      pkgCacheGenerator Gen(Map.Get(),Progress);
       if (_error->PendingError() == true)
 	 return false;
       if (BuildCache(Gen,Progress,CurrentSize,TotalSize,
@@ -1101,7 +1109,7 @@
       TotalSize = ComputeSize(Files.begin(),Files.end());
       
       // Build the source cache
-      pkgCacheGenerator Gen(Map.Get(),&Progress);
+      pkgCacheGenerator Gen(Map.Get(),Progress);
       if (_error->PendingError() == true)
 	 return false;
       if (BuildCache(Gen,Progress,CurrentSize,TotalSize,
@@ -1160,10 +1168,12 @@
    return true;
 }
 									/*}}}*/
-// MakeOnlyStatusCache - Build a cache with just the status files	/*{{{*/
+// CacheGenerator::MakeOnlyStatusCache - Build only a status files cache/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-bool pkgMakeOnlyStatusCache(OpProgress &Progress,DynamicMMap **OutMap)
+__deprecated bool pkgMakeOnlyStatusCache(OpProgress &Progress,DynamicMMap **OutMap)
+   { return pkgCacheGenerator::MakeOnlyStatusCache(&Progress, OutMap); }
+bool pkgCacheGenerator::MakeOnlyStatusCache(OpProgress *Progress,DynamicMMap **OutMap)
 {
    unsigned long MapSize = _config->FindI("APT::Cache-Limit",20*1024*1024);
    vector<pkgIndexFile *> Files;
@@ -1178,8 +1188,9 @@
    TotalSize = ComputeSize(Files.begin()+EndOfSource,Files.end());
    
    // Build the status cache
-   Progress.OverallProgress(0,1,1,_("Reading package lists"));
-   pkgCacheGenerator Gen(Map.Get(),&Progress);
+   if (Progress != NULL)
+      Progress->OverallProgress(0,1,1,_("Reading package lists"));
+   pkgCacheGenerator Gen(Map.Get(),Progress);
    if (_error->PendingError() == true)
       return false;
    if (BuildCache(Gen,Progress,CurrentSize,TotalSize,

=== modified file 'apt-pkg/pkgcachegen.h'
--- apt-pkg/pkgcachegen.h	2010-04-01 17:30:43 +0000
+++ apt-pkg/pkgcachegen.h	2010-06-10 14:02:22 +0000
@@ -76,7 +76,11 @@
 
    bool HasFileDeps() {return FoundFileDeps;};
    bool MergeFileProvides(ListParser &List);
-   bool FinishCache(OpProgress &Progress);
+   bool FinishCache(OpProgress *Progress);
+
+   static bool MakeStatusCache(pkgSourceList &List,OpProgress *Progress,
+			MMap **OutMap = 0,bool AllowMem = false);
+   static bool MakeOnlyStatusCache(OpProgress *Progress,DynamicMMap **OutMap);
 
    pkgCacheGenerator(DynamicMMap *Map,OpProgress *Progress);
    ~pkgCacheGenerator();
@@ -134,10 +138,12 @@
    virtual ~ListParser() {};
 };
 									/*}}}*/
+
 bool pkgMakeStatusCache(pkgSourceList &List,OpProgress &Progress,
 			MMap **OutMap = 0,bool AllowMem = false);
 bool pkgMakeOnlyStatusCache(OpProgress &Progress,DynamicMMap **OutMap);
 
+
 #ifdef APT_COMPATIBILITY
 #if APT_COMPATIBILITY != 986
 #warning "Using APT_COMPATIBILITY"
@@ -145,7 +151,7 @@
 MMap *pkgMakeStatusCacheMem(pkgSourceList &List,OpProgress &Progress)
 {
    MMap *Map = 0;
-   if (pkgMakeStatusCache(List,Progress,&Map,true) == false)
+   if (pkgCacheGenerator::MakeStatusCache(List,&Progress,&Map,true) == false)
       return 0;
    return Map;
 }

=== modified file 'apt-pkg/policy.cc'
--- apt-pkg/policy.cc	2010-05-25 16:01:42 +0000
+++ apt-pkg/policy.cc	2010-06-10 14:02:22 +0000
@@ -115,7 +115,7 @@
 // ---------------------------------------------------------------------
 /* Evaluate the package pins and the default list to deteremine what the
    best package is. */
-pkgCache::VerIterator pkgPolicy::GetCandidateVer(pkgCache::PkgIterator Pkg)
+pkgCache::VerIterator pkgPolicy::GetCandidateVer(pkgCache::PkgIterator const &Pkg)
 {
    // Look for a package pin and evaluate it.
    signed Max = GetPriority(Pkg);
@@ -147,6 +147,16 @@
     */
    for (pkgCache::VerIterator Ver = Pkg.VersionList(); Ver.end() == false; Ver++)
    {
+      /* Lets see if this version is the installed version */
+      bool instVer = (Pkg.CurrentVer() == Ver);
+      if (Ver.Pseudo() == true && instVer == false)
+      {
+	 pkgCache::PkgIterator const allPkg = Ver.ParentPkg().Group().FindPkg("all");
+	 if (allPkg->CurrentVer != 0 && allPkg.CurrentVer()->Hash == Ver->Hash &&
+	     strcmp(allPkg.CurVersion(), Ver.VerStr()) == 0)
+	    instVer = true;
+      }
+
       for (pkgCache::VerFileIterator VF = Ver.FileList(); VF.end() == false; VF++)
       {
 	 /* If this is the status file, and the current version is not the
@@ -155,9 +165,9 @@
 	    out bogus entries that may be due to config-file states, or
 	    other. */
 	 if ((VF.File()->Flags & pkgCache::Flag::NotSource) == pkgCache::Flag::NotSource &&
-	     Pkg.CurrentVer() != Ver)
+	     instVer == false)
 	    continue;
-	 	 	 
+
 	 signed Prio = PFPriority[VF.File()->ID];
 	 if (Prio > Max)
 	 {
@@ -171,7 +181,7 @@
 	 }	 
       }      
       
-      if (Pkg.CurrentVer() == Ver && Max < 1000)
+      if (instVer == true && Max < 1000)
       {
 	 /* Elevate our current selection (or the status file itself)
 	    to the Pseudo-status priority. */
@@ -189,6 +199,7 @@
    // will always be a candidate (Closes: #512318)
    if (!Pref.IsGood() && MaxAlt > 0)
        Pref = PrefAlt;
+
    return Pref;
 }
 									/*}}}*/
@@ -238,15 +249,14 @@
 // Policy::GetMatch - Get the matching version for a package pin	/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-pkgCache::VerIterator pkgPolicy::GetMatch(pkgCache::PkgIterator Pkg)
+pkgCache::VerIterator pkgPolicy::GetMatch(pkgCache::PkgIterator const &Pkg)
 {
    const Pin &PPkg = Pins[Pkg->ID];
-   if (PPkg.Type != pkgVersionMatch::None)
-   {
-      pkgVersionMatch Match(PPkg.Data,PPkg.Type);
-      return Match.Find(Pkg);
-   }
-   return pkgCache::VerIterator(*Pkg.Cache());
+   if (PPkg.Type == pkgVersionMatch::None)
+      return pkgCache::VerIterator(*Pkg.Cache());
+
+   pkgVersionMatch Match(PPkg.Data,PPkg.Type);
+   return Match.Find(Pkg);
 }
 									/*}}}*/
 // Policy::GetPriority - Get the priority of the package pin		/*{{{*/

=== modified file 'apt-pkg/policy.h'
--- apt-pkg/policy.h	2009-07-29 19:16:22 +0000
+++ apt-pkg/policy.h	2010-06-10 14:02:22 +0000
@@ -72,10 +72,10 @@
    inline signed short GetPriority(pkgCache::PkgFileIterator const &File) 
        {return PFPriority[File->ID];};
    signed short GetPriority(pkgCache::PkgIterator const &Pkg);
-   pkgCache::VerIterator GetMatch(pkgCache::PkgIterator Pkg);
+   pkgCache::VerIterator GetMatch(pkgCache::PkgIterator const &Pkg);
 
    // Things for the cache interface.
-   virtual pkgCache::VerIterator GetCandidateVer(pkgCache::PkgIterator Pkg);
+   virtual pkgCache::VerIterator GetCandidateVer(pkgCache::PkgIterator const &Pkg);
    virtual bool IsImportantDep(pkgCache::DepIterator Dep) {return pkgDepCache::Policy::IsImportantDep(Dep);};
    bool InitDefaults();
    

=== modified file 'apt-pkg/tagfile.cc'
--- apt-pkg/tagfile.cc	2010-04-01 17:30:43 +0000
+++ apt-pkg/tagfile.cc	2010-06-10 14:02:22 +0000
@@ -365,6 +365,30 @@
    return Result;
 }
 									/*}}}*/
+// TagSection::FindULL - Find an unsigned long long integer		/*{{{*/
+// ---------------------------------------------------------------------
+/* */
+unsigned long long pkgTagSection::FindULL(const char *Tag, unsigned long long const &Default) const
+{
+   const char *Start;
+   const char *Stop;
+   if (Find(Tag,Start,Stop) == false)
+      return Default;
+
+   // Copy it into a temp buffer so we can use strtoull
+   char S[100];
+   if ((unsigned)(Stop - Start) >= sizeof(S))
+      return Default;
+   strncpy(S,Start,Stop-Start);
+   S[Stop - Start] = 0;
+   
+   char *End;
+   unsigned long long Result = strtoull(S,&End,10);
+   if (S == End)
+      return Default;
+   return Result;
+}
+									/*}}}*/
 // TagSection::FindFlag - Locate a yes/no type flag			/*{{{*/
 // ---------------------------------------------------------------------
 /* The bits marked in Flag are masked on/off in Flags */
@@ -409,6 +433,7 @@
                           "Section",
                           "Installed-Size",
                           "Maintainer",
+                          "Original-Maintainer",
                           "Architecture",
                           "Source",
                           "Version",
@@ -438,6 +463,7 @@
                                       "Priority",
                                       "Section",
                                       "Maintainer",
+				      "Original-Maintainer",
                                       "Build-Depends",
                                       "Build-Depends-Indep",
                                       "Build-Conflicts",

=== modified file 'apt-pkg/tagfile.h'
--- apt-pkg/tagfile.h	2010-04-01 17:30:43 +0000
+++ apt-pkg/tagfile.h	2010-06-10 14:02:22 +0000
@@ -57,6 +57,7 @@
    bool Find(const char *Tag,unsigned &Pos) const;
    string FindS(const char *Tag) const;
    signed int FindI(const char *Tag,signed long Default = 0) const ;
+   unsigned long long FindULL(const char *Tag, unsigned long long const &Default = 0) const;
    bool FindFlag(const char *Tag,unsigned long &Flags,
 		 unsigned long Flag) const;
    bool Scan(const char *Start,unsigned long MaxLength);

=== modified file 'cmdline/apt-cache.cc'
--- cmdline/apt-cache.cc	2010-05-06 09:32:54 +0000
+++ cmdline/apt-cache.cc	2010-06-10 14:02:22 +0000
@@ -29,6 +29,7 @@
 #include <apt-pkg/tagfile.h>
 #include <apt-pkg/algorithms.h>
 #include <apt-pkg/sptr.h>
+#include <apt-pkg/cacheset.h>
 
 #include <config.h>
 #include <apti18n.h>
@@ -45,9 +46,6 @@
 
 using namespace std;
 
-pkgCache *GCache = 0;
-pkgSourceList *SrcList = 0;
-
 // LocalitySort - Sort a version list by package file locality		/*{{{*/
 // ---------------------------------------------------------------------
 /* */
@@ -83,15 +81,8 @@
 // UnMet - Show unmet dependencies					/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-bool UnMet(CommandLine &CmdL)
+bool ShowUnMet(pkgCache::VerIterator const &V, bool const &Important)
 {
-   pkgCache &Cache = *GCache;
-   bool Important = _config->FindB("APT::Cache::Important",false);
-   
-   for (pkgCache::PkgIterator P = Cache.PkgBegin(); P.end() == false; P++)
-   {
-      for (pkgCache::VerIterator V = P.VersionList(); V.end() == false; V++)
-      {
 	 bool Header = false;
 	 for (pkgCache::DepIterator D = V.DependsList(); D.end() == false;)
 	 {
@@ -99,20 +90,19 @@
 	    pkgCache::DepIterator Start;
 	    pkgCache::DepIterator End;
 	    D.GlobOr(Start,End);
-	    
-	    // Skip conflicts and replaces
-	    if (End->Type != pkgCache::Dep::PreDepends &&
-		End->Type != pkgCache::Dep::Depends && 
-		End->Type != pkgCache::Dep::Suggests &&
-	        End->Type != pkgCache::Dep::Recommends)
-	       continue;
 
 	    // Important deps only
 	    if (Important == true)
 	       if (End->Type != pkgCache::Dep::PreDepends &&
 	           End->Type != pkgCache::Dep::Depends)
 		  continue;
-	    
+
+	    // Skip conflicts and replaces
+	    if (End->Type == pkgCache::Dep::DpkgBreaks ||
+		End->Type == pkgCache::Dep::Replaces ||
+		End->Type == pkgCache::Dep::Conflicts)
+	       continue;
+
 	    // Verify the or group
 	    bool OK = false;
 	    pkgCache::DepIterator RealStart = Start;
@@ -141,7 +131,7 @@
 	    // Oops, it failed..
 	    if (Header == false)
 	       ioprintf(cout,_("Package %s version %s has an unmet dep:\n"),
-			P.FullName(true).c_str(),V.VerStr());
+			V.ParentPkg().FullName(true).c_str(),V.VerStr());
 	    Header = true;
 	    
 	    // Print out the dep type
@@ -163,9 +153,31 @@
 	    while (1);
 	    
 	    cout << endl;
-	 }	 
-      }
-   }   
+	 }
+   return true;
+}
+bool UnMet(CommandLine &CmdL)
+{
+   bool const Important = _config->FindB("APT::Cache::Important",false);
+
+   pkgCacheFile CacheFile;
+   if (unlikely(CacheFile.GetPkgCache() == NULL))
+      return false;
+
+   if (CmdL.FileSize() <= 1)
+   {
+      for (pkgCache::PkgIterator P = CacheFile.GetPkgCache()->PkgBegin(); P.end() == false; P++)
+	 for (pkgCache::VerIterator V = P.VersionList(); V.end() == false; ++V)
+	    if (ShowUnMet(V, Important) == false)
+	       return false;
+   }
+   else
+   {
+      APT::VersionSet verset = APT::VersionSet::FromCommandLine(CacheFile, CmdL.FileList + 1);
+      for (APT::VersionSet::iterator V = verset.begin(); V != verset.end(); ++V)
+	 if (ShowUnMet(V, Important) == false)
+	    return false;
+   }
    return true;
 }
 									/*}}}*/
@@ -173,17 +185,12 @@
 // ---------------------------------------------------------------------
 /* */
 bool DumpPackage(CommandLine &CmdL)
-{   
-   pkgCache &Cache = *GCache;
-   for (const char **I = CmdL.FileList + 1; *I != 0; I++)
+{
+   pkgCacheFile CacheFile;
+   APT::PackageSet pkgset = APT::PackageSet::FromCommandLine(CacheFile, CmdL.FileList + 1);
+
+   for (APT::PackageSet::const_iterator Pkg = pkgset.begin(); Pkg != pkgset.end(); ++Pkg)
    {
-      pkgCache::PkgIterator Pkg = Cache.FindPkg(*I);
-      if (Pkg.end() == true)
-      {
-	 _error->Warning(_("Unable to locate package %s"),*I);
-	 continue;
-      }
-
       cout << "Package: " << Pkg.FullName(true) << endl;
       cout << "Versions: " << endl;
       for (pkgCache::VerIterator Cur = Pkg.VersionList(); Cur.end() != true; Cur++)
@@ -243,18 +250,22 @@
 /* */
 bool Stats(CommandLine &Cmd)
 {
-   pkgCache &Cache = *GCache;
-   cout << _("Total package names: ") << Cache.Head().GroupCount << " (" <<
-      SizeToStr(Cache.Head().GroupCount*Cache.Head().GroupSz) << ')' << endl
-        << _("Total package structures: ") << Cache.Head().PackageCount << " (" <<
-      SizeToStr(Cache.Head().PackageCount*Cache.Head().PackageSz) << ')' << endl;
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   if (unlikely(Cache == NULL))
+      return false;
+
+   cout << _("Total package names: ") << Cache->Head().GroupCount << " (" <<
+      SizeToStr(Cache->Head().GroupCount*Cache->Head().GroupSz) << ')' << endl
+        << _("Total package structures: ") << Cache->Head().PackageCount << " (" <<
+      SizeToStr(Cache->Head().PackageCount*Cache->Head().PackageSz) << ')' << endl;
 
    int Normal = 0;
    int Virtual = 0;
    int NVirt = 0;
    int DVirt = 0;
    int Missing = 0;
-   pkgCache::PkgIterator I = Cache.PkgBegin();
+   pkgCache::PkgIterator I = Cache->PkgBegin();
    for (;I.end() != true; I++)
    {
       if (I->VersionList != 0 && I->ProvidesList == 0)
@@ -292,33 +303,33 @@
    cout << _("  Mixed virtual packages: ") << NVirt << endl;
    cout << _("  Missing: ") << Missing << endl;
    
-   cout << _("Total distinct versions: ") << Cache.Head().VersionCount << " (" <<
-      SizeToStr(Cache.Head().VersionCount*Cache.Head().VersionSz) << ')' << endl;
-   cout << _("Total distinct descriptions: ") << Cache.Head().DescriptionCount << " (" <<
-      SizeToStr(Cache.Head().DescriptionCount*Cache.Head().DescriptionSz) << ')' << endl;
-   cout << _("Total dependencies: ") << Cache.Head().DependsCount << " (" << 
-      SizeToStr(Cache.Head().DependsCount*Cache.Head().DependencySz) << ')' << endl;
+   cout << _("Total distinct versions: ") << Cache->Head().VersionCount << " (" <<
+      SizeToStr(Cache->Head().VersionCount*Cache->Head().VersionSz) << ')' << endl;
+   cout << _("Total distinct descriptions: ") << Cache->Head().DescriptionCount << " (" <<
+      SizeToStr(Cache->Head().DescriptionCount*Cache->Head().DescriptionSz) << ')' << endl;
+   cout << _("Total dependencies: ") << Cache->Head().DependsCount << " (" << 
+      SizeToStr(Cache->Head().DependsCount*Cache->Head().DependencySz) << ')' << endl;
    
-   cout << _("Total ver/file relations: ") << Cache.Head().VerFileCount << " (" <<
-      SizeToStr(Cache.Head().VerFileCount*Cache.Head().VerFileSz) << ')' << endl;
-   cout << _("Total Desc/File relations: ") << Cache.Head().DescFileCount << " (" <<
-      SizeToStr(Cache.Head().DescFileCount*Cache.Head().DescFileSz) << ')' << endl;
-   cout << _("Total Provides mappings: ") << Cache.Head().ProvidesCount << " (" <<
-      SizeToStr(Cache.Head().ProvidesCount*Cache.Head().ProvidesSz) << ')' << endl;
+   cout << _("Total ver/file relations: ") << Cache->Head().VerFileCount << " (" <<
+      SizeToStr(Cache->Head().VerFileCount*Cache->Head().VerFileSz) << ')' << endl;
+   cout << _("Total Desc/File relations: ") << Cache->Head().DescFileCount << " (" <<
+      SizeToStr(Cache->Head().DescFileCount*Cache->Head().DescFileSz) << ')' << endl;
+   cout << _("Total Provides mappings: ") << Cache->Head().ProvidesCount << " (" <<
+      SizeToStr(Cache->Head().ProvidesCount*Cache->Head().ProvidesSz) << ')' << endl;
    
    // String list stats
    unsigned long Size = 0;
    unsigned long Count = 0;
-   for (pkgCache::StringItem *I = Cache.StringItemP + Cache.Head().StringList;
-        I!= Cache.StringItemP; I = Cache.StringItemP + I->NextItem)
+   for (pkgCache::StringItem *I = Cache->StringItemP + Cache->Head().StringList;
+        I!= Cache->StringItemP; I = Cache->StringItemP + I->NextItem)
    {
       Count++;
-      Size += strlen(Cache.StrP + I->String) + 1;
+      Size += strlen(Cache->StrP + I->String) + 1;
    }
    cout << _("Total globbed strings: ") << Count << " (" << SizeToStr(Size) << ')' << endl;
 
    unsigned long DepVerSize = 0;
-   for (pkgCache::PkgIterator P = Cache.PkgBegin(); P.end() == false; P++)
+   for (pkgCache::PkgIterator P = Cache->PkgBegin(); P.end() == false; P++)
    {
       for (pkgCache::VerIterator V = P.VersionList(); V.end() == false; V++)
       {
@@ -333,15 +344,15 @@
    
    unsigned long Slack = 0;
    for (int I = 0; I != 7; I++)
-      Slack += Cache.Head().Pools[I].ItemSize*Cache.Head().Pools[I].Count;
+      Slack += Cache->Head().Pools[I].ItemSize*Cache->Head().Pools[I].Count;
    cout << _("Total slack space: ") << SizeToStr(Slack) << endl;
    
    unsigned long Total = 0;
-   Total = Slack + Size + Cache.Head().DependsCount*Cache.Head().DependencySz + 
-           Cache.Head().VersionCount*Cache.Head().VersionSz +
-           Cache.Head().PackageCount*Cache.Head().PackageSz + 
-           Cache.Head().VerFileCount*Cache.Head().VerFileSz +
-           Cache.Head().ProvidesCount*Cache.Head().ProvidesSz;
+   Total = Slack + Size + Cache->Head().DependsCount*Cache->Head().DependencySz + 
+           Cache->Head().VersionCount*Cache->Head().VersionSz +
+           Cache->Head().PackageCount*Cache->Head().PackageSz + 
+           Cache->Head().VerFileCount*Cache->Head().VerFileSz +
+           Cache->Head().ProvidesCount*Cache->Head().ProvidesSz;
    cout << _("Total space accounted for: ") << SizeToStr(Total) << endl;
    
    return true;
@@ -352,10 +363,14 @@
 /* This is worthless except fer debugging things */
 bool Dump(CommandLine &Cmd)
 {
-   pkgCache &Cache = *GCache;
-   cout << "Using Versioning System: " << Cache.VS->Label << endl;
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   if (unlikely(Cache == NULL))
+      return false;
+
+   cout << "Using Versioning System: " << Cache->VS->Label << endl;
    
-   for (pkgCache::PkgIterator P = Cache.PkgBegin(); P.end() == false; P++)
+   for (pkgCache::PkgIterator P = Cache->PkgBegin(); P.end() == false; P++)
    {
       cout << "Package: " << P.FullName(true) << endl;
       for (pkgCache::VerIterator V = P.VersionList(); V.end() == false; V++)
@@ -374,7 +389,7 @@
       }      
    }
 
-   for (pkgCache::PkgFileIterator F = Cache.FileBegin(); F.end() == false; F++)
+   for (pkgCache::PkgFileIterator F = Cache->FileBegin(); F.end() == false; F++)
    {
       cout << "File: " << F.FileName() << endl;
       cout << " Type: " << F.IndexType() << endl;
@@ -400,18 +415,17 @@
    make this run really fast, perhaps I went a little overboard.. */
 bool DumpAvail(CommandLine &Cmd)
 {
-   pkgCache &Cache = *GCache;
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   if (unlikely(Cache == NULL || CacheFile.BuildPolicy() == false))
+      return false;
 
-   pkgPolicy Plcy(&Cache);
-   if (ReadPinFile(Plcy) == false || ReadPinDir(Plcy) == false)
-      return false;
-   
-   unsigned long Count = Cache.HeaderP->PackageCount+1;
+   unsigned long Count = Cache->HeaderP->PackageCount+1;
    pkgCache::VerFile **VFList = new pkgCache::VerFile *[Count];
    memset(VFList,0,sizeof(*VFList)*Count);
    
    // Map versions that we want to write out onto the VerList array.
-   for (pkgCache::PkgIterator P = Cache.PkgBegin(); P.end() == false; P++)
+   for (pkgCache::PkgIterator P = Cache->PkgBegin(); P.end() == false; P++)
    {    
       if (P->VersionList == 0)
 	 continue;
@@ -419,7 +433,7 @@
       /* Find the proper version to use. If the policy says there are no
          possible selections we return the installed version, if available..
        	 This prevents dselect from making it obsolete. */
-      pkgCache::VerIterator V = Plcy.GetCandidateVer(P);
+      pkgCache::VerIterator V = CacheFile.GetPolicy()->GetCandidateVer(P);
       if (V.end() == true)
       {
 	 if (P->CurrentVer == 0)
@@ -464,10 +478,10 @@
    LocalitySort(VFList,Count,sizeof(*VFList));
 
    // Iterate over all the package files and write them out.
-   char *Buffer = new char[Cache.HeaderP->MaxVerFileSize+10];
+   char *Buffer = new char[Cache->HeaderP->MaxVerFileSize+10];
    for (pkgCache::VerFile **J = VFList; *J != 0;)
    {
-      pkgCache::PkgFileIterator File(Cache,(*J)->File + Cache.PkgFileP);
+      pkgCache::PkgFileIterator File(*Cache,(*J)->File + Cache->PkgFileP);
       if (File.IsOk() == false)
       {
 	 _error->Error(_("Package file %s is out of sync."),File.FileName());
@@ -486,7 +500,7 @@
       unsigned long Pos = 0;
       for (; *J != 0; J++)
       {
-	 if ((*J)->File + Cache.PkgFileP != File)
+	 if ((*J)->File + Cache->PkgFileP != File)
 	    break;
 	 
 	 const pkgCache::VerFile &VF = **J;
@@ -542,21 +556,18 @@
 /* */
 bool Depends(CommandLine &CmdL)
 {
-   pkgCache &Cache = *GCache;
-   SPtrArray<unsigned> Colours = new unsigned[Cache.Head().PackageCount];
-   memset(Colours,0,sizeof(*Colours)*Cache.Head().PackageCount);
-   
-   for (const char **I = CmdL.FileList + 1; *I != 0; I++)
-   {
-      pkgCache::PkgIterator Pkg = Cache.FindPkg(*I);
-      if (Pkg.end() == true)
-      {
-	 _error->Warning(_("Unable to locate package %s"),*I);
-	 continue;
-      }
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   if (unlikely(Cache == NULL))
+      return false;
+
+   SPtrArray<unsigned> Colours = new unsigned[Cache->Head().PackageCount];
+   memset(Colours,0,sizeof(*Colours)*Cache->Head().PackageCount);
+
+   APT::PackageSet pkgset = APT::PackageSet::FromCommandLine(CacheFile, CmdL.FileList + 1);
+   for (APT::PackageSet::const_iterator Pkg = pkgset.begin(); Pkg != pkgset.end(); ++Pkg)
       Colours[Pkg->ID] = 1;
-   }
-   
+
    bool Recurse = _config->FindB("APT::Cache::RecurseDepends",false);
    bool Installed = _config->FindB("APT::Cache::Installed",false);
    bool Important = _config->FindB("APT::Cache::Important",false);
@@ -564,7 +575,7 @@
    do
    {
       DidSomething = false;
-      for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; Pkg++)
+      for (pkgCache::PkgIterator Pkg = Cache->PkgBegin(); Pkg.end() == false; Pkg++)
       {
 	 if (Colours[Pkg->ID] != 1)
 	    continue;
@@ -611,11 +622,11 @@
 	    
 	    // Display all solutions
 	    SPtrArray<pkgCache::Version *> List = D.AllTargets();
-	    pkgPrioSortList(Cache,List);
+	    pkgPrioSortList(*Cache,List);
 	    for (pkgCache::Version **I = List; *I != 0; I++)
 	    {
-	       pkgCache::VerIterator V(Cache,*I);
-	       if (V != Cache.VerP + V.ParentPkg()->VersionList ||
+	       pkgCache::VerIterator V(*Cache,*I);
+	       if (V != Cache->VerP + V.ParentPkg()->VersionList ||
 		   V->ParentPkg == D->Package)
 		  continue;
 	       cout << "    " << V.ParentPkg().FullName(true) << endl;
@@ -636,28 +647,25 @@
 /* */
 bool RDepends(CommandLine &CmdL)
 {
-   pkgCache &Cache = *GCache;
-   SPtrArray<unsigned> Colours = new unsigned[Cache.Head().PackageCount];
-   memset(Colours,0,sizeof(*Colours)*Cache.Head().PackageCount);
-   
-   for (const char **I = CmdL.FileList + 1; *I != 0; I++)
-   {
-      pkgCache::PkgIterator Pkg = Cache.FindPkg(*I);
-      if (Pkg.end() == true)
-      {
-	 _error->Warning(_("Unable to locate package %s"),*I);
-	 continue;
-      }
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   if (unlikely(Cache == NULL))
+      return false;
+
+   SPtrArray<unsigned> Colours = new unsigned[Cache->Head().PackageCount];
+   memset(Colours,0,sizeof(*Colours)*Cache->Head().PackageCount);
+
+   APT::PackageSet pkgset = APT::PackageSet::FromCommandLine(CacheFile, CmdL.FileList + 1);
+   for (APT::PackageSet::const_iterator Pkg = pkgset.begin(); Pkg != pkgset.end(); ++Pkg)
       Colours[Pkg->ID] = 1;
-   }
-   
+
    bool Recurse = _config->FindB("APT::Cache::RecurseDepends",false);
    bool Installed = _config->FindB("APT::Cache::Installed",false);
    bool DidSomething;
    do
    {
       DidSomething = false;
-      for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; Pkg++)
+      for (pkgCache::PkgIterator Pkg = Cache->PkgBegin(); Pkg.end() == false; Pkg++)
       {
 	 if (Colours[Pkg->ID] != 1)
 	    continue;
@@ -699,11 +707,11 @@
 	    
 	    // Display all solutions
 	    SPtrArray<pkgCache::Version *> List = D.AllTargets();
-	    pkgPrioSortList(Cache,List);
+	    pkgPrioSortList(*Cache,List);
 	    for (pkgCache::Version **I = List; *I != 0; I++)
 	    {
-	       pkgCache::VerIterator V(Cache,*I);
-	       if (V != Cache.VerP + V.ParentPkg()->VersionList ||
+	       pkgCache::VerIterator V(*Cache,*I);
+	       if (V != Cache->VerP + V.ParentPkg()->VersionList ||
 		   V->ParentPkg == D->Package)
 		  continue;
 	       cout << "    " << V.ParentPkg().FullName(true) << endl;
@@ -725,7 +733,11 @@
 
 bool XVcg(CommandLine &CmdL)
 {
-   pkgCache &Cache = *GCache;
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   if (unlikely(Cache == NULL))
+      return false;
+
    bool GivenOnly = _config->FindB("APT::Cache::GivenOnly",false);
    
    /* Normal packages are boxes
@@ -742,21 +754,21 @@
       0 = None */
    enum States {None=0, ToShow, ToShowNR, DoneNR, Done};
    enum TheFlags {ForceNR=(1<<0)};
-   unsigned char *Show = new unsigned char[Cache.Head().PackageCount];
-   unsigned char *Flags = new unsigned char[Cache.Head().PackageCount];
-   unsigned char *ShapeMap = new unsigned char[Cache.Head().PackageCount];
+   unsigned char *Show = new unsigned char[Cache->Head().PackageCount];
+   unsigned char *Flags = new unsigned char[Cache->Head().PackageCount];
+   unsigned char *ShapeMap = new unsigned char[Cache->Head().PackageCount];
    
    // Show everything if no arguments given
    if (CmdL.FileList[1] == 0)
-      for (unsigned long I = 0; I != Cache.Head().PackageCount; I++)
+      for (unsigned long I = 0; I != Cache->Head().PackageCount; I++)
 	 Show[I] = ToShow;
    else
-      for (unsigned long I = 0; I != Cache.Head().PackageCount; I++)
+      for (unsigned long I = 0; I != Cache->Head().PackageCount; I++)
 	 Show[I] = None;
-   memset(Flags,0,sizeof(*Flags)*Cache.Head().PackageCount);
+   memset(Flags,0,sizeof(*Flags)*Cache->Head().PackageCount);
    
    // Map the shapes
-   for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; Pkg++)
+   for (pkgCache::PkgIterator Pkg = Cache->PkgBegin(); Pkg.end() == false; Pkg++)
    {   
       if (Pkg->VersionList == 0)
       {
@@ -775,38 +787,24 @@
 	    ShapeMap[Pkg->ID] = 3;
       }
    }
-   
+
    // Load the list of packages from the command line into the show list
-   for (const char **I = CmdL.FileList + 1; *I != 0; I++)
+   std::list<APT::PackageSet::Modifier> mods;
+   mods.push_back(APT::PackageSet::Modifier(0, ",", APT::PackageSet::Modifier::POSTFIX));
+   mods.push_back(APT::PackageSet::Modifier(1, "^", APT::PackageSet::Modifier::POSTFIX));
+   std::map<unsigned short, APT::PackageSet> pkgsets =
+		APT::PackageSet::GroupedFromCommandLine(CacheFile, CmdL.FileList + 1, mods, 0);
+
+   for (APT::PackageSet::const_iterator Pkg = pkgsets[0].begin();
+	Pkg != pkgsets[0].end(); ++Pkg)
+      Show[Pkg->ID] = ToShow;
+   for (APT::PackageSet::const_iterator Pkg = pkgsets[1].begin();
+	Pkg != pkgsets[1].end(); ++Pkg)
    {
-      // Process per-package flags
-      string P = *I;
-      bool Force = false;
-      if (P.length() > 3)
-      {
-	 if (P.end()[-1] == '^')
-	 {
-	    Force = true;
-	    P.erase(P.end()-1);
-	 }
-	 
-	 if (P.end()[-1] == ',')
-	    P.erase(P.end()-1);
-      }
-      
-      // Locate the package
-      pkgCache::PkgIterator Pkg = Cache.FindPkg(P);
-      if (Pkg.end() == true)
-      {
-	 _error->Warning(_("Unable to locate package %s"),*I);
-	 continue;
-      }
       Show[Pkg->ID] = ToShow;
-      
-      if (Force == true)
-	 Flags[Pkg->ID] |= ForceNR;
+      Flags[Pkg->ID] |= ForceNR;
    }
-   
+
    // Little header
    cout << "graph: { title: \"packages\"" << endl <<
      "xmax: 700 ymax: 700 x: 30 y: 30" << endl <<
@@ -816,7 +814,7 @@
    while (Act == true)
    {
       Act = false;
-      for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; Pkg++)
+      for (pkgCache::PkgIterator Pkg = Cache->PkgBegin(); Pkg.end() == false; Pkg++)
       {
 	 // See we need to show this package
 	 if (Show[Pkg->ID] == None || Show[Pkg->ID] >= DoneNR)
@@ -851,7 +849,7 @@
 	    for (pkgCache::VerIterator I = DPkg.VersionList();
 		      I.end() == false && Hit == false; I++)
 	    {
-	       if (Cache.VS->CheckDep(I.VerStr(),D->CompareOp,D.TargetVer()) == true)
+	       if (Cache->VS->CheckDep(I.VerStr(),D->CompareOp,D.TargetVer()) == true)
 		  Hit = true;
 	    }
 	    
@@ -859,7 +857,7 @@
 	    for (pkgCache::PrvIterator I = DPkg.ProvidesList(); 
 		      I.end() == false && Hit == false; I++)
 	    {
-	       if (Cache.VS->CheckDep(I.ProvideVersion(),D->CompareOp,D.TargetVer()) == false)
+	       if (Cache->VS->CheckDep(I.ProvideVersion(),D->CompareOp,D.TargetVer()) == false)
 		  Hit = true;
 	    }
 	    
@@ -920,7 +918,7 @@
    
    /* Draw the box colours after the fact since we can not tell what colour
       they should be until everything is finished drawing */
-   for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; Pkg++)
+   for (pkgCache::PkgIterator Pkg = Cache->PkgBegin(); Pkg.end() == false; Pkg++)
    {
       if (Show[Pkg->ID] < DoneNR)
 	 continue;
@@ -949,7 +947,11 @@
    http://www.research.att.com/sw/tools/graphviz/ */
 bool Dotty(CommandLine &CmdL)
 {
-   pkgCache &Cache = *GCache;
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   if (unlikely(Cache == NULL))
+      return false;
+
    bool GivenOnly = _config->FindB("APT::Cache::GivenOnly",false);
    
    /* Normal packages are boxes
@@ -966,21 +968,21 @@
       0 = None */
    enum States {None=0, ToShow, ToShowNR, DoneNR, Done};
    enum TheFlags {ForceNR=(1<<0)};
-   unsigned char *Show = new unsigned char[Cache.Head().PackageCount];
-   unsigned char *Flags = new unsigned char[Cache.Head().PackageCount];
-   unsigned char *ShapeMap = new unsigned char[Cache.Head().PackageCount];
+   unsigned char *Show = new unsigned char[Cache->Head().PackageCount];
+   unsigned char *Flags = new unsigned char[Cache->Head().PackageCount];
+   unsigned char *ShapeMap = new unsigned char[Cache->Head().PackageCount];
    
    // Show everything if no arguments given
    if (CmdL.FileList[1] == 0)
-      for (unsigned long I = 0; I != Cache.Head().PackageCount; I++)
+      for (unsigned long I = 0; I != Cache->Head().PackageCount; I++)
 	 Show[I] = ToShow;
    else
-      for (unsigned long I = 0; I != Cache.Head().PackageCount; I++)
+      for (unsigned long I = 0; I != Cache->Head().PackageCount; I++)
 	 Show[I] = None;
-   memset(Flags,0,sizeof(*Flags)*Cache.Head().PackageCount);
+   memset(Flags,0,sizeof(*Flags)*Cache->Head().PackageCount);
    
    // Map the shapes
-   for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; Pkg++)
+   for (pkgCache::PkgIterator Pkg = Cache->PkgBegin(); Pkg.end() == false; Pkg++)
    {   
       if (Pkg->VersionList == 0)
       {
@@ -999,38 +1001,24 @@
 	    ShapeMap[Pkg->ID] = 3;
       }
    }
-   
+
    // Load the list of packages from the command line into the show list
-   for (const char **I = CmdL.FileList + 1; *I != 0; I++)
+   std::list<APT::PackageSet::Modifier> mods;
+   mods.push_back(APT::PackageSet::Modifier(0, ",", APT::PackageSet::Modifier::POSTFIX));
+   mods.push_back(APT::PackageSet::Modifier(1, "^", APT::PackageSet::Modifier::POSTFIX));
+   std::map<unsigned short, APT::PackageSet> pkgsets =
+		APT::PackageSet::GroupedFromCommandLine(CacheFile, CmdL.FileList + 1, mods, 0);
+
+   for (APT::PackageSet::const_iterator Pkg = pkgsets[0].begin();
+	Pkg != pkgsets[0].end(); ++Pkg)
+      Show[Pkg->ID] = ToShow;
+   for (APT::PackageSet::const_iterator Pkg = pkgsets[1].begin();
+	Pkg != pkgsets[1].end(); ++Pkg)
    {
-      // Process per-package flags
-      string P = *I;
-      bool Force = false;
-      if (P.length() > 3)
-      {
-	 if (P.end()[-1] == '^')
-	 {
-	    Force = true;
-	    P.erase(P.end()-1);
-	 }
-	 
-	 if (P.end()[-1] == ',')
-	    P.erase(P.end()-1);
-      }
-      
-      // Locate the package
-      pkgCache::PkgIterator Pkg = Cache.FindPkg(P);
-      if (Pkg.end() == true)
-      {
-	 _error->Warning(_("Unable to locate package %s"),*I);
-	 continue;
-      }
       Show[Pkg->ID] = ToShow;
-      
-      if (Force == true)
-	 Flags[Pkg->ID] |= ForceNR;
+      Flags[Pkg->ID] |= ForceNR;
    }
-   
+
    // Little header
    printf("digraph packages {\n");
    printf("concentrate=true;\n");
@@ -1040,7 +1028,7 @@
    while (Act == true)
    {
       Act = false;
-      for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; Pkg++)
+      for (pkgCache::PkgIterator Pkg = Cache->PkgBegin(); Pkg.end() == false; Pkg++)
       {
 	 // See we need to show this package
 	 if (Show[Pkg->ID] == None || Show[Pkg->ID] >= DoneNR)
@@ -1073,7 +1061,7 @@
 	    for (pkgCache::VerIterator I = DPkg.VersionList();
 		      I.end() == false && Hit == false; I++)
 	    {
-	       if (Cache.VS->CheckDep(I.VerStr(),D->CompareOp,D.TargetVer()) == true)
+	       if (Cache->VS->CheckDep(I.VerStr(),D->CompareOp,D.TargetVer()) == true)
 		  Hit = true;
 	    }
 	    
@@ -1081,7 +1069,7 @@
 	    for (pkgCache::PrvIterator I = DPkg.ProvidesList(); 
 		      I.end() == false && Hit == false; I++)
 	    {
-	       if (Cache.VS->CheckDep(I.ProvideVersion(),D->CompareOp,D.TargetVer()) == false)
+	       if (Cache->VS->CheckDep(I.ProvideVersion(),D->CompareOp,D.TargetVer()) == false)
 		  Hit = true;
 	    }
 	    
@@ -1135,7 +1123,7 @@
    
    /* Draw the box colours after the fact since we can not tell what colour
       they should be until everything is finished drawing */
-   for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; Pkg++)
+   for (pkgCache::PkgIterator Pkg = Cache->PkgBegin(); Pkg.end() == false; Pkg++)
    {
       if (Show[Pkg->ID] < DoneNR)
 	 continue;
@@ -1209,8 +1197,12 @@
 // ---------------------------------------------------------------------
 /* This displays the package record from the proper package index file. 
    It is not used by DumpAvail for performance reasons. */
-bool DisplayRecord(pkgCache::VerIterator V)
+bool DisplayRecord(pkgCacheFile &CacheFile, pkgCache::VerIterator V)
 {
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   if (unlikely(Cache == NULL))
+      return false;
+
    // Find an appropriate file
    pkgCache::VerFileIterator Vf = V.FileList();
    for (; Vf.end() == false; Vf++)
@@ -1223,13 +1215,13 @@
    pkgCache::PkgFileIterator I = Vf.File();
    if (I.IsOk() == false)
       return _error->Error(_("Package file %s is out of sync."),I.FileName());
-   
-   FileFd PkgF(I.FileName(),FileFd::ReadOnly);
-   if (_error->PendingError() == true)
+
+   FileFd PkgF;
+   if (PkgF.Open(I.FileName(), FileFd::ReadOnly) == false)
       return false;
-   
+
    // Read the record
-   unsigned char *Buffer = new unsigned char[GCache->HeaderP->MaxVerFileSize+1];
+   unsigned char *Buffer = new unsigned char[Cache->HeaderP->MaxVerFileSize+1];
    Buffer[V.FileList()->Size] = '\n';
    if (PkgF.Seek(V.FileList()->Offset) == false ||
        PkgF.Read(Buffer,V.FileList()->Size) == false)
@@ -1249,7 +1241,7 @@
    }
 
    // Show the right description
-   pkgRecords Recs(*GCache);
+   pkgRecords Recs(*Cache);
    pkgCache::DescIterator Desc = V.TranslatedDescription();
    pkgRecords::Parser &P = Recs.Lookup(Desc.FileList());
    cout << "Description" << ( (strcmp(Desc.LanguageCode(),"") != 0) ? "-" : "" ) << Desc.LanguageCode() << ": " << P.LongDesc();
@@ -1289,16 +1281,19 @@
 /* This searches the package names and package descriptions for a pattern */
 bool Search(CommandLine &CmdL)
 {
-   pkgCache &Cache = *GCache;
-   bool ShowFull = _config->FindB("APT::Cache::ShowFull",false);
-   bool NamesOnly = _config->FindB("APT::Cache::NamesOnly",false);
-   unsigned NumPatterns = CmdL.FileSize() -1;
-   
-   pkgDepCache::Policy Plcy;
-   
+   bool const ShowFull = _config->FindB("APT::Cache::ShowFull",false);
+   bool const NamesOnly = _config->FindB("APT::Cache::NamesOnly",false);
+   unsigned int const NumPatterns = CmdL.FileSize() -1;
+   
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   pkgDepCache::Policy *Plcy = CacheFile.GetPolicy();
+   if (unlikely(Cache == NULL || Plcy == NULL))
+      return false;
+
    // Make sure there is at least one argument
    if (NumPatterns < 1)
-      return _error->Error(_("You must give exactly one pattern"));
+      return _error->Error(_("You must give at least one search pattern"));
    
    // Compile the regex pattern
    regex_t *Patterns = new regex_t[NumPatterns];
@@ -1314,8 +1309,6 @@
       }      
    }
    
-   // Create the text record parser
-   pkgRecords Recs(Cache);
    if (_error->PendingError() == true)
    {
       for (unsigned I = 0; I != NumPatterns; I++)
@@ -1323,70 +1316,75 @@
       return false;
    }
    
-   ExDescFile *DFList = new ExDescFile[Cache.HeaderP->PackageCount+1];
-   memset(DFList,0,sizeof(*DFList)*Cache.HeaderP->PackageCount+1);
+   ExDescFile *DFList = new ExDescFile[Cache->HeaderP->GroupCount+1];
+   memset(DFList,0,sizeof(*DFList)*Cache->HeaderP->GroupCount+1);
 
    // Map versions that we want to write out onto the VerList array.
-   for (pkgCache::PkgIterator P = Cache.PkgBegin(); P.end() == false; P++)
+   for (pkgCache::GrpIterator G = Cache->GrpBegin(); G.end() == false; ++G)
    {
-      DFList[P->ID].NameMatch = NumPatterns != 0;
+      if (DFList[G->ID].NameMatch == true)
+	 continue;
+
+      DFList[G->ID].NameMatch = true;
       for (unsigned I = 0; I != NumPatterns; I++)
       {
-	 if (regexec(&Patterns[I],P.Name(),0,0,0) == 0)
-	    DFList[P->ID].NameMatch &= true;
-	 else
-	    DFList[P->ID].NameMatch = false;
+	 if (regexec(&Patterns[I],G.Name(),0,0,0) == 0)
+	    continue;
+	 DFList[G->ID].NameMatch = false;
+	 break;
       }
         
       // Doing names only, drop any that dont match..
-      if (NamesOnly == true && DFList[P->ID].NameMatch == false)
+      if (NamesOnly == true && DFList[G->ID].NameMatch == false)
 	 continue;
 	 
-      // Find the proper version to use. 
-      pkgCache::VerIterator V = Plcy.GetCandidateVer(P);
+      // Find the proper version to use
+      pkgCache::PkgIterator P = G.FindPreferredPkg();
+      if (P.end() == true)
+	 continue;
+      pkgCache::VerIterator V = Plcy->GetCandidateVer(P);
       if (V.end() == false)
-	 DFList[P->ID].Df = V.DescriptionList().FileList();
-   }
-      
-   // Include all the packages that provide matching names too
-   for (pkgCache::PkgIterator P = Cache.PkgBegin(); P.end() == false; P++)
-   {
-      if (DFList[P->ID].NameMatch == false)
+	 DFList[G->ID].Df = V.DescriptionList().FileList();
+
+      if (DFList[G->ID].NameMatch == false)
 	 continue;
 
+      // Include all the packages that provide matching names too
       for (pkgCache::PrvIterator Prv = P.ProvidesList() ; Prv.end() == false; Prv++)
       {
-	 pkgCache::VerIterator V = Plcy.GetCandidateVer(Prv.OwnerPkg());
-	 if (V.end() == false)
-	 {
-	    DFList[Prv.OwnerPkg()->ID].Df = V.DescriptionList().FileList();
-	    DFList[Prv.OwnerPkg()->ID].NameMatch = true;
-	 }
+	 pkgCache::VerIterator V = Plcy->GetCandidateVer(Prv.OwnerPkg());
+	 if (V.end() == true)
+	    continue;
+
+	 unsigned long id = Prv.OwnerPkg().Group()->ID;
+	 DFList[id].Df = V.DescriptionList().FileList();
+	 DFList[id].NameMatch = true;
       }
    }
    
-   LocalitySort(&DFList->Df,Cache.HeaderP->PackageCount,sizeof(*DFList));
+   LocalitySort(&DFList->Df,Cache->HeaderP->GroupCount,sizeof(*DFList));
 
+   // Create the text record parser
+   pkgRecords Recs(*Cache);
    // Iterate over all the version records and check them
    for (ExDescFile *J = DFList; J->Df != 0; J++)
    {
-      pkgRecords::Parser &P = Recs.Lookup(pkgCache::DescFileIterator(Cache,J->Df));
+      pkgRecords::Parser &P = Recs.Lookup(pkgCache::DescFileIterator(*Cache,J->Df));
 
-      bool Match = true;
-      if (J->NameMatch == false)
+      if (J->NameMatch == false && NamesOnly == false)
       {
-	 string LongDesc = P.LongDesc();
-	 Match = NumPatterns != 0;
+	 string const LongDesc = P.LongDesc();
+	 J->NameMatch = true;
 	 for (unsigned I = 0; I != NumPatterns; I++)
 	 {
 	    if (regexec(&Patterns[I],LongDesc.c_str(),0,0,0) == 0)
-	       Match &= true;
-	    else
-	       Match = false;
+	       continue;
+	    J->NameMatch = false;
+	    break;
 	 }
       }
       
-      if (Match == true)
+      if (J->NameMatch == true)
       {
 	 if (ShowFull == true)
 	 {
@@ -1413,15 +1411,17 @@
 /* show automatically installed packages (sorted) */
 bool ShowAuto(CommandLine &CmdL)
 {
-   OpProgress op;
-   pkgDepCache DepCache(GCache);
-   DepCache.Init(&op);
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   pkgDepCache *DepCache = CacheFile.GetDepCache();
+   if (unlikely(Cache == NULL || DepCache == NULL))
+      return false;
 
    std::vector<string> packages;
-   packages.reserve(GCache->HeaderP->PackageCount / 3);
+   packages.reserve(Cache->HeaderP->PackageCount / 3);
    
-   for (pkgCache::PkgIterator P = GCache->PkgBegin(); P.end() == false; P++)
-      if (DepCache[P].Flags & pkgCache::Flag::Auto)
+   for (pkgCache::PkgIterator P = Cache->PkgBegin(); P.end() == false; P++)
+      if ((*DepCache)[P].Flags & pkgCache::Flag::Auto)
          packages.push_back(P.Name());
 
     std::sort(packages.begin(), packages.end());
@@ -1436,48 +1436,16 @@
 // ---------------------------------------------------------------------
 /* */
 bool ShowPackage(CommandLine &CmdL)
-{   
-   pkgCache &Cache = *GCache;
-   pkgDepCache::Policy Plcy;
-
-   unsigned found = 0;
-   
-   for (const char **I = CmdL.FileList + 1; *I != 0; I++)
-   {
-      // FIXME: Handle the case in which pkgname name:arch is not found
-      pkgCache::PkgIterator Pkg = Cache.FindPkg(*I);
-      if (Pkg.end() == true)
-      {
-	 Pkg = Cache.FindPkg(*I, "any");
-	 if (Pkg.end() == true) {
-		_error->Warning(_("Unable to locate package %s"),*I);
-		continue;
-	 }
-      }
-
-      ++found;
-
-      // Find the proper version to use.
-      if (_config->FindB("APT::Cache::AllVersions","true") == true)
-      {
-	 pkgCache::VerIterator V;
-	 for (V = Pkg.VersionList(); V.end() == false; V++)
-	 {
-	    if (DisplayRecord(V) == false)
-	       return false;
-	 }
-      }
-      else
-      {
-	 pkgCache::VerIterator V = Plcy.GetCandidateVer(Pkg);
-	 if (V.end() == true || V.FileList().end() == true)
-	    continue;
-	 if (DisplayRecord(V) == false)
-	    return false;
-      }      
-   }
-
-   if (found > 0)
+{
+   pkgCacheFile CacheFile;
+   APT::VersionSet::Version const select = _config->FindB("APT::Cache::AllVersions", true) ?
+			APT::VersionSet::ALL : APT::VersionSet::CANDIDATE;
+   APT::VersionSet const verset = APT::VersionSet::FromCommandLine(CacheFile, CmdL.FileList + 1, select);
+   for (APT::VersionSet::const_iterator Ver = verset.begin(); Ver != verset.end(); ++Ver)
+      if (DisplayRecord(CacheFile, Ver) == false)
+	 return false;
+
+   if (verset.empty() == false)
         return true;
    return _error->Error(_("No packages found"));
 }
@@ -1487,8 +1455,10 @@
 /* This does a prefix match on the first argument */
 bool ShowPkgNames(CommandLine &CmdL)
 {
-   pkgCache &Cache = *GCache;
-   pkgCache::GrpIterator I = Cache.GrpBegin();
+   pkgCacheFile CacheFile;
+   if (unlikely(CacheFile.BuildCaches(NULL, false) == false))
+      return false;
+   pkgCache::GrpIterator I = CacheFile.GetPkgCache()->GrpBegin();
    bool const All = _config->FindB("APT::Cache::AllNames","false");
 
    if (CmdL.FileList[1] != 0)
@@ -1524,11 +1494,13 @@
 /* */
 bool ShowSrcPackage(CommandLine &CmdL)
 {
-   pkgSourceList List;
-   List.ReadMainList();
-   
+   pkgCacheFile CacheFile;
+   pkgSourceList *List = CacheFile.GetSourceList();
+   if (unlikely(List == NULL))
+      return false;
+
    // Create the text record parsers
-   pkgSrcRecords SrcRecs(List);
+   pkgSrcRecords SrcRecs(*List);
    if (_error->PendingError() == true)
       return false;
 
@@ -1559,19 +1531,24 @@
 /* */
 bool Policy(CommandLine &CmdL)
 {
-   if (SrcList == 0)
-      return _error->Error("Generate must be enabled for this function");
-   
-   pkgCache &Cache = *GCache;
-   pkgPolicy Plcy(&Cache);
-   if (ReadPinFile(Plcy) == false || ReadPinDir(Plcy) == false)
+   pkgCacheFile CacheFile;
+   pkgCache *Cache = CacheFile.GetPkgCache();
+   pkgPolicy *Plcy = CacheFile.GetPolicy();
+   pkgSourceList *SrcList = CacheFile.GetSourceList();
+   if (unlikely(Cache == NULL || Plcy == NULL || SrcList == NULL))
       return false;
-   
+
+   /* Should the MultiArchKiller be run to see which pseudo packages for an
+      arch all package are currently installed? Activating it gives a speed
+      penality for no real gain beside enhanced debugging, so in general no. */
+   if (_config->FindB("APT::Cache::Policy::DepCache", false) == true)
+      CacheFile.GetDepCache();
+
    // Print out all of the package files
    if (CmdL.FileList[1] == 0)
    {
       cout << _("Package files:") << endl;   
-      for (pkgCache::PkgFileIterator F = Cache.FileBegin(); F.end() == false; F++)
+      for (pkgCache::PkgFileIterator F = Cache->FileBegin(); F.end() == false; F++)
       {
 	 // Locate the associated index files so we can derive a description
 	 pkgIndexFile *Indx;
@@ -1580,7 +1557,7 @@
 	    return _error->Error(_("Cache is out of sync, can't x-ref a package file"));
 	 
 	 printf("%4i %s\n",
-		Plcy.GetPriority(F),Indx->Describe(true).c_str());
+		Plcy->GetPriority(F),Indx->Describe(true).c_str());
 	 
 	 // Print the reference information for the package
 	 string Str = F.RelStr();
@@ -1592,16 +1569,16 @@
       
       // Show any packages have explicit pins
       cout << _("Pinned packages:") << endl;
-      pkgCache::PkgIterator I = Cache.PkgBegin();
+      pkgCache::PkgIterator I = Cache->PkgBegin();
       for (;I.end() != true; I++)
       {
-	 if (Plcy.GetPriority(I) == 0)
+	 if (Plcy->GetPriority(I) == 0)
 	    continue;
 
 	 // Print the package name and the version we are forcing to
 	 cout << "     " << I.FullName(true) << " -> ";
 	 
-	 pkgCache::VerIterator V = Plcy.GetMatch(I);
+	 pkgCache::VerIterator V = Plcy->GetMatch(I);
 	 if (V.end() == true)
 	    cout << _("(not found)") << endl;
 	 else
@@ -1622,17 +1599,12 @@
 		(InstalledLessCandidate > 0 ? (InstalledLessCandidate) : 0) - 1;
 
    // Print out detailed information for each package
-   for (const char **I = CmdL.FileList + 1; *I != 0; I++)
+   APT::PackageSet pkgset = APT::PackageSet::FromCommandLine(CacheFile, CmdL.FileList + 1);
+   for (APT::PackageSet::const_iterator I = pkgset.begin(); I != pkgset.end(); ++I)
    {
-      pkgCache::GrpIterator Grp = Cache.FindGrp(*I);
-      pkgCache::PkgIterator Pkg = Grp.FindPkg("any");
-      if (Pkg.end() == true)
-      {
-	 _error->Warning(_("Unable to locate package %s"),*I);
-	 continue;
-      }
+      pkgCache::PkgIterator Pkg = I.Group().FindPkg("any");
 
-      for (; Pkg.end() != true; Pkg = Grp.NextPkg(Pkg)) {
+      for (; Pkg.end() != true; Pkg = I.Group().NextPkg(Pkg)) {
       if (strcmp(Pkg.Arch(),"all") == 0)
 	 continue;
 
@@ -1647,17 +1619,17 @@
       
       // Candidate Version 
       cout << msgCandidate << OutputInDepth(deepCandidate, " ");
-      pkgCache::VerIterator V = Plcy.GetCandidateVer(Pkg);
+      pkgCache::VerIterator V = Plcy->GetCandidateVer(Pkg);
       if (V.end() == true)
 	 cout << _("(none)") << endl;
       else
 	 cout << V.VerStr() << endl;
 
       // Pinned version
-      if (Plcy.GetPriority(Pkg) != 0)
+      if (Plcy->GetPriority(Pkg) != 0)
       {
 	 cout << _("  Package pin: ");
-	 V = Plcy.GetMatch(Pkg);
+	 V = Plcy->GetMatch(Pkg);
 	 if (V.end() == true)
 	    cout << _("(not found)") << endl;
 	 else
@@ -1672,7 +1644,7 @@
 	    cout << " *** " << V.VerStr();
 	 else
 	    cout << "     " << V.VerStr();
-	 cout << " " << Plcy.GetPriority(Pkg) << endl;
+	 cout << " " << Plcy->GetPriority(Pkg) << endl;
 	 for (pkgCache::VerFileIterator VF = V.FileList(); VF.end() == false; VF++)
 	 {
 	    // Locate the associated index files so we can derive a description
@@ -1680,7 +1652,7 @@
 	    if (SrcList->FindIndex(VF.File(),Indx) == false &&
 		_system->FindIndex(VF.File(),Indx) == false)
 	       return _error->Error(_("Cache is out of sync, can't x-ref a package file"));
-	    printf("       %4i %s\n",Plcy.GetPriority(VF.File()),
+	    printf("       %4i %s\n",Plcy->GetPriority(VF.File()),
 		   Indx->Describe(true).c_str());
 	 }
       }
@@ -1695,12 +1667,11 @@
 /* */
 bool Madison(CommandLine &CmdL)
 {
+   pkgCacheFile CacheFile;
+   pkgSourceList *SrcList = CacheFile.GetSourceList();
+
    if (SrcList == 0)
-      return _error->Error("Generate must be enabled for this function");
-
-   SrcList->ReadMainList();
-
-   pkgCache &Cache = *GCache;
+      return false;
 
    // Create the src text record parsers and ignore errors about missing
    // deb-src lines that are generated from pkgSrcRecords::pkgSrcRecords
@@ -1708,10 +1679,9 @@
    if (_error->PendingError() == true)
       _error->Discard();
 
-   for (const char **I = CmdL.FileList + 1; *I != 0; I++)
+   APT::PackageSet pkgset = APT::PackageSet::FromCommandLine(CacheFile, CmdL.FileList + 1);
+   for (APT::PackageSet::const_iterator Pkg = pkgset.begin(); Pkg != pkgset.end(); ++Pkg)
    {
-      pkgCache::PkgIterator Pkg = Cache.FindPkg(*I);
-
       if (Pkg.end() == false)
       {
          for (pkgCache::VerIterator V = Pkg.VersionList(); V.end() == false; V++)
@@ -1746,7 +1716,7 @@
       
       SrcRecs.Restart();
       pkgSrcRecords::Parser *SrcParser;
-      while ((SrcParser = SrcRecs.Find(*I,false)) != 0)
+      while ((SrcParser = SrcRecs.Find(Pkg.Name(),false)) != 0)
       {
          // Maybe support Release info here too eventually
          cout << setw(10) << SrcParser->Package() << " | "
@@ -1764,11 +1734,9 @@
 bool GenCaches(CommandLine &Cmd)
 {
    OpTextProgress Progress(*_config);
-   
-   pkgSourceList List;
-   if (List.ReadMainList() == false)
-      return false;   
-   return pkgMakeStatusCache(List,Progress);
+
+   pkgCacheFile CacheFile;
+   return CacheFile.BuildCaches(&Progress, true);
 }
 									/*}}}*/
 // ShowHelp - Show a help screen					/*{{{*/
@@ -1846,6 +1814,8 @@
       {'n',"names-only","APT::Cache::NamesOnly",0},
       {0,"all-names","APT::Cache::AllNames",0},
       {0,"recurse","APT::Cache::RecurseDepends",0},
+      {'t',"target-release","APT::Default-Release",CommandLine::HasArg},
+      {'t',"default-release","APT::Default-Release",CommandLine::HasArg},
       {'c',"config-file",0,CommandLine::ConfigFile},
       {'o',"option",0,CommandLine::ArbItem},
       {0,"installed","APT::Cache::Installed",0},
@@ -1900,35 +1870,10 @@
    if (isatty(STDOUT_FILENO) && _config->FindI("quiet",0) < 1)
       _config->Set("quiet","1");
 
+//       if (_config->FindB("APT::Cache::Generate",true) == false)
    if (CmdL.DispatchArg(CmdsA,false) == false && _error->PendingError() == false)
-   { 
-      MMap *Map = 0;
-      if (_config->FindB("APT::Cache::Generate",true) == false)
-      {
-	 Map = new MMap(*new FileFd(_config->FindFile("Dir::Cache::pkgcache"),
-				    FileFd::ReadOnly),MMap::Public|MMap::ReadOnly);
-      }
-      else
-      {
-	 // Open the cache file
-	 SrcList = new pkgSourceList;
-	 SrcList->ReadMainList();
+      CmdL.DispatchArg(CmdsB);
 
-	 // Generate it and map it
-	 OpProgress Prog;
-	 pkgMakeStatusCache(*SrcList,Prog,&Map,true);
-      }
-      
-      if (_error->PendingError() == false)
-      {
-	 pkgCache Cache(Map);   
-	 GCache = &Cache;
-	 if (_error->PendingError() == false)
-	    CmdL.DispatchArg(CmdsB);
-      }
-      delete Map;
-   }
-   
    // Print any errors or warnings found during parsing
    if (_error->empty() == false)
    {

=== modified file 'cmdline/apt-cdrom.cc'
--- cmdline/apt-cdrom.cc	2010-02-18 22:07:23 +0000
+++ cmdline/apt-cdrom.cc	2010-06-10 14:02:22 +0000
@@ -147,7 +147,7 @@
    pkgCdrom cdrom;
    bool res = true;
 
-   bool AutoDetect = _config->FindB("Acquire::cdrom::AutoDetect");
+   bool AutoDetect = _config->FindB("Acquire::cdrom::AutoDetect", true);
    unsigned int count = 0;
    
    if (AutoDetect && UdevCdroms.Dlopen())

=== modified file 'cmdline/apt-extracttemplates.cc'
--- cmdline/apt-extracttemplates.cc	2010-02-18 22:07:23 +0000
+++ cmdline/apt-extracttemplates.cc	2010-06-10 14:02:22 +0000
@@ -296,8 +296,7 @@
 	MMap *Map = 0;
 	pkgSourceList List;
 	List.ReadMainList();
-	OpProgress Prog;
-	pkgMakeStatusCache(List,Prog,&Map,true);
+	pkgCacheGenerator::MakeStatusCache(List,NULL,&Map,true);
 	if (Map == 0)
 	   return false;
 	DebFile::Cache = new pkgCache(Map);

=== modified file 'cmdline/apt-get.cc'
--- cmdline/apt-get.cc	2010-05-25 16:01:42 +0000
+++ cmdline/apt-get.cc	2010-06-10 14:02:22 +0000
@@ -40,7 +40,8 @@
 #include <apt-pkg/sptr.h>
 #include <apt-pkg/md5.h>
 #include <apt-pkg/versionmatch.h>
-    
+#include <apt-pkg/cacheset.h>
+
 #include <config.h>
 #include <apti18n.h>
 
@@ -90,14 +91,14 @@
    bool BuildCaches(bool WithLock = true)
    {
       OpTextProgress Prog(*_config);
-      if (pkgCacheFile::BuildCaches(Prog,WithLock) == false)
+      if (pkgCacheFile::BuildCaches(&Prog,WithLock) == false)
 	 return false;
       return true;
    }
    bool Open(bool WithLock = true) 
    {
       OpTextProgress Prog(*_config);
-      if (pkgCacheFile::Open(Prog,WithLock) == false)
+      if (pkgCacheFile::Open(&Prog,WithLock) == false)
 	 return false;
       Sort();
       
@@ -837,9 +838,9 @@
       return false;
 
    // Display statistics
-   double FetchBytes = Fetcher.FetchNeeded();
-   double FetchPBytes = Fetcher.PartialPresent();
-   double DebBytes = Fetcher.TotalNeeded();
+   unsigned long long FetchBytes = Fetcher.FetchNeeded();
+   unsigned long long FetchPBytes = Fetcher.PartialPresent();
+   unsigned long long DebBytes = Fetcher.TotalNeeded();
    if (DebBytes != Cache->DebSize())
    {
       c0out << DebBytes << ',' << Cache->DebSize() << endl;
@@ -1780,51 +1781,24 @@
 	 Packages++;
 	 if (Pkg.end() == true)
 	 {
-	    // Check if the name is a regex
-	    const char *I;
-	    for (I = S; *I != 0; I++)
-	       if (*I == '?' || *I == '*' || *I == '|' ||
-		   *I == '[' || *I == '^' || *I == '$')
-		  break;
-	    if (*I == 0)
+	    APT::PackageSet pkgset = APT::PackageSet::FromRegEx(Cache, S, c1out);
+	    if (pkgset.empty() == true)
 	       return _error->Error(_("Couldn't find package %s"),S);
 
 	    // Regexs must always be confirmed
 	    ExpectedInst += 1000;
-	 
-	    // Compile the regex pattern
-	    regex_t Pattern;
-	    int Res;
-	    if ((Res = regcomp(&Pattern,S,REG_EXTENDED | REG_ICASE |
-			       REG_NOSUB)) != 0)
-	    {
-	       char Error[300];	    
-	       regerror(Res,&Pattern,Error,sizeof(Error));
-	       return _error->Error(_("Regex compilation error - %s"),Error);
-	    }
-	 
-	    // Run over the matches
+
 	    bool Hit = false;
-	    for (pkgCache::GrpIterator Grp = Cache->GrpBegin(); Grp.end() == false; ++Grp)
+	    for (APT::PackageSet::const_iterator Pkg = pkgset.begin(); Pkg != pkgset.end(); ++Pkg)
 	    {
-	       if (regexec(&Pattern,Grp.Name(),0,0,0) != 0)
-		  continue;
-	       Pkg = Grp.FindPkg("native");
-	       if (unlikely(Pkg.end() == true))
-		  continue;
-
-	       ioprintf(c1out,_("Note, selecting %s for regex '%s'\n"),
-			Pkg.Name(),S);
-	    
 	       if (VerTag != 0)
 		  if (TryToChangeVer(Pkg,Cache,VerTag,VerIsRel) == false)
 		     return false;
-	    
+
 	       Hit |= TryToInstall(Pkg,Cache,Fix,Remove,BrokenFix,
 				   ExpectedInst,false);
 	    }
-	    regfree(&Pattern);
-	 
+
 	    if (Hit == false)
 	       return _error->Error(_("Couldn't find package %s"),S);
 	 }
@@ -2306,6 +2280,33 @@
       if (Last == 0)
 	 return _error->Error(_("Unable to find a source package for %s"),Src.c_str());
       
+      string srec = Last->AsStr();
+      string::size_type pos = srec.find("\nVcs-");
+      while (pos != string::npos)
+      {
+	 pos += strlen("\nVcs-");
+	 string vcs = srec.substr(pos,srec.find(":",pos)-pos);
+	 if(vcs == "Browser") 
+	 {
+	    pos = srec.find("\nVcs-", pos);
+	    continue;
+	 }
+	 pos += vcs.length()+2;
+	 string::size_type epos = srec.find("\n", pos);
+	 string uri = srec.substr(pos,epos-pos).c_str();
+	 ioprintf(c1out, _("NOTICE: '%s' packaging is maintained in "
+			   "the '%s' version control system at:\n"
+			   "%s\n"),
+		  Src.c_str(), vcs.c_str(), uri.c_str());
+	 if(vcs == "Bzr") 
+	    ioprintf(c1out,_("Please use:\n"
+			     "bzr get %s\n"
+			     "to retrieve the latest (possibly unreleased) "
+			     "updates to the package.\n"),
+		     uri.c_str());
+	 break;
+      }
+
       // Back track
       vector<pkgSrcRecords::File> Lst;
       if (Last->Files(Lst) == false)
@@ -2362,9 +2363,9 @@
    }
    
    // Display statistics
-   double FetchBytes = Fetcher.FetchNeeded();
-   double FetchPBytes = Fetcher.PartialPresent();
-   double DebBytes = Fetcher.TotalNeeded();
+   unsigned long long FetchBytes = Fetcher.FetchNeeded();
+   unsigned long long FetchPBytes = Fetcher.PartialPresent();
+   unsigned long long DebBytes = Fetcher.TotalNeeded();
 
    // Check for enough free space
    struct statvfs Buf;
@@ -2968,7 +2969,6 @@
                                    {"remove",&DoInstall},
                                    {"purge",&DoInstall},
 				   {"autoremove",&DoInstall},
-				   {"purge",&DoInstall},
 				   {"markauto",&DoMarkAuto},
 				   {"unmarkauto",&DoMarkAuto},
                                    {"dist-upgrade",&DoDistUpgrade},

=== added file 'cmdline/apt-report-mirror-failure'
--- cmdline/apt-report-mirror-failure	1970-01-01 00:00:00 +0000
+++ cmdline/apt-report-mirror-failure	2010-06-10 14:02:22 +0000
@@ -0,0 +1,29 @@
+#!/usr/bin/python
+#
+# This is a stub that is meant to support failure reporting of 
+# mirrors to a central database
+#
+# its currently not used
+
+import sys
+import urllib
+import apt_pkg
+
+apt_pkg.init()
+url = apt_pkg.Config.find("Acquire::Mirror::ReportFailures", "")
+                          #"http://people.ubuntu.com:9000/mirror-failure")
+                          #"http://localhost:9000/mirror-failure")
+if not url:
+    sys.exit(0)
+
+print "Reporting mirror failure to '%s'" % url
+
+data = {}
+data['mirror'] = sys.argv[1]
+data['failurl'] = sys.argv[2]
+data['error'] = sys.argv[3]
+f = urllib.urlopen(url, urllib.urlencode(data))
+f.read()
+f.close()
+
+

=== modified file 'cmdline/makefile'
--- cmdline/makefile	2008-11-05 13:14:56 +0000
+++ cmdline/makefile	2010-06-10 14:02:22 +0000
@@ -58,3 +58,9 @@
 TO=$(BIN)
 TARGET=program
 include $(COPY_H)
+
+# The apt-report-mirror-failure program
+#SOURCE=apt-report-mirror-failure
+#TO=$(BIN)
+#TARGET=program
+#include $(COPY_H)

=== modified file 'configure'
--- configure	2010-05-25 16:01:42 +0000
+++ configure	2010-06-10 14:02:22 +0000
@@ -2449,7 +2449,7 @@
 
 
 cat >>confdefs.h <<_ACEOF
-#define VERSION "0.7.26~exp5"
+#define VERSION "0.7.26~exp6"
 _ACEOF
 
 PACKAGE="apt"

=== modified file 'configure.in'
--- configure.in	2010-05-25 16:01:42 +0000
+++ configure.in	2010-06-10 14:02:22 +0000
@@ -18,7 +18,7 @@
 AC_CONFIG_HEADER(include/config.h:buildlib/config.h.in include/apti18n.h:buildlib/apti18n.h.in)
 
 dnl -- SET THIS TO THE RELEASE VERSION --
-AC_DEFINE_UNQUOTED(VERSION,"0.7.26~exp5")
+AC_DEFINE_UNQUOTED(VERSION,"0.7.26~exp6")
 PACKAGE="apt"
 AC_DEFINE_UNQUOTED(PACKAGE,"$PACKAGE")
 AC_SUBST(PACKAGE)

=== modified file 'debian/apt.conf.autoremove'
--- debian/apt.conf.autoremove	2009-12-15 09:21:55 +0000
+++ debian/apt.conf.autoremove	2010-06-10 14:02:22 +0000
@@ -1,9 +1,24 @@
 APT
 {
-  NeverAutoRemove  
-  { 
-	"^linux-image.*";  
+  NeverAutoRemove
+  {
+	"^firmware-linux.*";
+	"^linux-firmware$";
+	"^linux-image.*";
+	"^kfreebsd-image.*";
 	"^linux-restricted-modules.*";
-	"^kfreebsd-image.*";  
+	"^linux-ubuntu-modules-.*";
+  };
+
+  Never-MarkAuto-Sections
+  {
+	"metapackages";
+	"restricted/metapackages";
+	"universe/metapackages";
+	"multiverse/metapackages";
+	"oldlibs";
+	"restricted/oldlibs";
+	"universe/oldlibs";
+	"multiverse/oldlibs";
   };
 };

=== modified file 'debian/apt.dirs'
--- debian/apt.dirs	2010-01-09 21:52:36 +0000
+++ debian/apt.dirs	2010-06-10 14:02:22 +0000
@@ -9,6 +9,7 @@
 etc/logrotate.d
 var/cache/apt/archives/partial
 var/lib/apt/lists/partial
+var/lib/apt/mirrors/partial
 var/lib/apt/periodic
 var/log/apt
 usr/share/bug/apt

=== modified file 'debian/changelog'
--- debian/changelog	2010-05-25 16:01:42 +0000
+++ debian/changelog	2010-06-10 14:02:22 +0000
@@ -1,3 +1,95 @@
+apt (0.7.26~exp6) experimental; urgency=low
+
+  [ Michael Vogt ]
+  * merge the remaining Ubuntu change:
+    - on gpg verification failure warn and restore the last known
+      good state
+    - on failure display the IP of the server (useful for servers
+      that use round robin DNS)
+    - support Original-Maintainer in RewritePackageOrder
+    - enable cdrom autodetection via libudev by default
+    - show message about Vcs in use when apt-get source is run for
+      packages maintained in a Vcs
+    - better support transitional packages with mark auto-installed. 
+      when the transitional package is in "oldlibs" the new package
+      is not marked auto installed (same is true for section
+      metapackages)
+    - provide new "deb mirror://archive.foo/mirrors.list sid main"
+      method expects a list of mirrors (generated on the server e.g.
+      via geoip) and will use that, including cycle on failure
+    - write apport crash file on package failure (disabled by default
+      on debian until apport is available)
+    - support mirror failure reporting (disabled by default on debian)
+  
+  [ David Kalnischkies ]
+  * apt-pkg/deb/dpkgpm.cc:
+    - write Disappeared also to the history.log
+    - forward manual-installed bit on package disappearance
+  * apt-pkg/deb/debsystem.cc:
+    - add better config item for extended_states file
+  * apt-pkg/pkgcache.h:
+    - switch {,Install-}Size to unsigned long long
+  * apt-pkg/depcache.cc:
+    - do the autoremove mark process also for required packages to handle
+      these illegally depending on lower priority packages (Closes: #583517)
+    - try harder to find the other pseudo versions for autoremove multiarch
+    - correct "Dangerous iterator usage" pointed out by cppcheck
+    - deal with long long, not with int to remove 2GB Limit (LP: #250909)
+    - deprecate AddSize with Multiplier as it is unused and switch to
+      boolean instead to handle the sizes more gracefully.
+    - switch i{Download,Usr}Size from double to (un)signed long long
+  * apt-pkg/aptconfiguration.cc:
+    - remove duplicate architectures in getArchitectures()
+  * apt-pkg/indexrecords.{cc,h}:
+    - backport forgotten Valid-Until patch from the obsolete experimental
+      branch to prevent replay attacks better, thanks to Thomas Viehmann
+      for the initial patch! (Closes: #499897)
+    - add a constant Exists check for MetaKeys
+  * apt-pkg/acquire-item.cc:
+    - do not try PDiff if it is not listed in the Meta file
+    - sent Last-Modified header also for Translation files
+  * apt-pkg/cacheiterator.h:
+    - let pkgCache::Iterator inherent std::iterator
+  * ftparchive/writer.h:
+    - add a virtual destructor to FTWScanner class (for cppcheck)
+  * apt-pkg/cacheset.{cc,h}:
+    - add simple wrapper around std::set for cache structures
+    - move regex magic from apt-get to new FromRegEx method
+    - move cmdline parsing from apt-cache to new FromCommandLine method
+    - support special release-modifier 'installed' and 'candidate'
+  * apt-pkg/contrib/cmdline.cc:
+    - fix segfault in SaveInConfig caused by writing over char[] sizes
+  * apt-pkg/pkgcache.cc:
+    - get the best matching arch package from a group with FindPreferredPkg
+  * cmdline/apt-cache.cc:
+    - make the search multiarch compatible by using GrpIterator instead
+    - use pkgCacheFile and the new CacheSets all over the place
+    - add --target-release option (Closes: #115520)
+    - accept pkg/release and pkg=version in show and co. (Closes: #236270)
+    - accept package versions in the unmet command
+  * cmdline/apt-get.cc:
+    - use unsigned long long instead of double to store values it gets
+  * apt-pkg/cachefile.{cc,h}:
+    - split Open() into submethods to be able to build only parts
+    - make the OpProgress optional in the Cache buildprocess
+    - store also the SourceList we use internally for export
+  * doc/apt.conf.5.xml:
+    - document the new Valid-Until related options
+  * apt-pkg/contrib/strutl.cc:
+    - split StrToTime() into HTTP1.1 and FTP date parser methods and
+      use strptime() instead of some self-made scanf mangling
+    - use the portable timegm shown in his manpage instead of a strange
+      looking code copycat from wget
+  * ftparchive/writer.cc:
+    - add ValidTime option to generate a Valid-Until header in Release file
+  * apt-pkg/policy.cc:
+    - get the candidate right for a not-installed pseudo package if
+      his non-pseudo friend is installed
+  * apt-pkg/indexcopy.cc:
+    - move the gpg codecopy to a new method and use it also in methods/gpgv.cc
+
+ -- Michael Vogt <mvo@debian.org>  Thu, 10 Jun 2010 14:02:22 +0200
+
 apt (0.7.26~exp5) experimental; urgency=low
 
   [ David Kalnischkies ]

=== modified file 'debian/control'
--- debian/control	2010-05-06 09:32:54 +0000
+++ debian/control	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
  Christian Perrier <bubulle@debian.org>, Daniel Burrows <dburrows@debian.org>,
  Luca Bruno <lethalman88@gmail.com>, Julian Andres Klode <jak@debian.org>
 Standards-Version: 3.8.4
-Build-Depends: debhelper (>= 5.0), libdb-dev, gettext (>= 0.12), libcurl4-gnutls-dev | libcurl3-gnutls-dev (>= 7.15.5), debiandoc-sgml, xsltproc, docbook-xsl, po4a (>= 0.34-2), autotools-dev, autoconf, automake, doxygen
+Build-Depends: debhelper (>= 5.0), libdb-dev, gettext (>= 0.12), libcurl4-gnutls-dev | libcurl3-gnutls-dev (>= 7.15.5), debiandoc-sgml, xsltproc, docbook-xsl, po4a (>= 0.34-2), autotools-dev, autoconf, automake, doxygen, intltool
 Build-Conflicts: autoconf2.13, automake1.4
 
 Package: apt

=== modified file 'debian/rules'
--- debian/rules	2010-05-25 16:01:42 +0000
+++ debian/rules	2010-06-10 14:02:22 +0000
@@ -225,6 +225,10 @@
 	rm -f build/po/*.pot
 	rm -f po/*.pot
 
+	# move the mirror failure script in place
+	#mv debian/$@/usr/bin/apt-report-mirror-failure \
+	#   debian/$@/usr/lib/apt/apt-report-mirror-failure \
+
 	dh_installexamples -p$@ $(BLD)/docs/examples/*
 	dh_installman -p$@ $(wildcard $(patsubst %,doc/%.[158],$(apt_MANPAGES)) $(patsubst %,doc/*/%.*.[158],$(apt_MANPAGES)))
 	dh_installcron -p$@

=== modified file 'doc/apt-ftparchive.1.xml'
--- doc/apt-ftparchive.1.xml	2010-05-25 16:01:42 +0000
+++ doc/apt-ftparchive.1.xml	2010-06-10 14:02:22 +0000
@@ -122,7 +122,8 @@
      e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The supported fields
      are: <literal>Origin</literal>, <literal>Label</literal>, <literal>Suite</literal>,
      <literal>Version</literal>, <literal>Codename</literal>, <literal>Date</literal>,
-     <literal>Architectures</literal>, <literal>Components</literal>, <literal>Description</literal>.</para></listitem>
+     <literal>Valid-Until</literal>, <literal>Architectures</literal>,
+     <literal>Components</literal>, <literal>Description</literal>.</para></listitem>
 
      </varlistentry>
 

=== modified file 'doc/apt-mark.8.xml'
--- doc/apt-mark.8.xml	2009-12-15 09:21:55 +0000
+++ doc/apt-mark.8.xml	2010-06-10 14:02:22 +0000
@@ -121,12 +121,7 @@
 
  <refsect1><title>Files</title>
    <variablelist>
-      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>
-      <listitem><para>Status list of auto-installed packages.
-		      Configuration Item: <literal>Dir::State</literal>
-		      sets the path to the <filename>extended_states</filename> file.
-      </para></listitem>
-      </varlistentry>
+	&file-extended_states;
    </variablelist>
  </refsect1>
 

=== modified file 'doc/apt.conf.5.xml'
--- doc/apt.conf.5.xml	2010-05-25 16:01:42 +0000
+++ doc/apt.conf.5.xml	2010-06-10 14:02:22 +0000
@@ -230,6 +230,30 @@
    and the URI handlers. 
 
    <variablelist>
+     <varlistentry><term>Check-Valid-Until</term>
+	 <listitem><para>Security related option defaulting to true as an
+	 expiring validation for a Release file prevents longtime replay attacks
+	 and can e.g. also help users to identify no longer updated mirrors -
+	 but the feature depends on the correctness of the time on the user system.
+	 Archive maintainers are encouraged to create Release files with the
+	 <literal>Valid-Until</literal> header, but if they don't or a stricter value
+	 is volitional the following <literal>Max-ValidTime</literal> option can be used.
+	 </para></listitem>
+     </varlistentry>
+
+     <varlistentry><term>Max-ValidTime</term>
+	 <listitem><para>Seconds the Release file should be considered valid after
+	 it was created. The default is "for ever" (0) if the Release file of the
+	 archive doesn't include a <literal>Valid-Until</literal> header.
+	 If it does then this date is the default. The date from the Release file or
+	 the date specified by the creation time of the Release file
+	 (<literal>Date</literal> header) plus the seconds specified with this
+	 options are used to check if the validation of a file has expired by using
+	 the earlier date of the two. Archive specific settings can be made by
+	 appending the label of the archive to the option name.
+	 </para></listitem>
+     </varlistentry>
+
      <varlistentry><term>PDiffs</term>
 	 <listitem><para>Try to download deltas called <literal>PDiffs</literal> for
 	 Packages or Sources files instead of downloading whole ones. True

=== modified file 'doc/apt.ent'
--- doc/apt.ent	2010-05-25 16:01:42 +0000
+++ doc/apt.ent	2010-06-10 14:02:22 +0000
@@ -363,6 +363,14 @@
      </varlistentry>
 ">
 
+<!ENTITY file-extended_states "
+      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>
+      <listitem><para>Status list of auto-installed packages.
+      Configuration Item: <literal>Dir::State::extended_states</literal>.
+      </para></listitem>
+      </varlistentry>
+">
+
 <!-- TRANSLATOR: This is the section header for the following paragraphs - comparable
      to the other headers like NAME and DESCRIPTION and should therefore be uppercase. -->
 <!ENTITY translation-title "TRANSLATION">

=== modified file 'doc/examples/configure-index'
--- doc/examples/configure-index	2010-05-06 09:32:54 +0000
+++ doc/examples/configure-index	2010-06-10 14:02:22 +0000
@@ -176,6 +176,10 @@
   PDiffs::SizeLimit "50"; // don't use diffs if size of all patches excess
 			  // 50% of the size of the original file
 
+  Check-Valid-Until "true";
+  Max-ValidTime "864000"; // 10 days
+  Max-ValidTime::Debian-Security "604800"; // 7 days, label specific configuration
+
   // HTTP method configuration
   http 
   {
@@ -294,9 +298,8 @@
   State "var/lib/apt/" 
   {
      Lists "lists/";
-     xstatus "xstatus";
-     userstatus "status.user";
      status "/var/lib/dpkg/status";
+     extended_states "extended_states";
      cdroms "cdroms.list";
   };
   

=== modified file 'doc/po/apt-doc.pot'
--- doc/po/apt-doc.pot	2010-05-25 16:01:42 +0000
+++ doc/po/apt-doc.pot	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -792,7 +792,21 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:369
+#: apt.ent:373
+#, no-wrap
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      "
+"<varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr ""
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - "
@@ -803,7 +817,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has "
@@ -822,7 +836,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of "
@@ -842,7 +856,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> "
 "<!ENTITY testing-codename \"squeeze\">"
@@ -1296,7 +1310,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56 apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89 apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56 apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89 apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr ""
 
@@ -1319,7 +1333,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362 apt-sortpkgs.1.xml:58
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362 apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr ""
 
@@ -1339,12 +1353,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr ""
 
@@ -1393,7 +1407,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr ""
 
@@ -1489,12 +1503,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98 apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547 apt-sortpkgs.1.xml:64
+#: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98 apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547 apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122 apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122 apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr ""
 
@@ -1504,7 +1518,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103 apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562 apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181 apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651 sources.list.5.xml:233
+#: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103 apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562 apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181 apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651 sources.list.5.xml:233
 msgid "See Also"
 msgstr ""
 
@@ -1514,7 +1528,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108 apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568 apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108 apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568 apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr ""
 
@@ -1618,7 +1632,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr ""
 
@@ -1813,7 +1827,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618 apt-sortpkgs.1.xml:70
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619 apt-sortpkgs.1.xml:70
 msgid "&apt-conf;"
 msgstr ""
 
@@ -2052,17 +2066,17 @@
 "fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, "
 "<literal>Codename</literal>, <literal>Date</literal>, "
-"<literal>Architectures</literal>, <literal>Components</literal>, "
-"<literal>Description</literal>."
+"<literal>Valid-Until</literal>, <literal>Architectures</literal>, "
+"<literal>Components</literal>, <literal>Description</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 msgid "generate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2072,24 +2086,24 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 msgid "The Generate Configuration"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2100,17 +2114,17 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid "The generate configuration has 4 separate sections, each described below."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 msgid "Dir Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 msgid ""
 "The <literal>Dir</literal> section defines the standard directories needed "
 "to locate the files required during the generation process. These "
@@ -2119,12 +2133,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2132,44 +2146,44 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the "
 "<literal>FileList</literal> setting is used below."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -2177,12 +2191,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -2191,72 +2205,72 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 msgid "Translation::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Translation-en master file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section "
@@ -2264,36 +2278,36 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 msgid "LongDescription"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -2301,12 +2315,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each "
 "day. The contents files are round-robined so that over several days they "
@@ -2314,12 +2328,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is "
@@ -2330,60 +2344,60 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to "
 "<filename>$(DIST)/$(SECTION)/binary-$(ARCH)/</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to "
 "<filename>$(DIST)/$(SECTION)/source/</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to "
 "<filename>$(DIST)/$(SECTION)/binary-$(ARCH)/Packages</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 msgid ""
 "Sets the output Sources file. Defaults to "
 "<filename>$(DIST)/$(SECTION)/source/Sources</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 msgid "Translation"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to "
@@ -2391,12 +2405,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to "
@@ -2404,12 +2418,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to "
 "<filename>$(DIST)/Contents-$(ARCH)</filename>. If this setting causes "
@@ -2419,34 +2433,34 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, "
 "<command>apt-ftparchive</command> should read the list of files from the "
@@ -2454,12 +2468,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, "
 "<command>apt-ftparchive</command> should read the list of files from the "
@@ -2468,12 +2482,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -2483,7 +2497,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 msgid ""
 "The <literal>Tree</literal> section takes a scope tag which sets the "
 "<literal>$(DIST)</literal> variable and defines the root of the tree (the "
@@ -2492,7 +2506,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -2500,7 +2514,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, no-wrap
 msgid ""
 "for i in Sections do \n"
@@ -2510,7 +2524,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 msgid ""
 "When processing a <literal>Tree</literal> section "
 "<command>apt-ftparchive</command> performs an operation similar to: "
@@ -2518,12 +2532,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 msgid "Sections"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib "
@@ -2531,12 +2545,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -2544,56 +2558,56 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 msgid "BinOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -2603,64 +2617,64 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 msgid "The Binary Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -2670,19 +2684,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder "
 "type=\"literallayout\" id=\"0\"/> or simply, <placeholder "
@@ -2693,12 +2707,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 msgid "The Source Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -2706,12 +2720,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -2719,12 +2733,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -2732,19 +2746,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
 "Configuration Item: <literal>APT::FTPArchive::DB</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -2753,12 +2767,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
 "then this option actually enables delinking of the files. It defaults to on "
@@ -2767,12 +2781,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -2782,12 +2796,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
 "command.  Configuration Item: "
@@ -2795,24 +2809,24 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 msgid ""
 "Make the caching databases read only.  Configuration Item: "
 "<literal>APT::FTPArchive::ReadOnlyDB</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 msgid "<option>--arch</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 msgid ""
 "Accept in the <literal>packages</literal> and <literal>contents</literal> "
 "commands only package files matching <literal>*_arch.deb</literal> or "
@@ -2821,12 +2835,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -2840,12 +2854,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 msgid ""
 "This configuration option defaults to \"<literal>true</literal>\" and should "
 "only be set to <literal>\"false\"</literal> if the Archive generated with "
@@ -2855,12 +2869,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491 sources.list.5.xml:193
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491 sources.list.5.xml:193
 msgid "Examples"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid ""
 "<command>apt-ftparchive</command> packages "
@@ -2869,14 +2883,14 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -4068,26 +4082,18 @@
 msgid "Show the program version."
 msgstr ""
 
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr ""
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: "
-"<literal>Dir::State</literal> sets the path to the "
-"<filename>extended_states</filename> file."
+msgid "  &file-extended_states;"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 msgid "&apt-get;,&aptitude;,&apt-conf;"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -4757,18 +4763,54 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was "
+"created. The default is \"for ever\" (0) if the Release file of the archive "
+"doesn't include a <literal>Valid-Until</literal> header.  If it does then "
+"this date is the default. The date from the Release file or the date "
+"specified by the creation time of the Release file (<literal>Date</literal> "
+"header) plus the seconds specified with this options are used to check if "
+"the validation of a file has expired by using the earlier date of the "
+"two. Archive specific settings can be made by appending the label of the "
+"archive to the option name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -4779,12 +4821,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of "
 "<literal>host</literal> or <literal>access</literal> which determines how "
@@ -4794,36 +4836,36 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 msgid "Source-Symlinks"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 msgid ""
 "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
 "standard form of <literal>http://[[user][:pass]@]host[:port]/</literal>. Per "
@@ -4835,7 +4877,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -4849,7 +4891,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -4857,7 +4899,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 msgid ""
 "One setting is provided to control the pipeline depth in cases where the "
 "remote server is not RFC conforming or buggy (such as Squid 2.0.2).  "
@@ -4869,7 +4911,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with "
 "<literal>Acquire::http::Dl-Limit</literal> which accepts integer values in "
@@ -4879,7 +4921,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -4887,12 +4929,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 msgid ""
 "HTTPS URIs. Cache-control, Timeout, AllowRedirect, Dl-Limit and proxy "
 "options are the same as for <literal>http</literal> method and will also "
@@ -4902,7 +4944,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -4924,12 +4966,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 msgid ""
 "FTP URIs; ftp::Proxy is the default ftp proxy to use. It is in the standard "
 "form of <literal>ftp://[[user][:pass]@]host[:port]/</literal>. Per host "
@@ -4949,7 +4991,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -4959,7 +5001,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the "
 "<envar>ftp_proxy</envar> environment variable to a http url - see the "
@@ -4969,7 +5011,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -4979,18 +5021,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, no-wrap
 msgid "/cdrom/::Mount \"foo\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -5003,12 +5045,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -5016,12 +5058,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid ""
 "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> "
@@ -5029,7 +5071,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -5041,19 +5083,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -5070,13 +5112,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the "
 "<literal>Dir::Bin::<replaceable>Methodname</replaceable></literal> will be "
@@ -5091,7 +5133,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -5101,12 +5143,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 msgid ""
 "The Languages subsection controls which <filename>Translation</filename> "
 "files are downloaded and in which order APT tries to display the "
@@ -5119,13 +5161,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 msgid ""
 "The default list includes \"environment\" and "
 "\"en\". \"<literal>environment</literal>\" has a special meaning here: It "
@@ -5156,12 +5198,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -5173,7 +5215,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -5186,7 +5228,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -5196,7 +5238,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -5204,7 +5246,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 msgid ""
 "Binary programs are pointed to by "
 "<literal>Dir::Bin</literal>. <literal>Dir::Bin::Methods</literal> specifies "
@@ -5216,7 +5258,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -5229,12 +5271,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 msgid "APT in DSelect"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -5242,12 +5284,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 msgid "Clean"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -5258,50 +5300,50 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 msgid "Updateoptions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -5309,17 +5351,17 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -5328,12 +5370,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -5343,7 +5385,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -5354,36 +5396,36 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is "
 "<filename>/</filename>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 msgid "Build-options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -5398,7 +5440,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -5408,7 +5450,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -5422,12 +5464,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -5439,12 +5481,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 msgid "PackageManager::Configure"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -5461,12 +5503,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 msgid "DPkg::ConfigurePending"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure "
 "--pending</command> to let dpkg handle all required configurations and "
@@ -5478,12 +5520,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -5493,12 +5535,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by "
@@ -5510,12 +5552,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -5527,7 +5569,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -5541,12 +5583,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -5555,12 +5597,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 msgid "Debug options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -5571,7 +5613,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, "
@@ -5579,7 +5621,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s "
@@ -5587,7 +5629,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -5597,110 +5639,110 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
 "in CDROM IDs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 msgid "<literal>Debug::Hashes</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the "
 "<literal>apt</literal> libraries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -5708,92 +5750,92 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial "
@@ -5803,12 +5845,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as "
 "keep/install/remove while the ProblemResolver does his work.  Each addition "
@@ -5826,90 +5868,90 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -5917,32 +5959,32 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 msgid "<literal>Debug::sourceList</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from "
 "<filename>/etc/apt/vendors.list</filename>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 msgid "&file-aptconf;"
 msgstr ""
 
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr ""
 

=== modified file 'doc/po/de.po'
--- doc/po/de.po	2010-05-25 16:01:42 +0000
+++ doc/po/de.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: apt-doc 0.7.24\n"
 "Report-Msgid-Bugs-To: APT Development Team <deity@lists.debian.org>\n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: 2010-04-21 14:04+0200\n"
 "Last-Translator: Chris Leick <c.leick@vollbio.de>\n"
 "Language-Team: German <debian-l10n-german@lists.debian.org>\n"
@@ -1093,7 +1093,31 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:369
+#: apt.ent:373
+#, fuzzy, no-wrap
+#| msgid ""
+#| "<!ENTITY file-sourceslist \"\n"
+#| "     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+#| "     <listitem><para>Locations to fetch packages from.\n"
+#| "     Configuration Item: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+#| "     </varlistentry>\n"
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr ""
+"<!ENTITY file-sourceslist \"\n"
+"     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+"     <listitem><para>Orte, von denen Pakete geladen werden.\n"
+"     Konfigurationselement: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+"     </varlistentry>\n"
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - comparable\n"
@@ -1102,7 +1126,7 @@
 msgstr "<!ENTITY translation-title \"ÜBERSETZUNG\">\n"
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has contributed\n"
@@ -1120,7 +1144,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of untranslated/fuzzy strings\n"
@@ -1136,7 +1160,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> <!"
 "ENTITY testing-codename \"squeeze\">"
@@ -1760,8 +1784,8 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
 #: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56
-#: apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89
-#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89
+#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr "Optionen"
 
@@ -1788,7 +1812,7 @@
 "pkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362
 #: apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr "<option>-s</option>"
@@ -1816,12 +1840,12 @@
 "srcpkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr "<option>-q</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr "<option>--quiet</option>"
 
@@ -1880,7 +1904,7 @@
 "Konfigurationselement: <literal>APT::Cache::ShowFull</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr "<option>-a</option>"
 
@@ -1997,14 +2021,14 @@
 
 #. type: Content of: <refentry><refsect1><variablelist>
 #: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98
-#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547
+#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547
 #: apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr "&apt-commonoptions;"
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122
-#: apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr "Dateien"
 
@@ -2015,9 +2039,9 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103
-#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562
-#: apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181
-#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651
+#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562
+#: apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181
+#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651
 #: sources.list.5.xml:233
 msgid "See Also"
 msgstr "Siehe auch"
@@ -2029,8 +2053,8 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108
-#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568
-#: apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568
+#: apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr "Diagnose"
 
@@ -2171,7 +2195,7 @@
 msgstr "Optionen"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr "<option>-d</option>"
 
@@ -2414,7 +2438,7 @@
 msgstr "Nur der Inhalt des Konfigurationsbereichs wird angezeigt."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619
 #: apt-sortpkgs.1.xml:70
 msgid "&apt-conf;"
 msgstr "&apt-conf;"
@@ -2749,14 +2773,25 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #: apt-ftparchive.1.xml:119
+#, fuzzy
+#| msgid ""
+#| "Values for the additional metadata fields in the Release file are taken "
+#| "from the corresponding variables under <literal>APT::FTPArchive::Release</"
+#| "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
+#| "supported fields are: <literal>Origin</literal>, <literal>Label</"
+#| "literal>, <literal>Suite</literal>, <literal>Version</literal>, "
+#| "<literal>Codename</literal>, <literal>Date</literal>, "
+#| "<literal>Architectures</literal>, <literal>Components</literal>, "
+#| "<literal>Description</literal>."
 msgid ""
 "Values for the additional metadata fields in the Release file are taken from "
 "the corresponding variables under <literal>APT::FTPArchive::Release</"
 "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
 "supported fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, <literal>Codename</"
-"literal>, <literal>Date</literal>, <literal>Architectures</literal>, "
-"<literal>Components</literal>, <literal>Description</literal>."
+"literal>, <literal>Date</literal>, <literal>Valid-Until</literal>, "
+"<literal>Architectures</literal>, <literal>Components</literal>, "
+"<literal>Description</literal>."
 msgstr ""
 "Werte für zusätzliche Metadatenfelder in der Release-Datei werden den "
 "entsprechenden Variablen unter <literal>APT::FTPArchive::Release</literal> "
@@ -2768,12 +2803,12 @@
 "<literal>Description</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 msgid "generate"
 msgstr "generate"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2789,12 +2824,12 @@
 "Verwaltung der erforderlichen Einstellungen bereitstellt."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr "clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
@@ -2804,12 +2839,12 @@
 "Datensätze entfernt."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 msgid "The Generate Configuration"
 msgstr "Die Generate-Konfiguration"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2827,7 +2862,7 @@
 "wenn die Markierung »scope« behandelt wird."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid ""
 "The generate configuration has 4 separate sections, each described below."
 msgstr ""
@@ -2835,12 +2870,12 @@
 "unterhalb beschrieben"
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 msgid "Dir Section"
 msgstr "Dir-Abschnitt"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 msgid ""
 "The <literal>Dir</literal> section defines the standard directories needed "
 "to locate the files required during the generation process. These "
@@ -2854,12 +2889,12 @@
 "absoluten Pfad zu bilden."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr "ArchiveDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2870,32 +2905,32 @@
 "enthält."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr "OverrideDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr "Gibt den Ort der Override-Dateien an"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr "CacheDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr "Gibt den Ort der Zwischenspeicherdateien an"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr "FileListDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the <literal>FileList</"
 "literal> setting is used below."
@@ -2904,12 +2939,12 @@
 "unterhalb gesetzt ist."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr "Vorgabe-Abschnitt"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -2920,12 +2955,12 @@
 "können diese Vorgaben mit einer Einstellung pro Abschnitt überschreiben."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr "Packages::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -2938,12 +2973,12 @@
 "»gzip« und »bzip2«. Die Vorgabe für alle Kompressionsschemata ist ». gzip«."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr "Packages::Extensions"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
@@ -2952,12 +2987,12 @@
 "Vorgabe ist ».deb«."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr "Sources::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
@@ -2966,12 +3001,12 @@
 "Kompression der Quelldateien steuert."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr "Sources::Extensions"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
@@ -2980,12 +3015,12 @@
 "Vorgabe ist ».dsc«."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr "Contents::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
@@ -2994,14 +3029,14 @@
 "Kompression der Inhaltsdateien steuert."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 #, fuzzy
 #| msgid "Contents::Compress"
 msgid "Translation::Compress"
 msgstr "Contents::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 #, fuzzy
 #| msgid ""
 #| "This is similar to <literal>Packages::Compress</literal> except that it "
@@ -3014,12 +3049,12 @@
 "Kompression der Inhaltsdateien steuert."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr "DeLinkLimit"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section <literal>External-"
@@ -3030,12 +3065,12 @@
 "<literal>External-Links</literal>-Einstellung pro Abschnitt benutzt."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr "FileMode"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
@@ -3044,26 +3079,26 @@
 "Indexdateien werden ohne Beachtung von umask auf diese Rechte gesetzt."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 #, fuzzy
 #| msgid "Description"
 msgid "LongDescription"
 msgstr "Beschreibung"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr "TreeDefault-Abschnitt"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -3074,12 +3109,12 @@
 "$(SECTION) und $(ARCH) durch ihre jeweiligen Werte ersetzt."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr "MaxContentsChange"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each day. "
 "The contents files are round-robined so that over several days they will all "
@@ -3090,12 +3125,12 @@
 "Tage alle neu gebildet werden."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr "ContentsAge"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is updated. "
@@ -3113,12 +3148,12 @@
 "eine neue Datei benötigen. Die Vorgabe ist 10, die Einheiten sind Tage."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr "Directory"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to <filename>$(DIST)/"
 "$(SECTION)/binary-$(ARCH)/</filename>"
@@ -3127,12 +3162,12 @@
 "$(SECTION)/binary-$(ARCH)/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr "SrcDirectory"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to <filename>"
 "$(DIST)/$(SECTION)/source/</filename>"
@@ -3141,12 +3176,12 @@
 "$(DIST)/$(SECTION)/source/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr "Packages"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "binary-$(ARCH)/Packages</filename>"
@@ -3155,12 +3190,12 @@
 "binary-$(ARCH)/Packages</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr "Sources"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 #, fuzzy
 #| msgid ""
 #| "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
@@ -3173,14 +3208,14 @@
 "source/Sources</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 #, fuzzy
 #| msgid "Operation"
 msgid "Translation"
 msgstr "Betrieb"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to <filename>$(DIST)/"
@@ -3188,12 +3223,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr "InternalPrefix"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to <filename>$(DIST)/$(SECTION)/</"
@@ -3204,12 +3239,12 @@
 "<filename>$(DIST)/$(SECTION)/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr "Contents"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to <filename>$(DIST)/Contents-$(ARCH)"
 "</filename>. If this setting causes multiple Packages files to map onto a "
@@ -3223,22 +3258,22 @@
 "automatisch integrieren."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr "Contents::Header"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr "Setzt die Kopfdatendatei, um sie der Inhaltsausgabe voranzustellen."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr "BinCacheDB"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
@@ -3247,12 +3282,12 @@
 "Abschnitt. Mehrere Abschnitte können sich die gleiche Datenbank teilen."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr "FileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3263,12 +3298,12 @@
 "Relativen Dateinamen wird das Archivverzeichnis vorangestellt."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr "SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3281,12 +3316,12 @@
 "benutzt, wenn Quellindizes verarbeitet werden."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr "Tree-Abschnitt"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -3301,7 +3336,7 @@
 "<literal>Directory</literal>-Ersetzungsvariable definiert."
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 #, fuzzy
 #| msgid ""
 #| "The <literal>Tree</literal> section takes a scope tag which sets the "
@@ -3321,7 +3356,7 @@
 "filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -3332,7 +3367,7 @@
 "Variablen benutzt werden."
 
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, fuzzy, no-wrap
 #| msgid ""
 #| "for i in Sections do \n"
@@ -3349,7 +3384,7 @@
 "      Generiere for DIST=Geltungsbereich SECTION=i ARCH=j\n"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 #, fuzzy
 #| msgid ""
 #| "When processing a <literal>Tree</literal> section <command>apt-"
@@ -3363,12 +3398,12 @@
 "<command>apt-ftparchive</command> eine Operation aus, die folgender ähnelt:"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 msgid "Sections"
 msgstr "Abschnitte"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib non-"
@@ -3379,12 +3414,12 @@
 "non-free</literal>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr "Architekturen"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -3395,12 +3430,12 @@
 "benutzt, um anzugeben, dass dieser Baum ein Quellarchiv besitzt."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 msgid "BinOverride"
 msgstr "BinOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
@@ -3409,12 +3444,12 @@
 "Priorität und Adressinformationen des Betreuers."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr "SrcOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
@@ -3423,32 +3458,32 @@
 "Abschnittsinformationen."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr "ExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr "Setzt die zusätzliche Programm-Override-Datei."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr "SrcExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr "Setzt die zusätzliche Quell-Override-Datei."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr "BinDirectory-Abschnitt"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -3463,12 +3498,12 @@
 "<literal>Abschnitt</literal><literal>Architektur</literal> ähnlich."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr "Setzt die Packages-Dateiausgabe."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
@@ -3477,52 +3512,52 @@
 "<literal>Sources</literal> ist erforderlich."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr "Setzt die Contents-Dateiausgabe. (optional)"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr "Setzt die Programm-Override-Datei."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr "Setzt die Quell-Override-Datei."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr "Setzt die Zwischenspeicherdatenbank."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr "PathPrefix"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr "Hängt einen Pfad an alle Ausgabepfade an."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr "FileList, SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr "Gibt die Dateilistendatei an."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 msgid "The Binary Override File"
 msgstr "Die Programm-Override-Datei "
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -3537,19 +3572,19 @@
 "und das letzte Feld ist das Betreuerumsetzungsfeld."
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr "alt [// oldn]* => neu"
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr "neu"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder type="
 "\"literallayout\" id=\"0\"/> or simply, <placeholder type=\"literallayout\" "
@@ -3566,12 +3601,12 @@
 "bedingungslos."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 msgid "The Source Override File"
 msgstr "Die Quell-Override-Datei"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -3582,12 +3617,12 @@
 "Quellpaketname, das zweite ist der Abschnitt, dem er zugeordnet ist."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr "Die zusätzlich Override-Datei"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -3599,12 +3634,12 @@
 "ist der neue Wert."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr "<option>--md5</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -3615,12 +3650,12 @@
 "ist. Konfigurationselement: <literal>APT::FTPArchive::MD5</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr "<option>--db</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
 "Configuration Item: <literal>APT::FTPArchive::DB</literal>."
@@ -3630,7 +3665,7 @@
 "DB</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -3644,12 +3679,12 @@
 "Konfigurationselement: <literal>quiet</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr "<option>--delink</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
 "then this option actually enables delinking of the files. It defaults to on "
@@ -3663,12 +3698,12 @@
 "DeLinkAct</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr "<option>--contents</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -3684,12 +3719,12 @@
 "Konfigurationselement: <literal>APT::FTPArchive::Contents</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr "<option>--source-override</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
 "command.  Configuration Item: <literal>APT::FTPArchive::SourceOverride</"
@@ -3700,12 +3735,12 @@
 "SourceOverride</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr "<option>--readonly</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 msgid ""
 "Make the caching databases read only.  Configuration Item: <literal>APT::"
 "FTPArchive::ReadOnlyDB</literal>."
@@ -3714,14 +3749,14 @@
 "<literal>APT::FTPArchive::ReadOnlyDB</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 #, fuzzy
 #| msgid "<option>-a</option>"
 msgid "<option>--arch</option>"
 msgstr "<option>-a</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 #, fuzzy
 #| msgid ""
 #| "If the command is either <literal>install</literal> or <literal>remove</"
@@ -3741,14 +3776,14 @@
 "AutomaticRemove</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 #, fuzzy
 #| msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr "<option>APT::FTPArchive::LongDescription</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -3762,12 +3797,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr "<option>APT::FTPArchive::LongDescription</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 #, fuzzy
 #| msgid ""
 #| "This configuration option defaults to \"<literal>true</literal>\" and "
@@ -3789,19 +3824,19 @@
 "Dateien mit <command>apt-ftparchive</command> zu erstellen."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491
 #: sources.list.5.xml:193
 msgid "Examples"
 msgstr "Beispiele"
 
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 msgstr "<command>apt-ftparchive</command> Pakete <replaceable>Verzeichnis</replaceable> | <command>gzip</command> > <filename>Pakete.gz</filename>\n"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
@@ -3811,7 +3846,7 @@
 ">"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -5456,29 +5491,18 @@
 msgid "Show the program version."
 msgstr "Die Programmversion anzeigen."
 
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr "<filename>/var/lib/apt/extended_states</filename>"
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: <literal>Dir::"
-"State</literal> sets the path to the <filename>extended_states</filename> "
-"file."
+msgid "  &file-extended_states;"
 msgstr ""
-"Statusliste automatisch installierter Pakete. Konfigurationselement: "
-"<literal>Dir::State</literal> setzt den Pfad zur Datei "
-"<filename>extended_states</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 msgid "&apt-get;,&aptitude;,&apt-conf;"
 msgstr "&apt-get;,&aptitude;,&apt-conf;"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -6450,11 +6474,47 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was created. "
+"The default is \"for ever\" (0) if the Release file of the archive doesn't "
+"include a <literal>Valid-Until</literal> header.  If it does then this date "
+"is the default. The date from the Release file or the date specified by the "
+"creation time of the Release file (<literal>Date</literal> header) plus the "
+"seconds specified with this options are used to check if the validation of a "
+"file has expired by using the earlier date of the two. Archive specific "
+"settings can be made by appending the label of the archive to the option "
+"name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr "PDiffs"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
@@ -6464,7 +6524,7 @@
 "True."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -6475,12 +6535,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr "Queue-Mode"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of <literal>host</"
 "literal> or <literal>access</literal> which determines how APT parallelizes "
@@ -6496,12 +6556,12 @@
 "URI-Art geöffnet wird."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr "Retries"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
@@ -6510,12 +6570,12 @@
 "APT fehlgeschlagene Dateien in der angegebenen Zahl erneut versuchen."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 msgid "Source-Symlinks"
 msgstr "Source-Symlinks"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
@@ -6525,12 +6585,12 @@
 "kopiert zu werden. True ist die Vorgabe."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr "http"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 msgid ""
 "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
 "standard form of <literal>http://[[user][:pass]@]host[:port]/</literal>. Per "
@@ -6548,7 +6608,7 @@
 "die Umgebungsvariable <envar>http_proxy</envar> benutzt."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -6574,7 +6634,7 @@
 "unterstützt keine dieser Optionen."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -6585,7 +6645,7 @@
 "Dinge, einschließlich Verbindungs- und Datenzeitüberschreitungen, angewandt."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 msgid ""
 "One setting is provided to control the pipeline depth in cases where the "
 "remote server is not RFC conforming or buggy (such as Squid 2.0.2).  "
@@ -6605,7 +6665,7 @@
 "gegen RFC 2068."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with <literal>Acquire::http::Dl-Limit</"
 "literal> which accepts integer values in kilobyte. The default value is 0 "
@@ -6621,7 +6681,7 @@
 "deaktiviert.)"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -6633,12 +6693,12 @@
 "bekannten Bezeichner verwendet."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr "https"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 msgid ""
 "HTTPS URIs. Cache-control, Timeout, AllowRedirect, Dl-Limit and proxy "
 "options are the same as for <literal>http</literal> method and will also "
@@ -6653,7 +6713,7 @@
 "<literal>Pipeline-Depth</literal> wird noch nicht unterstützt."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -6692,12 +6752,12 @@
 "SslForceVersion</literal> ist die entsprechende per-Host-Option."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr "ftp"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 msgid ""
 "FTP URIs; ftp::Proxy is the default ftp proxy to use. It is in the standard "
 "form of <literal>ftp://[[user][:pass]@]host[:port]/</literal>. Per host "
@@ -6732,7 +6792,7 @@
 "entsprechenden URI-Bestandteil genommen."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -6749,7 +6809,7 @@
 "Beispielskonfiguration, um Beispiele zu erhalten)."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the <envar>ftp_proxy</"
 "envar> environment variable to a http url - see the discussion of the http "
@@ -6763,7 +6823,7 @@
 "Effizienz nicht empfohlen FTP über HTTP zu benutzen."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -6779,18 +6839,18 @@
 "Server RFC2428 unterstützen."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr "cdrom"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, no-wrap
 msgid "/cdrom/::Mount \"foo\";"
 msgstr "/cdrom/::Mount \"foo\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -6812,12 +6872,12 @@
 "können per UMount angegeben werden."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr "gpgv"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -6828,18 +6888,18 @@
 "Zusätzliche Parameter werden an gpgv weitergeleitet."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr "CompressionTypes"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> \"<replaceable>Methodname</replaceable>\";"
 msgstr "Acquire::CompressionTypes::<replaceable>Dateierweiterung</replaceable> \"<replaceable>Methodenname</replaceable>\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -6859,19 +6919,19 @@
 "\"synopsis\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr "Acquire::CompressionTypes::Order:: \"gz\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -6902,13 +6962,13 @@
 "explizit zur Liste hinzuzufügen, da es automatisch hinzufügt wird."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr "Dir::Bin::bzip2 \"/bin/bzip2\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the <literal>Dir::Bin::<replaceable>Methodname</"
 "replaceable></literal> will be checked: If this setting exists the method "
@@ -6934,7 +6994,7 @@
 "diesen Typ nur vor die Liste setzen."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -6951,12 +7011,12 @@
 "unterstützen."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr "Sprachen"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 #, fuzzy
 #| msgid ""
 #| "The Languages subsection controls which <filename>Translation</filename> "
@@ -6988,13 +7048,13 @@
 "hier unmögliche Werte einsetzen."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 #, fuzzy
 #| msgid ""
 #| "The default list includes \"environment\" and \"en\". "
@@ -7066,12 +7126,12 @@
 "id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr "Verzeichnisse"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -7091,7 +7151,7 @@
 "filename> oder <filename>./</filename> beginnen."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -7114,7 +7174,7 @@
 "<literal>Dir::Cache</literal> enthalten."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -7129,7 +7189,7 @@
 "Konfigurationsdatei erfolgt)."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -7141,7 +7201,7 @@
 "geladen."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 msgid ""
 "Binary programs are pointed to by <literal>Dir::Bin</literal>. <literal>Dir::"
 "Bin::Methods</literal> specifies the location of the method handlers and "
@@ -7159,7 +7219,7 @@
 "Programms an."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -7179,12 +7239,12 @@
 "<filename>/tmp/staging/var/lib/dpkg/status</filename> nachgesehen."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 msgid "APT in DSelect"
 msgstr "APT in DSelect"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -7195,12 +7255,12 @@
 "<literal>DSelect</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 msgid "Clean"
 msgstr "Clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -7218,7 +7278,7 @@
 "vor dem Herunterladen neuer Pakete durch."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
@@ -7227,12 +7287,12 @@
 "übermittelt, wenn es für die Installationsphase durchlaufen wird."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 msgid "Updateoptions"
 msgstr "Updateoptions"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
@@ -7241,12 +7301,12 @@
 "übermittelt, wenn es für die Aktualisierungsphase durchlaufen wird."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr "PromptAfterUpdate"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
@@ -7255,12 +7315,12 @@
 "nachfragen, um fortzufahren. Vorgabe ist es, nur bei Fehlern nachzufragen."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr "Wie APT Dpkg aufruft"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
@@ -7269,7 +7329,7 @@
 "stehen im Abschnitt <literal>DPkg</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -7280,17 +7340,17 @@
 "jedes Listenelement wird als einzelnes Argument an &dpkg; übermittelt."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr "Pre-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr "Post-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7304,12 +7364,12 @@
 "APT abgebrochen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr "Pre-Install-Pkgs"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7326,7 +7386,7 @@
 "pro Zeile."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -7342,12 +7402,12 @@
 "literal> gegeben wird."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr "Run-Directory"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is <filename>/"
 "</filename>."
@@ -7356,12 +7416,12 @@
 "die Vorgabe ist <filename>/</filename>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 msgid "Build-options"
 msgstr "Build-options"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
@@ -7371,12 +7431,12 @@
 "Programme werden erstellt."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr "Dpkd-Trigger-Benutzung (und zugehöriger Optionen)"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -7402,7 +7462,7 @@
 "Status 100% stehen, während es aktuell alle Pakete konfiguriert."
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -7416,7 +7476,7 @@
 "DPkg::TriggersPending \"true\";"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -7441,12 +7501,12 @@
 "wäre <placeholder type=\"literallayout\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr "DPkg::NoTriggers"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -7467,12 +7527,12 @@
 "außerdem an die »unpack«- und »remove«-Aufrufe anhängen."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 msgid "PackageManager::Configure"
 msgstr "PackageManager::Configure"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -7501,12 +7561,12 @@
 "mehr startbar sein könnte."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 msgid "DPkg::ConfigurePending"
 msgstr "DPkg::ConfigurePending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure --pending</"
 "command> to let dpkg handle all required configurations and triggers. This "
@@ -7525,12 +7585,12 @@
 "deaktivieren."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr "DPkg::TriggersPending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -7546,12 +7606,12 @@
 "benötigt werden."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr "PackageManager::UnpackAll"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by Pre-"
@@ -7570,12 +7630,12 @@
 "und weitere Verbesserungen benötigt, bevor sie wirklich nützlich wird."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr "OrderList::Score::Immediate"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -7593,7 +7653,7 @@
 "};"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -7617,12 +7677,12 @@
 "mit ihren Vorgabewerten. <placeholder type=\"literallayout\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr "Periodische- und Archivoptionen"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -7636,12 +7696,12 @@
 "Dokumentation dieser Optionen zu erhalten."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 msgid "Debug options"
 msgstr "Fehlersuchoptionen"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -7659,7 +7719,7 @@
 "könnten es sein:"
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, purge</"
@@ -7670,7 +7730,7 @@
 "getroffenen Entscheidungen ein."
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s install</"
@@ -7681,7 +7741,7 @@
 "<literal>apt-get -s install</literal>) als nicht root-Anwender auszuführen."
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -7693,7 +7753,7 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
 "in CDROM IDs."
@@ -7702,17 +7762,17 @@
 "Daten in CD-ROM-IDs aus."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr "Eine vollständige Liste der Fehlersuchoptionen von APT folgt."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr "<literal>Debug::Acquire::cdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid ""
 "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
@@ -7720,48 +7780,48 @@
 "literal>-Quellen beziehen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr "<literal>Debug::Acquire::ftp</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr ""
 "Gibt Informationen aus, die sich auf das Herunterladen von Paketen per FTP "
 "beziehen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr "<literal>Debug::Acquire::http</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr ""
 "Gibt Informationen aus, die sich auf das Herunterladen von Paketen per HTTP "
 "beziehen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr "<literal>Debug::Acquire::https</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr ""
 "Gibt Informationen aus, die sich auf das Herunterladen von Paketen per HTTPS "
 "beziehen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr "<literal>Debug::Acquire::gpgv</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
@@ -7770,12 +7830,12 @@
 "mittels <literal>gpg</literal> beziehen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr "<literal>Debug::aptcdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
@@ -7784,23 +7844,23 @@
 "CD-ROMs gespeichert sind."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr "<literal>Debug::BuildDeps</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 "Beschreibt den Prozess der Auflösung von Bauabhängigkeiten in &apt-get;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 msgid "<literal>Debug::Hashes</literal>"
 msgstr "<literal>Debug::Hashes</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the <literal>apt</"
 "literal> libraries."
@@ -7809,12 +7869,12 @@
 "Bibliotheken generiert wurde."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr "<literal>Debug::IdentCDROM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -7825,12 +7885,12 @@
 "ID für eine CD-ROM generiert wird."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr "<literal>Debug::NoLocking</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
@@ -7840,24 +7900,24 @@
 "gleichen Zeit laufen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr "<literal>Debug::pkgAcquire</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 "Protokollieren, wenn Elemente aus der globalen Warteschlange zum "
 "Herunterladen hinzugefügt oder entfernt werden."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr "<literal>Debug::pkgAcquire::Auth</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
@@ -7866,12 +7926,12 @@
 "und kryptografischen Signaturen von heruntergeladenen Dateien beziehen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr "<literal>Debug::pkgAcquire::Diffs</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
@@ -7880,12 +7940,12 @@
 "und Fehler, die die Paketindexlisten-Diffs betreffen, ausgeben."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr "<literal>Debug::pkgAcquire::RRed</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
@@ -7895,12 +7955,12 @@
 "werden."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr "<literal>Debug::pkgAcquire::Worker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid ""
 "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
@@ -7908,12 +7968,12 @@
 "durchführen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr "<literal>Debug::pkgAutoRemove</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
@@ -7923,12 +7983,12 @@
 "beziehen."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial auto-"
@@ -7944,12 +8004,12 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr "<literal>Debug::pkgDepCache::Marker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as keep/install/"
 "remove while the ProblemResolver does his work.  Each addition or deletion "
@@ -7981,23 +8041,23 @@
 "erscheint."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr "<literal>Debug::pkgInitConfig</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr ""
 "Die Vorgabekonfiguration beim Start auf der Standardfehlerausgabe ausgeben."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr "<literal>Debug::pkgDPkgPM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
@@ -8007,12 +8067,12 @@
 "sind."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr "<literal>Debug::pkgDPkgProgressReporting</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
@@ -8021,12 +8081,12 @@
 "alle während deren Auswertung gefundenen Fehler ausgeben."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr "<literal>Debug::pkgOrderList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
@@ -8036,12 +8096,12 @@
 "soll."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr "<literal>Debug::pkgPackageManager</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid ""
 "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr ""
@@ -8049,22 +8109,22 @@
 "von &dpkg; ausgeführt werden."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr "<literal>Debug::pkgPolicy</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr "Die Priorität jeder Paketliste beim Start ausgeben."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr "<literal>Debug::pkgProblemResolver</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
@@ -8074,12 +8134,12 @@
 "aufgetreten ist)."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -8091,12 +8151,12 @@
 "beschrieben."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 msgid "<literal>Debug::sourceList</literal>"
 msgstr "<literal>Debug::sourceList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from <filename>/etc/apt/vendors."
 "list</filename>."
@@ -8105,7 +8165,7 @@
 "gelesenen Anbieter ausgeben."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
@@ -8114,13 +8174,13 @@
 "möglichen Optionen zeigen."
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 msgid "&file-aptconf;"
 msgstr "&file-aptconf;"
 
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr "&apt-cache;, &apt-config;, &apt-preferences;."
 
@@ -11609,6 +11669,18 @@
 #~ "  </citerefentry>\"\n"
 #~ ">\n"
 
+#~ msgid "<filename>/var/lib/apt/extended_states</filename>"
+#~ msgstr "<filename>/var/lib/apt/extended_states</filename>"
+
+#~ msgid ""
+#~ "Status list of auto-installed packages.  Configuration Item: "
+#~ "<literal>Dir::State</literal> sets the path to the "
+#~ "<filename>extended_states</filename> file."
+#~ msgstr ""
+#~ "Statusliste automatisch installierter Pakete. Konfigurationselement: "
+#~ "<literal>Dir::State</literal> setzt den Pfad zur Datei "
+#~ "<filename>extended_states</filename>."
+
 #~ msgid "Pin: release n=squeeze\n"
 #~ msgstr "Pin: release n=squeeze\n"
 

=== modified file 'doc/po/es.po'
--- doc/po/es.po	2010-05-25 16:01:42 +0000
+++ doc/po/es.po	2010-06-10 14:02:22 +0000
@@ -36,7 +36,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: apt 0.7.25\n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: 2010-03-02 18:43+0200\n"
 "Last-Translator: Francisco Javier Cuadrado <fcocuadrado@gmail.com>\n"
 "Language-Team: Debian Spanish l10n <debian-l10n-spanish@lists.debian.org>\n"
@@ -1127,7 +1127,31 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:369
+#: apt.ent:373
+#, fuzzy, no-wrap
+#| msgid ""
+#| "<!ENTITY file-sourceslist \"\n"
+#| "     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+#| "     <listitem><para>Locations to fetch packages from.\n"
+#| "     Configuration Item: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+#| "     </varlistentry>\n"
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr ""
+"<!ENTITY file-sourceslist \"\n"
+"     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+"     <listitem><para>Ubicaciones de dónde conseguir los paquetes.\n"
+"     Opción de configuración: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+"     </varlistentry>\n"
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - comparable\n"
@@ -1136,7 +1160,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has contributed\n"
@@ -1150,7 +1174,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of untranslated/fuzzy strings\n"
@@ -1166,7 +1190,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> <!"
 "ENTITY testing-codename \"squeeze\">"
@@ -1788,8 +1812,8 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
 #: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56
-#: apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89
-#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89
+#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr "Opciones"
 
@@ -1815,7 +1839,7 @@
 "configuración: <literal>Dir::Cache::pkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362
 #: apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr "<option>-s</option>"
@@ -1841,12 +1865,12 @@
 "Opción de configuración: <literal>Dir::Cache::srcpkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr "<option>-q</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr "<option>--quiet</option>"
 
@@ -1905,7 +1929,7 @@
 "Opción de configuración: <literal>APT::Cache::ShowFull</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr "<option>-a</option>"
 
@@ -2022,14 +2046,14 @@
 
 #. type: Content of: <refentry><refsect1><variablelist>
 #: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98
-#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547
+#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547
 #: apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr "&apt-commonoptions;"
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122
-#: apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr "Ficheros"
 
@@ -2040,9 +2064,9 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103
-#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562
-#: apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181
-#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651
+#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562
+#: apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181
+#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651
 #: sources.list.5.xml:233
 msgid "See Also"
 msgstr "Véase también"
@@ -2054,8 +2078,8 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108
-#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568
-#: apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568
+#: apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr "Diagnósticos"
 
@@ -2196,7 +2220,7 @@
 msgstr "Opciones"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr "<option>-d</option>"
 
@@ -2441,7 +2465,7 @@
 msgstr "Sólo muestra el contenido del espacio de configuración."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619
 #: apt-sortpkgs.1.xml:70
 msgid "&apt-conf;"
 msgstr "&apt-conf;"
@@ -2776,14 +2800,25 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #: apt-ftparchive.1.xml:119
+#, fuzzy
+#| msgid ""
+#| "Values for the additional metadata fields in the Release file are taken "
+#| "from the corresponding variables under <literal>APT::FTPArchive::Release</"
+#| "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
+#| "supported fields are: <literal>Origin</literal>, <literal>Label</"
+#| "literal>, <literal>Suite</literal>, <literal>Version</literal>, "
+#| "<literal>Codename</literal>, <literal>Date</literal>, "
+#| "<literal>Architectures</literal>, <literal>Components</literal>, "
+#| "<literal>Description</literal>."
 msgid ""
 "Values for the additional metadata fields in the Release file are taken from "
 "the corresponding variables under <literal>APT::FTPArchive::Release</"
 "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
 "supported fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, <literal>Codename</"
-"literal>, <literal>Date</literal>, <literal>Architectures</literal>, "
-"<literal>Components</literal>, <literal>Description</literal>."
+"literal>, <literal>Date</literal>, <literal>Valid-Until</literal>, "
+"<literal>Architectures</literal>, <literal>Components</literal>, "
+"<literal>Description</literal>."
 msgstr ""
 "Los valores para los campos de metadatos adicionales en el fichero «Release» "
 "se toman de las variables correspondientes en <literal>APT::FTPArchive::"
@@ -2795,12 +2830,12 @@
 "<literal>Description</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 msgid "generate"
 msgstr "generate"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2816,12 +2851,12 @@
 "configuración necesaria."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr "clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
@@ -2831,12 +2866,12 @@
 "necesarios."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 msgid "The Generate Configuration"
 msgstr "La configuración de «generate»"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2854,7 +2889,7 @@
 "etiqueta."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid ""
 "The generate configuration has 4 separate sections, each described below."
 msgstr ""
@@ -2862,12 +2897,12 @@
 "describen a continuación."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 msgid "Dir Section"
 msgstr "Sección Dir"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 msgid ""
 "The <literal>Dir</literal> section defines the standard directories needed "
 "to locate the files required during the generation process. These "
@@ -2880,12 +2915,12 @@
 "secciones posteriores para producir una ruta absoluta."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr "Sección ArchiveDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2896,32 +2931,32 @@
 "«dist»."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr "Sección OverrideDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr "Define la ubicación de los ficheros alternativos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr "Sección CacheDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr "Define la ubicación de los ficheros de la caché."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr "Sección FileListDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the <literal>FileList</"
 "literal> setting is used below."
@@ -2930,12 +2965,12 @@
 "posteriormente el valor <literal>FileList</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr "Sección Default"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -2946,12 +2981,12 @@
 "sobrescribir estos valores predeterminados con un valor de la sección."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr "Packages::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -2965,12 +3000,12 @@
 "compresión es «. gzip»."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr "Packages::Extensions"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
@@ -2979,12 +3014,12 @@
 "paquete. El valor predeterminado es «.deb»."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr "Sources::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
@@ -2993,12 +3028,12 @@
 "controla la compresión para los ficheros «Sources»."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr "Sources::Extensions"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
@@ -3007,12 +3042,12 @@
 "ficheros de fuentes. El valor predeterminado es «.dsc»."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr "Contents::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
@@ -3021,14 +3056,14 @@
 "controla la compresión para los ficheros «Contents»."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 #, fuzzy
 #| msgid "Contents::Compress"
 msgid "Translation::Compress"
 msgstr "Contents::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 #, fuzzy
 #| msgid ""
 #| "This is similar to <literal>Packages::Compress</literal> except that it "
@@ -3041,12 +3076,12 @@
 "controla la compresión para los ficheros «Contents»."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr "DeLinkLimit"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section <literal>External-"
@@ -3057,12 +3092,12 @@
 "cada sección."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr "FileMode"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
@@ -3072,26 +3107,26 @@
 "sin tener en cuenta la máscara de usuario («umask»)."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 #, fuzzy
 #| msgid "Description"
 msgid "LongDescription"
 msgstr "Descripción"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr "Sección TreeDefault"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -3102,12 +3137,12 @@
 "$(DIST), $(SECTION) y $(ARCH) con sus valores respectivos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr "MaxContentsChange"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each day. "
 "The contents files are round-robined so that over several days they will all "
@@ -3118,12 +3153,12 @@
 "que durante varios días todos se regenerarán."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr "ContentsAge"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is updated. "
@@ -3142,12 +3177,12 @@
 "unidades usadas son días."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr "Directory"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to <filename>$(DIST)/"
 "$(SECTION)/binary-$(ARCH)/</filename>"
@@ -3156,12 +3191,12 @@
 "$(DIST)/$(SECTION)/binary-$(ARCH)/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr "SrcDirectory"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to <filename>"
 "$(DIST)/$(SECTION)/source/</filename>"
@@ -3170,12 +3205,12 @@
 "predeterminado es <filename>$(DIST)/$(SECTION)/source/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr "Packages"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "binary-$(ARCH)/Packages</filename>"
@@ -3184,12 +3219,12 @@
 "$(DIST)/$(SECTION)/binary-$(ARCH)/Packages</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr "Sources"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 #, fuzzy
 #| msgid ""
 #| "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
@@ -3202,14 +3237,14 @@
 "$(DIST)/$(SECTION)/source/Sources</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 #, fuzzy
 #| msgid "Operation"
 msgid "Translation"
 msgstr "Operación"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to <filename>$(DIST)/"
@@ -3217,12 +3252,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr "InternalPrefix"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to <filename>$(DIST)/$(SECTION)/</"
@@ -3233,12 +3268,12 @@
 "<filename>$(DIST)/$(SECTION)/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr "Contents"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to <filename>$(DIST)/Contents-$(ARCH)"
 "</filename>. If this setting causes multiple Packages files to map onto a "
@@ -3252,22 +3287,22 @@
 "esos ficheros de paquete juntos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr "Contents::Header"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr "Define el fichero de cabecera a añadir al fichero «Contents» de salida."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr "BinCacheDB"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
@@ -3276,12 +3311,12 @@
 "Varias secciones pueden compartir la misma base de datos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr "FileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3293,12 +3328,12 @@
 "como prefijo el directorio del archivo."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr "SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3312,12 +3347,12 @@
 "índices de fuentes."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr "Sección Tree"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -3332,7 +3367,7 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 #, fuzzy
 #| msgid ""
 #| "The <literal>Tree</literal> section takes a scope tag which sets the "
@@ -3351,7 +3386,7 @@
 "valor como <filename>dists/woody</filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -3362,7 +3397,7 @@
 "variables."
 
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, fuzzy, no-wrap
 #| msgid ""
 #| "for i in Sections do \n"
@@ -3379,7 +3414,7 @@
 "      Generar con DIST=scope SECTION=i ARCH=j\n"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 #, fuzzy
 #| msgid ""
 #| "When processing a <literal>Tree</literal> section <command>apt-"
@@ -3393,12 +3428,12 @@
 "ftparchive</command> realiza una operación similar a la siguiente:"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 msgid "Sections"
 msgstr "Secciones"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib non-"
@@ -3409,12 +3444,12 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr "Arquitecturas"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -3425,12 +3460,12 @@
 "indicar que este árbol tiene un fichero de fuentes."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 msgid "BinOverride"
 msgstr "BinOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
@@ -3439,12 +3474,12 @@
 "sección, la prioridad y la dirección del mantenedor."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr "SrcOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
@@ -3453,32 +3488,32 @@
 "la sección."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr "ExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr "Define el fichero binario alternativo adicional."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr "SrcExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr "Define el fichero de fuentes alternativo adicional."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr "Sección BinDirectory"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -3493,12 +3528,12 @@
 "<literal>Section</literal><literal>Architecture</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr "Define el fichero «Packages» de salida."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
@@ -3507,52 +3542,52 @@
 "<literal>Packages</literal> o <literal>Sources</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr "Define el fichero «Contents» de salida. (Opcional)"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr "Define el fichero binario alternativo."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr "Define el fichero de fuentes alternativo."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr "Define la base de datos de la caché."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr "PathPrefix"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr "Añade una ruta a todas las rutas de salida."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr "FileList, SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr "Define el fichero de la lista de ficheros."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 msgid "The Binary Override File"
 msgstr "El fichero binario alternativo"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -3567,19 +3602,19 @@
 "de permutación del mantenedor."
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr "antigua [// antigua-n]* => nueva"
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr "nueva"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder type="
 "\"literallayout\" id=\"0\"/> or simply, <placeholder type=\"literallayout\" "
@@ -3596,12 +3631,12 @@
 "segunda forma sustituye de forma incondicional el campo del mantenedor."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 msgid "The Source Override File"
 msgstr "El fichero de fuentes alternativo"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -3612,12 +3647,12 @@
 "nombre del paquete fuente, el segundo es la sección a la que se asignará."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr "El fichero alternativo adicional"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -3628,12 +3663,12 @@
 "paquete, la segunda es la etiqueta y el resto de la línea es el nuevo valor."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr "<option>--md5</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -3645,12 +3680,12 @@
 "FTPArchive::MD5</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr "<option>--db</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
 "Configuration Item: <literal>APT::FTPArchive::DB</literal>."
@@ -3659,7 +3694,7 @@
 "«generate». Opción de configuración: <literal>APT::FTPArchive::DB</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -3673,12 +3708,12 @@
 "configuración. Opción de configuración: <literal>quiet</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr "<option>--delink</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
 "then this option actually enables delinking of the files. It defaults to on "
@@ -3691,12 +3726,12 @@
 "Opción de configuración: <literal>APT::FTPArchive::DeLinkAct</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr "<option>--contents</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -3713,12 +3748,12 @@
 "Contents</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr "<option>--source-override</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
 "command.  Configuration Item: <literal>APT::FTPArchive::SourceOverride</"
@@ -3729,12 +3764,12 @@
 "FTPArchive::SourceOverride</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr "<option>--readonly</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 msgid ""
 "Make the caching databases read only.  Configuration Item: <literal>APT::"
 "FTPArchive::ReadOnlyDB</literal>."
@@ -3743,14 +3778,14 @@
 "Opción de configuración: <literal>APT::FTPArchive::ReadOnlyDB</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 #, fuzzy
 #| msgid "<option>-a</option>"
 msgid "<option>--arch</option>"
 msgstr "<option>-a</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 #, fuzzy
 #| msgid ""
 #| "If the command is either <literal>install</literal> or <literal>remove</"
@@ -3769,14 +3804,14 @@
 "configuración: <literal>APT::Get::AutomaticRemove</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 #, fuzzy
 #| msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr "<option>APT::FTPArchive::LongDescription</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -3790,12 +3825,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr "<option>APT::FTPArchive::LongDescription</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 #, fuzzy
 #| msgid ""
 #| "This configuration option defaults to \"<literal>true</literal>\" and "
@@ -3818,19 +3853,19 @@
 "command>."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491
 #: sources.list.5.xml:193
 msgid "Examples"
 msgstr "Ejemplos"
 
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 msgstr "<command>apt-ftparchive</command> packages <replaceable>directorio</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
@@ -3839,7 +3874,7 @@
 "paquetes binarios («.deb»): <placeholder type=\"programlisting\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -5471,29 +5506,18 @@
 msgid "Show the program version."
 msgstr "Muestra la versión del programa."
 
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr "<filename>/var/lib/apt/extended_states</filename>"
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: <literal>Dir::"
-"State</literal> sets the path to the <filename>extended_states</filename> "
-"file."
+msgid "  &file-extended_states;"
 msgstr ""
-"Lista del estado de los paquetes instalados automáticamente. Opción de "
-"configuración: <literal>Dir::State</literal> define la ruta del fichero "
-"<filename>extended_states</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 msgid "&apt-get;,&aptitude;,&apt-conf;"
 msgstr "&apt-get;,&aptitude;,&apt-conf;"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -6446,11 +6470,47 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was created. "
+"The default is \"for ever\" (0) if the Release file of the archive doesn't "
+"include a <literal>Valid-Until</literal> header.  If it does then this date "
+"is the default. The date from the Release file or the date specified by the "
+"creation time of the Release file (<literal>Date</literal> header) plus the "
+"seconds specified with this options are used to check if the validation of a "
+"file has expired by using the earlier date of the two. Archive specific "
+"settings can be made by appending the label of the archive to the option "
+"name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr "PDiffs"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
@@ -6460,7 +6520,7 @@
 "predeterminada"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -6471,12 +6531,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr "Queue-Mode"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of <literal>host</"
 "literal> or <literal>access</literal> which determines how APT parallelizes "
@@ -6491,12 +6551,12 @@
 "se abrirá una conexión por cada tipo de URI."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr "Retries"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
@@ -6505,12 +6565,12 @@
 "intentar obtener los ficheros fallidos el número de veces proporcionado."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 msgid "Source-Symlinks"
 msgstr "Source-Symlinks"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
@@ -6520,12 +6580,12 @@
 "forma predeterminada."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr "http"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 msgid ""
 "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
 "standard form of <literal>http://[[user][:pass]@]host[:port]/</literal>. Per "
@@ -6543,7 +6603,7 @@
 "definir ninguna de las opciones anteriores."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -6568,7 +6628,7 @@
 "grandes. Aviso: Squid 2.0.2 no permite usar ninguna de estas opciones."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -6579,7 +6639,7 @@
 "realizar la conexión y para recibir datos."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 msgid ""
 "One setting is provided to control the pipeline depth in cases where the "
 "remote server is not RFC conforming or buggy (such as Squid 2.0.2).  "
@@ -6598,7 +6658,7 @@
 "necesitan esto violan la RFC 2068."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with <literal>Acquire::http::Dl-Limit</"
 "literal> which accepts integer values in kilobyte. The default value is 0 "
@@ -6613,7 +6673,7 @@
 "implícitamente la descarga simultánea desde varios servidores)."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -6624,12 +6684,12 @@
 "permiten el acceso para clientes que usan un identificador conocido."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr "https"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 msgid ""
 "HTTPS URIs. Cache-control, Timeout, AllowRedirect, Dl-Limit and proxy "
 "options are the same as for <literal>http</literal> method and will also "
@@ -6644,7 +6704,7 @@
 "<literal>Pipeline-Depth</literal> no se puede usar por ahora."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -6681,12 +6741,12 @@
 "corresponde a la opción por máquina."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr "ftp"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 msgid ""
 "FTP URIs; ftp::Proxy is the default ftp proxy to use. It is in the standard "
 "form of <literal>ftp://[[user][:pass]@]host[:port]/</literal>. Per host "
@@ -6720,7 +6780,7 @@
 "URI."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -6736,7 +6796,7 @@
 "fichero de configuración de muestra para ver algunos ejemplos)."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the <envar>ftp_proxy</"
 "envar> environment variable to a http url - see the discussion of the http "
@@ -6750,7 +6810,7 @@
 "de http debido a su poca eficiencia."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -6766,18 +6826,18 @@
 "compatibles con la RFC 2428."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr "cdrom"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, no-wrap
 msgid "/cdrom/::Mount \"foo\";"
 msgstr "/cdrom/::Mount \"algo\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -6799,12 +6859,12 @@
 "para desmontar usando UMount."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr "gpgv"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -6815,18 +6875,18 @@
 "introducidos a gpgv."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr "CompressionTypes"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> \"<replaceable>Methodname</replaceable>\";"
 msgstr "Acquire::CompressionTypes::<replaceable>extensión-del-fichero</replaceable> \"<replaceable>nombre-del-método</replaceable>\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -6846,19 +6906,19 @@
 "\"/>"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr "Acquire::CompressionTypes::Order:: \"gz\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -6889,13 +6949,13 @@
 "lista ya que se añadirá de forma automática."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr "Dir::Bin::bzip2 \"/bin/bzip2\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the <literal>Dir::Bin::<replaceable>Methodname</"
 "replaceable></literal> will be checked: If this setting exists the method "
@@ -6921,7 +6981,7 @@
 "lista definida, sólo añadirá este tipo  al principio de la lista."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -6936,12 +6996,12 @@
 "sin comprimir de modo que se permita el uso de réplicas locales."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr "Languages"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 #, fuzzy
 #| msgid ""
 #| "The Languages subsection controls which <filename>Translation</filename> "
@@ -6972,13 +7032,13 @@
 "informarse de cuales están disponibles antes de definir valores imposibles."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; }"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 #, fuzzy
 #| msgid ""
 #| "The default list includes \"environment\" and \"en\". "
@@ -7047,12 +7107,12 @@
 "paquetes y los gestores de URI. <placeholder type=\"variablelist\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr "Directorios"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -7072,7 +7132,7 @@
 "empiecen con <filename>/</filename> ó <filename>./</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -7094,7 +7154,7 @@
 "predeterminado está en <literal>Dir::Cache</literal>"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -7110,7 +7170,7 @@
 "<envar>APT_CONFIG</envar>)."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -7121,7 +7181,7 @@
 "Al finalizar este proceso carga el fichero de configuración principal."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 msgid ""
 "Binary programs are pointed to by <literal>Dir::Bin</literal>. <literal>Dir::"
 "Bin::Methods</literal> specifies the location of the method handlers and "
@@ -7138,7 +7198,7 @@
 "literal> especifican la ubicación de sus respectivos programas."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -7159,12 +7219,12 @@
 "staging/var/lib/dpkg/status</filename>."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 msgid "APT in DSelect"
 msgstr "APT con DSelect"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -7175,12 +7235,12 @@
 "encuentran en la sección <literal>DSelect</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 msgid "Clean"
 msgstr "Clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -7198,7 +7258,7 @@
 "descargar los paquetes nuevos."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
@@ -7207,12 +7267,12 @@
 "la línea de ordenes al ejecutar la fase de instalación."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 msgid "Updateoptions"
 msgstr "Updateoptions"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
@@ -7221,12 +7281,12 @@
 "la línea de ordenes al ejecutar la fase de actualización."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr "PromptAfterUpdate"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
@@ -7236,12 +7296,12 @@
 "preguntará en caso de error."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr "Cómo invoca APT a dpkg"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
@@ -7250,7 +7310,7 @@
 "se encuentran en la sección <literal>DPkg</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -7261,17 +7321,17 @@
 "introduce a &dpkg; como un sólo argumento."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr "Pre-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr "Post-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7284,12 +7344,12 @@
 "sh</filename>, y APT finalizará en caso de fallo."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr "Pre-Install-Pkgs"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7305,7 +7365,7 @@
 "instalar, uno por línea."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -7321,12 +7381,12 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr "Run-Directory"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is <filename>/"
 "</filename>."
@@ -7335,12 +7395,12 @@
 "predeterminado es <filename>/</filename>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 msgid "Build-options"
 msgstr "Build-options"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
@@ -7350,12 +7410,12 @@
 "paquetes y a producir todos los binarios."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr "Uso del disparador de dpkg (y de las opciones relacionadas)"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -7381,7 +7441,7 @@
 "mientras se están configurando todos los paquetes."
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -7395,7 +7455,7 @@
 "DPkg::TriggersPending \"true\";"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -7419,12 +7479,12 @@
 "\"literallayout\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr "DPkg::NoTriggers"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -7445,12 +7505,12 @@
 "opción a las llamadas de desempaquetado y borrado."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 msgid "PackageManager::Configure"
 msgstr "PackageManager::Configure"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -7478,12 +7538,12 @@
 "podría derivar en la imposibilidad de arrancar el sistema. "
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 msgid "DPkg::ConfigurePending"
 msgstr "DPkg::ConfigurePending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure --pending</"
 "command> to let dpkg handle all required configurations and triggers. This "
@@ -7501,12 +7561,12 @@
 "desactivar esta opción en todas las ejecuciones menos la última."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr "DPkg::TriggersPending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -7522,12 +7582,12 @@
 "necesarios para configurar este paquete."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr "PackageManager::UnpackAll"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by Pre-"
@@ -7547,12 +7607,12 @@
 "realmente útil."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr "OrderList::Score::Immediate"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -7570,7 +7630,7 @@
 "};"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -7595,12 +7655,12 @@
 "\"literallayout\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr "Las opciones «Periodic» y «Archives»"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -7614,12 +7674,12 @@
 "documentación de estas opciones."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 msgid "Debug options"
 msgstr "Opciones de depuración"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -7636,7 +7696,7 @@
 "para un usuario normal, aunque unas cuantas sí son:"
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, purge</"
@@ -7647,7 +7707,7 @@
 "purge</literal>."
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s install</"
@@ -7658,7 +7718,7 @@
 "<literal>apt-get -s install</literal>) como un usuario normal."
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -7670,7 +7730,7 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
 "in CDROM IDs."
@@ -7679,19 +7739,19 @@
 "statfs en los identificadores de los CDROM."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr ""
 "A continuación, se muestra la lista completa de las opciones de depuración "
 "de apt."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr "<literal>Debug::Acquire::cdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid ""
 "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
@@ -7699,46 +7759,46 @@
 "<literal>cdrom://</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr "<literal>Debug::Acquire::ftp</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr ""
 "Muestra la información relacionada con la descarga de paquetes mediante FTP."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr "<literal>Debug::Acquire::http</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr ""
 "Muestra la información relacionada con la descarga de paquetes mediante HTTP."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr "<literal>Debug::Acquire::https</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr ""
 "Muestra la información relacionada con la descarga de paquetes mediante "
 "HTTPS."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr "<literal>Debug::Acquire::gpgv</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
@@ -7747,12 +7807,12 @@
 "criptográficas mediante <literal>gpg</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr "<literal>Debug::aptcdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
@@ -7761,24 +7821,24 @@
 "paquetes almacenadas en CD-ROM."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr "<literal>Debug::BuildDeps</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 "Describe el proceso de resolución de dependencias de compilación en &apt-"
 "get;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 msgid "<literal>Debug::Hashes</literal>"
 msgstr "<literal>Debug::Hashes</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the <literal>apt</"
 "literal> libraries."
@@ -7787,12 +7847,12 @@
 "<literal>apt</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr "<literal>Debug::IdentCDROM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -7803,12 +7863,12 @@
 "identificador de un CD-ROM."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr "<literal>Debug::NoLocking</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
@@ -7818,24 +7878,24 @@
 "a la vez."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr "<literal>Debug::pkgAcquire</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 "Registra los elementos que se añaden o se borran de la cola de descarga "
 "global."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr "<literal>Debug::pkgAcquire::Auth</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
@@ -7845,12 +7905,12 @@
 "ficheros descargados."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr "<literal>Debug::pkgAcquire::Diffs</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
@@ -7859,12 +7919,12 @@
 "lista de índices de paquetes, y los errores relacionados con éstos."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr "<literal>Debug::pkgAcquire::RRed</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
@@ -7874,12 +7934,12 @@
 "índices completos."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr "<literal>Debug::pkgAcquire::Worker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid ""
 "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
@@ -7887,12 +7947,12 @@
 "descargas."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr "<literal>Debug::pkgAutoRemove</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
@@ -7901,12 +7961,12 @@
 "de los paquetes y con la eliminación de los paquetes sin usar."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial auto-"
@@ -7921,12 +7981,12 @@
 "<literal>apt</literal>. Véase <literal>Debug::pkgProblemResolver</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr "<literal>Debug::pkgDepCache::Marker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as keep/install/"
 "remove while the ProblemResolver does his work.  Each addition or deletion "
@@ -7956,24 +8016,24 @@
 "la sección en la que aparece el paquete."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr "<literal>Debug::pkgInitConfig</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr ""
 "Vuelca la configuración predeterminada a la salida estándar durante al "
 "iniciarse."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr "<literal>Debug::pkgDPkgPM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
@@ -7982,12 +8042,12 @@
 "invocó, con los argumentos separados por un espacio."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr "<literal>Debug::pkgDPkgProgressReporting</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
@@ -7996,12 +8056,12 @@
 "estado y cualquier error encontrado durante el análisis."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr "<literal>Debug::pkgOrderList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
@@ -8010,12 +8070,12 @@
 "literal> debería entregar los paquetes a &dpkg;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr "<literal>Debug::pkgPackageManager</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid ""
 "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr ""
@@ -8023,22 +8083,22 @@
 "&dpkg;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr "<literal>Debug::pkgPolicy</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr "Muestra la prioridad de cada lista de paquetes al iniciarse."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr "<literal>Debug::pkgProblemResolver</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
@@ -8047,12 +8107,12 @@
 "lo que ocurre cuando se encuentra un problema de dependencias complejo)."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -8063,12 +8123,12 @@
 "misma que la descrita en <literal>Debug::pkgDepCache::Marker</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 msgid "<literal>Debug::sourceList</literal>"
 msgstr "<literal>Debug::sourceList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from <filename>/etc/apt/vendors."
 "list</filename>."
@@ -8077,7 +8137,7 @@
 "vendors.list</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
@@ -8086,13 +8146,13 @@
 "valores de ejemplo para todas las opciones posibles."
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 msgid "&file-aptconf;"
 msgstr "&file-aptconf;"
 
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr "&apt-cache;, &apt-config;, &apt-preferences;."
 
@@ -11523,6 +11583,18 @@
 #~ "  </citerefentry>\"\n"
 #~ ">\n"
 
+#~ msgid "<filename>/var/lib/apt/extended_states</filename>"
+#~ msgstr "<filename>/var/lib/apt/extended_states</filename>"
+
+#~ msgid ""
+#~ "Status list of auto-installed packages.  Configuration Item: "
+#~ "<literal>Dir::State</literal> sets the path to the "
+#~ "<filename>extended_states</filename> file."
+#~ msgstr ""
+#~ "Lista del estado de los paquetes instalados automáticamente. Opción de "
+#~ "configuración: <literal>Dir::State</literal> define la ruta del fichero "
+#~ "<filename>extended_states</filename>."
+
 #~ msgid "Pin: release n=squeeze\n"
 #~ msgstr "Pin: release n=squeeze\n"
 

=== modified file 'doc/po/fr.po'
--- doc/po/fr.po	2010-05-25 16:01:42 +0000
+++ doc/po/fr.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: 2010-03-23 09:02+0100\n"
 "Last-Translator: Christian Perrier <bubulle@debian.org>\n"
 "Language-Team: fr <debian-l10n-french@lists.debian.org>\n"
@@ -1087,7 +1087,31 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:369
+#: apt.ent:373
+#, fuzzy, no-wrap
+#| msgid ""
+#| "<!ENTITY file-sourceslist \"\n"
+#| "     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+#| "     <listitem><para>Locations to fetch packages from.\n"
+#| "     Configuration Item: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+#| "     </varlistentry>\n"
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr ""
+"<!ENTITY file-sourceslist \"\n"
+"     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+"     <listitem><para>Emplacement pour la récupération des paquets.\n"
+"     Élément de configuration : <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+"     </varlistentry>\n"
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - comparable\n"
@@ -1096,7 +1120,7 @@
 msgstr "<!ENTITY translation-title \"TRADUCTEURS\">\n"
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has contributed\n"
@@ -1114,7 +1138,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of untranslated/fuzzy strings\n"
@@ -1135,7 +1159,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> <!"
 "ENTITY testing-codename \"squeeze\">"
@@ -1757,8 +1781,8 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
 #: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56
-#: apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89
-#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89
+#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr "options"
 
@@ -1784,7 +1808,7 @@
 "<literal>Dir::Cache::pkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362
 #: apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr "<option>-s</option>"
@@ -1811,12 +1835,12 @@
 "<literal>Dir::Cache::srcpkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr "<option>-q</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr "<option>--quiet</option>"
 
@@ -1877,7 +1901,7 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr "<option>-a</option>"
 
@@ -1997,14 +2021,14 @@
 
 #. type: Content of: <refentry><refsect1><variablelist>
 #: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98
-#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547
+#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547
 #: apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr "&apt-commonoptions;"
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122
-#: apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr "Fichiers"
 
@@ -2015,9 +2039,9 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103
-#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562
-#: apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181
-#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651
+#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562
+#: apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181
+#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651
 #: sources.list.5.xml:233
 msgid "See Also"
 msgstr "Voir aussi"
@@ -2029,8 +2053,8 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108
-#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568
-#: apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568
+#: apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr "Diagnostics"
 
@@ -2164,7 +2188,7 @@
 msgstr "Options"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr "<option>-d</option>"
 
@@ -2409,7 +2433,7 @@
 msgstr "Affiche seulement le contenu de l'espace de configuration."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619
 #: apt-sortpkgs.1.xml:70
 msgid "&apt-conf;"
 msgstr "&apt-conf;"
@@ -2724,14 +2748,25 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #: apt-ftparchive.1.xml:119
+#, fuzzy
+#| msgid ""
+#| "Values for the additional metadata fields in the Release file are taken "
+#| "from the corresponding variables under <literal>APT::FTPArchive::Release</"
+#| "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
+#| "supported fields are: <literal>Origin</literal>, <literal>Label</"
+#| "literal>, <literal>Suite</literal>, <literal>Version</literal>, "
+#| "<literal>Codename</literal>, <literal>Date</literal>, "
+#| "<literal>Architectures</literal>, <literal>Components</literal>, "
+#| "<literal>Description</literal>."
 msgid ""
 "Values for the additional metadata fields in the Release file are taken from "
 "the corresponding variables under <literal>APT::FTPArchive::Release</"
 "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
 "supported fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, <literal>Codename</"
-"literal>, <literal>Date</literal>, <literal>Architectures</literal>, "
-"<literal>Components</literal>, <literal>Description</literal>."
+"literal>, <literal>Date</literal>, <literal>Valid-Until</literal>, "
+"<literal>Architectures</literal>, <literal>Components</literal>, "
+"<literal>Description</literal>."
 msgstr ""
 "La valeur des autres champs du fichier Release est tirée de la valeur "
 "correspondante dans <literal>APT::FTPArchive::Release</literal>, p. ex. "
@@ -2742,12 +2777,12 @@
 "<literal>Components</literal>, <literal>Description</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 msgid "generate"
 msgstr "generate"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2761,12 +2796,12 @@
 "préciser index et répertoires aussi bien que les paramètres requis."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr "clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
@@ -2776,12 +2811,12 @@
 "sont plus nécessaires."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 msgid "The Generate Configuration"
 msgstr "Configuration de la commande generate"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2798,19 +2833,19 @@
 "arborescence. Cela n'affecte que l'usage de l'étiquette de visée (scope tag)."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid ""
 "The generate configuration has 4 separate sections, each described below."
 msgstr ""
 "Ce fichier de configuration possède quatre sections, décrites ci-dessous."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 msgid "Dir Section"
 msgstr "La section Dir"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 msgid ""
 "The <literal>Dir</literal> section defines the standard directories needed "
 "to locate the files required during the generation process. These "
@@ -2823,12 +2858,12 @@
 "manière à produire un chemin absolu et complet."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr "ArchiveDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2839,32 +2874,32 @@
 "filename> et les noeuds des distributions."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr "OverrideDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr "Indique l'emplacement des fichiers d'« override »."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr "CacheDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr "Indique l'emplacement des fichiers de cache."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr "FileListDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the <literal>FileList</"
 "literal> setting is used below."
@@ -2873,12 +2908,12 @@
 "sert de la valeur <literal>FileList</literal> définie plus bas)."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr "La section Default"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -2889,12 +2924,12 @@
 "annulées dans d'autres sections (paramètrage par section)."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr "Packages::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -2907,12 +2942,12 @@
 "défaut, c'est la chaîne « . gzip »."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr "Packages::Extensions"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
@@ -2921,12 +2956,12 @@
 "paquets. Par défaut, c'est « .deb »."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr "Sources::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
@@ -2935,12 +2970,12 @@
 "compressés les fichiers sources."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr "Sources::Extensions"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
@@ -2949,12 +2984,12 @@
 "fichiers sources. Par défaut, c'est « .dsc »."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr "Contents::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
@@ -2963,14 +2998,14 @@
 "compressés les fichiers « Contents »."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 #, fuzzy
 #| msgid "Contents::Compress"
 msgid "Translation::Compress"
 msgstr "Contents::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 #, fuzzy
 #| msgid ""
 #| "This is similar to <literal>Packages::Compress</literal> except that it "
@@ -2983,12 +3018,12 @@
 "compressés les fichiers « Contents »."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr "DeLinkLimit"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section <literal>External-"
@@ -2999,12 +3034,12 @@
 "paramètre <literal>External-Links</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr "FileMode"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
@@ -3014,26 +3049,26 @@
 "utilisateur (umasq) est ignoré."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 #, fuzzy
 #| msgid "Description"
 msgid "LongDescription"
 msgstr "Description"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr "La section TreeDefault"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -3045,12 +3080,12 @@
 "respective."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr "MaxContentsChange"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each day. "
 "The contents files are round-robined so that over several days they will all "
@@ -3062,12 +3097,12 @@
 "soient reconstruits."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr "ContentsAge"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is updated. "
@@ -3085,12 +3120,12 @@
 "nombre vaut 10, l'unité étant le jour."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr "Directory"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to <filename>$(DIST)/"
 "$(SECTION)/binary-$(ARCH)/</filename>"
@@ -3099,12 +3134,12 @@
 "$(DIST)/$(SECTION)/binary-$(ARCH)/</filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr "SrcDirectory"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to <filename>"
 "$(DIST)/$(SECTION)/source/</filename>"
@@ -3113,12 +3148,12 @@
 "<filename>$(DIST)/$(SECTION)/source/</filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr "Packages"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "binary-$(ARCH)/Packages</filename>"
@@ -3127,12 +3162,12 @@
 "$(SECTION)/binary-$(ARCH)/Packages</filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr "Sources"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 msgid ""
 "Sets the output Sources file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "source/Sources</filename>"
@@ -3141,14 +3176,14 @@
 "$(SECTION)/source/Sources</filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 #, fuzzy
 #| msgid "Operation"
 msgid "Translation"
 msgstr "Fonctionnement"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to <filename>$(DIST)/"
@@ -3156,12 +3191,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr "InternalPrefix"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to <filename>$(DIST)/$(SECTION)/</"
@@ -3172,12 +3207,12 @@
 "défaut, c'est <filename>$(DIST)/$(SECTION)/</filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr "Contents"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to <filename>$(DIST)/Contents-$(ARCH)"
 "</filename>. If this setting causes multiple Packages files to map onto a "
@@ -3190,22 +3225,22 @@
 "ftparchive</command> les intègre automatiquement."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr "Contents::Header"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr "Indique l'en-tête à préfixer au fichier « Contents » créé."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr "BinCacheDB"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
@@ -3214,12 +3249,12 @@
 "Différentes sections peuvent partager cette base de données."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr "FileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3230,12 +3265,12 @@
 "relatifs sont préfixés par le répertoire de l'archive."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr "SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3248,12 +3283,12 @@
 "traiter les index de sources."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr "La section Tree"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -3267,7 +3302,7 @@
 "par la variable de substitution <literal>Directory</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 #, fuzzy
 #| msgid ""
 #| "The <literal>Tree</literal> section takes a scope tag which sets the "
@@ -3286,7 +3321,7 @@
 "C'est par exemple : <filename>dists/woody</filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -3297,7 +3332,7 @@
 "trois nouvelles variables suivantes."
 
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, no-wrap
 msgid ""
 "for i in Sections do \n"
@@ -3311,7 +3346,7 @@
 "     "
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 msgid ""
 "When processing a <literal>Tree</literal> section <command>apt-ftparchive</"
 "command> performs an operation similar to: <placeholder type=\"programlisting"
@@ -3322,12 +3357,12 @@
 "\"programlisting\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 msgid "Sections"
 msgstr "Sections"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib non-"
@@ -3338,12 +3373,12 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr "Architectures"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -3354,12 +3389,12 @@
 "que l'arborescence est une arborescence de sources."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 msgid "BinOverride"
 msgstr "BinOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
@@ -3368,12 +3403,12 @@
 "informations sur la section, la priorité et le responsable du paquet."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr "SrcOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
@@ -3382,32 +3417,32 @@
 "informations sur la section."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr "ExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr "Indique un autre fichier d'« override » pour les binaires."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr "SrcExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr "Indique un autre fichier d'« override » pour les sources."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr "La section BinDirectory"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -3422,12 +3457,12 @@
 "paramètrage de <literal>Section</literal><literal>Architecture</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr "Définit le fichier « Packages » créé."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
@@ -3436,52 +3471,52 @@
 "<literal>Packages</literal> ou <literal>Sources</literal> est nécessaire."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr "Définit le fichier « Contents » créé."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr "Définit le fichier d'« override » pour les binaires."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr "Définit le fichier d'« override » pour les sources."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr "Définit la base de données cache."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr "PathPrefix"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr "Ajoute un chemin à tous les chemins créés."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr "FileList, SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr "Définit le fichier contenant la liste des fichiers."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 msgid "The Binary Override File"
 msgstr "Le fichier d'« Override » pour les binaires."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -3496,19 +3531,19 @@
 "responsable de paquet."
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr "old [// oldn]* =&gt; new"
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr "new"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder type="
 "\"literallayout\" id=\"0\"/> or simply, <placeholder type=\"literallayout\" "
@@ -3525,12 +3560,12 @@
 "deuxième forme remplace inconditionnellement le champ."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 msgid "The Source Override File"
 msgstr "Le fichier d'« Override » pour les sources"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -3541,12 +3576,12 @@
 "sa section."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr "Le fichier supplémentaire d'« Override »"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -3558,12 +3593,12 @@
 "la nouvelle valeur."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr "<option>--md5</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -3575,12 +3610,12 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr "<option>--db</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
 "Configuration Item: <literal>APT::FTPArchive::DB</literal>."
@@ -3590,7 +3625,7 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -3605,12 +3640,12 @@
 "configuration : <literal>quiet</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr "<option>--delink</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
 "then this option actually enables delinking of the files. It defaults to on "
@@ -3624,12 +3659,12 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr "<option>--contents</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -3645,12 +3680,12 @@
 "de configuration : <literal>APT::FTPArchive::Contents</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr "<option>--source-override</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
 "command.  Configuration Item: <literal>APT::FTPArchive::SourceOverride</"
@@ -3661,12 +3696,12 @@
 "FTPArchive::SourceOverride</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr "<option>--readonly</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 msgid ""
 "Make the caching databases read only.  Configuration Item: <literal>APT::"
 "FTPArchive::ReadOnlyDB</literal>."
@@ -3675,12 +3710,12 @@
 "configuration : <literal>APT::FTPArchive::ReadOnlyDB</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 msgid "<option>--arch</option>"
 msgstr "<option>--arch</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 msgid ""
 "Accept in the <literal>packages</literal> and <literal>contents</literal> "
 "commands only package files matching <literal>*_arch.deb</literal> or "
@@ -3694,12 +3729,12 @@
 "<literal>APT::FTPArchive::Architecture</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr "<option>APT::FTPArchive::AlwaysStat</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -3722,12 +3757,12 @@
 "survenir et l'ensemble de ces contrôles devient inutile."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr "<option>APT::FTPArchive::LongDescription</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 #, fuzzy
 #| msgid ""
 #| "This configuration option defaults to \"<literal>true</literal>\" and "
@@ -3749,19 +3784,19 @@
 "pas possible de créer ces fichiers avec <command>apt-ftparchive</command>."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491
 #: sources.list.5.xml:193
 msgid "Examples"
 msgstr "Exemples"
 
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 msgstr "<command>apt-ftparchive</command> packages <replaceable>répertoire</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
@@ -3770,7 +3805,7 @@
 "paquets binaires (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -5383,29 +5418,18 @@
 msgid "Show the program version."
 msgstr "Affiche la version du programme."
 
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr "<filename>/var/lib/apt/extended_states</filename>"
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: <literal>Dir::"
-"State</literal> sets the path to the <filename>extended_states</filename> "
-"file."
+msgid "  &file-extended_states;"
 msgstr ""
-"États des paquets automatiquement installés. L'élément de configuration "
-"<literal>Dir::State</literal> définit le chemin d'accès au fichier "
-"<filename>extended_states</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 msgid "&apt-get;,&aptitude;,&apt-conf;"
 msgstr "&apt-get;,&aptitude;,&apt-conf;"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -6347,11 +6371,47 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was created. "
+"The default is \"for ever\" (0) if the Release file of the archive doesn't "
+"include a <literal>Valid-Until</literal> header.  If it does then this date "
+"is the default. The date from the Release file or the date specified by the "
+"creation time of the Release file (<literal>Date</literal> header) plus the "
+"seconds specified with this options are used to check if the validation of a "
+"file has expired by using the earlier date of the two. Archive specific "
+"settings can be made by appending the label of the archive to the option "
+"name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr "PDiffs"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
@@ -6361,7 +6421,7 @@
 "télécharger entièrement. Par défaut à « true »."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -6380,12 +6440,12 @@
 "fichiers de différences."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr "Queue-Mode"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of <literal>host</"
 "literal> or <literal>access</literal> which determines how APT parallelizes "
@@ -6401,12 +6461,12 @@
 "initiée."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr "Retries"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
@@ -6416,12 +6476,12 @@
 "échoué."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 msgid "Source-Symlinks"
 msgstr "Source-Symlinks"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
@@ -6431,12 +6491,12 @@
 "archives de sources au lieu de les copier.  Par défaut à « true »."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr "http"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 msgid ""
 "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
 "standard form of <literal>http://[[user][:pass]@]host[:port]/</literal>. Per "
@@ -6456,7 +6516,7 @@
 "options de mandataire HTTP."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -6481,7 +6541,7 @@
 "en compte aucune de ces options."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -6492,7 +6552,7 @@
 "données."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 msgid ""
 "One setting is provided to control the pipeline depth in cases where the "
 "remote server is not RFC conforming or buggy (such as Squid 2.0.2).  "
@@ -6512,7 +6572,7 @@
 "cette option ne respectent pas la RFC 2068."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with <literal>Acquire::http::Dl-Limit</"
 "literal> which accepts integer values in kilobyte. The default value is 0 "
@@ -6527,7 +6587,7 @@
 "implicitement le téléchargement simultané depuis plusieurs serveurs."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -6539,12 +6599,12 @@
 "n'autorisent l'accès qu'aux client s'identifiant de manière spécifique.."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr "https"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 msgid ""
 "HTTPS URIs. Cache-control, Timeout, AllowRedirect, Dl-Limit and proxy "
 "options are the same as for <literal>http</literal> method and will also "
@@ -6560,7 +6620,7 @@
 "encore gérée."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -6592,12 +6652,12 @@
 "ou 'SSLv3'."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr "ftp"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 msgid ""
 "FTP URIs; ftp::Proxy is the default ftp proxy to use. It is in the standard "
 "form of <literal>ftp://[[user][:pass]@]host[:port]/</literal>. Per host "
@@ -6632,7 +6692,7 @@
 "correspond à l'élément respectif de l'URI."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -6649,7 +6709,7 @@
 "modèle de fichier de configuration)."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the <envar>ftp_proxy</"
 "envar> environment variable to a http url - see the discussion of the http "
@@ -6664,7 +6724,7 @@
 "efficacité de cette méthode."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -6680,18 +6740,18 @@
 "des serveurs FTP ne suivent pas la RFC 2428."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr "cdrom"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, no-wrap
 msgid "/cdrom/::Mount \"foo\";"
 msgstr "/cdrom/::Mount \"foo\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -6713,12 +6773,12 @@
 "spécifiées en utilisant <literal>UMount</literal>."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr "gpgv"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -6729,18 +6789,18 @@
 "supplémentaires passées à gpgv."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr "CompressionTypes"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> \"<replaceable>Methodname</replaceable>\";"
 msgstr "Acquire::CompressionTypes::<replaceable>ExtensionFichier</replaceable> \"<replaceable>NomMethode</replaceable>\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -6760,19 +6820,19 @@
 "type=\"synopsis\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr "Acquire::CompressionTypes::Order:: \"gz\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -6803,13 +6863,13 @@
 "<literal>bz2</literal> à liste car il sera ajouté automatiquement."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr "Dir::Bin::bzip2 \"/bin/bzip2\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the <literal>Dir::Bin::<replaceable>Methodname</"
 "replaceable></literal> will be checked: If this setting exists the method "
@@ -6835,7 +6895,7 @@
 "simplement préfixée avec l'option en question."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -6851,12 +6911,12 @@
 "non compressés afin de gérer des miroirs locaux."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr "Langues"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 msgid ""
 "The Languages subsection controls which <filename>Translation</filename> "
 "files are downloaded and in which order APT tries to display the Description-"
@@ -6878,13 +6938,13 @@
 "sur ce qui est disponible avant d'établir des réglages impossibles."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr "Acquire::Languages { \"environment\"; \"fr\"; \"en\"; \"none\"; \"de\"; };"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 msgid ""
 "The default list includes \"environment\" and \"en\". "
 "\"<literal>environment</literal>\" has a special meaning here: It will be "
@@ -6936,12 +6996,12 @@
 "id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr "Les répertoires"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -6961,7 +7021,7 @@
 "filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -6984,7 +7044,7 @@
 "Cache</literal>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -6999,7 +7059,7 @@
 "fichier de configuration indiqué par la variable <envar>APT_CONFIG</envar>)."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -7010,7 +7070,7 @@
 "configuration est chargé."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 msgid ""
 "Binary programs are pointed to by <literal>Dir::Bin</literal>. <literal>Dir::"
 "Bin::Methods</literal> specifies the location of the method handlers and "
@@ -7028,7 +7088,7 @@
 "programmes correspondants."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -7050,12 +7110,12 @@
 "staging/var/lib/dpkg/status</filename>."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 msgid "APT in DSelect"
 msgstr "APT et DSelect"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -7066,12 +7126,12 @@
 "<literal>DSelect</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 msgid "Clean"
 msgstr "Clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -7089,7 +7149,7 @@
 "supprime avant de récupérer de nouveaux paquets."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
@@ -7098,12 +7158,12 @@
 "&apt-get; lors de la phase d'installation."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 msgid "Updateoptions"
 msgstr "UpdateOptions"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
@@ -7112,12 +7172,12 @@
 "&apt-get; lors de la phase de mise à jour."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr "PromptAfterUpdate"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
@@ -7127,12 +7187,12 @@
 "d'erreur que l'on propose à l'utilisateur d'intervenir."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr "Méthode d'appel de &dpkg; par APT"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
@@ -7141,7 +7201,7 @@
 "&dpkg; : elles figurent dans la section <literal>DPkg</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -7152,17 +7212,17 @@
 "est passé comme un seul paramètre à &dpkg;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr "Pre-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr "Post-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7175,12 +7235,12 @@
 "<filename>/bin/sh</filename> : APT s'arrête dès que l'une d'elles échoue."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr "Pre-Install-Pkgs"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7196,7 +7256,7 @@
 "qu'il va installer, à raison d'un par ligne."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -7212,12 +7272,12 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr "Run-Directory"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is <filename>/"
 "</filename>."
@@ -7226,12 +7286,12 @@
 "le répertoire <filename>/</filename>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 msgid "Build-options"
 msgstr "Build-options"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
@@ -7241,14 +7301,14 @@
 "créés."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr ""
 "utilisation des actions différées (« triggers ») de dpkg (et options "
 "associées)"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -7275,7 +7335,7 @@
 "configuration des paquets."
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -7289,7 +7349,7 @@
 "DPkg::TriggersPending \"true\";"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -7313,12 +7373,12 @@
 "type=\"literallayout\" id=\"0\"/>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr "DPkg::NoTriggers"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -7340,12 +7400,12 @@
 "options « unpack » et « remove »."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 msgid "PackageManager::Configure"
 msgstr "PackageManager::Configure"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -7373,12 +7433,12 @@
 "configuré et donc éventuellement non amorçable."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 msgid "DPkg::ConfigurePending"
 msgstr "DPkg::ConfigurePending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure --pending</"
 "command> to let dpkg handle all required configurations and triggers. This "
@@ -7397,12 +7457,12 @@
 "peut conserver l'option active."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr "DPkg::TriggersPending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -7420,12 +7480,12 @@
 "celles concernant le paquet en cours de traitement."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr "PackageManager::UnpackAll"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by Pre-"
@@ -7450,12 +7510,12 @@
 "traduction n'est pas exclu...)."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr "OrderList::Score::Immediate"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -7473,7 +7533,7 @@
 "};"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -7499,12 +7559,12 @@
 "id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr "Options « Periodic » et « Archive »"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -7516,12 +7576,12 @@
 "script <literal>/etc/cron.daily/apt</literal>, lancé quotidiennement."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 msgid "Debug options"
 msgstr "Les options de débogage"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -7539,7 +7599,7 @@
 "peuvent tout de même être utiles :"
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, purge</"
@@ -7550,7 +7610,7 @@
 "upgrade, upgrade, install, remove et purge</literal>."
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s install</"
@@ -7562,7 +7622,7 @@
 "superutilisateur."
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -7574,7 +7634,7 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
 "in CDROM IDs."
@@ -7583,17 +7643,17 @@
 "type statfs dans les identifiants de CD."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr "Liste complète des options de débogage de APT :"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr "<literal>Debug::Acquire::cdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid ""
 "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
@@ -7601,44 +7661,44 @@
 "literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr "<literal>Debug::Acquire::ftp</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr ""
 "Affiche les informations concernant le téléchargement de paquets par FTP."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr "<literal>Debug::Acquire::http</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr ""
 "Affiche les informations concernant le téléchargement de paquets par HTTP."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr "<literal>Debug::Acquire::https</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr "Print information related to downloading packages using HTTPS."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr "<literal>Debug::Acquire::gpgv</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
@@ -7647,12 +7707,12 @@
 "cryptographiques avec <literal>gpg</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr "<literal>Debug::aptcdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
@@ -7661,24 +7721,24 @@
 "stockées sur CD."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr "<literal>Debug::BuildDeps</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 "Décrit le processus de résolution des dépendances pour la construction de "
 "paquets source ( « build-dependencies » ) par &apt-get;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 msgid "<literal>Debug::Hashes</literal>"
 msgstr "<literal>Debug::Hashes</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the <literal>apt</"
 "literal> libraries."
@@ -7687,12 +7747,12 @@
 "librairies d'<literal>apt</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr "<literal>Debug::IdentCDROM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -7703,12 +7763,12 @@
 "utilisés sur le système de fichier du CD."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr "<literal>Debug::NoLocking</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
@@ -7718,24 +7778,24 @@
 "temps."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr "<literal>Debug::pkgAcquire</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 "Trace les ajouts et suppressions d'éléments de la queue globale de "
 "téléchargement."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr "<literal>Debug::pkgAcquire::Auth</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
@@ -7745,12 +7805,12 @@
 "éventuelles."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr "<literal>Debug::pkgAcquire::Diffs</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
@@ -7760,12 +7820,12 @@
 "éventuelles."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr "<literal>Debug::pkgAcquire::RRed</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
@@ -7775,12 +7835,12 @@
 "place des fichiers complets."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr "<literal>Debug::pkgAcquire::Worker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid ""
 "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
@@ -7788,12 +7848,12 @@
 "effectivement des téléchargements."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr "<literal>Debug::pkgAutoRemove</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
@@ -7802,12 +7862,12 @@
 "automatiquement, et la suppression des paquets inutiles."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial auto-"
@@ -7822,12 +7882,12 @@
 "de APT ; voir <literal>Debug::pkgProblemResolver</literal> pour ce dernier."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr "<literal>Debug::pkgDepCache::Marker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as keep/install/"
 "remove while the ProblemResolver does his work.  Each addition or deletion "
@@ -7862,24 +7922,24 @@
 "de APT ; voir <literal>Debug::pkgProblemResolver</literal> pour ce dernier."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr "<literal>Debug::pkgInitConfig</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr ""
 "Affiche, au lancement, l'ensemble de la configuration sur la sortie d'erreur "
 "standard."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr "<literal>Debug::pkgDPkgPM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
@@ -7888,12 +7948,12 @@
 "paramètres sont séparés par des espaces."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr "<literal>Debug::pkgDPkgProgressReporting</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
@@ -7903,12 +7963,12 @@
 "fichier."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr "<literal>Debug::pkgOrderList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
@@ -7917,33 +7977,33 @@
 "<literal>apt</literal> passe les paquets à &dpkg;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr "<literal>Debug::pkgPackageManager</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid ""
 "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr "Affiche le détail des opérations liées à l'invocation de &dpkg;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr "<literal>Debug::pkgPolicy</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr "Affiche, au lancement, la priorité de chaque liste de paquets."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr "<literal>Debug::pkgProblemResolver</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
@@ -7952,12 +8012,12 @@
 "concerne que les cas où un problème de dépendances complexe se présente)."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -7968,12 +8028,12 @@
 "est décrite dans <literal>Debug::pkgDepCache::Marker</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 msgid "<literal>Debug::sourceList</literal>"
 msgstr "<literal>Debug::sourceList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from <filename>/etc/apt/vendors."
 "list</filename>."
@@ -7982,7 +8042,7 @@
 "list</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
@@ -7991,13 +8051,13 @@
 "exemples pour toutes les options existantes."
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 msgid "&file-aptconf;"
 msgstr "&file-aptconf;"
 
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr "&apt-cache;, &apt-config;, &apt-preferences;."
 
@@ -11417,6 +11477,18 @@
 #~ "  </citerefentry>\"\n"
 #~ ">\n"
 
+#~ msgid "<filename>/var/lib/apt/extended_states</filename>"
+#~ msgstr "<filename>/var/lib/apt/extended_states</filename>"
+
+#~ msgid ""
+#~ "Status list of auto-installed packages.  Configuration Item: "
+#~ "<literal>Dir::State</literal> sets the path to the "
+#~ "<filename>extended_states</filename> file."
+#~ msgstr ""
+#~ "États des paquets automatiquement installés. L'élément de configuration "
+#~ "<literal>Dir::State</literal> définit le chemin d'accès au fichier "
+#~ "<filename>extended_states</filename>."
+
 #~ msgid "Pin: release n=squeeze\n"
 #~ msgstr "Pin: release n=squeeze\n"
 

=== modified file 'doc/po/it.po'
--- doc/po/it.po	2010-05-25 16:01:42 +0000
+++ doc/po/it.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: \n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: 2003-04-26 23:26+0100\n"
 "Last-Translator: Traduzione di Eugenia Franzoni <eugenia@linuxcare.com>\n"
 "Language-Team: <debian-l10n-italian@lists.debian.org>\n"
@@ -764,7 +764,20 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:369
+#: apt.ent:373
+#, no-wrap
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr ""
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - comparable\n"
@@ -773,7 +786,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has contributed\n"
@@ -787,7 +800,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of untranslated/fuzzy strings\n"
@@ -803,7 +816,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> <!"
 "ENTITY testing-codename \"squeeze\">"
@@ -1262,8 +1275,8 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
 #: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56
-#: apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89
-#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89
+#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr ""
 
@@ -1286,7 +1299,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362
 #: apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr ""
@@ -1307,12 +1320,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr ""
 
@@ -1361,7 +1374,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr ""
 
@@ -1457,14 +1470,14 @@
 
 #. type: Content of: <refentry><refsect1><variablelist>
 #: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98
-#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547
+#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547
 #: apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122
-#: apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr ""
 
@@ -1475,9 +1488,9 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103
-#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562
-#: apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181
-#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651
+#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562
+#: apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181
+#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651
 #: sources.list.5.xml:233
 msgid "See Also"
 msgstr ""
@@ -1489,8 +1502,8 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108
-#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568
-#: apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568
+#: apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr ""
 
@@ -1594,7 +1607,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr ""
 
@@ -1789,7 +1802,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619
 #: apt-sortpkgs.1.xml:70
 msgid "&apt-conf;"
 msgstr ""
@@ -2025,18 +2038,19 @@
 "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
 "supported fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, <literal>Codename</"
-"literal>, <literal>Date</literal>, <literal>Architectures</literal>, "
-"<literal>Components</literal>, <literal>Description</literal>."
+"literal>, <literal>Date</literal>, <literal>Valid-Until</literal>, "
+"<literal>Architectures</literal>, <literal>Components</literal>, "
+"<literal>Description</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 #, fuzzy
 msgid "generate"
 msgstr "Descrizione generale"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2046,24 +2060,24 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 msgid "The Generate Configuration"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2074,18 +2088,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid ""
 "The generate configuration has 4 separate sections, each described below."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 msgid "Dir Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 msgid ""
 "The <literal>Dir</literal> section defines the standard directories needed "
 "to locate the files required during the generation process. These "
@@ -2094,12 +2108,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2107,44 +2121,44 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the <literal>FileList</"
 "literal> setting is used below."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -2152,12 +2166,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -2166,72 +2180,72 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 msgid "Translation::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Translation-en master file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section <literal>External-"
@@ -2239,36 +2253,36 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 msgid "LongDescription"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -2276,12 +2290,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each day. "
 "The contents files are round-robined so that over several days they will all "
@@ -2289,12 +2303,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is updated. "
@@ -2305,60 +2319,60 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to <filename>$(DIST)/"
 "$(SECTION)/binary-$(ARCH)/</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to <filename>"
 "$(DIST)/$(SECTION)/source/</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "binary-$(ARCH)/Packages</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 msgid ""
 "Sets the output Sources file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "source/Sources</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 msgid "Translation"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to <filename>$(DIST)/"
@@ -2366,12 +2380,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to <filename>$(DIST)/$(SECTION)/</"
@@ -2379,12 +2393,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to <filename>$(DIST)/Contents-$(ARCH)"
 "</filename>. If this setting causes multiple Packages files to map onto a "
@@ -2393,34 +2407,34 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -2428,12 +2442,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -2442,12 +2456,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -2457,7 +2471,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 msgid ""
 "The <literal>Tree</literal> section takes a scope tag which sets the "
 "<literal>$(DIST)</literal> variable and defines the root of the tree (the "
@@ -2466,7 +2480,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -2474,7 +2488,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, no-wrap
 msgid ""
 "for i in Sections do \n"
@@ -2484,7 +2498,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 msgid ""
 "When processing a <literal>Tree</literal> section <command>apt-ftparchive</"
 "command> performs an operation similar to: <placeholder type=\"programlisting"
@@ -2492,12 +2506,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 msgid "Sections"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib non-"
@@ -2505,12 +2519,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -2518,56 +2532,56 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 msgid "BinOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -2577,64 +2591,64 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 msgid "The Binary Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -2644,19 +2658,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder type="
 "\"literallayout\" id=\"0\"/> or simply, <placeholder type=\"literallayout\" "
@@ -2667,12 +2681,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 msgid "The Source Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -2680,12 +2694,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -2693,12 +2707,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -2706,19 +2720,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
 "Configuration Item: <literal>APT::FTPArchive::DB</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -2727,12 +2741,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
 "then this option actually enables delinking of the files. It defaults to on "
@@ -2741,12 +2755,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -2756,12 +2770,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
 "command.  Configuration Item: <literal>APT::FTPArchive::SourceOverride</"
@@ -2769,24 +2783,24 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 msgid ""
 "Make the caching databases read only.  Configuration Item: <literal>APT::"
 "FTPArchive::ReadOnlyDB</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 msgid "<option>--arch</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 msgid ""
 "Accept in the <literal>packages</literal> and <literal>contents</literal> "
 "commands only package files matching <literal>*_arch.deb</literal> or "
@@ -2795,12 +2809,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -2814,12 +2828,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 msgid ""
 "This configuration option defaults to \"<literal>true</literal>\" and should "
 "only be set to <literal>\"false\"</literal> if the Archive generated with "
@@ -2829,26 +2843,26 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491
 #: sources.list.5.xml:193
 msgid "Examples"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -4039,26 +4053,18 @@
 msgid "Show the program version."
 msgstr ""
 
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr ""
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: <literal>Dir::"
-"State</literal> sets the path to the <filename>extended_states</filename> "
-"file."
+msgid "  &file-extended_states;"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 msgid "&apt-get;,&aptitude;,&apt-conf;"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -4726,18 +4732,54 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was created. "
+"The default is \"for ever\" (0) if the Release file of the archive doesn't "
+"include a <literal>Valid-Until</literal> header.  If it does then this date "
+"is the default. The date from the Release file or the date specified by the "
+"creation time of the Release file (<literal>Date</literal> header) plus the "
+"seconds specified with this options are used to check if the validation of a "
+"file has expired by using the earlier date of the two. Archive specific "
+"settings can be made by appending the label of the archive to the option "
+"name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -4748,12 +4790,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of <literal>host</"
 "literal> or <literal>access</literal> which determines how APT parallelizes "
@@ -4763,36 +4805,36 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 msgid "Source-Symlinks"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 msgid ""
 "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
 "standard form of <literal>http://[[user][:pass]@]host[:port]/</literal>. Per "
@@ -4803,7 +4845,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -4817,7 +4859,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -4825,7 +4867,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 msgid ""
 "One setting is provided to control the pipeline depth in cases where the "
 "remote server is not RFC conforming or buggy (such as Squid 2.0.2).  "
@@ -4837,7 +4879,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with <literal>Acquire::http::Dl-Limit</"
 "literal> which accepts integer values in kilobyte. The default value is 0 "
@@ -4847,7 +4889,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -4855,12 +4897,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 msgid ""
 "HTTPS URIs. Cache-control, Timeout, AllowRedirect, Dl-Limit and proxy "
 "options are the same as for <literal>http</literal> method and will also "
@@ -4870,7 +4912,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -4891,12 +4933,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 msgid ""
 "FTP URIs; ftp::Proxy is the default ftp proxy to use. It is in the standard "
 "form of <literal>ftp://[[user][:pass]@]host[:port]/</literal>. Per host "
@@ -4915,7 +4957,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -4925,7 +4967,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the <envar>ftp_proxy</"
 "envar> environment variable to a http url - see the discussion of the http "
@@ -4934,7 +4976,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -4944,18 +4986,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, no-wrap
 msgid "/cdrom/::Mount \"foo\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -4968,12 +5010,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -4981,18 +5023,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> \"<replaceable>Methodname</replaceable>\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -5004,19 +5046,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -5033,13 +5075,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the <literal>Dir::Bin::<replaceable>Methodname</"
 "replaceable></literal> will be checked: If this setting exists the method "
@@ -5054,7 +5096,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -5064,12 +5106,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 msgid ""
 "The Languages subsection controls which <filename>Translation</filename> "
 "files are downloaded and in which order APT tries to display the Description-"
@@ -5082,13 +5124,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 msgid ""
 "The default list includes \"environment\" and \"en\". "
 "\"<literal>environment</literal>\" has a special meaning here: It will be "
@@ -5118,12 +5160,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -5135,7 +5177,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -5148,7 +5190,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -5158,7 +5200,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -5166,7 +5208,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 msgid ""
 "Binary programs are pointed to by <literal>Dir::Bin</literal>. <literal>Dir::"
 "Bin::Methods</literal> specifies the location of the method handlers and "
@@ -5177,7 +5219,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -5190,13 +5232,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 #, fuzzy
 msgid "APT in DSelect"
 msgstr "DSelect"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -5204,12 +5246,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 msgid "Clean"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -5220,50 +5262,50 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 msgid "Updateoptions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -5271,17 +5313,17 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -5290,12 +5332,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -5305,7 +5347,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -5315,36 +5357,36 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is <filename>/"
 "</filename>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 msgid "Build-options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -5359,7 +5401,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -5369,7 +5411,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -5383,12 +5425,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -5400,12 +5442,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 msgid "PackageManager::Configure"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -5421,12 +5463,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 msgid "DPkg::ConfigurePending"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure --pending</"
 "command> to let dpkg handle all required configurations and triggers. This "
@@ -5437,12 +5479,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -5452,12 +5494,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by Pre-"
@@ -5469,12 +5511,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -5486,7 +5528,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -5500,12 +5542,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -5514,12 +5556,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 msgid "Debug options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -5530,7 +5572,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, purge</"
@@ -5538,7 +5580,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s install</"
@@ -5546,7 +5588,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -5556,111 +5598,111 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
 "in CDROM IDs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid ""
 "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 msgid "<literal>Debug::Hashes</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the <literal>apt</"
 "literal> libraries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -5668,93 +5710,93 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid ""
 "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial auto-"
@@ -5764,12 +5806,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as keep/install/"
 "remove while the ProblemResolver does his work.  Each addition or deletion "
@@ -5786,91 +5828,91 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid ""
 "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -5878,32 +5920,32 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 msgid "<literal>Debug::sourceList</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from <filename>/etc/apt/vendors."
 "list</filename>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 msgid "&file-aptconf;"
 msgstr ""
 
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr ""
 

=== modified file 'doc/po/ja.po'
--- doc/po/ja.po	2010-05-25 16:01:42 +0000
+++ doc/po/ja.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: 2009-07-30 22:55+0900\n"
 "Last-Translator: KURASAWA Nozomu <nabetaro@caldron.jp>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -1095,8 +1095,23 @@
 "\">\n"
 msgstr "取得中状態情報格納エリア。設定項目 - <literal>Dir::State::Lists</literal> (必然的に不完全)"
 
-#. type: Plain text
-#: apt.ent:369
+# type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
+#. type: Plain text
+#: apt.ent:373
+#, fuzzy, no-wrap
+#| msgid "Storage area for state information for each package resource specified in &sources-list; Configuration Item: <literal>Dir::State::Lists</literal>."
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr "&sources-list; に指定した、パッケージリソースごとの状態情報格納エリア。設定項目 - <literal>Dir::State::Lists</literal>"
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - comparable\n"
@@ -1105,7 +1120,7 @@
 msgstr "<!ENTITY translation-title \"訳者\">\n"
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has contributed\n"
@@ -1123,7 +1138,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of untranslated/fuzzy strings\n"
@@ -1139,7 +1154,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> <!"
 "ENTITY testing-codename \"squeeze\">"
@@ -1796,8 +1811,8 @@
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
 #: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56
-#: apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89
-#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89
+#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr "オプション"
 
@@ -1824,7 +1839,7 @@
 "pkgcache</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362
 #: apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr "<option>-s</option>"
@@ -1851,12 +1866,12 @@
 "<literal>Dir::Cache::srcpkgcache</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr "<option>-q</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr "<option>--quiet</option>"
 
@@ -1917,7 +1932,7 @@
 "ShowFull</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr "<option>-a</option>"
 
@@ -2039,7 +2054,7 @@
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><variablelist>
 #: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98
-#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547
+#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547
 #: apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr "&apt-commonoptions;"
@@ -2047,7 +2062,7 @@
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122
-#: apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr "ファイル"
 
@@ -2059,9 +2074,9 @@
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103
-#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562
-#: apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181
-#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651
+#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562
+#: apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181
+#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651
 #: sources.list.5.xml:233
 msgid "See Also"
 msgstr "関連項目"
@@ -2075,8 +2090,8 @@
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108
-#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568
-#: apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568
+#: apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr "診断メッセージ"
 
@@ -2225,7 +2240,7 @@
 msgstr "オプション"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr "<option>-d</option>"
 
@@ -2483,7 +2498,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619
 #: apt-sortpkgs.1.xml:70
 msgid "&apt-conf;"
 msgstr "&apt-conf;"
@@ -2838,14 +2853,25 @@
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #: apt-ftparchive.1.xml:119
+#, fuzzy
+#| msgid ""
+#| "Values for the additional metadata fields in the Release file are taken "
+#| "from the corresponding variables under <literal>APT::FTPArchive::Release</"
+#| "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
+#| "supported fields are: <literal>Origin</literal>, <literal>Label</"
+#| "literal>, <literal>Suite</literal>, <literal>Version</literal>, "
+#| "<literal>Codename</literal>, <literal>Date</literal>, "
+#| "<literal>Architectures</literal>, <literal>Components</literal>, "
+#| "<literal>Description</literal>."
 msgid ""
 "Values for the additional metadata fields in the Release file are taken from "
 "the corresponding variables under <literal>APT::FTPArchive::Release</"
 "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
 "supported fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, <literal>Codename</"
-"literal>, <literal>Date</literal>, <literal>Architectures</literal>, "
-"<literal>Components</literal>, <literal>Description</literal>."
+"literal>, <literal>Date</literal>, <literal>Valid-Until</literal>, "
+"<literal>Architectures</literal>, <literal>Components</literal>, "
+"<literal>Description</literal>."
 msgstr ""
 "Release ファイルの追加メタデータフィールドの値は、<literal>APT::FTPArchive::"
 "Release</literal> 以下の相当する値 (例: <literal>APT::FTPArchive::Release::"
@@ -2856,13 +2882,13 @@
 "<literal>Description</literal> です。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 msgid "generate"
 msgstr "generate"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2876,13 +2902,13 @@
 "のディレクトリから作成するかを指定する、柔軟な方法を提供します。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr "clean"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
@@ -2892,13 +2918,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 msgid "The Generate Configuration"
 msgstr "Generate 設定"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2916,7 +2942,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid ""
 "The generate configuration has 4 separate sections, each described below."
 msgstr ""
@@ -2925,13 +2951,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 msgid "Dir Section"
 msgstr "Dir セクション"
 
 # type: Content of: <refentry><refsect1><refsect2><para>
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 #, fuzzy
 #| msgid ""
 #| "The <literal>Dir</literal> section defines the standard directories "
@@ -2950,13 +2976,13 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr "ArchiveDir"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2966,36 +2992,36 @@
 "リには <filename>ls-LR</filename> と dist ノードがあります。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr "OverrideDir"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr "オーバーライドファイルの場所を指定します。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr "CacheDir"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr "キャッシュファイルの場所を指定します。"
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr "FileListDir"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the <literal>FileList</"
 "literal> setting is used below."
@@ -3005,13 +3031,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr "Default セクション"
 
 # type: Content of: <refentry><refsect1><refsect2><para>
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -3023,13 +3049,13 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr "Packages::Compress"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -3041,13 +3067,13 @@
 "法のデフォルトはすべて '. gzip' です。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr "Packages::Extensions"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
@@ -3056,13 +3082,13 @@
 "deb' です。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr "Sources::Compress"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
@@ -3071,13 +3097,13 @@
 "指定します。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr "Sources::Extensions"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
@@ -3086,13 +3112,13 @@
 "す。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr "Contents::Compress"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
@@ -3101,7 +3127,7 @@
 "指定します。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 #, fuzzy
 #| msgid "Contents::Compress"
 msgid "Translation::Compress"
@@ -3109,7 +3135,7 @@
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 #, fuzzy
 #| msgid ""
 #| "This is similar to <literal>Packages::Compress</literal> except that it "
@@ -3122,13 +3148,13 @@
 "指定します。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr "DeLinkLimit"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section <literal>External-"
@@ -3140,13 +3166,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr "FileMode"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
@@ -3156,14 +3182,14 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 #, fuzzy
 #| msgid "Description"
 msgid "LongDescription"
 msgstr "説明"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
@@ -3171,13 +3197,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr "TreeDefault セクション"
 
 # type: Content of: <refentry><refsect1><refsect2><para>
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -3188,13 +3214,13 @@
 "に展開します。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr "MaxContentsChange"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each day. "
 "The contents files are round-robined so that over several days they will all "
@@ -3205,13 +3231,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr "ContentsAge"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is updated. "
@@ -3228,13 +3254,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr "Directory"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to <filename>$(DIST)/"
 "$(SECTION)/binary-$(ARCH)/</filename>"
@@ -3244,13 +3270,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr "SrcDirectory"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to <filename>"
 "$(DIST)/$(SECTION)/source/</filename>"
@@ -3260,13 +3286,13 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr "Packages"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "binary-$(ARCH)/Packages</filename>"
@@ -3276,13 +3302,13 @@
 
 # type: Content of: <refentry><refnamediv><refname>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr "Sources"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 #, fuzzy
 #| msgid ""
 #| "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
@@ -3296,13 +3322,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 #, fuzzy
 msgid "Translation"
 msgstr "オプション"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to <filename>$(DIST)/"
@@ -3310,13 +3336,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr "InternalPrefix"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to <filename>$(DIST)/$(SECTION)/</"
@@ -3327,13 +3353,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr "Contents"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to <filename>$(DIST)/Contents-$(ARCH)"
 "</filename>. If this setting causes multiple Packages files to map onto a "
@@ -3346,24 +3372,24 @@
 "ftparchive</command> は自動でパッケージファイルをまとめます。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr "Contents::Header"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr "contents の出力に付けるヘッダファイルを設定します。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr "BinCacheDB"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
@@ -3373,13 +3399,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr "FileList"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3391,13 +3417,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr "SourceFileList"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3410,13 +3436,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr "Tree セクション"
 
 # type: Content of: <refentry><refsect1><refsect2><para>
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -3431,7 +3457,7 @@
 
 # type: Content of: <refentry><refsect1><refsect2><para>
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 #, fuzzy
 #| msgid ""
 #| "The <literal>Tree</literal> section takes a scope tag which sets the "
@@ -3451,7 +3477,7 @@
 
 # type: Content of: <refentry><refsect1><refsect2><para>
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -3462,7 +3488,7 @@
 
 # type: Content of: <refentry><refsect1><refsect2><para><informalexample><programlisting>
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, fuzzy, no-wrap
 #| msgid ""
 #| "for i in Sections do \n"
@@ -3480,7 +3506,7 @@
 
 # type: Content of: <refentry><refsect1><refsect2><para><informalexample>
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 #, fuzzy
 #| msgid ""
 #| "When processing a <literal>Tree</literal> section <command>apt-"
@@ -3495,13 +3521,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 msgid "Sections"
 msgstr "Sections"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib non-"
@@ -3512,13 +3538,13 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr "Architectures"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -3530,13 +3556,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 msgid "BinOverride"
 msgstr "BinOverride"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
@@ -3546,13 +3572,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr "SrcOverride"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
@@ -3562,37 +3588,37 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr "ExtraOverride"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr "バイナリ特別オーバーライドファイルを設定します。"
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr "SrcExtraOverride"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr "ソース特別オーバーライドファイルを設定します。"
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr "BinDirectory セクション"
 
 # type: Content of: <refentry><refsect1><refsect2><para>
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -3607,13 +3633,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr "Packages ファイルの出力先を設定します。"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
@@ -3623,59 +3649,59 @@
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr "Contents ファイルの出力先を設定します。(オプション)"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr "バイナリオーバーライドファイルを設定します。"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr "ソースオーバーライドファイルを設定します。"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr "キャッシュ DB を設定します。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr "PathPrefix"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr "全出力パスに付加するパス。"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr "FileList, SourceFileList"
 
 # type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr "ファイル一覧ファイルを指定します。"
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 msgid "The Binary Override File"
 msgstr "バイナリオーバーライドファイル"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -3690,20 +3716,20 @@
 "す。"
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr "old [// oldn]* => new"
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr "new"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder type="
 "\"literallayout\" id=\"0\"/> or simply, <placeholder type=\"literallayout\" "
@@ -3721,13 +3747,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 msgid "The Source Override File"
 msgstr "ソースオーバーライドファイル"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -3739,13 +3765,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr "特別オーバーライドファイル"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -3755,13 +3781,13 @@
 "す。3 列からなり、先頭はパッケージ、2番目はタグ、残りは新しい値です。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr "<option>--md5</option>"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -3772,13 +3798,13 @@
 "FTPArchive::MD5</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr "<option>--db</option>"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
 "Configuration Item: <literal>APT::FTPArchive::DB</literal>."
@@ -3788,7 +3814,7 @@
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -3801,13 +3827,13 @@
 "<literal>quiet</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr "<option>--delink</option>"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
 "then this option actually enables delinking of the files. It defaults to on "
@@ -3820,13 +3846,13 @@
 "<literal>APT::FTPArchive::DeLinkAct</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr "<option>--contents</option>"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -3841,13 +3867,13 @@
 "<literal>APT::FTPArchive::Contents</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr "<option>--source-override</option>"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
 "command.  Configuration Item: <literal>APT::FTPArchive::SourceOverride</"
@@ -3857,13 +3883,13 @@
 "選択します。設定項目 - <literal>APT::FTPArchive::SourceOverride</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr "<option>--readonly</option>"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 msgid ""
 "Make the caching databases read only.  Configuration Item: <literal>APT::"
 "FTPArchive::ReadOnlyDB</literal>."
@@ -3872,7 +3898,7 @@
 "FTPArchive::ReadOnlyDB</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 #, fuzzy
 #| msgid "<option>-a</option>"
 msgid "<option>--arch</option>"
@@ -3880,7 +3906,7 @@
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 #, fuzzy
 #| msgid ""
 #| "If the command is either <literal>install</literal> or <literal>remove</"
@@ -3899,14 +3925,14 @@
 "literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 #, fuzzy
 #| msgid "<option>--version</option>"
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr "<option>--version</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -3920,14 +3946,14 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 #, fuzzy
 #| msgid "<option>--version</option>"
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr "<option>--version</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 msgid ""
 "This configuration option defaults to \"<literal>true</literal>\" and should "
 "only be set to <literal>\"false\"</literal> if the Archive generated with "
@@ -3938,21 +3964,21 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491
 #: sources.list.5.xml:193
 msgid "Examples"
 msgstr "サンプル"
 
 # type: Content of: <refentry><refsect1><para><programlisting>
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 msgstr "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
@@ -3962,7 +3988,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -5647,25 +5673,14 @@
 msgid "Show the program version."
 msgstr "プログラムのバージョン情報を表示します"
 
-# type: Content of: <refentry><refsect1><para>
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-#, fuzzy
-#| msgid "<filename>/etc/apt/preferences</filename>"
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr "<filename>/etc/apt/preferences</filename>"
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: <literal>Dir::"
-"State</literal> sets the path to the <filename>extended_states</filename> "
-"file."
+msgid "  &file-extended_states;"
 msgstr ""
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 #, fuzzy
 #| msgid "&apt-cache; &apt-conf;"
 msgid "&apt-get;,&aptitude;,&apt-conf;"
@@ -5673,7 +5688,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -6642,11 +6657,47 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was created. "
+"The default is \"for ever\" (0) if the Release file of the archive doesn't "
+"include a <literal>Valid-Until</literal> header.  If it does then this date "
+"is the default. The date from the Release file or the date specified by the "
+"creation time of the Release file (<literal>Date</literal> header) plus the "
+"seconds specified with this options are used to check if the validation of a "
+"file has expired by using the earlier date of the two. Archive specific "
+"settings can be made by appending the label of the archive to the option "
+"name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr "PDiffs"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
@@ -6656,7 +6707,7 @@
 "ルトでは True です。"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -6667,13 +6718,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr "Queue-Mode"
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of <literal>host</"
 "literal> or <literal>access</literal> which determines how APT parallelizes "
@@ -6688,13 +6739,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr "Retries"
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
@@ -6703,13 +6754,13 @@
 "えられた回数だけリトライを行います。"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 msgid "Source-Symlinks"
 msgstr "Source-Symlinks"
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
@@ -6720,13 +6771,13 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr "http"
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 #, fuzzy
 #| msgid ""
 #| "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
@@ -6752,7 +6803,7 @@
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -6777,7 +6828,7 @@
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -6789,7 +6840,7 @@
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 #, fuzzy
 #| msgid ""
 #| "One setting is provided to control the pipeline depth in cases where the "
@@ -6817,7 +6868,7 @@
 "ます。"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with <literal>Acquire::http::Dl-Limit</"
 "literal> which accepts integer values in kilobyte. The default value is 0 "
@@ -6827,7 +6878,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -6836,12 +6887,12 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr "https"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 #, fuzzy
 #| msgid ""
 #| "HTTPS URIs. Cache-control and proxy options are the same as for "
@@ -6859,7 +6910,7 @@
 "していません。"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -6881,13 +6932,13 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr "ftp"
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 #, fuzzy
 #| msgid ""
 #| "FTP URIs; ftp::Proxy is the default proxy server to use. It is in the "
@@ -6930,7 +6981,7 @@
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -6946,7 +6997,7 @@
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the <envar>ftp_proxy</"
 "envar> environment variable to a http url - see the discussion of the http "
@@ -6960,7 +7011,7 @@
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -6977,12 +7028,12 @@
 
 # type: Content of: <refentry><refnamediv><refname>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr "cdrom"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, fuzzy, no-wrap
 #| msgid "\"/cdrom/\"::Mount \"foo\";"
 msgid "/cdrom/::Mount \"foo\";"
@@ -6990,7 +7041,7 @@
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -7011,13 +7062,13 @@
 "す。"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr "gpgv"
 
 # type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -7028,18 +7079,18 @@
 "す。"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> \"<replaceable>Methodname</replaceable>\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -7051,19 +7102,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -7080,13 +7131,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the <literal>Dir::Bin::<replaceable>Methodname</"
 "replaceable></literal> will be checked: If this setting exists the method "
@@ -7101,7 +7152,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -7111,12 +7162,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 msgid ""
 "The Languages subsection controls which <filename>Translation</filename> "
 "files are downloaded and in which order APT tries to display the Description-"
@@ -7129,13 +7180,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 msgid ""
 "The default list includes \"environment\" and \"en\". "
 "\"<literal>environment</literal>\" has a special meaning here: It will be "
@@ -7170,13 +7221,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr "ディレクトリ"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -7196,7 +7247,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -7218,7 +7269,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -7233,7 +7284,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -7245,7 +7296,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 #, fuzzy
 #| msgid ""
 #| "Binary programs are pointed to by <literal>Dir::Bin</literal>. "
@@ -7270,7 +7321,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -7291,13 +7342,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 msgid "APT in DSelect"
 msgstr "DSelect での APT"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -7307,13 +7358,13 @@
 "設定項目で、デフォルトの動作を制御します。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 msgid "Clean"
 msgstr "Clean"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -7330,7 +7381,7 @@
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
@@ -7340,13 +7391,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 msgid "Updateoptions"
 msgstr "Updateoptions"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
@@ -7355,13 +7406,13 @@
 "されます。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr "PromptAfterUpdate"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
@@ -7371,13 +7422,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr "APT が dpkg を呼ぶ方法"
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
@@ -7387,7 +7438,7 @@
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -7397,18 +7448,18 @@
 "ければなりません。また、各リストは単一の引数として &dpkg; に渡されます。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr "Pre-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr "Post-Invoke"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7422,13 +7473,13 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr "Pre-Install-Pkgs"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7444,7 +7495,7 @@
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -7460,13 +7511,13 @@
 
 # type: Content of: <refentry><refsect1><refsect2><title>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr "Run-Directory"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is <filename>/"
 "</filename>."
@@ -7476,13 +7527,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 msgid "Build-options"
 msgstr "Build-options"
 
 # type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
@@ -7491,12 +7542,12 @@
 "ます。デフォルトでは署名を無効にし、全バイナリを生成します。"
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -7511,7 +7562,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -7521,7 +7572,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -7535,12 +7586,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -7553,14 +7604,14 @@
 
 # type: <tag></tag>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 #, fuzzy
 #| msgid "Packages::Compress"
 msgid "PackageManager::Configure"
 msgstr "Packages::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -7577,13 +7628,13 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 #, fuzzy
 msgid "DPkg::ConfigurePending"
 msgstr "ユーザの設定"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure --pending</"
 "command> to let dpkg handle all required configurations and triggers. This "
@@ -7594,12 +7645,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -7609,12 +7660,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by Pre-"
@@ -7626,12 +7677,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -7643,7 +7694,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -7657,12 +7708,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr "Periodic オプションと Archives オプション"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -7676,12 +7727,12 @@
 
 # type: Content of: <refentry><refsect1><title>
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 msgid "Debug options"
 msgstr "デバッグオプション"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -7692,7 +7743,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, purge</"
@@ -7703,7 +7754,7 @@
 "にします。"
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s install</"
@@ -7714,7 +7765,7 @@
 "literal>) を行う場合に使用します。"
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -7724,66 +7775,66 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
 "in CDROM IDs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr "<literal>Debug::Acquire::cdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid ""
 "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
 "<literal>cdrom://</literal> ソースへのアクセスに関する情報を出力します。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr "<literal>Debug::Acquire::ftp</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr "FTP を用いたパッケージのダウンロードに関する情報を出力します。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr "<literal>Debug::Acquire::http</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr "HTTP を用いたパッケージのダウンロードに関する情報を出力します。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr "<literal>Debug::Acquire::https</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr "HTTPS を用いたパッケージのダウンロードに関する情報を出力します。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr "<literal>Debug::Acquire::gpgv</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
@@ -7791,46 +7842,46 @@
 "<literal>gpg</literal> を用いた暗号署名の検証に関する情報を出力します。"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr "<literal>Debug::aptcdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr "<literal>Debug::BuildDeps</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 msgid "<literal>Debug::Hashes</literal>"
 msgstr "<literal>Debug::Hashes</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the <literal>apt</"
 "literal> libraries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr "<literal>Debug::IdentCDROM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -7838,93 +7889,93 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr "<literal>Debug::NoLocking</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr "<literal>Debug::pkgAcquire</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr "<literal>Debug::pkgAcquire::Auth</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr "<literal>Debug::pkgAcquire::Diffs</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr "<literal>Debug::pkgAcquire::RRed</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr "<literal>Debug::pkgAcquire::Worker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid ""
 "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr "<literal>Debug::pkgAutoRemove</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial auto-"
@@ -7934,12 +7985,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr "<literal>Debug::pkgDepCache::Marker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as keep/install/"
 "remove while the ProblemResolver does his work.  Each addition or deletion "
@@ -7956,91 +8007,91 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr "<literal>Debug::pkgInitConfig</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr "<literal>Debug::pkgDPkgPM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr "<literal>Debug::pkgDPkgProgressReporting</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr "<literal>Debug::pkgOrderList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr "<literal>Debug::pkgPackageManager</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid ""
 "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr "<literal>Debug::pkgPolicy</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr "<literal>Debug::pkgProblemResolver</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -8048,12 +8099,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 msgid "<literal>Debug::sourceList</literal>"
 msgstr "<literal>Debug::sourceList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from <filename>/etc/apt/vendors."
 "list</filename>."
@@ -8061,7 +8112,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
@@ -8071,7 +8122,7 @@
 
 # type: Content of: <refentry><refsect1><para>
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 #, fuzzy
 #| msgid "&apt-conf;"
 msgid "&file-aptconf;"
@@ -8080,7 +8131,7 @@
 # type: Content of: <refentry><refsect1><para>
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr "&apt-cache;, &apt-config;, &apt-preferences;."
 
@@ -11158,6 +11209,12 @@
 #~ "  </citerefentry>\"\n"
 #~ ">\n"
 
+# type: Content of: <refentry><refsect1><para>
+#, fuzzy
+#~| msgid "<filename>/etc/apt/preferences</filename>"
+#~ msgid "<filename>/var/lib/apt/extended_states</filename>"
+#~ msgstr "<filename>/etc/apt/preferences</filename>"
+
 # type: Content of: <refentry><refsect1><refsect2><para><variablelist><varlistentry><listitem><programlisting>
 #~ msgid "Pin: release n=squeeze\n"
 #~ msgstr "Pin: release n=squeeze\n"

=== modified file 'doc/po/pl.po'
--- doc/po/pl.po	2010-05-25 16:01:42 +0000
+++ doc/po/pl.po	2010-06-10 14:02:22 +0000
@@ -10,7 +10,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: apt 0.7.25.3\n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: 2010-03-18 22:00+0100\n"
 "Last-Translator: Robert Luberda <robert@debian.org>\n"
 "Language-Team: <debian-l10n-polish@lists.debian.org>\n"
@@ -1101,7 +1101,31 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:369
+#: apt.ent:373
+#, fuzzy, no-wrap
+#| msgid ""
+#| "<!ENTITY file-sourceslist \"\n"
+#| "     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+#| "     <listitem><para>Locations to fetch packages from.\n"
+#| "     Configuration Item: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+#| "     </varlistentry>\n"
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr ""
+"<!ENTITY file-sourceslist \"\n"
+"     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+"     <listitem><para>Lokalizacje, z których będą ściągane pakiety.\n"
+"     Pozycja w pliku konfiguracyjnym: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+"     </varlistentry>\n"
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - comparable\n"
@@ -1110,7 +1134,7 @@
 msgstr "<!ENTITY translation-title \"TŁUMACZENIE\">\n"
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has contributed\n"
@@ -1128,7 +1152,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of untranslated/fuzzy strings\n"
@@ -1149,7 +1173,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> <!"
 "ENTITY testing-codename \"squeeze\">"
@@ -1803,8 +1827,8 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
 #: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56
-#: apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89
-#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89
+#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr "opcje"
 
@@ -1831,7 +1855,7 @@
 "<literal>Dir::Cache::pkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362
 #: apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr "<option>-s</option>"
@@ -1859,12 +1883,12 @@
 "Cache::srcpkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr "<option>-q</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr "<option>--quiet</option>"
 
@@ -1926,7 +1950,7 @@
 "konfiguracyjnym: <literal>APT::Cache::ShowFull</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr "<option>-a</option>"
 
@@ -2052,14 +2076,14 @@
 
 #. type: Content of: <refentry><refsect1><variablelist>
 #: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98
-#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547
+#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547
 #: apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr "&apt-commonoptions;"
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122
-#: apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr "Pliki"
 
@@ -2070,9 +2094,9 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103
-#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562
-#: apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181
-#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651
+#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562
+#: apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181
+#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651
 #: sources.list.5.xml:233
 msgid "See Also"
 msgstr "Zobacz także"
@@ -2085,8 +2109,8 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108
-#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568
-#: apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568
+#: apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr "Diagnostyka"
 
@@ -2234,7 +2258,7 @@
 msgstr "Opcje"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr "<option>-d</option>"
 
@@ -2486,7 +2510,7 @@
 msgstr "Wyświetla zawartość przestrzeni konfiguracji."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619
 #: apt-sortpkgs.1.xml:70
 msgid "&apt-conf;"
 msgstr "&apt-conf;"
@@ -2787,17 +2811,18 @@
 "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
 "supported fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, <literal>Codename</"
-"literal>, <literal>Date</literal>, <literal>Architectures</literal>, "
-"<literal>Components</literal>, <literal>Description</literal>."
+"literal>, <literal>Date</literal>, <literal>Valid-Until</literal>, "
+"<literal>Architectures</literal>, <literal>Components</literal>, "
+"<literal>Description</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 msgid "generate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2807,25 +2832,25 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr "clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 #, fuzzy
 msgid "The Generate Configuration"
 msgstr "Plik konfiguracyjny"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2836,18 +2861,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid ""
 "The generate configuration has 4 separate sections, each described below."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 msgid "Dir Section"
 msgstr "Dir Section"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 msgid ""
 "The <literal>Dir</literal> section defines the standard directories needed "
 "to locate the files required during the generation process. These "
@@ -2856,12 +2881,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2869,44 +2894,44 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr "OverrideDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr "CacheDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr "FileListDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the <literal>FileList</"
 "literal> setting is used below."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -2914,12 +2939,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr "Packages::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -2928,74 +2953,74 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 #, fuzzy
 #| msgid "Packages::Compress"
 msgid "Translation::Compress"
 msgstr "Packages::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Translation-en master file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section <literal>External-"
@@ -3003,38 +3028,38 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr "FileMode"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 #, fuzzy
 #| msgid "Description"
 msgid "LongDescription"
 msgstr "Opis"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -3042,12 +3067,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each day. "
 "The contents files are round-robined so that over several days they will all "
@@ -3055,12 +3080,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is updated. "
@@ -3071,62 +3096,62 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to <filename>$(DIST)/"
 "$(SECTION)/binary-$(ARCH)/</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to <filename>"
 "$(DIST)/$(SECTION)/source/</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "binary-$(ARCH)/Packages</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr "Sources"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 msgid ""
 "Sets the output Sources file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "source/Sources</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 #, fuzzy
 #| msgid "Operation"
 msgid "Translation"
 msgstr "Kolejne kroki"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to <filename>$(DIST)/"
@@ -3134,12 +3159,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to <filename>$(DIST)/$(SECTION)/</"
@@ -3147,12 +3172,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to <filename>$(DIST)/Contents-$(ARCH)"
 "</filename>. If this setting causes multiple Packages files to map onto a "
@@ -3161,34 +3186,34 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr "BinCacheDB"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr "FileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3196,12 +3221,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr "SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3210,12 +3235,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -3225,7 +3250,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 msgid ""
 "The <literal>Tree</literal> section takes a scope tag which sets the "
 "<literal>$(DIST)</literal> variable and defines the root of the tree (the "
@@ -3234,7 +3259,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -3242,7 +3267,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, no-wrap
 msgid ""
 "for i in Sections do \n"
@@ -3256,7 +3281,7 @@
 "     "
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 msgid ""
 "When processing a <literal>Tree</literal> section <command>apt-ftparchive</"
 "command> performs an operation similar to: <placeholder type=\"programlisting"
@@ -3264,12 +3289,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 msgid "Sections"
 msgstr "Sections"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib non-"
@@ -3277,12 +3302,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -3290,57 +3315,57 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 #, fuzzy
 msgid "BinOverride"
 msgstr "BinOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr "SrcOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr "ExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr "SrcExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -3350,65 +3375,65 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 #, fuzzy
 msgid "The Binary Override File"
 msgstr "Wprowadzenie"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -3418,19 +3443,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr "old [// oldn]* => new"
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr "new"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder type="
 "\"literallayout\" id=\"0\"/> or simply, <placeholder type=\"literallayout\" "
@@ -3441,13 +3466,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 #, fuzzy
 msgid "The Source Override File"
 msgstr "Wprowadzenie"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -3455,12 +3480,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -3468,12 +3493,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr "<option>--md5</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -3481,13 +3506,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr "<option>--db</option>"
 
 #
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 #, fuzzy
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
@@ -3498,7 +3523,7 @@
 
 #
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -3512,13 +3537,13 @@
 "pliku konfiguracyjnym: <literal>quiet</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr "<option>--delink</option>"
 
 #
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 #, fuzzy
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
@@ -3532,12 +3557,12 @@
 "<literal>APT::Cache::Generate</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr "<option>--contents</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -3547,13 +3572,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr "<option>--source-override</option>"
 
 #
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 #, fuzzy
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
@@ -3565,13 +3590,13 @@
 "konfiguracyjnym: <literal>APT::Cache::Installed</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr "<option>--readonly</option>"
 
 #
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 #, fuzzy
 msgid ""
 "Make the caching databases read only.  Configuration Item: <literal>APT::"
@@ -3581,14 +3606,14 @@
 "pliku konfiguracyjnym: <literal>APT::Cache::NamesOnly</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 #, fuzzy
 #| msgid "<option>-a</option>"
 msgid "<option>--arch</option>"
 msgstr "<option>-a</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 #, fuzzy
 #| msgid ""
 #| "If the command is either <literal>install</literal> or <literal>remove</"
@@ -3608,13 +3633,13 @@
 "AutomaticRemove</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 #, fuzzy
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr "<option>--version</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -3628,13 +3653,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 #, fuzzy
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr "<option>--version</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 msgid ""
 "This configuration option defaults to \"<literal>true</literal>\" and should "
 "only be set to <literal>\"false\"</literal> if the Archive generated with "
@@ -3644,19 +3669,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491
 #: sources.list.5.xml:193
 msgid "Examples"
 msgstr "Przykłady"
 
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 msgstr "<command>apt-ftparchive</command> packages <replaceable>katalog</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
@@ -3664,7 +3689,7 @@
 
 #
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -5329,30 +5354,19 @@
 msgid "Show the program version."
 msgstr "Wyświetla wersję programu."
 
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr "<filename>/var/lib/apt/extended_states</filename>"
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: <literal>Dir::"
-"State</literal> sets the path to the <filename>extended_states</filename> "
-"file."
+msgid "  &file-extended_states;"
 msgstr ""
-"Lista stanów pakietów zainstalowanych automatycznie. Pozycja w pliku "
-"konfiguracyjnym:  <literal>Dir::State</literal> ustawia ścieżkę do pliku o "
-"nazwie <filename>extended_states</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 msgid "&apt-get;,&aptitude;,&apt-conf;"
 msgstr "&apt-get;,&aptitude;,&apt-conf;"
 
 #
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -6056,18 +6070,54 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was created. "
+"The default is \"for ever\" (0) if the Release file of the archive doesn't "
+"include a <literal>Valid-Until</literal> header.  If it does then this date "
+"is the default. The date from the Release file or the date specified by the "
+"creation time of the Release file (<literal>Date</literal> header) plus the "
+"seconds specified with this options are used to check if the validation of a "
+"file has expired by using the earlier date of the two. Archive specific "
+"settings can be made by appending the label of the archive to the option "
+"name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -6078,12 +6128,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of <literal>host</"
 "literal> or <literal>access</literal> which determines how APT parallelizes "
@@ -6093,37 +6143,37 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 #, fuzzy
 msgid "Source-Symlinks"
 msgstr "Sources"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr "http"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 msgid ""
 "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
 "standard form of <literal>http://[[user][:pass]@]host[:port]/</literal>. Per "
@@ -6134,7 +6184,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -6148,7 +6198,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -6156,7 +6206,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 msgid ""
 "One setting is provided to control the pipeline depth in cases where the "
 "remote server is not RFC conforming or buggy (such as Squid 2.0.2).  "
@@ -6168,7 +6218,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with <literal>Acquire::http::Dl-Limit</"
 "literal> which accepts integer values in kilobyte. The default value is 0 "
@@ -6178,7 +6228,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -6186,12 +6236,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr "https"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 msgid ""
 "HTTPS URIs. Cache-control, Timeout, AllowRedirect, Dl-Limit and proxy "
 "options are the same as for <literal>http</literal> method and will also "
@@ -6201,7 +6251,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -6222,12 +6272,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr "ftp"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 msgid ""
 "FTP URIs; ftp::Proxy is the default ftp proxy to use. It is in the standard "
 "form of <literal>ftp://[[user][:pass]@]host[:port]/</literal>. Per host "
@@ -6246,7 +6296,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -6256,7 +6306,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the <envar>ftp_proxy</"
 "envar> environment variable to a http url - see the discussion of the http "
@@ -6265,7 +6315,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -6275,18 +6325,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr "cdrom"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, no-wrap
 msgid "/cdrom/::Mount \"foo\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -6299,12 +6349,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr "gpgv"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -6312,18 +6362,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> \"<replaceable>Methodname</replaceable>\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -6335,19 +6385,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr "Acquire::CompressionTypes::Order:: \"gz\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -6364,13 +6414,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr "Dir::Bin::bzip2 \"/bin/bzip2\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the <literal>Dir::Bin::<replaceable>Methodname</"
 "replaceable></literal> will be checked: If this setting exists the method "
@@ -6385,7 +6435,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -6395,12 +6445,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 msgid ""
 "The Languages subsection controls which <filename>Translation</filename> "
 "files are downloaded and in which order APT tries to display the Description-"
@@ -6413,13 +6463,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 msgid ""
 "The default list includes \"environment\" and \"en\". "
 "\"<literal>environment</literal>\" has a special meaning here: It will be "
@@ -6449,12 +6499,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -6466,7 +6516,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -6479,7 +6529,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -6489,7 +6539,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -6497,7 +6547,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 msgid ""
 "Binary programs are pointed to by <literal>Dir::Bin</literal>. <literal>Dir::"
 "Bin::Methods</literal> specifies the location of the method handlers and "
@@ -6508,7 +6558,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -6521,12 +6571,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 msgid "APT in DSelect"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -6534,13 +6584,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 #, fuzzy
 msgid "Clean"
 msgstr "B<clean>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -6551,51 +6601,51 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 #, fuzzy
 msgid "Updateoptions"
 msgstr "opcje"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -6603,17 +6653,17 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -6622,12 +6672,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -6637,7 +6687,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -6647,37 +6697,37 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is <filename>/"
 "</filename>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 #, fuzzy
 msgid "Build-options"
 msgstr "opcje"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -6692,7 +6742,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -6706,7 +6756,7 @@
 "DPkg::TriggersPending \"true\";"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -6720,12 +6770,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr "DPkg::NoTriggers"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -6737,12 +6787,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 msgid "PackageManager::Configure"
 msgstr "PackageManager::Configure"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -6758,12 +6808,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 msgid "DPkg::ConfigurePending"
 msgstr "DPkg::ConfigurePending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure --pending</"
 "command> to let dpkg handle all required configurations and triggers. This "
@@ -6774,12 +6824,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr "DPkg::TriggersPending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -6789,12 +6839,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr "PackageManager::UnpackAll"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by Pre-"
@@ -6806,12 +6856,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr "OrderList::Score::Immediate"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -6829,7 +6879,7 @@
 "};"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -6843,12 +6893,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -6857,13 +6907,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 #, fuzzy
 msgid "Debug options"
 msgstr "opcje"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -6874,7 +6924,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, purge</"
@@ -6882,7 +6932,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s install</"
@@ -6890,7 +6940,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -6900,7 +6950,7 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 #, fuzzy
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
@@ -6910,104 +6960,104 @@
 "in CDROM IDs."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr "<literal>Debug::Acquire::cdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid ""
 "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr "<literal>Debug::Acquire::ftp</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr "<literal>Debug::Acquire::http</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr "<literal>Debug::Acquire::https</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr "<literal>Debug::Acquire::gpgv</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr "<literal>Debug::aptcdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr "<literal>Debug::BuildDeps</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 msgid "<literal>Debug::Hashes</literal>"
 msgstr "<literal>Debug::Hashes</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the <literal>apt</"
 "literal> libraries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr "<literal>Debug::IdentCDROM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -7015,93 +7065,93 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr "<literal>Debug::NoLocking</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr "<literal>Debug::pkgAcquire</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr "<literal>Debug::pkgAcquire::Auth</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr "<literal>Debug::pkgAcquire::Diffs</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr "<literal>Debug::pkgAcquire::RRed</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr "<literal>Debug::pkgAcquire::Worker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid ""
 "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr "<literal>Debug::pkgAutoRemove</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial auto-"
@@ -7111,12 +7161,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr "<literal>Debug::pkgDepCache::Marker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as keep/install/"
 "remove while the ProblemResolver does his work.  Each addition or deletion "
@@ -7133,91 +7183,91 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr "<literal>Debug::pkgInitConfig</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr "<literal>Debug::pkgDPkgPM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr "<literal>Debug::pkgDPkgProgressReporting</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr "<literal>Debug::pkgOrderList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr "<literal>Debug::pkgPackageManager</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid ""
 "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr "<literal>Debug::pkgPolicy</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr "<literal>Debug::pkgProblemResolver</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -7225,32 +7275,32 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 msgid "<literal>Debug::sourceList</literal>"
 msgstr "<literal>Debug::sourceList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from <filename>/etc/apt/vendors."
 "list</filename>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 msgid "&file-aptconf;"
 msgstr "&file-aptconf;"
 
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr "&apt-cache;, &apt-config;, &apt-preferences;."
 
@@ -10323,5 +10373,17 @@
 #~ "  </citerefentry>\"\n"
 #~ ">\n"
 
+#~ msgid "<filename>/var/lib/apt/extended_states</filename>"
+#~ msgstr "<filename>/var/lib/apt/extended_states</filename>"
+
+#~ msgid ""
+#~ "Status list of auto-installed packages.  Configuration Item: "
+#~ "<literal>Dir::State</literal> sets the path to the "
+#~ "<filename>extended_states</filename> file."
+#~ msgstr ""
+#~ "Lista stanów pakietów zainstalowanych automatycznie. Pozycja w pliku "
+#~ "konfiguracyjnym:  <literal>Dir::State</literal> ustawia ścieżkę do pliku "
+#~ "o nazwie <filename>extended_states</filename>."
+
 #~ msgid "Pin: release n=squeeze\n"
 #~ msgstr "Pin: release n=squeeze\n"

=== modified file 'doc/po/pt.po'
--- doc/po/pt.po	2010-05-25 16:01:42 +0000
+++ doc/po/pt.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: apt-doc 0.7.26~exp3\n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: 2010-03-19 00:21+0000\n"
 "Last-Translator: Américo Monteiro <a_monteiro@netcabo.pt>\n"
 "Language-Team: Portuguese <traduz@debianpt.org>\n"
@@ -1085,7 +1085,31 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:369
+#: apt.ent:373
+#, fuzzy, no-wrap
+#| msgid ""
+#| "<!ENTITY file-sourceslist \"\n"
+#| "     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+#| "     <listitem><para>Locations to fetch packages from.\n"
+#| "     Configuration Item: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+#| "     </varlistentry>\n"
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr ""
+"<!ENTITY file-sourceslist \"\n"
+"     <varlistentry><term><filename>/etc/apt/sources.list</filename></term>\n"
+"     <listitem><para>Localizações de onde obter pacotes.\n"
+"     Item de Configuração: <literal>Dir::Etc::SourceList</literal>.</para></listitem>\n"
+"     </varlistentry>\n"
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - comparable\n"
@@ -1094,7 +1118,7 @@
 msgstr "<!ENTITY translation-title \"TRADUÇÃO\">\n"
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has contributed\n"
@@ -1112,7 +1136,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of untranslated/fuzzy strings\n"
@@ -1133,7 +1157,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> <!"
 "ENTITY testing-codename \"squeeze\">"
@@ -1754,8 +1778,8 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
 #: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56
-#: apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89
-#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89
+#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr "opções"
 
@@ -1781,7 +1805,7 @@
 "<literal>Dir::Cache::pkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362
 #: apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr "<option>-s</option>"
@@ -1807,12 +1831,12 @@
 "pacote. Item de Configuração: <literal>Dir::Cache::srcpkgcache</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr "<option>-q</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr "<option>--quiet</option>"
 
@@ -1871,7 +1895,7 @@
 "<literal>APT::Cache::ShowFull</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr "<option>-a</option>"
 
@@ -1988,14 +2012,14 @@
 
 #. type: Content of: <refentry><refsect1><variablelist>
 #: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98
-#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547
+#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547
 #: apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr "&apt-commonoptions;"
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122
-#: apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr "Ficheiros"
 
@@ -2006,9 +2030,9 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103
-#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562
-#: apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181
-#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651
+#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562
+#: apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181
+#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651
 #: sources.list.5.xml:233
 msgid "See Also"
 msgstr "Veja também"
@@ -2020,8 +2044,8 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108
-#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568
-#: apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568
+#: apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr "Diagnóstico"
 
@@ -2155,7 +2179,7 @@
 msgstr "Opções"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr "<option>-d</option>"
 
@@ -2397,7 +2421,7 @@
 msgstr "Apenas mostra o conteúdo do espaço de configuração."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619
 #: apt-sortpkgs.1.xml:70
 msgid "&apt-conf;"
 msgstr "&apt-conf;"
@@ -2712,14 +2736,25 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
 #: apt-ftparchive.1.xml:119
+#, fuzzy
+#| msgid ""
+#| "Values for the additional metadata fields in the Release file are taken "
+#| "from the corresponding variables under <literal>APT::FTPArchive::Release</"
+#| "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
+#| "supported fields are: <literal>Origin</literal>, <literal>Label</"
+#| "literal>, <literal>Suite</literal>, <literal>Version</literal>, "
+#| "<literal>Codename</literal>, <literal>Date</literal>, "
+#| "<literal>Architectures</literal>, <literal>Components</literal>, "
+#| "<literal>Description</literal>."
 msgid ""
 "Values for the additional metadata fields in the Release file are taken from "
 "the corresponding variables under <literal>APT::FTPArchive::Release</"
 "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
 "supported fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, <literal>Codename</"
-"literal>, <literal>Date</literal>, <literal>Architectures</literal>, "
-"<literal>Components</literal>, <literal>Description</literal>."
+"literal>, <literal>Date</literal>, <literal>Valid-Until</literal>, "
+"<literal>Architectures</literal>, <literal>Components</literal>, "
+"<literal>Description</literal>."
 msgstr ""
 "Valores para os campos de metadados adicionais no ficheiro Release são "
 "tomados a partir das variáveis correspondentes sob <literal>APT::FTPArchive::"
@@ -2731,12 +2766,12 @@
 "<literal>Description</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 msgid "generate"
 msgstr "generate"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2752,12 +2787,12 @@
 "definições requeridas."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr "clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
@@ -2767,12 +2802,12 @@
 "são necessários."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 msgid "The Generate Configuration"
 msgstr "A Configuração do Generate"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2789,7 +2824,7 @@
 "árvore. Isto apenas afecta o modo de como a etiqueta scope é manuseada."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid ""
 "The generate configuration has 4 separate sections, each described below."
 msgstr ""
@@ -2797,12 +2832,12 @@
 "abaixo."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 msgid "Dir Section"
 msgstr "Secção Dir"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 msgid ""
 "The <literal>Dir</literal> section defines the standard directories needed "
 "to locate the files required during the generation process. These "
@@ -2815,12 +2850,12 @@
 "posteriores para produzir um caminho completo e absoluto."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr "ArchiveDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2830,32 +2865,32 @@
 "directório que contém o <filename>ls-LR</filename> e nós da distribuição."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr "OverrideDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr "Especifica a localização dos ficheiros de sobrepor."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr "CacheDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr "Especifica a localização dos ficheiros de cache"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr "FileListDir"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the <literal>FileList</"
 "literal> setting is used below."
@@ -2864,12 +2899,12 @@
 "definição <literal>FileList</literal> for usada mais abaixo."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr "Secção Default"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -2880,12 +2915,12 @@
 "sobrepor estas predefinições em uma definição por-secção."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr "Packages::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -2898,12 +2933,12 @@
 "predefinição para todos os esquemas de compressão é '. gzip'."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr "Packages::Extensions"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
@@ -2912,12 +2947,12 @@
 "pacote. A predefinição é '.deb'."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr "Sources::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
@@ -2926,12 +2961,12 @@
 "controla a compressão para os ficheiros das Fontes."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr "Sources::Extensions"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
@@ -2940,12 +2975,12 @@
 "fontes. A predefinição é '.dsc'."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr "Contents::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
@@ -2954,14 +2989,14 @@
 "controla a compressão para os ficheiros de Conteúdos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 #, fuzzy
 #| msgid "Contents::Compress"
 msgid "Translation::Compress"
 msgstr "Contents::Compress"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 #, fuzzy
 #| msgid ""
 #| "This is similar to <literal>Packages::Compress</literal> except that it "
@@ -2974,12 +3009,12 @@
 "controla a compressão para os ficheiros de Conteúdos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr "DeLinkLimit"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section <literal>External-"
@@ -2990,12 +3025,12 @@
 "Links</literal> por secção."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr "FileMode"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
@@ -3005,26 +3040,26 @@
 "independentemente do umask."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 #, fuzzy
 #| msgid "Description"
 msgid "LongDescription"
 msgstr "Descrição"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr "Secção TreeDefault"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -3035,12 +3070,12 @@
 "$(DIST), $(SECTION) e $(ARCH) substituídas pelos seus respectivos valores."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr "MaxContentsChange"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each day. "
 "The contents files are round-robined so that over several days they will all "
@@ -3051,12 +3086,12 @@
 "alguns dias todos sejam reconstruídos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr "ContentsAge"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is updated. "
@@ -3074,12 +3109,12 @@
 "modo. A predefinição é 10, as unidades são em dias."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr "Directory"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to <filename>$(DIST)/"
 "$(SECTION)/binary-$(ARCH)/</filename>"
@@ -3088,12 +3123,12 @@
 "$(DIST)/$(SECTION)/binary-$(ARCH)/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr "SrcDirectory"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to <filename>"
 "$(DIST)/$(SECTION)/source/</filename>"
@@ -3102,12 +3137,12 @@
 "<filename>$(DIST)/$(SECTION)/source/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr "Packages"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "binary-$(ARCH)/Packages</filename>"
@@ -3116,12 +3151,12 @@
 "$(SECTION)/binary-$(ARCH)/Packages</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr "Sources"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 msgid ""
 "Sets the output Sources file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "source/Sources</filename>"
@@ -3130,14 +3165,14 @@
 "$(SECTION)/source/Sources</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 #, fuzzy
 #| msgid "Operation"
 msgid "Translation"
 msgstr "Operação"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to <filename>$(DIST)/"
@@ -3145,12 +3180,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr "InternalPrefix"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to <filename>$(DIST)/$(SECTION)/</"
@@ -3161,12 +3196,12 @@
 "$(SECTION)/</filename>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr "Contents"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to <filename>$(DIST)/Contents-$(ARCH)"
 "</filename>. If this setting causes multiple Packages files to map onto a "
@@ -3180,22 +3215,22 @@
 "ficheiros pacotes todos juntos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr "Contents::Header"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr "Define o ficheiro cabeçalho para prefixar a saída de conteúdos."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr "BinCacheDB"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
@@ -3204,12 +3239,12 @@
 "secções podem partilhar a mesma base de dados."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr "FileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3221,12 +3256,12 @@
 "arquivo."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr "SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -3239,12 +3274,12 @@
 "arquivo. Isto é usado quando se processa índices de fonte."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr "Secção Tree"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -3259,7 +3294,7 @@
 "<literal>Directory</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 #, fuzzy
 #| msgid ""
 #| "The <literal>Tree</literal> section takes a scope tag which sets the "
@@ -3278,7 +3313,7 @@
 "definição tal como <filename>dists/woody</filename>."
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -3289,7 +3324,7 @@
 "variáveis."
 
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, no-wrap
 msgid ""
 "for i in Sections do \n"
@@ -3303,7 +3338,7 @@
 "     "
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 msgid ""
 "When processing a <literal>Tree</literal> section <command>apt-ftparchive</"
 "command> performs an operation similar to: <placeholder type=\"programlisting"
@@ -3314,12 +3349,12 @@
 "\"programlisting\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 msgid "Sections"
 msgstr "Sections"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib non-"
@@ -3330,12 +3365,12 @@
 "literal>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr "Architectures"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -3346,12 +3381,12 @@
 "indicar que esta árvore tem um arquivo fonte."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 msgid "BinOverride"
 msgstr "BinOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
@@ -3360,12 +3395,12 @@
 "informação de secção, prioridade e endereço do responsável."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr "SrcOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
@@ -3374,32 +3409,32 @@
 "informação de secção."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr "ExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr "Define o ficheiro de sobreposição extra binário."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr "SrcExtraOverride"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr "Define o ficheiro de sobreposição extra fonte."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr "Secção BinDirectory"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -3414,12 +3449,12 @@
 "definições <literal>Section</literal><literal>Architecture</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr "Define a saída do ficheiro Packages."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
@@ -3428,52 +3463,52 @@
 "<literal>Packages</literal> ou <literal>Sources</literal>."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr "Define a saída do ficheiro Contents (opcional)"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr "Define o ficheiro de sobreposição binário."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr "Define o ficheiro de sobreposição fonte."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr "Define a base de dados de cache."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr "PathPrefix"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr "Acrescenta um caminho a todos os caminhos de saída."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr "FileList, SourceFileList"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr "Especifica o ficheiro de lista de ficheiros."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 msgid "The Binary Override File"
 msgstr "O Ficheiro Binary Override"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -3488,19 +3523,19 @@
 "permutação do responsável."
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr "old [// oldn]* => new"
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr "new"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder type="
 "\"literallayout\" id=\"0\"/> or simply, <placeholder type=\"literallayout\" "
@@ -3517,12 +3552,12 @@
 "formato substitui incondicionalmente o campo do responsável."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 msgid "The Source Override File"
 msgstr "O Ficheiro Source Override"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -3533,12 +3568,12 @@
 "nome de pacote fonte, o segundo é a secção onde o atribuir."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr "O Ficheiro Extra Override"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -3549,12 +3584,12 @@
 "pacote, a segunda é a etiqueta e restante da linha é o novo valor."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr "<option>--md5</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -3565,12 +3600,12 @@
 "<literal>APT::FTPArchive::MD5</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr "<option>--db</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
 "Configuration Item: <literal>APT::FTPArchive::DB</literal>."
@@ -3579,7 +3614,7 @@
 "generate. Item de configuração: <literal>APT::FTPArchive::DB</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -3593,12 +3628,12 @@
 "<literal>quiet</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr "<option>--delink</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
 "then this option actually enables delinking of the files. It defaults to on "
@@ -3611,12 +3646,12 @@
 "option>. Item de Configuração: <literal>APT::FTPArchive::DeLinkAct</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr "<option>--contents</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -3632,12 +3667,12 @@
 "de Configuração: <literal>APT::FTPArchive::Contents</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr "<option>--source-override</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
 "command.  Configuration Item: <literal>APT::FTPArchive::SourceOverride</"
@@ -3648,12 +3683,12 @@
 "SourceOverride</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr "<option>--readonly</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 msgid ""
 "Make the caching databases read only.  Configuration Item: <literal>APT::"
 "FTPArchive::ReadOnlyDB</literal>."
@@ -3662,12 +3697,12 @@
 "<literal>APT::FTPArchive::ReadOnlyDB</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 msgid "<option>--arch</option>"
 msgstr "<option>--arch</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 msgid ""
 "Accept in the <literal>packages</literal> and <literal>contents</literal> "
 "commands only package files matching <literal>*_arch.deb</literal> or "
@@ -3681,12 +3716,12 @@
 "FTPArchive::Architecture</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr "<option>APT::FTPArchive::AlwaysStat</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -3710,12 +3745,12 @@
 "as verificações extras serão desnecessárias."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr "<option>APT::FTPArchive::LongDescription</option>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 #, fuzzy
 #| msgid ""
 #| "This configuration option defaults to \"<literal>true</literal>\" and "
@@ -3737,19 +3772,19 @@
 "esses ficheiros com <command>apt-ftparchive</command>."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491
 #: sources.list.5.xml:193
 msgid "Examples"
 msgstr "Examples"
 
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 msgstr "<command>apt-ftparchive</command> pacotes <replaceable>directório</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
@@ -3758,7 +3793,7 @@
 "pacotes binários (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -5354,29 +5389,18 @@
 msgid "Show the program version."
 msgstr "Mostra a versão do programa."
 
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr "<filename>/var/lib/apt/extended_states</filename>"
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: <literal>Dir::"
-"State</literal> sets the path to the <filename>extended_states</filename> "
-"file."
+msgid "  &file-extended_states;"
 msgstr ""
-"Lista de estado de pacotes auto-instalados. Item de Configuração: "
-"<literal>Dir::State</literal> que define o caminho para o ficheiro "
-"<filename>extended_states</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 msgid "&apt-get;,&aptitude;,&apt-conf;"
 msgstr "&apt-get;,&aptitude;,&apt-conf;"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -6310,11 +6334,47 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was created. "
+"The default is \"for ever\" (0) if the Release file of the archive doesn't "
+"include a <literal>Valid-Until</literal> header.  If it does then this date "
+"is the default. The date from the Release file or the date specified by the "
+"creation time of the Release file (<literal>Date</literal> header) plus the "
+"seconds specified with this options are used to check if the validation of a "
+"file has expired by using the earlier date of the two. Archive specific "
+"settings can be made by appending the label of the archive to the option "
+"name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr "PDiffs"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
@@ -6324,7 +6384,7 @@
 "predefinição."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -6341,12 +6401,12 @@
 "limites for excedido, é descarregado o ficheiro completo em vez das patches."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr "Queue-Mode"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of <literal>host</"
 "literal> or <literal>access</literal> which determines how APT parallelizes "
@@ -6361,12 +6421,12 @@
 "aberta uma ligação por tipo de URI."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr "Retries"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
@@ -6375,12 +6435,12 @@
 "tentar, no número fornecido de vezes, obter ficheiros falhados."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 msgid "Source-Symlinks"
 msgstr "Source-Symlinks"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
@@ -6390,12 +6450,12 @@
 "A predefinição é verdadeiro."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr "http"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 msgid ""
 "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
 "standard form of <literal>http://[[user][:pass]@]host[:port]/</literal>. Per "
@@ -6412,7 +6472,7 @@
 "especificada, será usada a variável de ambiente <envar>http_proxy</envar>."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -6437,7 +6497,7 @@
 "suporta nenhuma destas opções."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -6448,7 +6508,7 @@
 "e tempos limite de dados."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 msgid ""
 "One setting is provided to control the pipeline depth in cases where the "
 "remote server is not RFC conforming or buggy (such as Squid 2.0.2).  "
@@ -6467,7 +6527,7 @@
 "As máquinas que requerem isto estão em violação de RFC 2068."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with <literal>Acquire::http::Dl-Limit</"
 "literal> which accepts integer values in kilobyte. The default value is 0 "
@@ -6482,7 +6542,7 @@
 "múltiplos servidores ao mesmo tempo.)"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -6494,12 +6554,12 @@
 "identificador conhecido."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr "https"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 msgid ""
 "HTTPS URIs. Cache-control, Timeout, AllowRedirect, Dl-Limit and proxy "
 "options are the same as for <literal>http</literal> method and will also "
@@ -6514,7 +6574,7 @@
 "literal> ainda não é suportada."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -6551,12 +6611,12 @@
 "host&gt;::SslForceVersion</literal> é a opção po máquina correspondente."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr "ftp"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 msgid ""
 "FTP URIs; ftp::Proxy is the default ftp proxy to use. It is in the standard "
 "form of <literal>ftp://[[user][:pass]@]host[:port]/</literal>. Per host "
@@ -6589,7 +6649,7 @@
 "$(SITE_PORT)</literal>. Cada uma é tirada do seu componente URI respectivo."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -6605,7 +6665,7 @@
 "específica (Veja a amostra de ficheiro de configuração para exemplos)."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the <envar>ftp_proxy</"
 "envar> environment variable to a http url - see the discussion of the http "
@@ -6619,7 +6679,7 @@
 "eficiência."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -6634,18 +6694,18 @@
 "ligações IPv4. Note que a maioria dos servidores FTP não suporta RFC2428."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr "cdrom"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, no-wrap
 msgid "/cdrom/::Mount \"foo\";"
 msgstr "/cdrom/::Mount \"foo\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -6666,12 +6726,12 @@
 "Comandos para desmontar podem ser especificados usando UMount."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr "gpgv"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -6682,18 +6742,18 @@
 "passadas ao gpgv."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr "CompressionTypes"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> \"<replaceable>Methodname</replaceable>\";"
 msgstr "Acquire::CompressionTypes::<replaceable>Extensão de Ficheiro</replaceable> \"<replaceable>Nome de método</replaceable>\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -6712,19 +6772,19 @@
 "alterado. A sintaxe para isto é: <placeholder type=\"synopsis\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr "Acquire::CompressionTypes::Order:: \"gz\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -6755,13 +6815,13 @@
 "lista pois será adicionado automaticamente."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr "Dir::Bin::bzip2 \"/bin/bzip2\";"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the <literal>Dir::Bin::<replaceable>Methodname</"
 "replaceable></literal> will be checked: If this setting exists the method "
@@ -6786,7 +6846,7 @@
 "sobrepor a lista definida, irá apenas prefixar a lista com este tipo."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -6802,12 +6862,12 @@
 "utilização de mirrors locais."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr "Languages"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 msgid ""
 "The Languages subsection controls which <filename>Translation</filename> "
 "files are downloaded and in which order APT tries to display the Description-"
@@ -6829,13 +6889,13 @@
 "de definir aqui valores impossíveis."
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 msgid ""
 "The default list includes \"environment\" and \"en\". "
 "\"<literal>environment</literal>\" has a special meaning here: It will be "
@@ -6884,12 +6944,12 @@
 "e os manipuladores de URI. <placeholder type=\"variablelist\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr "Directories"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -6908,7 +6968,7 @@
 "com <filename>/</filename> ou <filename>./</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -6929,7 +6989,7 @@
 "literal> o directório predefinido é contido em <literal>Dir::Cache</literal>"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -6944,7 +7004,7 @@
 "ficheiro de configuração especificado por <envar>APT_CONFIG</envar>)."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -6955,7 +7015,7 @@
 "estar feito então é carregado o ficheiro de configuração principal."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 msgid ""
 "Binary programs are pointed to by <literal>Dir::Bin</literal>. <literal>Dir::"
 "Bin::Methods</literal> specifies the location of the method handlers and "
@@ -6973,7 +7033,7 @@
 "respectivos programas."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -6994,12 +7054,12 @@
 "procurado em <filename>/tmp/staging/var/lib/dpkg/status</filename>."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 msgid "APT in DSelect"
 msgstr "APT em DSelect"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -7010,12 +7070,12 @@
 "<literal>DSelect</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 msgid "Clean"
 msgstr "Clean"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -7032,7 +7092,7 @@
 "descarregar novos pacotes."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
@@ -7041,12 +7101,12 @@
 "comandos quando é corrido para a fase de instalação."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 msgid "Updateoptions"
 msgstr "Updateoptions"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
@@ -7055,12 +7115,12 @@
 "comandos quando é executado para a fase de actualização."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr "PromptAfterUpdate"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
@@ -7069,12 +7129,12 @@
 "continuar. A predefinição é avisar apenas em caso de erro."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr "Como o APT chama o dpkg"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
@@ -7083,7 +7143,7 @@
 "&dpkg;. Estas estão na secção <literal>DPkg</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -7094,17 +7154,17 @@
 "um argumento único ao &dpkg;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr "Pre-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr "Post-Invoke"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7117,12 +7177,12 @@
 "bin/sh</filename>, caso algum deles falhe, o APT irá abortar."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr "Pre-Install-Pkgs"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -7138,7 +7198,7 @@
 "deb que vai instalar, um por cada linha."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -7153,12 +7213,12 @@
 "dado ao <literal>Pre-Install-Pkgs</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr "Run-Directory"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is <filename>/"
 "</filename>."
@@ -7167,12 +7227,12 @@
 "predefinição é <filename>/</filename>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 msgid "Build-options"
 msgstr "Build-options"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
@@ -7181,12 +7241,12 @@
 "predefinição é desactivar a assinatura e produzir todos os binários."
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr "Utilização trigger do dpkg (e opções relacionadas)"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -7212,7 +7272,7 @@
 "todos os pacotes."
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -7226,7 +7286,7 @@
 "DPkg::TriggersPending \"true\";"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -7250,12 +7310,12 @@
 "\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr "DPkg::NoTriggers"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -7276,12 +7336,12 @@
 "chamadas unpack e remove."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 msgid "PackageManager::Configure"
 msgstr "PackageManager::Configure"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -7309,12 +7369,12 @@
 "poderia não arrancar!"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 msgid "DPkg::ConfigurePending"
 msgstr "DPkg::ConfigurePending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure --pending</"
 "command> to let dpkg handle all required configurations and triggers. This "
@@ -7332,12 +7392,12 @@
 "esta opção em todas excepto na última execução."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr "DPkg::TriggersPending"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -7353,12 +7413,12 @@
 "configurar este pacote."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr "PackageManager::UnpackAll"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by Pre-"
@@ -7377,12 +7437,12 @@
 "experimental e necessita de mais melhorias antes de se tornar realmente útil."
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr "OrderList::Score::Immediate"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -7400,7 +7460,7 @@
 "};"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -7424,12 +7484,12 @@
 "predefinidos. <placeholder type=\"literallayout\" id=\"0\"/>"
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr "Opções Periodic e Archives"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -7442,12 +7502,12 @@
 "Veja o cabeçalho deste script para uma breve documentação das suas opções."
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 msgid "Debug options"
 msgstr "Opções de depuração"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -7464,7 +7524,7 @@
 "interesse para o utilizador normal, mas algumas podem ter:"
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, purge</"
@@ -7475,7 +7535,7 @@
 "remove, purge</literal>."
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s install</"
@@ -7486,7 +7546,7 @@
 "<literal>apt-get -s install</literal>) como um utilizador não root."
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -7498,7 +7558,7 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
 "in CDROM IDs."
@@ -7507,17 +7567,17 @@
 "IDs de CDROM."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr "Segue-se uma lista completa de opções de depuração para o apt."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr "<literal>Debug::Acquire::cdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid ""
 "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
@@ -7525,45 +7585,45 @@
 "literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr "<literal>Debug::Acquire::ftp</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr ""
 "Escreve informação relacionada com o descarregamento de pacotes usando FTP."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr "<literal>Debug::Acquire::http</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr ""
 "Escreve informação relacionada com o descarregamento de pacotes usando HTTP."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr "<literal>Debug::Acquire::https</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr ""
 "Escreve informação relacionada com o descarregamento de pacotes usando HTTPS."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr "<literal>Debug::Acquire::gpgv</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
@@ -7572,12 +7632,12 @@
 "criptográficas usando <literal>gpg</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr "<literal>Debug::aptcdrom</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
@@ -7586,23 +7646,23 @@
 "armazenados em CD-ROMs."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr "<literal>Debug::BuildDeps</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 "Descreve os processos de resolver dependências de compilação no &apt-get;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 msgid "<literal>Debug::Hashes</literal>"
 msgstr "<literal>Debug::Hashes</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the <literal>apt</"
 "literal> libraries."
@@ -7611,12 +7671,12 @@
 "<literal>apt</literal>."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr "<literal>Debug::IdentCDROM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -7627,12 +7687,12 @@
 "para um CD-ROM."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr "<literal>Debug::NoLocking</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
@@ -7642,24 +7702,24 @@
 "literal></quote> ao mesmo tempo."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr "<literal>Debug::pkgAcquire</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 "Regista no log quando os items são adicionados ou removidos da fila de "
 "download global."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr "<literal>Debug::pkgAcquire::Auth</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
@@ -7668,12 +7728,12 @@
 "checksums e assinaturas criptográficas dos ficheiros descarregados."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr "<literal>Debug::pkgAcquire::Diffs</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
@@ -7683,12 +7743,12 @@
 "pacote."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr "<literal>Debug::pkgAcquire::RRed</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
@@ -7697,12 +7757,12 @@
 "do apt quando se descarrega diffs de índice em vez de índices completos."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr "<literal>Debug::pkgAcquire::Worker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid ""
 "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
@@ -7710,12 +7770,12 @@
 "downloads."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr "<literal>Debug::pkgAutoRemove</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
@@ -7724,12 +7784,12 @@
 "de pacotes e com a remoção de pacotes não utilizados."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial auto-"
@@ -7744,12 +7804,12 @@
 "literal>; veja <literal>Debug::pkgProblemResolver</literal> para isso."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr "<literal>Debug::pkgDepCache::Marker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as keep/install/"
 "remove while the ProblemResolver does his work.  Each addition or deletion "
@@ -7779,22 +7839,22 @@
 "pacote aparece."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr "<literal>Debug::pkgInitConfig</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr "Despeja a configuração predefinida para o erro standard no arranque."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr "<literal>Debug::pkgDPkgPM</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
@@ -7804,12 +7864,12 @@
 "único."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr "<literal>Debug::pkgDPkgProgressReporting</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
@@ -7818,12 +7878,12 @@
 "estado e quaisquer erros encontrados enquanto os analisa."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr "<literal>Debug::pkgOrderList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
@@ -7832,12 +7892,12 @@
 "literal> deve passar os pacotes ao &dpkg;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr "<literal>Debug::pkgPackageManager</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid ""
 "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr ""
@@ -7845,22 +7905,22 @@
 "&dpkg;."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr "<literal>Debug::pkgPolicy</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr "Escreve a prioridade da cada lista de pacote no arranque."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr "<literal>Debug::pkgProblemResolver</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
@@ -7869,12 +7929,12 @@
 "acontece quando é encontrado um problema de dependências complexo)."
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -7885,12 +7945,12 @@
 "mesma que é descrita em <literal>Debug::pkgDepCache::Marker</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 msgid "<literal>Debug::sourceList</literal>"
 msgstr "<literal>Debug::sourceList</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from <filename>/etc/apt/vendors."
 "list</filename>."
@@ -7899,7 +7959,7 @@
 "vendors.list</filename>."
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
@@ -7908,13 +7968,13 @@
 "para todas as opções possíveis."
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 msgid "&file-aptconf;"
 msgstr "&file-aptconf;"
 
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr "&apt-cache;, &apt-config;, &apt-preferences;."
 
@@ -11295,6 +11355,18 @@
 #~ "  </citerefentry>\"\n"
 #~ ">\n"
 
+#~ msgid "<filename>/var/lib/apt/extended_states</filename>"
+#~ msgstr "<filename>/var/lib/apt/extended_states</filename>"
+
+#~ msgid ""
+#~ "Status list of auto-installed packages.  Configuration Item: "
+#~ "<literal>Dir::State</literal> sets the path to the "
+#~ "<filename>extended_states</filename> file."
+#~ msgstr ""
+#~ "Lista de estado de pacotes auto-instalados. Item de Configuração: "
+#~ "<literal>Dir::State</literal> que define o caminho para o ficheiro "
+#~ "<filename>extended_states</filename>."
+
 #~ msgid "Pin: release n=squeeze\n"
 #~ msgstr "Pin: release n=squeeze\n"
 

=== modified file 'doc/po/pt_BR.po'
--- doc/po/pt_BR.po	2010-05-25 16:01:42 +0000
+++ doc/po/pt_BR.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: apt\n"
-"POT-Creation-Date: 2010-05-25 21:47+0300\n"
+"POT-Creation-Date: 2010-06-10 14:03+0300\n"
 "PO-Revision-Date: 2004-09-20 17:02+0000\n"
 "Last-Translator: André Luís Lopes <andrelop@debian.org>\n"
 "Language-Team: <debian-l10n-portuguese@lists.debian.org>\n"
@@ -807,7 +807,20 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:369
+#: apt.ent:373
+#, no-wrap
+msgid ""
+"<!ENTITY file-extended_states \"\n"
+"      <varlistentry><term><filename>/var/lib/apt/extended_states</filename></term>\n"
+"      <listitem><para>Status list of auto-installed packages.\n"
+"      Configuration Item: <literal>Dir::State::extended_states</literal>.\n"
+"      </para></listitem>\n"
+"      </varlistentry>\n"
+"\">\n"
+msgstr ""
+
+#. type: Plain text
+#: apt.ent:377
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is the section header for the following paragraphs - comparable\n"
@@ -816,7 +829,7 @@
 msgstr "<!ENTITY translation-title \"TRADUÇÃO\">\n"
 
 #. type: Plain text
-#: apt.ent:378
+#: apt.ent:386
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: This is a placeholder. You should write here who has contributed\n"
@@ -834,7 +847,7 @@
 "\">\n"
 
 #. type: Plain text
-#: apt.ent:389
+#: apt.ent:397
 #, no-wrap
 msgid ""
 "<!-- TRANSLATOR: As a translation is allowed to have 20% of untranslated/fuzzy strings\n"
@@ -850,7 +863,7 @@
 msgstr ""
 
 #. type: Plain text
-#: apt.ent:392
+#: apt.ent:400
 msgid ""
 "<!ENTITY oldstable-codename \"etch\"> <!ENTITY stable-codename \"lenny\"> <!"
 "ENTITY testing-codename \"squeeze\">"
@@ -1312,8 +1325,8 @@
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
 #: apt-cache.8.xml:281 apt-config.8.xml:93 apt-extracttemplates.1.xml:56
-#: apt-ftparchive.1.xml:518 apt-get.8.xml:305 apt-mark.8.xml:89
-#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:503 apt.conf.5.xml:525
+#: apt-ftparchive.1.xml:519 apt-get.8.xml:305 apt-mark.8.xml:89
+#: apt-sortpkgs.1.xml:54 apt.conf.5.xml:527 apt.conf.5.xml:549
 msgid "options"
 msgstr ""
 
@@ -1336,7 +1349,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:291 apt-ftparchive.1.xml:561 apt-get.8.xml:362
+#: apt-cache.8.xml:291 apt-ftparchive.1.xml:562 apt-get.8.xml:362
 #: apt-sortpkgs.1.xml:58
 msgid "<option>-s</option>"
 msgstr ""
@@ -1357,12 +1370,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>-q</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:299 apt-ftparchive.1.xml:535 apt-get.8.xml:352
+#: apt-cache.8.xml:299 apt-ftparchive.1.xml:536 apt-get.8.xml:352
 msgid "<option>--quiet</option>"
 msgstr ""
 
@@ -1411,7 +1424,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:573
+#: apt-cache.8.xml:317 apt-cdrom.8.xml:131 apt-ftparchive.1.xml:574
 msgid "<option>-a</option>"
 msgstr ""
 
@@ -1507,14 +1520,14 @@
 
 #. type: Content of: <refentry><refsect1><variablelist>
 #: apt-cache.8.xml:356 apt-cdrom.8.xml:150 apt-config.8.xml:98
-#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:601 apt-get.8.xml:547
+#: apt-extracttemplates.1.xml:67 apt-ftparchive.1.xml:602 apt-get.8.xml:547
 #: apt-sortpkgs.1.xml:64
 msgid "&apt-commonoptions;"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:361 apt-get.8.xml:552 apt-key.8.xml:153 apt-mark.8.xml:122
-#: apt.conf.5.xml:1036 apt_preferences.5.xml:644
+#: apt.conf.5.xml:1060 apt_preferences.5.xml:644
 msgid "Files"
 msgstr ""
 
@@ -1525,9 +1538,9 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:368 apt-cdrom.8.xml:155 apt-config.8.xml:103
-#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:617 apt-get.8.xml:562
-#: apt-key.8.xml:174 apt-mark.8.xml:133 apt-secure.8.xml:181
-#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1042 apt_preferences.5.xml:651
+#: apt-extracttemplates.1.xml:74 apt-ftparchive.1.xml:618 apt-get.8.xml:562
+#: apt-key.8.xml:174 apt-mark.8.xml:128 apt-secure.8.xml:181
+#: apt-sortpkgs.1.xml:69 apt.conf.5.xml:1066 apt_preferences.5.xml:651
 #: sources.list.5.xml:233
 #, fuzzy
 msgid "See Also"
@@ -1540,8 +1553,8 @@
 
 #. type: Content of: <refentry><refsect1><title>
 #: apt-cache.8.xml:373 apt-cdrom.8.xml:160 apt-config.8.xml:108
-#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:621 apt-get.8.xml:568
-#: apt-mark.8.xml:137 apt-sortpkgs.1.xml:73
+#: apt-extracttemplates.1.xml:78 apt-ftparchive.1.xml:622 apt-get.8.xml:568
+#: apt-mark.8.xml:132 apt-sortpkgs.1.xml:73
 msgid "Diagnostics"
 msgstr ""
 
@@ -1645,7 +1658,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:529 apt-get.8.xml:314
+#: apt-cdrom.8.xml:95 apt-ftparchive.1.xml:530 apt-get.8.xml:314
 msgid "<option>-d</option>"
 msgstr ""
 
@@ -1841,7 +1854,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:618
+#: apt-config.8.xml:104 apt-extracttemplates.1.xml:75 apt-ftparchive.1.xml:619
 #: apt-sortpkgs.1.xml:70
 #, fuzzy
 msgid "&apt-conf;"
@@ -2081,17 +2094,18 @@
 "literal>, e.g. <literal>APT::FTPArchive::Release::Origin</literal>.  The "
 "supported fields are: <literal>Origin</literal>, <literal>Label</literal>, "
 "<literal>Suite</literal>, <literal>Version</literal>, <literal>Codename</"
-"literal>, <literal>Date</literal>, <literal>Architectures</literal>, "
-"<literal>Components</literal>, <literal>Description</literal>."
+"literal>, <literal>Date</literal>, <literal>Valid-Until</literal>, "
+"<literal>Architectures</literal>, <literal>Components</literal>, "
+"<literal>Description</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:129
+#: apt-ftparchive.1.xml:130
 msgid "generate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:131
+#: apt-ftparchive.1.xml:132
 msgid ""
 "The <literal>generate</literal> command is designed to be runnable from a "
 "cron script and builds indexes according to the given config file. The "
@@ -2101,24 +2115,24 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:138 apt-get.8.xml:278
+#: apt-ftparchive.1.xml:139 apt-get.8.xml:278
 msgid "clean"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:140
+#: apt-ftparchive.1.xml:141
 msgid ""
 "The <literal>clean</literal> command tidies the databases used by the given "
 "configuration file by removing any records that are no longer necessary."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:146
+#: apt-ftparchive.1.xml:147
 msgid "The Generate Configuration"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:148
+#: apt-ftparchive.1.xml:149
 msgid ""
 "The <literal>generate</literal> command uses a configuration file to "
 "describe the archives that are going to be generated. It follows the typical "
@@ -2129,19 +2143,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:156
+#: apt-ftparchive.1.xml:157
 msgid ""
 "The generate configuration has 4 separate sections, each described below."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:158
+#: apt-ftparchive.1.xml:159
 #, fuzzy
 msgid "Dir Section"
 msgstr "Descrição"
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:160
+#: apt-ftparchive.1.xml:161
 msgid ""
 "The <literal>Dir</literal> section defines the standard directories needed "
 "to locate the files required during the generation process. These "
@@ -2150,12 +2164,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:165
+#: apt-ftparchive.1.xml:166
 msgid "ArchiveDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:167
+#: apt-ftparchive.1.xml:168
 msgid ""
 "Specifies the root of the FTP archive, in a standard Debian configuration "
 "this is the directory that contains the <filename>ls-LR</filename> and dist "
@@ -2163,44 +2177,44 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:172
+#: apt-ftparchive.1.xml:173
 msgid "OverrideDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:174
+#: apt-ftparchive.1.xml:175
 msgid "Specifies the location of the override files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:177
+#: apt-ftparchive.1.xml:178
 msgid "CacheDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:179
+#: apt-ftparchive.1.xml:180
 msgid "Specifies the location of the cache files"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:182
+#: apt-ftparchive.1.xml:183
 msgid "FileListDir"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:184
+#: apt-ftparchive.1.xml:185
 msgid ""
 "Specifies the location of the file list files, if the <literal>FileList</"
 "literal> setting is used below."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:190
+#: apt-ftparchive.1.xml:191
 msgid "Default Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:192
+#: apt-ftparchive.1.xml:193
 msgid ""
 "The <literal>Default</literal> section specifies default values, and "
 "settings that control the operation of the generator. Other sections may "
@@ -2208,12 +2222,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:196
+#: apt-ftparchive.1.xml:197
 msgid "Packages::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:198
+#: apt-ftparchive.1.xml:199
 msgid ""
 "Sets the default compression schemes to use for the Package index files. It "
 "is a string that contains a space separated list of at least one of: '.' (no "
@@ -2222,72 +2236,72 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:204
+#: apt-ftparchive.1.xml:205
 msgid "Packages::Extensions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:206
+#: apt-ftparchive.1.xml:207
 msgid ""
 "Sets the default list of file extensions that are package files.  This "
 "defaults to '.deb'."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:210
+#: apt-ftparchive.1.xml:211
 msgid "Sources::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:212
+#: apt-ftparchive.1.xml:213
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Sources files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:216
+#: apt-ftparchive.1.xml:217
 msgid "Sources::Extensions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:218
+#: apt-ftparchive.1.xml:219
 msgid ""
 "Sets the default list of file extensions that are source files.  This "
 "defaults to '.dsc'."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:222
+#: apt-ftparchive.1.xml:223
 msgid "Contents::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:224
+#: apt-ftparchive.1.xml:225
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Contents files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:228
+#: apt-ftparchive.1.xml:229
 msgid "Translation::Compress"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:230
+#: apt-ftparchive.1.xml:231
 msgid ""
 "This is similar to <literal>Packages::Compress</literal> except that it "
 "controls the compression for the Translation-en master file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:234
+#: apt-ftparchive.1.xml:235
 msgid "DeLinkLimit"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:236
+#: apt-ftparchive.1.xml:237
 msgid ""
 "Specifies the number of kilobytes to delink (and replace with hard links) "
 "per run. This is used in conjunction with the per-section <literal>External-"
@@ -2295,37 +2309,37 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:241
+#: apt-ftparchive.1.xml:242
 msgid "FileMode"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:243
+#: apt-ftparchive.1.xml:244
 msgid ""
 "Specifies the mode of all created index files. It defaults to 0644. All "
 "index files are set to this mode with no regard to the umask."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:248 apt-ftparchive.1.xml:394
+#: apt-ftparchive.1.xml:249 apt-ftparchive.1.xml:395
 #, fuzzy
 msgid "LongDescription"
 msgstr "Descrição"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:250 apt-ftparchive.1.xml:396
+#: apt-ftparchive.1.xml:251 apt-ftparchive.1.xml:397
 msgid ""
 "Sets if long descriptions should be included in the Packages file or split "
 "out into a master Translation-en file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:256
+#: apt-ftparchive.1.xml:257
 msgid "TreeDefault Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:258
+#: apt-ftparchive.1.xml:259
 msgid ""
 "Sets defaults specific to <literal>Tree</literal> sections. All of these "
 "variables are substitution variables and have the strings $(DIST), "
@@ -2333,12 +2347,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:263
+#: apt-ftparchive.1.xml:264
 msgid "MaxContentsChange"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:265
+#: apt-ftparchive.1.xml:266
 msgid ""
 "Sets the number of kilobytes of contents files that are generated each day. "
 "The contents files are round-robined so that over several days they will all "
@@ -2346,12 +2360,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:270
+#: apt-ftparchive.1.xml:271
 msgid "ContentsAge"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:272
+#: apt-ftparchive.1.xml:273
 msgid ""
 "Controls the number of days a contents file is allowed to be checked without "
 "changing. If this limit is passed the mtime of the contents file is updated. "
@@ -2362,61 +2376,61 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:281
+#: apt-ftparchive.1.xml:282
 msgid "Directory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:283
+#: apt-ftparchive.1.xml:284
 msgid ""
 "Sets the top of the .deb directory tree. Defaults to <filename>$(DIST)/"
 "$(SECTION)/binary-$(ARCH)/</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:287
+#: apt-ftparchive.1.xml:288
 msgid "SrcDirectory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:289
+#: apt-ftparchive.1.xml:290
 msgid ""
 "Sets the top of the source package directory tree. Defaults to <filename>"
 "$(DIST)/$(SECTION)/source/</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:293 apt-ftparchive.1.xml:432
+#: apt-ftparchive.1.xml:294 apt-ftparchive.1.xml:433
 msgid "Packages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:295
+#: apt-ftparchive.1.xml:296
 msgid ""
 "Sets the output Packages file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "binary-$(ARCH)/Packages</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:299 apt-ftparchive.1.xml:437
+#: apt-ftparchive.1.xml:300 apt-ftparchive.1.xml:438
 msgid "Sources"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:301
+#: apt-ftparchive.1.xml:302
 msgid ""
 "Sets the output Sources file. Defaults to <filename>$(DIST)/$(SECTION)/"
 "source/Sources</filename>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:305
+#: apt-ftparchive.1.xml:306
 #, fuzzy
 msgid "Translation"
 msgstr "Descrição"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:307
+#: apt-ftparchive.1.xml:308
 msgid ""
 "Set the output Translation-en master file with the long descriptions if they "
 "should be not included in the Packages file. Defaults to <filename>$(DIST)/"
@@ -2424,12 +2438,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:312
+#: apt-ftparchive.1.xml:313
 msgid "InternalPrefix"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:314
+#: apt-ftparchive.1.xml:315
 msgid ""
 "Sets the path prefix that causes a symlink to be considered an internal link "
 "instead of an external link. Defaults to <filename>$(DIST)/$(SECTION)/</"
@@ -2437,12 +2451,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:319 apt-ftparchive.1.xml:443
+#: apt-ftparchive.1.xml:320 apt-ftparchive.1.xml:444
 msgid "Contents"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:321
+#: apt-ftparchive.1.xml:322
 msgid ""
 "Sets the output Contents file. Defaults to <filename>$(DIST)/Contents-$(ARCH)"
 "</filename>. If this setting causes multiple Packages files to map onto a "
@@ -2451,34 +2465,34 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:328
+#: apt-ftparchive.1.xml:329
 msgid "Contents::Header"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:330
+#: apt-ftparchive.1.xml:331
 msgid "Sets header file to prepend to the contents output."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:333 apt-ftparchive.1.xml:468
+#: apt-ftparchive.1.xml:334 apt-ftparchive.1.xml:469
 msgid "BinCacheDB"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:335
+#: apt-ftparchive.1.xml:336
 msgid ""
 "Sets the binary cache database to use for this section. Multiple sections "
 "can share the same database."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:339
+#: apt-ftparchive.1.xml:340
 msgid "FileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:341
+#: apt-ftparchive.1.xml:342
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -2486,12 +2500,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:346
+#: apt-ftparchive.1.xml:347
 msgid "SourceFileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:348
+#: apt-ftparchive.1.xml:349
 msgid ""
 "Specifies that instead of walking the directory tree, <command>apt-"
 "ftparchive</command> should read the list of files from the given file. "
@@ -2500,12 +2514,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:356
+#: apt-ftparchive.1.xml:357
 msgid "Tree Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:358
+#: apt-ftparchive.1.xml:359
 msgid ""
 "The <literal>Tree</literal> section defines a standard Debian file tree "
 "which consists of a base directory, then multiple sections in that base "
@@ -2515,7 +2529,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:363
+#: apt-ftparchive.1.xml:364
 msgid ""
 "The <literal>Tree</literal> section takes a scope tag which sets the "
 "<literal>$(DIST)</literal> variable and defines the root of the tree (the "
@@ -2524,7 +2538,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:368
+#: apt-ftparchive.1.xml:369
 msgid ""
 "All of the settings defined in the <literal>TreeDefault</literal> section "
 "can be use in a <literal>Tree</literal> section as well as three new "
@@ -2532,7 +2546,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><programlisting>
-#: apt-ftparchive.1.xml:374
+#: apt-ftparchive.1.xml:375
 #, no-wrap
 msgid ""
 "for i in Sections do \n"
@@ -2542,7 +2556,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:371
+#: apt-ftparchive.1.xml:372
 msgid ""
 "When processing a <literal>Tree</literal> section <command>apt-ftparchive</"
 "command> performs an operation similar to: <placeholder type=\"programlisting"
@@ -2550,13 +2564,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:380
+#: apt-ftparchive.1.xml:381
 #, fuzzy
 msgid "Sections"
 msgstr "Descrição"
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:382
+#: apt-ftparchive.1.xml:383
 msgid ""
 "This is a space separated list of sections which appear under the "
 "distribution, typically this is something like <literal>main contrib non-"
@@ -2564,12 +2578,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:387
+#: apt-ftparchive.1.xml:388
 msgid "Architectures"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:389
+#: apt-ftparchive.1.xml:390
 msgid ""
 "This is a space separated list of all the architectures that appear under "
 "search section. The special architecture 'source' is used to indicate that "
@@ -2577,56 +2591,56 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:400 apt-ftparchive.1.xml:448
+#: apt-ftparchive.1.xml:401 apt-ftparchive.1.xml:449
 msgid "BinOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:402
+#: apt-ftparchive.1.xml:403
 msgid ""
 "Sets the binary override file. The override file contains section, priority "
 "and maintainer address information."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:406 apt-ftparchive.1.xml:453
+#: apt-ftparchive.1.xml:407 apt-ftparchive.1.xml:454
 msgid "SrcOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:408
+#: apt-ftparchive.1.xml:409
 msgid ""
 "Sets the source override file. The override file contains section "
 "information."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:412 apt-ftparchive.1.xml:458
+#: apt-ftparchive.1.xml:413 apt-ftparchive.1.xml:459
 msgid "ExtraOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:414 apt-ftparchive.1.xml:460
+#: apt-ftparchive.1.xml:415 apt-ftparchive.1.xml:461
 msgid "Sets the binary extra override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:417 apt-ftparchive.1.xml:463
+#: apt-ftparchive.1.xml:418 apt-ftparchive.1.xml:464
 msgid "SrcExtraOverride"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:419 apt-ftparchive.1.xml:465
+#: apt-ftparchive.1.xml:420 apt-ftparchive.1.xml:466
 msgid "Sets the source extra override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt-ftparchive.1.xml:424
+#: apt-ftparchive.1.xml:425
 msgid "BinDirectory Section"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt-ftparchive.1.xml:426
+#: apt-ftparchive.1.xml:427
 msgid ""
 "The <literal>bindirectory</literal> section defines a binary directory tree "
 "with no special structure. The scope tag specifies the location of the "
@@ -2636,64 +2650,64 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:434
+#: apt-ftparchive.1.xml:435
 msgid "Sets the Packages file output."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:439
+#: apt-ftparchive.1.xml:440
 msgid ""
 "Sets the Sources file output. At least one of <literal>Packages</literal> or "
 "<literal>Sources</literal> is required."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:445
+#: apt-ftparchive.1.xml:446
 msgid "Sets the Contents file output. (optional)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:450
+#: apt-ftparchive.1.xml:451
 msgid "Sets the binary override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:455
+#: apt-ftparchive.1.xml:456
 msgid "Sets the source override file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:470
+#: apt-ftparchive.1.xml:471
 msgid "Sets the cache DB."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:473
+#: apt-ftparchive.1.xml:474
 msgid "PathPrefix"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:475
+#: apt-ftparchive.1.xml:476
 msgid "Appends a path to all the output paths."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:478
+#: apt-ftparchive.1.xml:479
 msgid "FileList, SourceFileList"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:480
+#: apt-ftparchive.1.xml:481
 msgid "Specifies the file list file."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:487
+#: apt-ftparchive.1.xml:488
 msgid "The Binary Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:488
+#: apt-ftparchive.1.xml:489
 msgid ""
 "The binary override file is fully compatible with &dpkg-scanpackages;. It "
 "contains 4 fields separated by spaces. The first field is the package name, "
@@ -2703,19 +2717,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:494
+#: apt-ftparchive.1.xml:495
 #, no-wrap
 msgid "old [// oldn]* => new"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><literallayout>
-#: apt-ftparchive.1.xml:496
+#: apt-ftparchive.1.xml:497
 #, no-wrap
 msgid "new"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:493
+#: apt-ftparchive.1.xml:494
 msgid ""
 "The general form of the maintainer field is: <placeholder type="
 "\"literallayout\" id=\"0\"/> or simply, <placeholder type=\"literallayout\" "
@@ -2726,12 +2740,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:504
+#: apt-ftparchive.1.xml:505
 msgid "The Source Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:506
+#: apt-ftparchive.1.xml:507
 msgid ""
 "The source override file is fully compatible with &dpkg-scansources;. It "
 "contains 2 fields separated by spaces. The first fields is the source "
@@ -2739,12 +2753,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:511
+#: apt-ftparchive.1.xml:512
 msgid "The Extra Override File"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:513
+#: apt-ftparchive.1.xml:514
 msgid ""
 "The extra override file allows any arbitrary tag to be added or replaced in "
 "the output. It has 3 columns, the first is the package, the second is the "
@@ -2752,12 +2766,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:522
+#: apt-ftparchive.1.xml:523
 msgid "<option>--md5</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:524
+#: apt-ftparchive.1.xml:525
 msgid ""
 "Generate MD5 sums. This defaults to on, when turned off the generated index "
 "files will not have MD5Sum fields where possible.  Configuration Item: "
@@ -2765,19 +2779,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:529
+#: apt-ftparchive.1.xml:530
 msgid "<option>--db</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:531
+#: apt-ftparchive.1.xml:532
 msgid ""
 "Use a binary caching DB. This has no effect on the generate command.  "
 "Configuration Item: <literal>APT::FTPArchive::DB</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:537
+#: apt-ftparchive.1.xml:538
 msgid ""
 "Quiet; produces output suitable for logging, omitting progress indicators.  "
 "More q's will produce more quiet up to a maximum of 2. You can also use "
@@ -2786,12 +2800,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:543
+#: apt-ftparchive.1.xml:544
 msgid "<option>--delink</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:545
+#: apt-ftparchive.1.xml:546
 msgid ""
 "Perform Delinking. If the <literal>External-Links</literal> setting is used "
 "then this option actually enables delinking of the files. It defaults to on "
@@ -2800,12 +2814,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:551
+#: apt-ftparchive.1.xml:552
 msgid "<option>--contents</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:553
+#: apt-ftparchive.1.xml:554
 msgid ""
 "Perform contents generation. When this option is set and package indexes are "
 "being generated with a cache DB then the file listing will also be extracted "
@@ -2815,12 +2829,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:561
+#: apt-ftparchive.1.xml:562
 msgid "<option>--source-override</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:563
+#: apt-ftparchive.1.xml:564
 msgid ""
 "Select the source override file to use with the <literal>sources</literal> "
 "command.  Configuration Item: <literal>APT::FTPArchive::SourceOverride</"
@@ -2828,24 +2842,24 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:567
+#: apt-ftparchive.1.xml:568
 msgid "<option>--readonly</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:569
+#: apt-ftparchive.1.xml:570
 msgid ""
 "Make the caching databases read only.  Configuration Item: <literal>APT::"
 "FTPArchive::ReadOnlyDB</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:573
+#: apt-ftparchive.1.xml:574
 msgid "<option>--arch</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:574
+#: apt-ftparchive.1.xml:575
 msgid ""
 "Accept in the <literal>packages</literal> and <literal>contents</literal> "
 "commands only package files matching <literal>*_arch.deb</literal> or "
@@ -2854,12 +2868,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:580
+#: apt-ftparchive.1.xml:581
 msgid "<option>APT::FTPArchive::AlwaysStat</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:582
+#: apt-ftparchive.1.xml:583
 msgid ""
 "&apt-ftparchive; caches as much as possible of metadata in a cachedb. If "
 "packages are recompiled and/or republished with the same version again, this "
@@ -2873,12 +2887,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt-ftparchive.1.xml:592
+#: apt-ftparchive.1.xml:593
 msgid "<option>APT::FTPArchive::LongDescription</option>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-ftparchive.1.xml:594
+#: apt-ftparchive.1.xml:595
 msgid ""
 "This configuration option defaults to \"<literal>true</literal>\" and should "
 "only be set to <literal>\"false\"</literal> if the Archive generated with "
@@ -2888,27 +2902,27 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt-ftparchive.1.xml:606 apt.conf.5.xml:1030 apt_preferences.5.xml:491
+#: apt-ftparchive.1.xml:607 apt.conf.5.xml:1054 apt_preferences.5.xml:491
 #: sources.list.5.xml:193
 #, fuzzy
 msgid "Examples"
 msgstr "Exemplos"
 
 #. type: Content of: <refentry><refsect1><para><programlisting>
-#: apt-ftparchive.1.xml:612
+#: apt-ftparchive.1.xml:613
 #, no-wrap
 msgid "<command>apt-ftparchive</command> packages <replaceable>directory</replaceable> | <command>gzip</command> > <filename>Packages.gz</filename>\n"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:608
+#: apt-ftparchive.1.xml:609
 msgid ""
 "To create a compressed Packages file for a directory containing binary "
 "packages (.deb): <placeholder type=\"programlisting\" id=\"0\"/>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-ftparchive.1.xml:622
+#: apt-ftparchive.1.xml:623
 msgid ""
 "<command>apt-ftparchive</command> returns zero on normal operation, decimal "
 "100 on error."
@@ -4097,27 +4111,19 @@
 msgid "Show the program version."
 msgstr ""
 
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
+#. type: Content of: <refentry><refsect1><variablelist>
 #: apt-mark.8.xml:124
-msgid "<filename>/var/lib/apt/extended_states</filename>"
-msgstr ""
-
-#. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt-mark.8.xml:125
-msgid ""
-"Status list of auto-installed packages.  Configuration Item: <literal>Dir::"
-"State</literal> sets the path to the <filename>extended_states</filename> "
-"file."
+msgid "  &file-extended_states;"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:134
+#: apt-mark.8.xml:129
 #, fuzzy
 msgid "&apt-get;,&aptitude;,&apt-conf;"
 msgstr "&apt-get; &apt-cache; &apt-conf; &sources-list;"
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt-mark.8.xml:138
+#: apt-mark.8.xml:133
 msgid ""
 "<command>apt-mark</command> returns zero on normal operation, non-zero on "
 "error."
@@ -4785,18 +4791,54 @@
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
 #: apt.conf.5.xml:233
+msgid "Check-Valid-Until"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:234
+msgid ""
+"Security related option defaulting to true as an expiring validation for a "
+"Release file prevents longtime replay attacks and can e.g. also help users "
+"to identify no longer updated mirrors - but the feature depends on the "
+"correctness of the time on the user system.  Archive maintainers are "
+"encouraged to create Release files with the <literal>Valid-Until</literal> "
+"header, but if they don't or a stricter value is volitional the following "
+"<literal>Max-ValidTime</literal> option can be used."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:244
+msgid "Max-ValidTime"
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
+#: apt.conf.5.xml:245
+msgid ""
+"Seconds the Release file should be considered valid after it was created. "
+"The default is \"for ever\" (0) if the Release file of the archive doesn't "
+"include a <literal>Valid-Until</literal> header.  If it does then this date "
+"is the default. The date from the Release file or the date specified by the "
+"creation time of the Release file (<literal>Date</literal> header) plus the "
+"seconds specified with this options are used to check if the validation of a "
+"file has expired by using the earlier date of the two. Archive specific "
+"settings can be made by appending the label of the archive to the option "
+"name."
+msgstr ""
+
+#. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
+#: apt.conf.5.xml:257
 msgid "PDiffs"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:234
+#: apt.conf.5.xml:258
 msgid ""
 "Try to download deltas called <literal>PDiffs</literal> for Packages or "
 "Sources files instead of downloading whole ones. True by default."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:237
+#: apt.conf.5.xml:261
 msgid ""
 "Two sub-options to limit the use of PDiffs are also available: With "
 "<literal>FileLimit</literal> can be specified how many PDiff files are "
@@ -4807,12 +4849,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:246
+#: apt.conf.5.xml:270
 msgid "Queue-Mode"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:247
+#: apt.conf.5.xml:271
 msgid ""
 "Queuing mode; <literal>Queue-Mode</literal> can be one of <literal>host</"
 "literal> or <literal>access</literal> which determines how APT parallelizes "
@@ -4822,36 +4864,36 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:254
+#: apt.conf.5.xml:278
 msgid "Retries"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:255
+#: apt.conf.5.xml:279
 msgid ""
 "Number of retries to perform. If this is non-zero APT will retry failed "
 "files the given number of times."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:259
+#: apt.conf.5.xml:283
 msgid "Source-Symlinks"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:260
+#: apt.conf.5.xml:284
 msgid ""
 "Use symlinks for source archives. If set to true then source archives will "
 "be symlinked when possible instead of copying. True is the default."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:264 sources.list.5.xml:139
+#: apt.conf.5.xml:288 sources.list.5.xml:139
 msgid "http"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:265
+#: apt.conf.5.xml:289
 msgid ""
 "HTTP URIs; http::Proxy is the default http proxy to use. It is in the "
 "standard form of <literal>http://[[user][:pass]@]host[:port]/</literal>. Per "
@@ -4862,7 +4904,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:273
+#: apt.conf.5.xml:297
 msgid ""
 "Three settings are provided for cache control with HTTP/1.1 compliant proxy "
 "caches. <literal>No-Cache</literal> tells the proxy to not use its cached "
@@ -4876,7 +4918,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:283 apt.conf.5.xml:347
+#: apt.conf.5.xml:307 apt.conf.5.xml:371
 msgid ""
 "The option <literal>timeout</literal> sets the timeout timer used by the "
 "method, this applies to all things including connection timeout and data "
@@ -4884,7 +4926,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:286
+#: apt.conf.5.xml:310
 msgid ""
 "One setting is provided to control the pipeline depth in cases where the "
 "remote server is not RFC conforming or buggy (such as Squid 2.0.2).  "
@@ -4896,7 +4938,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:294
+#: apt.conf.5.xml:318
 msgid ""
 "The used bandwidth can be limited with <literal>Acquire::http::Dl-Limit</"
 "literal> which accepts integer values in kilobyte. The default value is 0 "
@@ -4906,7 +4948,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:299
+#: apt.conf.5.xml:323
 msgid ""
 "<literal>Acquire::http::User-Agent</literal> can be used to set a different "
 "User-Agent for the http download method as some proxies allow access for "
@@ -4914,12 +4956,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:305
+#: apt.conf.5.xml:329
 msgid "https"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:306
+#: apt.conf.5.xml:330
 msgid ""
 "HTTPS URIs. Cache-control, Timeout, AllowRedirect, Dl-Limit and proxy "
 "options are the same as for <literal>http</literal> method and will also "
@@ -4929,7 +4971,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:312
+#: apt.conf.5.xml:336
 msgid ""
 "<literal>CaInfo</literal> suboption specifies place of file that holds info "
 "about trusted certificates.  <literal>&lt;host&gt;::CaInfo</literal> is "
@@ -4950,12 +4992,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:330 sources.list.5.xml:150
+#: apt.conf.5.xml:354 sources.list.5.xml:150
 msgid "ftp"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:331
+#: apt.conf.5.xml:355
 msgid ""
 "FTP URIs; ftp::Proxy is the default ftp proxy to use. It is in the standard "
 "form of <literal>ftp://[[user][:pass]@]host[:port]/</literal>. Per host "
@@ -4974,7 +5016,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:350
+#: apt.conf.5.xml:374
 msgid ""
 "Several settings are provided to control passive mode. Generally it is safe "
 "to leave passive mode on, it works in nearly every environment.  However "
@@ -4984,7 +5026,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:357
+#: apt.conf.5.xml:381
 msgid ""
 "It is possible to proxy FTP over HTTP by setting the <envar>ftp_proxy</"
 "envar> environment variable to a http url - see the discussion of the http "
@@ -4993,7 +5035,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:362
+#: apt.conf.5.xml:386
 msgid ""
 "The setting <literal>ForceExtended</literal> controls the use of RFC2428 "
 "<literal>EPSV</literal> and <literal>EPRT</literal> commands. The default is "
@@ -5003,18 +5045,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:369 sources.list.5.xml:132
+#: apt.conf.5.xml:393 sources.list.5.xml:132
 msgid "cdrom"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:375
+#: apt.conf.5.xml:399
 #, no-wrap
 msgid "/cdrom/::Mount \"foo\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:370
+#: apt.conf.5.xml:394
 msgid ""
 "CDROM URIs; the only setting for CDROM URIs is the mount point, "
 "<literal>cdrom::Mount</literal> which must be the mount point for the CDROM "
@@ -5027,12 +5069,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:380
+#: apt.conf.5.xml:404
 msgid "gpgv"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:381
+#: apt.conf.5.xml:405
 msgid ""
 "GPGV URIs; the only option for GPGV URIs is the option to pass additional "
 "parameters to gpgv.  <literal>gpgv::Options</literal> Additional options "
@@ -5040,18 +5082,18 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:386
+#: apt.conf.5.xml:410
 msgid "CompressionTypes"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:392
+#: apt.conf.5.xml:416
 #, no-wrap
 msgid "Acquire::CompressionTypes::<replaceable>FileExtension</replaceable> \"<replaceable>Methodname</replaceable>\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:387
+#: apt.conf.5.xml:411
 msgid ""
 "List of compression types which are understood by the acquire methods.  "
 "Files like <filename>Packages</filename> can be available in various "
@@ -5063,19 +5105,19 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:397
+#: apt.conf.5.xml:421
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order:: \"gz\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><synopsis>
-#: apt.conf.5.xml:400
+#: apt.conf.5.xml:424
 #, no-wrap
 msgid "Acquire::CompressionTypes::Order { \"lzma\"; \"gz\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:393
+#: apt.conf.5.xml:417
 msgid ""
 "Also the <literal>Order</literal> subgroup can be used to define in which "
 "order the acquire system will try to download the compressed files. The "
@@ -5092,13 +5134,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:404
+#: apt.conf.5.xml:428
 #, no-wrap
 msgid "Dir::Bin::bzip2 \"/bin/bzip2\";"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:402
+#: apt.conf.5.xml:426
 msgid ""
 "Note that at run time the <literal>Dir::Bin::<replaceable>Methodname</"
 "replaceable></literal> will be checked: If this setting exists the method "
@@ -5113,7 +5155,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:409
+#: apt.conf.5.xml:433
 msgid ""
 "While it is possible to add an empty compression type to the order list, but "
 "APT in its current version doesn't understand it correctly and will display "
@@ -5123,12 +5165,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><term>
-#: apt.conf.5.xml:415
+#: apt.conf.5.xml:439
 msgid "Languages"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:416
+#: apt.conf.5.xml:440
 msgid ""
 "The Languages subsection controls which <filename>Translation</filename> "
 "files are downloaded and in which order APT tries to display the Description-"
@@ -5141,13 +5183,13 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para><programlisting>
-#: apt.conf.5.xml:432
+#: apt.conf.5.xml:456
 #, no-wrap
 msgid "Acquire::Languages { \"environment\"; \"de\"; \"en\"; \"none\"; \"fr\"; };"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:422
+#: apt.conf.5.xml:446
 msgid ""
 "The default list includes \"environment\" and \"en\". "
 "\"<literal>environment</literal>\" has a special meaning here: It will be "
@@ -5177,12 +5219,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:439
+#: apt.conf.5.xml:463
 msgid "Directories"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:441
+#: apt.conf.5.xml:465
 msgid ""
 "The <literal>Dir::State</literal> section has directories that pertain to "
 "local state information. <literal>lists</literal> is the directory to place "
@@ -5194,7 +5236,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:448
+#: apt.conf.5.xml:472
 msgid ""
 "<literal>Dir::Cache</literal> contains locations pertaining to local cache "
 "information, such as the two package caches <literal>srcpkgcache</literal> "
@@ -5207,7 +5249,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:457
+#: apt.conf.5.xml:481
 msgid ""
 "<literal>Dir::Etc</literal> contains the location of configuration files, "
 "<literal>sourcelist</literal> gives the location of the sourcelist and "
@@ -5217,7 +5259,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:463
+#: apt.conf.5.xml:487
 msgid ""
 "The <literal>Dir::Parts</literal> setting reads in all the config fragments "
 "in lexical order from the directory specified. After this is done then the "
@@ -5225,7 +5267,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:467
+#: apt.conf.5.xml:491
 msgid ""
 "Binary programs are pointed to by <literal>Dir::Bin</literal>. <literal>Dir::"
 "Bin::Methods</literal> specifies the location of the method handlers and "
@@ -5236,7 +5278,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:475
+#: apt.conf.5.xml:499
 msgid ""
 "The configuration item <literal>RootDir</literal> has a special meaning.  If "
 "set, all paths in <literal>Dir::</literal> will be relative to "
@@ -5249,12 +5291,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:488
+#: apt.conf.5.xml:512
 msgid "APT in DSelect"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:490
+#: apt.conf.5.xml:514
 msgid ""
 "When APT is used as a &dselect; method several configuration directives "
 "control the default behaviour. These are in the <literal>DSelect</literal> "
@@ -5262,12 +5304,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:494
+#: apt.conf.5.xml:518
 msgid "Clean"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:495
+#: apt.conf.5.xml:519
 msgid ""
 "Cache Clean mode; this value may be one of always, prompt, auto, pre-auto "
 "and never.  always and prompt will remove all packages from the cache after "
@@ -5278,50 +5320,50 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:504
+#: apt.conf.5.xml:528
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the install phase."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:508
+#: apt.conf.5.xml:532
 msgid "Updateoptions"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:509
+#: apt.conf.5.xml:533
 msgid ""
 "The contents of this variable is passed to &apt-get; as command line options "
 "when it is run for the update phase."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:513
+#: apt.conf.5.xml:537
 msgid "PromptAfterUpdate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:514
+#: apt.conf.5.xml:538
 msgid ""
 "If true the [U]pdate operation in &dselect; will always prompt to continue.  "
 "The default is to prompt only on error."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:520
+#: apt.conf.5.xml:544
 msgid "How APT calls dpkg"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:521
+#: apt.conf.5.xml:545
 msgid ""
 "Several configuration directives control how APT invokes &dpkg;. These are "
 "in the <literal>DPkg</literal> section."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:526
+#: apt.conf.5.xml:550
 msgid ""
 "This is a list of options to pass to dpkg. The options must be specified "
 "using the list notation and each list item is passed as a single argument to "
@@ -5329,17 +5371,17 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Pre-Invoke"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:531
+#: apt.conf.5.xml:555
 msgid "Post-Invoke"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:532
+#: apt.conf.5.xml:556
 msgid ""
 "This is a list of shell commands to run before/after invoking &dpkg;.  Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -5348,12 +5390,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:538
+#: apt.conf.5.xml:562
 msgid "Pre-Install-Pkgs"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:539
+#: apt.conf.5.xml:563
 msgid ""
 "This is a list of shell commands to run before invoking dpkg. Like "
 "<literal>options</literal> this must be specified in list notation. The "
@@ -5363,7 +5405,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:545
+#: apt.conf.5.xml:569
 msgid ""
 "Version 2 of this protocol dumps more information, including the protocol "
 "version, the APT configuration space and the packages, files and versions "
@@ -5373,36 +5415,36 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:552
+#: apt.conf.5.xml:576
 msgid "Run-Directory"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:553
+#: apt.conf.5.xml:577
 msgid ""
 "APT chdirs to this directory before invoking dpkg, the default is <filename>/"
 "</filename>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:557
+#: apt.conf.5.xml:581
 msgid "Build-options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:558
+#: apt.conf.5.xml:582
 msgid ""
 "These options are passed to &dpkg-buildpackage; when compiling packages, the "
 "default is to disable signing and produce all binaries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><title>
-#: apt.conf.5.xml:563
+#: apt.conf.5.xml:587
 msgid "dpkg trigger usage (and related options)"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:564
+#: apt.conf.5.xml:588
 msgid ""
 "APT can call dpkg in a way so it can make aggressive use of triggers over "
 "multiply calls of dpkg. Without further options dpkg will use triggers only "
@@ -5417,7 +5459,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para><literallayout>
-#: apt.conf.5.xml:579
+#: apt.conf.5.xml:603
 #, no-wrap
 msgid ""
 "DPkg::NoTriggers \"true\";\n"
@@ -5427,7 +5469,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><para>
-#: apt.conf.5.xml:573
+#: apt.conf.5.xml:597
 msgid ""
 "Note that it is not guaranteed that APT will support these options or that "
 "these options will not cause (big) trouble in the future. If you have "
@@ -5441,12 +5483,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:585
+#: apt.conf.5.xml:609
 msgid "DPkg::NoTriggers"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:586
+#: apt.conf.5.xml:610
 msgid ""
 "Add the no triggers flag to all dpkg calls (except the ConfigurePending "
 "call).  See &dpkg; if you are interested in what this actually means. In "
@@ -5458,12 +5500,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:593
+#: apt.conf.5.xml:617
 msgid "PackageManager::Configure"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:594
+#: apt.conf.5.xml:618
 msgid ""
 "Valid values are \"<literal>all</literal>\", \"<literal>smart</literal>\" "
 "and \"<literal>no</literal>\".  \"<literal>all</literal>\" is the default "
@@ -5479,12 +5521,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:604
+#: apt.conf.5.xml:628
 msgid "DPkg::ConfigurePending"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:605
+#: apt.conf.5.xml:629
 msgid ""
 "If this option is set apt will call <command>dpkg --configure --pending</"
 "command> to let dpkg handle all required configurations and triggers. This "
@@ -5495,12 +5537,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:611
+#: apt.conf.5.xml:635
 msgid "DPkg::TriggersPending"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:612
+#: apt.conf.5.xml:636
 msgid ""
 "Useful for <literal>smart</literal> configuration as a package which has "
 "pending triggers is not considered as <literal>installed</literal> and dpkg "
@@ -5510,12 +5552,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:617
+#: apt.conf.5.xml:641
 msgid "PackageManager::UnpackAll"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:618
+#: apt.conf.5.xml:642
 msgid ""
 "As the configuration can be deferred to be done at the end by dpkg it can be "
 "tried to order the unpack series only by critical needs, e.g. by Pre-"
@@ -5527,12 +5569,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><term>
-#: apt.conf.5.xml:625
+#: apt.conf.5.xml:649
 msgid "OrderList::Score::Immediate"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para><literallayout>
-#: apt.conf.5.xml:633
+#: apt.conf.5.xml:657
 #, no-wrap
 msgid ""
 "OrderList::Score {\n"
@@ -5544,7 +5586,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><refsect2><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:626
+#: apt.conf.5.xml:650
 msgid ""
 "Essential packages (and there dependencies) should be configured immediately "
 "after unpacking. It will be a good idea to do this quite early in the "
@@ -5558,12 +5600,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:646
+#: apt.conf.5.xml:670
 msgid "Periodic and Archives options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:647
+#: apt.conf.5.xml:671
 msgid ""
 "<literal>APT::Periodic</literal> and <literal>APT::Archives</literal> groups "
 "of options configure behavior of apt periodic updates, which is done by "
@@ -5572,12 +5614,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><title>
-#: apt.conf.5.xml:655
+#: apt.conf.5.xml:679
 msgid "Debug options"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:657
+#: apt.conf.5.xml:681
 msgid ""
 "Enabling options in the <literal>Debug::</literal> section will cause "
 "debugging information to be sent to the standard error stream of the program "
@@ -5588,7 +5630,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:668
+#: apt.conf.5.xml:692
 msgid ""
 "<literal>Debug::pkgProblemResolver</literal> enables output about the "
 "decisions made by <literal>dist-upgrade, upgrade, install, remove, purge</"
@@ -5596,7 +5638,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:676
+#: apt.conf.5.xml:700
 msgid ""
 "<literal>Debug::NoLocking</literal> disables all file locking.  This can be "
 "used to run some operations (for instance, <literal>apt-get -s install</"
@@ -5604,7 +5646,7 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:685
+#: apt.conf.5.xml:709
 msgid ""
 "<literal>Debug::pkgDPkgPM</literal> prints out the actual command line each "
 "time that <literal>apt</literal> invokes &dpkg;."
@@ -5614,120 +5656,120 @@
 #. 	   motivating example, except I haven't a clue why you'd want
 #. 	   to do this. 
 #. type: Content of: <refentry><refsect1><para><itemizedlist><listitem><para>
-#: apt.conf.5.xml:693
+#: apt.conf.5.xml:717
 msgid ""
 "<literal>Debug::IdentCdrom</literal> disables the inclusion of statfs data "
 "in CDROM IDs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:703
+#: apt.conf.5.xml:727
 msgid "A full list of debugging options to apt follows."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:708
+#: apt.conf.5.xml:732
 #, fuzzy
 msgid "<literal>Debug::Acquire::cdrom</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:712
+#: apt.conf.5.xml:736
 msgid ""
 "Print information related to accessing <literal>cdrom://</literal> sources."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:719
+#: apt.conf.5.xml:743
 #, fuzzy
 msgid "<literal>Debug::Acquire::ftp</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:723
+#: apt.conf.5.xml:747
 msgid "Print information related to downloading packages using FTP."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:730
+#: apt.conf.5.xml:754
 #, fuzzy
 msgid "<literal>Debug::Acquire::http</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:734
+#: apt.conf.5.xml:758
 msgid "Print information related to downloading packages using HTTP."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:741
+#: apt.conf.5.xml:765
 #, fuzzy
 msgid "<literal>Debug::Acquire::https</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:745
+#: apt.conf.5.xml:769
 msgid "Print information related to downloading packages using HTTPS."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:752
+#: apt.conf.5.xml:776
 #, fuzzy
 msgid "<literal>Debug::Acquire::gpgv</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:756
+#: apt.conf.5.xml:780
 msgid ""
 "Print information related to verifying cryptographic signatures using "
 "<literal>gpg</literal>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:763
+#: apt.conf.5.xml:787
 #, fuzzy
 msgid "<literal>Debug::aptcdrom</literal>"
 msgstr "a linha <literal>Version:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:767
+#: apt.conf.5.xml:791
 msgid ""
 "Output information about the process of accessing collections of packages "
 "stored on CD-ROMs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:774
+#: apt.conf.5.xml:798
 #, fuzzy
 msgid "<literal>Debug::BuildDeps</literal>"
 msgstr "a linha <literal>Label:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:777
+#: apt.conf.5.xml:801
 msgid "Describes the process of resolving build-dependencies in &apt-get;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:784
+#: apt.conf.5.xml:808
 #, fuzzy
 msgid "<literal>Debug::Hashes</literal>"
 msgstr "a linha <literal>Label:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:787
+#: apt.conf.5.xml:811
 msgid ""
 "Output each cryptographic hash that is generated by the <literal>apt</"
 "literal> libraries."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:794
+#: apt.conf.5.xml:818
 #, fuzzy
 msgid "<literal>Debug::IdentCDROM</literal>"
 msgstr "a linha <literal>Label:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:797
+#: apt.conf.5.xml:821
 msgid ""
 "Do not include information from <literal>statfs</literal>, namely the number "
 "of used and free blocks on the CD-ROM filesystem, when generating an ID for "
@@ -5735,99 +5777,99 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:805
+#: apt.conf.5.xml:829
 #, fuzzy
 msgid "<literal>Debug::NoLocking</literal>"
 msgstr "a linha <literal>Origin:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:808
+#: apt.conf.5.xml:832
 msgid ""
 "Disable all file locking.  For instance, this will allow two instances of "
 "<quote><literal>apt-get update</literal></quote> to run at the same time."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:816
+#: apt.conf.5.xml:840
 #, fuzzy
 msgid "<literal>Debug::pkgAcquire</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:820
+#: apt.conf.5.xml:844
 msgid "Log when items are added to or removed from the global download queue."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:827
+#: apt.conf.5.xml:851
 #, fuzzy
 msgid "<literal>Debug::pkgAcquire::Auth</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:830
+#: apt.conf.5.xml:854
 msgid ""
 "Output status messages and errors related to verifying checksums and "
 "cryptographic signatures of downloaded files."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:837
+#: apt.conf.5.xml:861
 #, fuzzy
 msgid "<literal>Debug::pkgAcquire::Diffs</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:840
+#: apt.conf.5.xml:864
 msgid ""
 "Output information about downloading and applying package index list diffs, "
 "and errors relating to package index list diffs."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:848
+#: apt.conf.5.xml:872
 #, fuzzy
 msgid "<literal>Debug::pkgAcquire::RRed</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:852
+#: apt.conf.5.xml:876
 msgid ""
 "Output information related to patching apt package lists when downloading "
 "index diffs instead of full indices."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:859
+#: apt.conf.5.xml:883
 #, fuzzy
 msgid "<literal>Debug::pkgAcquire::Worker</literal>"
 msgstr "a linha <literal>Archive:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:863
+#: apt.conf.5.xml:887
 msgid ""
 "Log all interactions with the sub-processes that actually perform downloads."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:870
+#: apt.conf.5.xml:894
 msgid "<literal>Debug::pkgAutoRemove</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:874
+#: apt.conf.5.xml:898
 msgid ""
 "Log events related to the automatically-installed status of packages and to "
 "the removal of unused packages."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:881
+#: apt.conf.5.xml:905
 msgid "<literal>Debug::pkgDepCache::AutoInstall</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:884
+#: apt.conf.5.xml:908
 msgid ""
 "Generate debug messages describing which packages are being automatically "
 "installed to resolve dependencies.  This corresponds to the initial auto-"
@@ -5837,12 +5879,12 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:895
+#: apt.conf.5.xml:919
 msgid "<literal>Debug::pkgDepCache::Marker</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:898
+#: apt.conf.5.xml:922
 msgid ""
 "Generate debug messages describing which package is marked as keep/install/"
 "remove while the ProblemResolver does his work.  Each addition or deletion "
@@ -5859,96 +5901,96 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:917
+#: apt.conf.5.xml:941
 #, fuzzy
 msgid "<literal>Debug::pkgInitConfig</literal>"
 msgstr "a linha <literal>Version:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:920
+#: apt.conf.5.xml:944
 msgid "Dump the default configuration to standard error on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:927
+#: apt.conf.5.xml:951
 #, fuzzy
 msgid "<literal>Debug::pkgDPkgPM</literal>"
 msgstr "a linha <literal>Package:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:930
+#: apt.conf.5.xml:954
 msgid ""
 "When invoking &dpkg;, output the precise command line with which it is being "
 "invoked, with arguments separated by a single space character."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:938
+#: apt.conf.5.xml:962
 msgid "<literal>Debug::pkgDPkgProgressReporting</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:941
+#: apt.conf.5.xml:965
 msgid ""
 "Output all the data received from &dpkg; on the status file descriptor and "
 "any errors encountered while parsing it."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:948
+#: apt.conf.5.xml:972
 #, fuzzy
 msgid "<literal>Debug::pkgOrderList</literal>"
 msgstr "a linha <literal>Origin:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:952
+#: apt.conf.5.xml:976
 msgid ""
 "Generate a trace of the algorithm that decides the order in which "
 "<literal>apt</literal> should pass packages to &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:960
+#: apt.conf.5.xml:984
 #, fuzzy
 msgid "<literal>Debug::pkgPackageManager</literal>"
 msgstr "a linha <literal>Package:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:964
+#: apt.conf.5.xml:988
 msgid ""
 "Output status messages tracing the steps performed when invoking &dpkg;."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:971
+#: apt.conf.5.xml:995
 #, fuzzy
 msgid "<literal>Debug::pkgPolicy</literal>"
 msgstr "a linha <literal>Label:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:975
+#: apt.conf.5.xml:999
 msgid "Output the priority of each package list on startup."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:981
+#: apt.conf.5.xml:1005
 msgid "<literal>Debug::pkgProblemResolver</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:985
+#: apt.conf.5.xml:1009
 msgid ""
 "Trace the execution of the dependency resolver (this applies only to what "
 "happens when a complex dependency problem is encountered)."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:993
+#: apt.conf.5.xml:1017
 msgid "<literal>Debug::pkgProblemResolver::ShowScores</literal>"
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:996
+#: apt.conf.5.xml:1020
 msgid ""
 "Display a list of all installed packages with their calculated score used by "
 "the pkgProblemResolver. The description of the package is the same as "
@@ -5956,33 +5998,33 @@
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><term>
-#: apt.conf.5.xml:1004
+#: apt.conf.5.xml:1028
 #, fuzzy
 msgid "<literal>Debug::sourceList</literal>"
 msgstr "a linha <literal>Version:</literal>"
 
 #. type: Content of: <refentry><refsect1><variablelist><varlistentry><listitem><para>
-#: apt.conf.5.xml:1008
+#: apt.conf.5.xml:1032
 msgid ""
 "Print information about the vendors read from <filename>/etc/apt/vendors."
 "list</filename>."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1031
+#: apt.conf.5.xml:1055
 msgid ""
 "&configureindex; is a configuration file showing example values for all "
 "possible options."
 msgstr ""
 
 #. type: Content of: <refentry><refsect1><variablelist>
-#: apt.conf.5.xml:1038
+#: apt.conf.5.xml:1062
 msgid "&file-aptconf;"
 msgstr ""
 
 #.  ? reading apt.conf 
 #. type: Content of: <refentry><refsect1><para>
-#: apt.conf.5.xml:1043
+#: apt.conf.5.xml:1067
 #, fuzzy
 msgid "&apt-cache;, &apt-config;, &apt-preferences;."
 msgstr "&apt-get; &apt-cache; &apt-conf; &sources-list;"

=== modified file 'ftparchive/writer.cc'
--- ftparchive/writer.cc	2010-05-06 09:32:54 +0000
+++ ftparchive/writer.cc	2010-06-10 14:02:22 +0000
@@ -924,6 +924,15 @@
       datestr[0] = '\0';
    }
 
+   time_t const validuntil = now + _config->FindI("APT::FTPArchive::Release::ValidTime", 0);
+   char validstr[128];
+   if (now == validuntil ||
+       strftime(validstr, sizeof(validstr), "%a, %d %b %Y %H:%M:%S UTC",
+                gmtime(&validuntil)) == 0)
+   {
+      datestr[0] = '\0';
+   }
+
    map<string,string> Fields;
    Fields["Origin"] = "";
    Fields["Label"] = "";
@@ -931,6 +940,7 @@
    Fields["Version"] = "";
    Fields["Codename"] = "";
    Fields["Date"] = datestr;
+   Fields["Valid-Until"] = validstr;
    Fields["Architectures"] = "";
    Fields["Components"] = "";
    Fields["Description"] = "";

=== modified file 'ftparchive/writer.h'
--- ftparchive/writer.h	2010-04-01 17:30:43 +0000
+++ ftparchive/writer.h	2010-06-10 14:02:22 +0000
@@ -72,6 +72,7 @@
    bool SetExts(string const &Vals);
       
    FTWScanner(string const &Arch = string());
+   virtual ~FTWScanner() {};
 };
 
 class TranslationWriter

=== modified file 'methods/connect.cc'
--- methods/connect.cc	2010-05-06 09:32:54 +0000
+++ methods/connect.cc	2010-06-10 14:02:22 +0000
@@ -18,6 +18,7 @@
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
+#include <sstream>
 
 #include<set>
 #include<string>
@@ -70,19 +71,17 @@
    Owner->Status(_("Connecting to %s (%s)"),Host.c_str(),Name);
 
    // if that addr did timeout before, we do not try it again
-   if(bad_addr.find(string(Name)) != bad_addr.end()) 
+   if(bad_addr.find(string(Name)) != bad_addr.end())
       return false;
 
    /* If this is an IP rotation store the IP we are using.. If something goes
       wrong this will get tacked onto the end of the error message */
    if (LastHostAddr->ai_next != 0)
    {
-      char Name2[NI_MAXHOST + NI_MAXSERV + 10];
-      snprintf(Name2,sizeof(Name2),_("[IP: %s %s]"),Name,Service);
-      Owner->SetFailExtraMsg(string(Name2));
-   }   
-   else
-      Owner->SetFailExtraMsg("");
+      std::stringstream ss;
+      ioprintf(ss, _("[IP: %s %s]"),Name,Service);
+      Owner->SetIP(ss.str());
+   }
       
    // Get a socket
    if ((Fd = socket(Addr->ai_family,Addr->ai_socktype,
@@ -100,7 +99,7 @@
       nonblocking */
    if (WaitFd(Fd,true,TimeOut) == false) {
       bad_addr.insert(bad_addr.begin(), string(Name));
-      Owner->SetFailExtraMsg("\nFailReason: Timeout");
+      Owner->SetFailReason("Timeout");
       return _error->Error(_("Could not connect to %s:%s (%s), "
 			   "connection timed out"),Host.c_str(),Service,Name);
    }
@@ -115,9 +114,9 @@
    {
       errno = Err;
       if(errno == ECONNREFUSED)
-         Owner->SetFailExtraMsg("\nFailReason: ConnectionRefused");
+         Owner->SetFailReason("ConnectionRefused");
       else if (errno == ETIMEDOUT)
-	 Owner->SetFailExtraMsg("\nFailReason: ConnectionTimedOut");
+	 Owner->SetFailReason("ConnectionTimedOut");
       bad_addr.insert(bad_addr.begin(), string(Name));
       return _error->Errno("connect",_("Could not connect to %s:%s (%s)."),Host.c_str(),
 			   Service,Name);
@@ -184,13 +183,13 @@
 		  continue;
 	       }
 	       bad_addr.insert(bad_addr.begin(), Host);
-	       Owner->SetFailExtraMsg("\nFailReason: ResolveFailure");
+	       Owner->SetFailReason("ResolveFailure");
 	       return _error->Error(_("Could not resolve '%s'"),Host.c_str());
 	    }
 	    
 	    if (Res == EAI_AGAIN)
 	    {
-	       Owner->SetFailExtraMsg("\nFailReason: TmpResolveFailure");
+	       Owner->SetFailReason("TmpResolveFailure");
 	       return _error->Error(_("Temporary failure resolving '%s'"),
 				    Host.c_str());
 	    }

=== modified file 'methods/copy.cc'
--- methods/copy.cc	2010-02-18 22:07:23 +0000
+++ methods/copy.cc	2010-06-10 14:02:22 +0000
@@ -84,6 +84,7 @@
    FileFd Fd(Res.Filename, FileFd::ReadOnly);
    Hash.AddFD(Fd.Fd(), Fd.Size());
    Res.TakeHashes(Hash);
+
    URIDone(Res);
    return true;
 }

=== modified file 'methods/ftp.cc'
--- methods/ftp.cc	2010-02-18 22:07:23 +0000
+++ methods/ftp.cc	2010-06-10 14:02:22 +0000
@@ -661,8 +661,7 @@
       return true;
    
    // Parse it
-   StrToTime(Msg,Time);
-   return true;
+   return FTPMDTMStrToTime(Msg.c_str(), Time);
 }
 									/*}}}*/
 // FTPConn::CreateDataFd - Get a data connection			/*{{{*/

=== modified file 'methods/gpgv.cc'
--- methods/gpgv.cc	2010-05-25 16:01:42 +0000
+++ methods/gpgv.cc	2010-06-10 14:02:22 +0000
@@ -2,6 +2,7 @@
 #include <apt-pkg/acquire-method.h>
 #include <apt-pkg/strutl.h>
 #include <apt-pkg/fileutl.h>
+#include <apt-pkg/indexcopy.h>
 #include <apti18n.h>
 
 #include <utime.h>
@@ -54,97 +55,29 @@
    if (Debug == true)
       std::clog << "inside VerifyGetSigners" << std::endl;
 
-   pid_t pid;
    int fd[2];
-   FILE *pipein;
-   int status;
-   string const gpgvpath = _config->Find("Dir::Bin::gpg", "/usr/bin/gpgv");
-   // FIXME: remove support for deprecated APT::GPGV setting
-   string const trustedFile = _config->FindFile("Dir::Etc::Trusted",
-			_config->Find("APT::GPGV::TrustedKeyring", "/etc/apt/trusted.gpg").c_str());
-   string const trustedPath = _config->FindDir("Dir::Etc::TrustedParts", "/etc/apt/trusted.gpg.d");
-   if (Debug == true)
-   {
-      std::clog << "gpgv path: " << gpgvpath << std::endl;
-      std::clog << "Keyring file: " << trustedFile << std::endl;
-      std::clog << "Keyring path: " << trustedPath << std::endl;
-   }
-
-   vector<string> keyrings = GetListOfFilesInDir(trustedPath, "gpg", false);
-   if (FileExists(trustedFile) == true)
-      keyrings.push_back(trustedFile);
-
-   if (keyrings.empty() == true)
-   {
-      // TRANSLATOR: %s is the trusted keyring parts directory
-      ioprintf(ret, _("No keyring installed in %s."), trustedPath.c_str());
-      return ret.str();
-   }
 
    if (pipe(fd) < 0)
       return "Couldn't create pipe";
 
-   pid = fork();
+   pid_t pid = fork();
    if (pid < 0)
       return string("Couldn't spawn new process") + strerror(errno);
    else if (pid == 0)
    {
-      std::vector<const char *> Args;
-      Args.reserve(30);
-
-      Args.push_back(gpgvpath.c_str());
-      Args.push_back("--status-fd");
-      Args.push_back("3");
-      Args.push_back("--ignore-time-conflict");
-      for (vector<string>::const_iterator K = keyrings.begin();
-	   K != keyrings.end(); ++K)
-      {
-	 Args.push_back("--keyring");
-	 Args.push_back(K->c_str());
-      }
-
-      Configuration::Item const *Opts;
-      Opts = _config->Tree("Acquire::gpgv::Options");
-      if (Opts != 0)
-      {
-         Opts = Opts->Child;
-	 for (; Opts != 0; Opts = Opts->Next)
-         {
-            if (Opts->Value.empty() == true)
-               continue;
-            Args.push_back(Opts->Value.c_str());
-         }
-      }
-      Args.push_back(file);
-      Args.push_back(outfile);
-      Args.push_back(NULL);
-
-      if (Debug == true)
-      {
-         std::clog << "Preparing to exec: " << gpgvpath;
-	 for(std::vector<const char *>::const_iterator a = Args.begin();*a != NULL; ++a)
-	    std::clog << " " << *a;
-	 std::clog << std::endl;
-      }
-      int const nullfd = open("/dev/null", O_RDONLY);
-      close(fd[0]);
-      // Redirect output to /dev/null; we read from the status fd
-      dup2(nullfd, STDOUT_FILENO); 
-      dup2(nullfd, STDERR_FILENO); 
-      // Redirect the pipe to the status fd (3)
-      dup2(fd[1], 3);
-
-      putenv((char *)"LANG=");
-      putenv((char *)"LC_ALL=");
-      putenv((char *)"LC_MESSAGES=");
-      execvp(gpgvpath.c_str(), (char **) &Args[0]);
-             
+      if (SigVerify::RunGPGV(outfile, file, 3, fd) == false)
+      {
+	 // TRANSLATOR: %s is the trusted keyring parts directory
+	 ioprintf(ret, _("No keyring installed in %s."),
+		  _config->FindDir("Dir::Etc::TrustedParts", "/etc/apt/trusted.gpg.d").c_str());
+	 return ret.str();
+      }
       exit(111);
    }
    close(fd[1]);
 
-   pipein = fdopen(fd[0], "r"); 
-   
+   FILE *pipein = fdopen(fd[0], "r");
+
    // Loop over the output of gpgv, and check the signatures.
    size_t buffersize = 64;
    char *buffer = (char *) malloc(buffersize);
@@ -217,6 +150,7 @@
    }
    fclose(pipein);
 
+   int status;
    waitpid(pid, &status, 0);
    if (Debug == true)
    {
@@ -235,7 +169,7 @@
    }
    else if (WEXITSTATUS(status) == 111)
    {
-      ioprintf(ret, _("Could not execute '%s' to verify signature (is gpgv installed?)"), gpgvpath.c_str());
+      ioprintf(ret, _("Could not execute 'gpgv' to verify signature (is gpgv installed?)"));
       return ret.str();
    }
    else

=== modified file 'methods/http.cc'
--- methods/http.cc	2010-05-25 16:01:42 +0000
+++ methods/http.cc	2010-06-10 14:02:22 +0000
@@ -631,7 +631,7 @@
    
    if (stringcasecmp(Tag,"Last-Modified:") == 0)
    {
-      if (StrToTime(Val,Date) == false)
+      if (RFC1123StrToTime(Val.c_str(), Date) == false)
 	 return _error->Error(_("Unknown date format"));
       return true;
    }
@@ -953,6 +953,9 @@
       failure */
    if (Srv->Result < 200 || Srv->Result >= 300)
    {
+      char err[255];
+      snprintf(err,sizeof(err)-1,"HttpError%i",Srv->Result);
+      SetFailReason(err);
       _error->Error("%u %s",Srv->Result,Srv->Code);
       if (Srv->HaveContent == true)
 	 return ERROR_WITH_CONTENT_PAGE;
@@ -1366,15 +1369,4 @@
 }
 									/*}}}*/
 
-int main()
-{
-   setlocale(LC_ALL, "");
-   // ignore SIGPIPE, this can happen on write() if the socket
-   // closes the connection (this is dealt with via ServerDie())
-   signal(SIGPIPE, SIG_IGN);
-
-   HttpMethod Mth;
-   return Mth.Loop();
-}
-
 

=== modified file 'methods/http.h'
--- methods/http.h	2010-05-25 16:01:42 +0000
+++ methods/http.h	2010-06-10 14:02:22 +0000
@@ -13,7 +13,7 @@
 
 #define MAXLEN 360
 
-#include <iostream>
+#include <apt-pkg/hashes.h>
 
 using std::cout;
 using std::endl;
@@ -167,7 +167,6 @@
    /** \brief Try to AutoDetect the proxy */
    bool AutoDetectProxy();
 
-   virtual bool Fetch(FetchItem *);
    virtual bool Configuration(string Message);
    
    // In the event of a fatal signal this file will be closed and timestamped.
@@ -175,6 +174,9 @@
    static int FailFd;
    static time_t FailTime;
    static void SigTerm(int);
+
+   protected:
+   virtual bool Fetch(FetchItem *);
    
    string NextURI;
    string AutoDetectProxyCmd;

=== added file 'methods/http_main.cc'
--- methods/http_main.cc	1970-01-01 00:00:00 +0000
+++ methods/http_main.cc	2010-06-10 14:02:22 +0000
@@ -0,0 +1,20 @@
+#include <apt-pkg/fileutl.h>
+#include <apt-pkg/acquire-method.h>
+#include <signal.h>
+
+#include "connect.h"
+#include "rfc2553emu.h"
+#include "http.h"
+
+
+int main()
+{
+   setlocale(LC_ALL, "");
+
+   // ignore SIGPIPE, this can happen on write() if the socket
+   // closes the connection (this is dealt with via ServerDie())
+   signal(SIGPIPE, SIG_IGN);
+
+   HttpMethod Mth;
+   return Mth.Loop();
+}

=== modified file 'methods/makefile'
--- methods/makefile	2010-02-18 22:07:23 +0000
+++ methods/makefile	2010-06-10 14:02:22 +0000
@@ -48,7 +48,7 @@
 PROGRAM=http
 SLIBS = -lapt-pkg $(SOCKETLIBS) $(INTLLIBS)
 LIB_MAKES = apt-pkg/makefile
-SOURCE = http.cc rfc2553emu.cc connect.cc
+SOURCE = http.cc http_main.cc rfc2553emu.cc connect.cc
 include $(PROGRAM_H)
 
 # The https method
@@ -79,9 +79,17 @@
 SOURCE = rsh.cc
 include $(PROGRAM_H)
 
+# The mirror method
+PROGRAM=mirror
+SLIBS = -lapt-pkg $(SOCKETLIBS)
+LIB_MAKES = apt-pkg/makefile
+SOURCE = mirror.cc http.cc rfc2553emu.cc connect.cc
+include $(PROGRAM_H)
+
 # SSH and bzip2 method symlink
 binary: $(BIN)/ssh $(BIN)/bzip2 $(BIN)/lzma
 veryclean: clean-$(BIN)/ssh clean-$(BIN)/bzip2 clean-$(BIN)/lzma
+
 $(BIN)/ssh:
 	echo "Installing ssh method link"
 	ln -fs rsh $(BIN)/ssh

=== added file 'methods/mirror.cc'
--- methods/mirror.cc	1970-01-01 00:00:00 +0000
+++ methods/mirror.cc	2010-06-10 14:02:22 +0000
@@ -0,0 +1,372 @@
+// -*- mode: cpp; mode: fold -*-
+// Description								/*{{{*/
+// $Id: mirror.cc,v 1.59 2004/05/08 19:42:35 mdz Exp $
+/* ######################################################################
+
+   Mirror Aquire Method - This is the Mirror aquire method for APT.
+   
+   ##################################################################### */
+									/*}}}*/
+// Include Files							/*{{{*/
+#include <apt-pkg/fileutl.h>
+#include <apt-pkg/acquire-method.h>
+#include <apt-pkg/acquire-item.h>
+#include <apt-pkg/acquire.h>
+#include <apt-pkg/error.h>
+#include <apt-pkg/hashes.h>
+#include <apt-pkg/sourcelist.h>
+
+#include <fstream>
+#include <iostream>
+#include <stdarg.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <dirent.h>
+
+using namespace std;
+
+#include<sstream>
+
+#include "mirror.h"
+#include "http.h"
+#include "apti18n.h"
+									/*}}}*/
+
+/* Done:
+ * - works with http (only!)
+ * - always picks the first mirror from the list
+ * - call out to problem reporting script
+ * - supports "deb mirror://host/path/to/mirror-list/// dist component"
+ * - uses pkgAcqMethod::FailReason() to have a string representation
+ *   of the failure that is also send to LP
+ * 
+ * TODO: 
+ * - deal with runing as non-root because we can't write to the lists 
+     dir then -> use the cached mirror file
+ * - better method to download than having a pkgAcquire interface here
+ *   and better error handling there!
+ * - support more than http
+ * - testing :)
+ */
+
+MirrorMethod::MirrorMethod()
+   : HttpMethod(), DownloadedMirrorFile(false)
+{
+};
+
+// HttpMethod::Configuration - Handle a configuration message		/*{{{*/
+// ---------------------------------------------------------------------
+/* We stash the desired pipeline depth */
+bool MirrorMethod::Configuration(string Message)
+{
+   if (pkgAcqMethod::Configuration(Message) == false)
+      return false;
+   Debug = _config->FindB("Debug::Acquire::mirror",false);
+   
+   return true;
+}
+									/*}}}*/
+
+// clean the mirrors dir based on ttl information
+bool MirrorMethod::Clean(string Dir)
+{
+   vector<metaIndex *>::const_iterator I;
+
+   if(Debug)
+      clog << "MirrorMethod::Clean(): " << Dir << endl;
+
+   if(Dir == "/")
+      return _error->Error("will not clean: '/'");
+
+   // read sources.list
+   pkgSourceList list;
+   list.ReadMainList();
+
+   DIR *D = opendir(Dir.c_str());   
+   if (D == 0)
+      return _error->Errno("opendir",_("Unable to read %s"),Dir.c_str());
+   
+   string StartDir = SafeGetCWD();
+   if (chdir(Dir.c_str()) != 0)
+   {
+      closedir(D);
+      return _error->Errno("chdir",_("Unable to change to %s"),Dir.c_str());
+   }
+   
+   for (struct dirent *Dir = readdir(D); Dir != 0; Dir = readdir(D))
+   {
+      // Skip some files..
+      if (strcmp(Dir->d_name,"lock") == 0 ||
+	  strcmp(Dir->d_name,"partial") == 0 ||
+	  strcmp(Dir->d_name,".") == 0 ||
+	  strcmp(Dir->d_name,"..") == 0)
+	 continue;
+
+      // see if we have that uri
+      for(I=list.begin(); I != list.end(); I++)
+      {
+	 string uri = (*I)->GetURI();
+	 if(uri.find("mirror://") != 0)
+	    continue;
+	 string BaseUri = uri.substr(0,uri.size()-1);
+	 if (URItoFileName(BaseUri) == Dir->d_name)
+	    break;
+      }
+      // nothing found, nuke it
+      if (I == list.end())
+	 unlink(Dir->d_name);
+   };
+   
+   chdir(StartDir.c_str());
+   closedir(D);
+   return true;   
+}
+
+
+bool MirrorMethod::DownloadMirrorFile(string mirror_uri_str)
+{
+   if(Debug)
+      clog << "MirrorMethod::DownloadMirrorFile(): " << endl;
+
+   // not that great to use pkgAcquire here, but we do not have 
+   // any other way right now
+   string fetch = BaseUri;
+   fetch.replace(0,strlen("mirror://"),"http://");
+
+   pkgAcquire Fetcher;
+   new pkgAcqFile(&Fetcher, fetch, "", 0, "", "", "", MirrorFile);
+   bool res = (Fetcher.Run() == pkgAcquire::Continue);
+   if(res)
+      DownloadedMirrorFile = true;
+   Fetcher.Shutdown();
+   return res;
+}
+
+/* convert a the Queue->Uri back to the mirror base uri and look
+ * at all mirrors we have for this, this is needed as queue->uri
+ * may point to different mirrors (if TryNextMirror() was run)
+ */
+void MirrorMethod::CurrentQueueUriToMirror()
+{
+   // already in mirror:// style so nothing to do
+   if(Queue->Uri.find("mirror://") == 0)
+      return;
+
+   // find current mirror and select next one
+   for (vector<string>::const_iterator mirror = AllMirrors.begin();
+	mirror != AllMirrors.end(); ++mirror)
+   {
+      if (Queue->Uri.find(*mirror) == 0)
+      {
+	 Queue->Uri.replace(0, mirror->length(), BaseUri);
+	 return;
+      }
+   }
+   _error->Error("Internal error: Failed to convert %s back to %s",
+		 Queue->Uri.c_str(), BaseUri.c_str());
+}
+
+bool MirrorMethod::TryNextMirror()
+{
+   // find current mirror and select next one
+   for (vector<string>::const_iterator mirror = AllMirrors.begin();
+	mirror != AllMirrors.end(); ++mirror)
+   {
+      if (Queue->Uri.find(*mirror) != 0)
+	 continue;
+
+      vector<string>::const_iterator nextmirror = mirror + 1;
+      if (nextmirror != AllMirrors.end())
+	 break;
+      Queue->Uri.replace(0, mirror->length(), *nextmirror);
+      if (Debug)
+	 clog << "TryNextMirror: " << Queue->Uri << endl;
+      return true;
+   }
+
+   if (Debug)
+      clog << "TryNextMirror could not find another mirror to try" << endl;
+
+   return false;
+}
+
+bool MirrorMethod::InitMirrors()
+{
+   // if we do not have a MirrorFile, fallback
+   if(!FileExists(MirrorFile))
+   {
+      // FIXME: fallback to a default mirror here instead 
+      //        and provide a config option to define that default
+      return _error->Error(_("No mirror file '%s' found "), MirrorFile.c_str());
+   }
+
+   // FIXME: make the mirror selection more clever, do not 
+   //        just use the first one!
+   // BUT: we can not make this random, the mirror has to be
+   //      stable accross session, because otherwise we can
+   //      get into sync issues (got indexfiles from mirror A,
+   //      but packages from mirror B - one might be out of date etc)
+   ifstream in(MirrorFile.c_str());
+   string s;
+   while (!in.eof()) 
+   {
+      getline(in, s);
+      if (s.size() > 0)
+	 AllMirrors.push_back(s);
+   }
+   Mirror = AllMirrors[0];
+   UsedMirror = Mirror;
+   return true;
+}
+
+string MirrorMethod::GetMirrorFileName(string mirror_uri_str)
+{
+   /* 
+    - a mirror_uri_str looks like this:
+    mirror://people.ubuntu.com/~mvo/apt/mirror/mirrors/dists/feisty/Release.gpg
+   
+    - the matching source.list entry
+    deb mirror://people.ubuntu.com/~mvo/apt/mirror/mirrors feisty main
+   
+    - we actually want to go after:
+    http://people.ubuntu.com/~mvo/apt/mirror/mirrors
+
+    And we need to save the BaseUri for later:
+    - mirror://people.ubuntu.com/~mvo/apt/mirror/mirrors
+
+   FIXME: what if we have two similar prefixes?
+     mirror://people.ubuntu.com/~mvo/mirror
+     mirror://people.ubuntu.com/~mvo/mirror2
+   then mirror_uri_str looks like:
+     mirror://people.ubuntu.com/~mvo/apt/mirror/dists/feisty/Release.gpg
+     mirror://people.ubuntu.com/~mvo/apt/mirror2/dists/feisty/Release.gpg
+   we search sources.list and find:
+     mirror://people.ubuntu.com/~mvo/apt/mirror
+   in both cases! So we need to apply some domain knowledge here :( and
+   check for /dists/ or /Release.gpg as suffixes
+   */
+   string name;
+   if(Debug)
+      std::cerr << "GetMirrorFileName: " << mirror_uri_str << std::endl;
+
+   // read sources.list and find match
+   vector<metaIndex *>::const_iterator I;
+   pkgSourceList list;
+   list.ReadMainList();
+   for(I=list.begin(); I != list.end(); I++)
+   {
+      string uristr = (*I)->GetURI();
+      if(Debug)
+	 std::cerr << "Checking: " << uristr << std::endl;
+      if(uristr.substr(0,strlen("mirror://")) != string("mirror://"))
+	 continue;
+      // find matching uri in sources.list
+      if(mirror_uri_str.substr(0,uristr.size()) == uristr)
+      {
+	 if(Debug)
+	    std::cerr << "found BaseURI: " << uristr << std::endl;
+	 BaseUri = uristr.substr(0,uristr.size()-1);
+      }
+   }
+   // get new file
+   name = _config->FindDir("Dir::State::mirrors") + URItoFileName(BaseUri);
+
+   if(Debug) 
+   {
+      cerr << "base-uri: " << BaseUri << endl;
+      cerr << "mirror-file: " << name << endl;
+   }
+   return name;
+}
+
+// MirrorMethod::Fetch - Fetch an item					/*{{{*/
+// ---------------------------------------------------------------------
+/* This adds an item to the pipeline. We keep the pipeline at a fixed
+   depth. */
+bool MirrorMethod::Fetch(FetchItem *Itm)
+{
+   if(Debug)
+      clog << "MirrorMethod::Fetch()" << endl;
+
+   // the http method uses Fetch(0) as a way to update the pipeline,
+   // just let it do its work in this case - Fetch() with a valid
+   // Itm will always run before the first Fetch(0)
+   if(Itm == NULL) 
+      return HttpMethod::Fetch(Itm);
+
+   // if we don't have the name of the mirror file on disk yet,
+   // calculate it now (can be derived from the uri)
+   if(MirrorFile.empty())
+      MirrorFile = GetMirrorFileName(Itm->Uri);
+
+  // download mirror file once (if we are after index files)
+   if(Itm->IndexFile && !DownloadedMirrorFile)
+   {
+      Clean(_config->FindDir("Dir::State::mirrors"));
+      DownloadMirrorFile(Itm->Uri);
+   }
+
+   if(AllMirrors.empty()) {
+      if(!InitMirrors()) {
+	 // no valid mirror selected, something went wrong downloading
+	 // from the master mirror site most likely and there is
+	 // no old mirror file availalbe
+	 return false;
+      }
+   }
+
+   if(Itm->Uri.find("mirror://") != string::npos)
+      Itm->Uri.replace(0,BaseUri.size(), Mirror);
+
+   if(Debug)
+      clog << "Fetch: " << Itm->Uri << endl << endl;
+   
+   // now run the real fetcher
+   return HttpMethod::Fetch(Itm);
+};
+
+void MirrorMethod::Fail(string Err,bool Transient)
+{
+   // FIXME: TryNextMirror is not ideal for indexfile as we may
+   //        run into auth issues
+
+   if (Debug)
+      clog << "Failure to get " << Queue->Uri << endl;
+
+   // try the next mirror on fail (if its not a expected failure,
+   // e.g. translations are ok to ignore)
+   if (!Queue->FailIgnore && TryNextMirror()) 
+      return;
+
+   // all mirrors failed, so bail out
+   string s;
+   strprintf(s, _("[Mirror: %s]"), Mirror.c_str());
+   SetIP(s);
+
+   CurrentQueueUriToMirror();
+   pkgAcqMethod::Fail(Err, Transient);
+}
+
+void MirrorMethod::URIStart(FetchResult &Res)
+{
+   CurrentQueueUriToMirror();
+   pkgAcqMethod::URIStart(Res);
+}
+
+void MirrorMethod::URIDone(FetchResult &Res,FetchResult *Alt)
+{
+   CurrentQueueUriToMirror();
+   pkgAcqMethod::URIDone(Res, Alt);
+}
+
+
+int main()
+{
+   setlocale(LC_ALL, "");
+
+   MirrorMethod Mth;
+
+   return Mth.Loop();
+}
+
+

=== added file 'methods/mirror.h'
--- methods/mirror.h	1970-01-01 00:00:00 +0000
+++ methods/mirror.h	2010-06-10 14:02:22 +0000
@@ -0,0 +1,55 @@
+// -*- mode: cpp; mode: fold -*-
+// Description								/*{{{*/// $Id: http.h,v 1.12 2002/04/18 05:09:38 jgg Exp $
+// $Id: http.h,v 1.12 2002/04/18 05:09:38 jgg Exp $
+/* ######################################################################
+
+   MIRROR Aquire Method - This is the MIRROR aquire method for APT.
+
+   ##################################################################### */
+									/*}}}*/
+
+#ifndef APT_MIRROR_H
+#define APT_MIRROR_H
+
+
+#include <iostream>
+
+using std::cout;
+using std::cerr;
+using std::endl;
+
+#include "http.h"
+
+class MirrorMethod : public HttpMethod
+{
+   FetchResult Res;
+   // we simply transform between BaseUri and Mirror
+   string BaseUri;    // the original mirror://... url
+   string Mirror;     // the selected mirror uri (http://...)
+   vector<string> AllMirrors; // all available mirrors
+   string MirrorFile; // the file that contains the list of mirrors
+   bool DownloadedMirrorFile; // already downloaded this session
+
+   bool Debug;
+
+ protected:
+   bool DownloadMirrorFile(string uri);
+   string GetMirrorFileName(string uri);
+   bool InitMirrors();
+   bool TryNextMirror();
+   void CurrentQueueUriToMirror();
+   bool Clean(string dir);
+   
+   // we need to overwrite those to transform the url back
+   virtual void Fail(string Why, bool Transient = false);
+   virtual void URIStart(FetchResult &Res);
+   virtual void URIDone(FetchResult &Res,FetchResult *Alt = 0);
+   virtual bool Configuration(string Message);
+
+ public:
+   MirrorMethod();
+   virtual bool Fetch(FetchItem *Itm);
+};
+
+
+#endif

=== modified file 'methods/rsh.cc'
--- methods/rsh.cc	2010-02-18 22:07:23 +0000
+++ methods/rsh.cc	2010-06-10 14:02:22 +0000
@@ -278,8 +278,7 @@
       return false;
 
    // Parse it
-   StrToTime(Msg,Time);
-   return true;
+   return FTPMDTMStrToTime(Msg.c_str(), Time);
 }
 									/*}}}*/
 // RSHConn::Get - Get a file						/*{{{*/

=== added file 'mirror-failure.py'
--- mirror-failure.py	1970-01-01 00:00:00 +0000
+++ mirror-failure.py	2010-06-10 14:02:22 +0000
@@ -0,0 +1,23 @@
+# File: cgihttpserver-example-1.py
+
+import CGIHTTPServer
+import BaseHTTPServer
+
+class Handler(CGIHTTPServer.CGIHTTPRequestHandler):
+    #cgi_directories = ["/cgi"]
+    def do_POST(self):
+	print "do_POST"
+        #print self.command
+        #print self.path
+        #print self.headers
+        print self.client_address
+        data = self.rfile.read(int(self.headers["content-length"]))
+        print data
+        self.wfile.write("200 Ok\n");
+
+PORT = 8000
+
+httpd = BaseHTTPServer.HTTPServer(("", PORT), Handler)
+print "serving at port", PORT
+httpd.serve_forever()
+

=== modified file 'po/apt-all.pot'
--- po/apt-all.pot	2010-05-25 16:01:42 +0000
+++ po/apt-all.pot	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -16,146 +16,143 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=INTEGER; plural=EXPRESSION;\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr ""
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr ""
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 msgid "Total package structures: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr ""
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+msgid "You must give at least one search pattern"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr ""
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr ""
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 msgid ""
 "Usage: apt-cache [options] command\n"
 "       apt-cache [options] add file1 [file2 ...]\n"
@@ -251,12 +248,12 @@
 "  -o=? Set an arbitrary configuration option, eg -o dir::cache=/tmp\n"
 msgstr ""
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr ""
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr ""
 
@@ -550,218 +547,218 @@
 msgid "Failed to rename %s to %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr ""
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr ""
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr ""
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr ""
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr ""
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr ""
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr ""
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr ""
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr ""
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr ""
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr ""
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr ""
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr ""
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr ""
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr ""
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr ""
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
 msgstr ""
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr ""
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr ""
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr ""
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr ""
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr ""
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr ""
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr ""
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr ""
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr ""
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr ""
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr ""
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr ""
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr ""
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr ""
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr ""
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr ""
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr ""
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr ""
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -769,46 +766,46 @@
 " ?] "
 msgstr ""
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr ""
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr ""
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr ""
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr ""
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
 msgstr ""
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr ""
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr ""
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr ""
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -818,48 +815,48 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr ""
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 msgid " [Not candidate version]"
 msgstr ""
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr ""
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -867,65 +864,65 @@
 "is only available from another source\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr ""
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr ""
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr ""
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr ""
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr ""
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr ""
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 msgid ""
 "The following package is automatically installed and is no longer required:"
 msgid_plural ""
@@ -934,7 +931,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -942,11 +939,11 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -962,49 +959,44 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr ""
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr ""
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
 msgstr ""
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1012,161 +1004,176 @@
 "or been moved out of Incoming."
 msgstr ""
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr ""
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr ""
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr ""
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr ""
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, c-format
 msgid "%s set to automatically installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr ""
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr ""
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr ""
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr ""
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr ""
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr ""
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr ""
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
 "package %s can satisfy version requirements"
 msgstr ""
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr ""
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr ""
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr ""
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 msgid ""
 "Usage: apt-get [options] command\n"
 "       apt-get [options] install|remove pkg1 [pkg2 ...]\n"
@@ -1444,8 +1451,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr ""
@@ -1474,10 +1482,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr ""
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr ""
 
@@ -1686,169 +1693,168 @@
 msgid "Write error"
 msgstr ""
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr ""
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr ""
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr ""
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr ""
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr ""
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr ""
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr ""
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr ""
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr ""
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr ""
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr ""
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr ""
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr ""
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr ""
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr ""
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr ""
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr ""
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr ""
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr ""
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr ""
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr ""
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr ""
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr ""
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr ""
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr ""
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr ""
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr ""
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr ""
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, c-format
 msgid "No keyring installed in %s."
 msgstr ""
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr ""
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr ""
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr ""
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -1925,19 +1931,19 @@
 msgid "Error reading from server"
 msgstr ""
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr ""
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr ""
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr ""
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr ""
 
@@ -2001,7 +2007,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr ""
@@ -2124,6 +2130,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr ""
@@ -2307,7 +2314,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr ""
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2435,7 +2442,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr ""
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2483,12 +2490,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr ""
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr ""
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr ""
 
@@ -2501,25 +2508,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr ""
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr ""
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr ""
 
@@ -2608,70 +2615,105 @@
 msgid "Couldn't stat source package list %s"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
 "to manually fix this package. (due to missing arch)"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
 "manually fix this package."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr ""
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr ""
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr ""
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr ""
+
+#: apt-pkg/indexrecords.cc:122
+#, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr ""
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2760,151 +2802,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, c-format
 msgid "Hash mismatch for: %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:194
+#, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, c-format
 msgid "Completely removing %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, c-format
 msgid "Could not open file '%s'"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -2919,6 +3044,6 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr ""

=== modified file 'po/ar.po'
--- po/ar.po	2010-05-25 16:01:42 +0000
+++ po/ar.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: apt_po\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2006-10-20 21:28+0300\n"
 "Last-Translator: Ossama M. Khayat <okhayat@yahoo.com>\n"
 "Language-Team: Arabic <support@arabeyes.org>\n"
@@ -18,149 +18,147 @@
 "X-Poedit-SourceCharset: utf-8\n"
 "X-Generator: KBabel 1.11.4\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "الحزمة %s النسخة %s لها معتمد غير مستوفى:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "تعذر العثور على الحزمة %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "أسماء الحزم الكلية :"
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "أسماء الحزم الكلية :"
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr " الحزم العادية:"
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "الحزمة الوهمية تماماً:"
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr " الحزمة الوهمية المفردة:"
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr " الحزم الوهمية المختلطة:"
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr " مفقودة:"
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "مجموع النسخ الفريدة:"
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "مجموع النسخ الفريدة:"
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "مجموع المعتمدات:"
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "مجموع علاقات النسخ/الملفات:"
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "مجموع علاقات النسخ/الملفات:"
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "مجموع علاقات النسخ/الملفات:"
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "مجموع المساحة المحسوب حسابها:"
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr ""
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "يجب أن تعطي صيغة واحدة بالضبط"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "لم يُعثر على أية حزم"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "تعذر العثور على الحزمة %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "ملفات الحزم:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "الحزم المُدبّسة:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(غير موجود)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr " مُثبّت:"
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  مرشّح: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(لاشيء)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr ""
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr " جدول النسخ:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s لـ%s %s مُجمّع على %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 msgid ""
 "Usage: apt-cache [options] command\n"
 "       apt-cache [options] add file1 [file2 ...]\n"
@@ -257,12 +255,12 @@
 "  -o=? Set an arbitrary configuration option, eg -o dir::cache=/tmp\n"
 msgstr ""
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "تعذرت الكتابة إلى %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "تعذر الحصول على نسخة debconf. هل هي مثبتة؟"
 
@@ -556,79 +554,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "فشل تغيير اسم %s إلى %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr ""
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "إلا أن %s مثبت"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "إلا أنه سيتم تثبيت %s"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "إلا أنه غير قابل للتثبيت"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "إلا أنها حزمة وهمية"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "إلا أنها غير مثبتة"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "إلا أنه لن يتم تثبيتها"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " أو"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "سيتم تثبيت الحزم الجديدة التالية:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "سيتم إزالة الحزم التالية:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "سيتم الإبقاء على الحزم التالية:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "ستتم ترقية الحزم التالية:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "سيتم تثبيط الحزم التالية:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "سيتم تغيير الحزم المبقاة التالية:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (بسبب %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -636,140 +634,140 @@
 "تحذير: ستتم إزالة الحزم الأساسية التالية.\n"
 "لا يجب أن تقوم بهذا إلى إن كنت تعرف تماماً ما تقوم به!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu سيتم ترقيتها، %lu مثبتة حديثاً،  "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu أعيد تثبيتها، "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu مثبطة، "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu لإزالتها و %lu لم يتم ترقيتها.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu غير مثبتة بالكامل أو مزالة.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "تصحيح المعتمدات..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " فشل."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "لم يمكن تصحيح المعتمدات"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "لم يمكن تقليص مجموعة الترقية"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " تم"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "قد ترغب بتنفيذ الأمر 'apt-get -f install' لتصحيح هذه."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "مُعتمدات غير مستوفاة. حاول استخدام -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "تحذير: تعذرت المصادقة على الحزم التالية!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "تم غض النظر عن تحذير المصادقة.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "تثبيت هذه الحزم دون التحقق منها [y/N]؟ "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "تعذرت المصادقة على بعض الحزم"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "هناك مشاكل وتم استخدام -y دون --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "خطأ داخلي، تم طلب InstallPackages مع وجود حزم معطوبة!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "حزم بحاجة للإزالة لكن الإزالة مُعطّلة."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "خطأ داخلي، لم تنته عملية الترتيب"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "تعذرت قراءة قائمة المصادر."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "يا للغرابة.. لم تتطابق الأحجام، الرجاء مراسلة apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "بحاجة إلى جلب %sب/%sب من الأرشيف.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "بحاجة إلى جلب %sب من الأرشيف.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "بعد الاستخراج %sب من المساحة الإضافيّة سيتمّ استخدامها.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "بعد الاستخراج %sب من المساحة ستفرّغ.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "تعذر حساب المساحة الحرة في %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "ليس هناك مساحة كافية في %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "نعم، افعل ما أقوله!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -780,28 +778,28 @@
 "كي تستمر اكتب العبارة '%s'\n"
 " ؟] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "إجهاض."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "هل تريد الاستمرار [Y/n]؟"
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "فشل إحضار %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "فشل تنزيل بعض الملفات"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "اكتمل التنزيل وفي وضع التنزيل فقط"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -809,19 +807,19 @@
 "تعذر إحضار بعض الأرشيف، ربما يمكنك محاولة تنفيذ apt-get update أو إضافة --"
 "fix-missing؟"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing وتبديل الأوساط غير مدعومة حالياً"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "تعذر تصحيح الحزم المفقودة."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "إجهاض التثبيت."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -831,48 +829,48 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "لاحظ، تحديد %s بدلاً من %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "تخطّي %s، حيث أنها مثبتة ولم يتمّ تعيين الترقية.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "تخطّي %s، حيث أنها مثبتة ولم يتمّ تعيين الترقية.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "الحزمة %s غير مُثبّتة، لذلك لن تُزال\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "الحزمة %s وهميّة وتوفّرها:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [مُثبّتة]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 msgid " [Not candidate version]"
 msgstr ""
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "يجب اختيار واحدة بالتحديد لتثبيتها."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -880,65 +878,65 @@
 "is only available from another source\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "على أيّ فإن الحزم التالية تحلّ مكانها:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "الحزمة %s ليس لها مرشح تثبيت"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "إعادة تثبيت  %s غير ممكنة، حيث أنّه لا يمكن تنزيلها.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s هي النسخة الأحدث.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "تعذر العثور على الإصدارة '%s' للحزمة '%s'"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "تعذر العثور على النسخة '%s' للحزمة '%s'"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "النسخة المحددة %s (%s) للإصدارة %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr ""
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "لا يقبل الأمر update أية مُعطيات"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -948,7 +946,7 @@
 msgstr[0] "سيتم تثبيت الحزم الجديدة التالية:"
 msgstr[1] "سيتم تثبيت الحزم الجديدة التالية:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -956,11 +954,11 @@
 msgstr[0] "سيتم تثبيت الحزم الجديدة التالية:"
 msgstr[1] "سيتم تثبيت الحزم الجديدة التالية:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -976,51 +974,46 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "قد تساعد المعلومات التالية في حل المشكلة:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "خطأ داخلي، عطب AllUpgrade بعض الأشياء"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "خطأ داخلي، عطب AllUpgrade بعض الأشياء"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "تعذر العثور على الحزمة %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "تعذر العثور على الحزمة %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "لاحظ، تحديد %s بسبب صيغة regex '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "إلا أنه سيتم تثبيت %s"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "قد ترغب بتشغيل 'apt-get -f install' لتصحيح هذه:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
 msgstr ""
 "مُعتمدات غير مستوفاة. جرب 'apt-get -f install' بدون أسماء حزم (أو حدّد حلاً)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1028,161 +1021,176 @@
 "or been moved out of Incoming."
 msgstr ""
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "حزم معطوبة"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "سيتم تثبيت الحزم الإضافيّة التالية:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "الحزم المقترحة:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "الحزم المستحسنة:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "إلا أنه سيتم تثبيت %s"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "حساب الترقية..."
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "فشل"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "تمّ"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "تعذر قَفْل دليل التنزيل"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "يجب تحديد حزمة واحدة على الأقل لجلب مصدرها"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "تعذر العثور على مصدر الحزمة %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "تخطي الملف '%s' المنزل مسبقاً\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "ليس هناك مساحة كافية في %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "يجب جلب %sب/%sب من الأرشيفات المصدرية.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "يجب جلب %sب من الأرشيفات المصدريّة.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "إحضار المصدر %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "فشل إحضار بعض الأرشيفات."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "أمر فك الحزمة '%s' فشل.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "أمر البناء '%s' فشل.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr ""
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr ""
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
 "package %s can satisfy version requirements"
 msgstr ""
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr ""
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr ""
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "الوحدات المدعومة:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 msgid ""
 "Usage: apt-get [options] command\n"
 "       apt-get [options] install|remove pkg1 [pkg2 ...]\n"
@@ -1465,8 +1473,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "تعذرت قراءة %s"
@@ -1495,10 +1504,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr ""
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "قراءة قوائم الحزم"
 
@@ -1711,169 +1719,168 @@
 msgid "Write error"
 msgstr "خطأ في الكتابة"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr ""
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr ""
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr ""
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr ""
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr ""
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr ""
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "تعذر إرسال الأمر PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr ""
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "فشل EPRT، ردّ الخادم: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr ""
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "تعذر قبول الاتصال"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr ""
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "تعذر إحضار الملف، ردّ الخادم '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr ""
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "فشل نقل البيانات، ردّ الخادم '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "استعلام"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr ""
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "الاتصال بـ%s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr ""
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "تعذر تمهيد الاتصال بـ%s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "تعذر الاتصال بـ%s:%s (%s)، انتهى وقت الاتصال"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "تعذر الاتصال بـ%s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "الاتصال بـ%s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr ""
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr ""
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr ""
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "تعذر الاتصال بـ%s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "إجهاض التثبيت."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr ""
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr ""
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr ""
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -1950,20 +1957,20 @@
 msgid "Error reading from server"
 msgstr "خطأ في القراءة من الخادم"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "فشلت كتابة الملف %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "بيانات ترويسة سيئة"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "فشل الاتصال"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "خطأ داخلي"
 
@@ -2029,7 +2036,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "تعذر العثور على التحديد %s"
@@ -2152,6 +2159,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr ""
@@ -2336,7 +2344,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "فشلت كتابة الملف %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2464,7 +2472,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr ""
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2512,12 +2520,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "الرجاء إدخال القرص المُسمّى  '%s' في السوّاقة '%s' وضغط مفتاح الإدخال."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "نظام الحزم '%s' غير مدعوم"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr ""
 
@@ -2530,25 +2538,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr ""
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "قد يساعدك تنفيذ الأمر apt-get update في تصحيح هذه المشاكل"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr ""
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr ""
 
@@ -2637,71 +2645,106 @@
 msgid "Couldn't stat source package list %s"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "فشل إعادة التسمية ، %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum غير متطابقة"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "MD5Sum غير متطابقة"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
 "to manually fix this package. (due to missing arch)"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
 "manually fix this package."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "الحجم غير متطابق"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "تعذر فتح ملف قاعدة البيانات %s: %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "لاحظ، تحديد %s بدلاً من %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "لاحظ، تحديد %s بدلاً من %s\n"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "تعذر فتح ملف قاعدة البيانات %s: %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2793,151 +2836,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "فتح ملف التهيئة %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "MD5Sum غير متطابقة"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "لاحظ، تحديد %s بسبب صيغة regex '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "النسخة المحددة %s (%s) للإصدارة %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "تم تثبيت %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "تهيئة %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "إزالة %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "تمت إزالة %s بالكامل"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "فشل إغلاق الملف %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "تحضير %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "فتح %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "التحضير لتهيئة %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "تم تثبيت %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "التحضير لإزالة %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "تم إزالة %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "التحضير لإزالة %s بالكامل"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "تمت إزالة %s بالكامل"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "تعذر قفل دليل القائمة"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -2952,7 +3078,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr ""
 

=== modified file 'po/ast.po'
--- po/ast.po	2010-05-25 16:01:42 +0000
+++ po/ast.po	2010-06-10 14:02:22 +0000
@@ -2,7 +2,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.18\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-07-01 18:09+0100\n"
 "Last-Translator: Marcos Alvarez Costales <marcos.alvarez.costales@gmail."
 "com>\n"
@@ -11,148 +11,146 @@
 "Content-Type: text/plain; charset=iso-8859-1\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "El paquete %s versin %s nun cumple una dependencia:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Nun pue alcontrase'l paquete %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Total de nomes de paquetes: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Total de nomes de paquetes: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Paquetes normales: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Paquetes virtuales puros: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Paquetes virtuales cenciellos: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Paquetes virtuales amestaos: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Falten: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Versiones distintes en total: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Descriciones distintes en total: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Dependencies totales: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Relaciones versin/ficheru en total: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Relaciones descricin/ficheru en total: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Mapes de provisiones en total: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Cadenes globalizaes en total: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Espaciu de dependencies de versin en total: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Espaciu ociosu en total: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Informe del total d'espaciu: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "El ficheru de paquetes %s nun ta sincronizu."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Has de dar exautamente un patrn"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Nun s'alcontraron paquetes"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Nun pue alcontrase'l paquete %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Ficheros de paquete:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "La cach nun ta sincronizada, nun puede facese x-ref a un ficheru de paquete"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Paquetes na chincheta:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(nun s'alcontr)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalu: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidatu: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(dengn)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Chincheta de paquetes: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabla de versiones:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s pa %s compilu en %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -310,12 +308,12 @@
 "-o=? Afita una opcin de configuracin arbitraria, p. ej. -o dir::cache=/"
 "tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Nun se pue escribir en %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Nun se pue alcontrar la versin de debconf. Ta instalu debconf?"
 
@@ -651,79 +649,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Nun pudo renomase %s como %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "S"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Error de compilacin d'espresin regular - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Los siguientes paquetes nun cumplen dependencies:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "pero %s ta instalu"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "pero %s ta pa instalar"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "pero nun ye instalable"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "pero ye un paquete virtual"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "pero nun ta instalu"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "pero nun va instalase"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " o"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Van instalase los siguientes paquetes NUEVOS:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Los siguientes paquetes van DESANICIASE:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Los siguientes paquetes tan retenos:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Los siguientes paquetes van actualizase:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Los siguientes paquetes van DESACTUALIZASE:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Van camudase los siguientes paquetes retenos:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (por %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -731,140 +729,140 @@
 "AVISU: Los siguientes paquetes esenciales van desaniciase.\n"
 "Esto NUN hai que facelo si nun sabes esautamente lo que faes!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu actualizaos, %lu nuevos instalaos, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstalaos, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu desactualizaos, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu para desaniciar y %lu nun actualizaos.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu nun instalaos dafechu o desaniciaos.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Iguando dependencies..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " fall."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Nun pudieron iguase les dependencies"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Nun pue amenorgase'l conxuntu d'actualizacin"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Fecho"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Habres d'executar 'apt-get -f install' para igualo."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dependencies incumples. Tntalo usando -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "AVISU: Nun pudieron autenticase los siguientes paquetes!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Avisu d'autenticacin saltu.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Instalar esos paquetes ensin verificacin [s/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Dellos paquetes nun pudieron autenticase"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Hai problemes y utilizose -y ensin --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Error internu, InstallPackages llamose con paquetes fraaos!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Fai falta desaniciar los paquetes pero desaniciar ta torgu."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Error internu, ordenar nun fin"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Nun pudo lleese la llista de fontes."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "Que raro.. Los tamaos nun concasen, escribe a apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Hai que descargar %sB/%sB d'archivos.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Hai que descargar %sB d'archivos.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Tres d'esta operacin, van usase %sB d'espaciu de discu adicional.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Tres d'esta operacin, van lliberase %sB d'espaciu de discu.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Nun pue determinase l'espaciu llibre de %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Nun tienes espaciu libre bastante en %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Conseose Trivial Only pero sta nun ye una operacin trivial."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "S, facer lo que digo!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -875,28 +873,28 @@
 "Pa continuar escribe la frase '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Encaboxar."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Quies continuar [S/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Fall algamar %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Dellos ficheros nun pudieron descargase"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Descarga completa y en mou de slo descarga"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -904,19 +902,19 @@
 "Nun pudieron algamase dellos archivos, seique executando apt-get update o "
 "tentando --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing y cambu de mediu nun ta sofitao actualmente"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Nun pudieron iguase los paquetes que falten."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Encaboxando la instalacin."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -926,49 +924,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Nota, escoyendo %s nel llugar de %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Saltando %s, ya ta instalau y la actualizacin nun ta activada.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Saltando %s, ya ta instalau y la actualizacin nun ta activada.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "El paquete %s nun ta instalau, nun va desaniciase\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "El paquete %s ye un paquete virtual ufru por:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Instalu]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versiones candidates"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Has d'escoyer esplcitamente unu pa instalar."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -979,65 +977,65 @@
 "Esto puede significar que falta el paquete, ta arrumbu, o slo\n"
 "ta disponible dende otra fonte\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Sicas, los siguientes paquetes reemplacenlu:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "El paquete %s nun tien candidatu pa instalacin"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "La reinstalacin de %s nun ye dable, nun pue descargase.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s y ta na versin ms nueva.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Nun s'alcontr la distribucin '%s' pa '%s'"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Nun s'alcontr la versin '%s' pa '%s'"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Escoyida la versin %s (%s) pa %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Nun se puede lleer la llista de paquetes d'orxenes %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "La orde update nun lleva argumentos"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Suponse que nun vamos esborrar coses; nun pue entamase AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1051,7 +1049,7 @@
 "Los siguientes paquetes instalaronse de manera automtica y ya nun se "
 "necesiten:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1063,11 +1061,11 @@
 "Los siguientes paquetes instalaronse de manera automtica y ya nun se "
 "necesiten:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Usa 'apt-get autoremove' pa desinstalalos."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1085,43 +1083,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "La siguiente informacin pue aidar a resolver la situacin:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Error internu, AutoRemover rompi coses"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Error internu, AllUpgrade rompi coses"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Nun pudo alcontrase la tarea %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Nun pudo alcontrase'l paquete %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Nota, escoyendo %s pa la espresin regular '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s axustu como instalu manualmente.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Habres d'executar 'apt-get -f install' para iguar estos:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1129,7 +1122,7 @@
 "Dependencies ensin cubrir. Tenta 'apt-get -f install' ensin paquetes (o "
 "consea una solucin)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1141,126 +1134,141 @@
 "inestable, que dellos paquetes necesarios nun se crearon o que\n"
 "s'allugaron fuera d'Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Paquetes fraaos"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Instalarnse los siguientes paquetes extra:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Paquetes afalaos:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Paquetes encamentaos"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s axustu como instalu manualmente.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Calculando l'autualizacin... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Fall"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Fecho"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Error internu, l'iguador de problemes fra coses"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Nun pue bloquiase'l direutoriu de descarga"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Has de consear polo menos un paquete p'algamar so fonte"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Nun pudo alcontrase un paquete fonte pa %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Saltando'l ficheru y descargu '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Nun hai espaciu llibre bastante en %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Hai falta descargar %sB/%sB d'archivos fonte.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Hai falta descargar %sB d'archivos fonte.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Fonte descargada %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Fall la descarga de dellos archivos."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Saltando'l desempaquetu de la fonte y desempaquetada en %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Fall la orde de desempaquetu '%s'.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Comprueba qu'el paquete 'dpkg-dev' ta instalu.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Fall la orde build '%s'.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Fall el procesu fu"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Hai que consear polo menos un paquete pa verificar les dependencies de "
 "construccin"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Nun pudo algamase informacin de dependencies de construccin pa %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s nun tien dependencies de construccin.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1269,7 +1277,7 @@
 "La dependencia %s en %s nun puede satisfacese porque nun se puede atopar el "
 "paquete %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1278,32 +1286,32 @@
 "La dependencia %s en %s nun puede satisfacese porque denguna versin "
 "disponible del paquete %s satisfaz los requisitos de versin"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Nun se pudo satisfacer la dependencia %s pa %s: El paquete instalu %s ye "
 "demasiao nuevu"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Fallu pa satisfacer la dependencia %s pa %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Les dependencies de construccin de %s nun pudieron satisfacese."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Fallu al procesar les dependencies de construccin"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Mdulos sofitaos:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1648,8 +1656,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Nun ye a lleer %s"
@@ -1679,10 +1688,9 @@
 msgstr ""
 "Los direutorios info y temp tienen de tar nel mesmu sistema de ficheros"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Lleendo llista de paquetes"
 
@@ -1898,170 +1906,170 @@
 msgid "Write error"
 msgstr "Fallu d'escritura"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Nun se pudo crear un socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Nun se pudo coneutar el zcalu de datos; gandi'l tiempu de conexn"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Nun se pudo coneutar un socket pasivu."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo nun pudo obtener un zcalu oyente"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Nun se pudo enllazar con un socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Nun se pudo escuchar nel socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Nun se pudo determinar el nome del socket"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Nun se pudo mandar la orde PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Direicin de familia %u desconocida (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT fall; el sirvidor dixo: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Gandi'l tiempu de conexn col zcalu de datos"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Nun se pudo aceptar la conexn"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Hebo un problema al xenerar el hash del ficheru"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Nun se pudo descargar el ficheru; el sirvidor dixo '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Gandi'l tiempu del zcalu de datos"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Fall la tresferencia de datos; el sirvidor dixo '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Consulta"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Nun se pudo invocar "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Coneutando a %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Nun se pudo crear un socket pa %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Nun se pudo coneutar a %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Nun se pudo coneutar a %s:%s (%s); expir'l tiempu de conexn"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Nun se pudo coneutar a %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Coneutando a %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nun se pudo resolver '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Fallu temporal al resolver '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Daqu raru pas resolviendo '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Nun se pudo coneutar a %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Encaboxando la instalacin."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Fallu internu: Robla bona, pero nun se pudo determinar la so gella dixital?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Atopse polo menos una robla mala."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "Nun se pudo executar '%s' pa verificar la robla (ta instalu gpgv?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Fallu desconocu al executar gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Les siguientes robles nun valieron:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2140,19 +2148,19 @@
 msgid "Error reading from server"
 msgstr "Fallu al lleer nel sirvidor"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Fall al francer el ficheru"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Datos de testera incorreutos"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Fallo la conexn"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Fallu internu"
 
@@ -2220,7 +2228,7 @@
 msgid "%lis"
 msgstr "%lis"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Escoyeta %s que nun s'atopa"
@@ -2345,6 +2353,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Nun se pudo cambiar a %s"
@@ -2528,7 +2537,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Fall la escritura del ficheru temporal d'estu %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2662,7 +2671,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Nun pueden iguase los problemes; tienes paquetes fraaos retenidos."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2712,12 +2721,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Por favor, introduz el discu '%s' nel presu '%s' y calca Intro."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "El sistema d'empaquetu '%s' nun ta sofitu"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Nun pudo determinase una triba de sistema d'empaquetu afayadiza"
 
@@ -2730,27 +2739,27 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Has de poner delles URIs 'fonte' nel ficheru sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Nun pudieron analizase o abrise les llistes de paquetes o el ficheru d'estu."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Has d'executar apt-get update pa iguar estos problemes"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "Rexistru invlidu nel ficheru de preferencies, nun hai cabecera Paquete"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Nun s'entiende'l tipu de pin %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Nun hai priorid (o ye cero) conseada pa pin"
 
@@ -2840,32 +2849,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Nun se puede lleer la llista de paquetes d'orxenes %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Recoyendo ficheros qu'apurren"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Fallu de E/S al grabar cach d'orxenes"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "fall'l cambiu de nome, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "La suma MD5 nun concasa"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "La suma hash nun concasa"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Nun hai clave pblica denguna disponible pa les IDs de clave darru:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2874,7 +2908,7 @@
 "Nun pudo alcontrase un ficheru pal paquete %s. Esto puede significar que "
 "necesites iguar manualmente esti paquete (por faltar una arquitectura)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2883,7 +2917,7 @@
 "Nun pudo alcontrase un ficheru pal paquete %s. Esto puede significar que "
 "necesites iguar manualmente esti paquete"
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2891,25 +2925,35 @@
 "Los ficheros d'indiz de paquetes tan corrompos. Nun hai campu Filename: pal "
 "paquete %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "El tamau nun concasa"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Nun se pudo tratar el ficheru de paquetes %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Nota, escoyendo %s nel llugar de %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Llinia invlida nel ficheru de desviacin: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Nun se pudo tratar el ficheru de paquetes %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3004,155 +3048,238 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Les entraes de la llista d'orxenes pa esti discu son:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i rexistros escritos.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i rexistros escritos con %i ficheros de menos.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i rexistros escritos con %i ficheros mal empareyaos\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Escribironse %i rexistros con %i ficheros perdos y %i ficheros que nun "
 "concasen\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Abriendo ficheros de configuracin %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "La suma hash nun concasa"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Nota, escoyendo %s pa la espresin regular '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Escoyida la versin %s (%s) pa %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Instalando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Configurando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Desinstalando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Desinstalse dafechu %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Executando activador de post-instalacin de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Falta'l direutoriu '%s'."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Nun se pudo abrir el ficheru %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Preparando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Desempaquetando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Preparndose pa configurar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s instalu"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Preparndose pa desinstalar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s desinstalu"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Preparndose pa desinstalar dafechu %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Desinstalse dafechu %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Nun puede escribise nel rexistru, fall openpty() (/dev/pts nun ta "
 "montu?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Nun pudo bloquiase'l direutoriu de llista"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "Non bloquiu"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3167,7 +3294,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Conexn encaboxada prematuramente"
 

=== modified file 'po/bg.po'
--- po/bg.po	2010-05-25 16:01:42 +0000
+++ po/bg.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.21\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-01-27 12:41+0200\n"
 "Last-Translator: Damyan Ivanov <dmn@debian.org>\n"
 "Language-Team: Bulgarian <dict@fsa-bg.org>\n"
@@ -19,148 +19,146 @@
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Generator: KBabel 1.11.4\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Пакетът %s версия %s има неудовлетворена зависимост:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Пакетът %s не може да бъде намерен"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Общо имена на пакети : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Общо имена на пакети : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Нормални пакети: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Чисти виртуални пакети: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Единични виртуални пакети: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Смесени виртуални пакети: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Липсващи: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Общо уникални версии: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Общо уникални описания: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Общо зависимости: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Общо отношения версия/файл: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Общо отношения описание/файл: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Общо отношения „Осигурява“: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Общо разгърнати низове: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Общо пространство за зависимости по версии: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Общо празно пространство: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Общо отчетено пространство: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Пакетният файл %s не е синхронизиран."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Трябва да въведете само един израз"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Няма намерени пакети"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Пакетът %s не може да бъде намерен"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Пакетни файлове:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Кешът не е синхронизиран, не може да се изпълни „x-ref“ на пакетен файл"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Отбити пакети:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(не са намерени)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Инсталирана: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Кандидат: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(няма)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Отбиване на пакета: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Таблица с версиите:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s за %s компилиран на %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -319,12 +317,12 @@
 "  -o=? Настройване на произволна конфигурационна опция, т.е. -o dir::cache=/"
 "tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Неуспех при записа на %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Не може да се извлече версията на debconf. Debconf инсталиран ли е?"
 
@@ -664,79 +662,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Неуспех при преименуването на %s на %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Грешка при компилирането на регулярния израз - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Следните пакети имат неудовлетворени зависимости:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "но е инсталиран %s"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "но ще бъде инсталиран %s"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "но той не може да бъде инсталиран"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "но той е виртуален пакет"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "но той не е инсталиран"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "но той няма да бъде инсталиран"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " или"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Следните НОВИ пакети ще бъдат инсталирани:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Следните пакети ще бъдат ПРЕМАХНАТИ:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Следните пакети няма да бъдат променени:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Следните пакети ще бъдат актуализирани:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Следните пакети ще бъдат ВЪРНАТИ КЪМ ПО-СТАРА ВЕРСИЯ:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Следните задържани пакети ще бъдат променени:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (поради %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -744,145 +742,145 @@
 "ПРЕДУПРЕЖДЕНИЕ: Следните необходими пакети ще бъдат премахнати.\n"
 "Това НЕ би трябвало да става освен ако знаете точно какво правите!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu актуализирани, %lu нови инсталирани, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu преинсталирани, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu върнати към по-стара версия, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu за премахване и %lu без промяна.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu не са напълно инсталирани или премахнати.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Коригиране на зависимостите..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " пропадна."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Неуспех при коригирането на зависимостите"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Неуспех при минимизирането на набора актуализации"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Готово"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 "Възможно е да изпълните „apt-get -f install“, за да коригирате тези "
 "неизправности."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Неудовлетворени зависимости. Опитайте с „-f“."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ПРЕДУПРЕЖДЕНИЕ: Следните пакети не могат да бъдат удостоверени!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Предупреждението за удостоверяването е пренебрегнато.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Инсталиране на тези пакети без проверка [y/N]?"
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Някои пакети не можаха да бъдат удостоверени"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Има проблеми и „-y“ е използвано без „--force-yes“"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Вътрешна грешка, „InstallPackages“ е предизвикано при счупени пакети!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Трябва да бъдат премахнати пакети, но премахването е изключено."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Вътрешна грешка, „Ordering“ не завърши"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Списъкът с източници не можа да бъде прочетен."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Странно.. Размерите не съвпадат, изпратете е-поща на apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Необходимо е да се изтеглят %sB/%sB архиви.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Необходимо е да се изтеглят %sB архиви.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "След тази операция ще бъде използвано %sB допълнително дисково "
 "пространство.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "След тази операция ще бъде освободено %sB дисково пространство.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Неуспех при определянето на свободното пространство в %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Нямате достатъчно свободно пространство в %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Указано е „Trivial Only“, но това не е тривиална операция."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Да, прави каквото казвам!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -893,28 +891,28 @@
 "За да продължите, въведете фразата „%s“\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Прекъсване."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Искате ли да продължите [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Неуспех при изтеглянето на %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Някои файлове не можаха да бъдат изтеглени"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Изтеглянето завърши в режим само на изтегляне"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -922,19 +920,19 @@
 "Неуспех при изтеглянето на някои архиви, може да изпълните „apt-get update“ "
 "или да опитате с „--fix-missing“?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "„--fix-missing“ и превключване на носители не се поддържа все още"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Неуспех при коригирането на липсващите пакети."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Прекъсване на инсталирането."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -944,49 +942,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Забележете, избиране на %s вместо %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Пропускане на %s, вече е инсталиран и не е маркиран за актуализация.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Пропускане на %s, вече е инсталиран и не е маркиран за актуализация.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Пакетът %s не е инсталиран, така че не е премахнат\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Пакетът %s е виртуален пакет, осигурен от:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Инсталиран]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Версии кандидати"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Трябва изрично да изберете един за инсталиране."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -997,66 +995,66 @@
 "Това може да означава, че пакета липсва, остарял е, или е достъпен\n"
 "само от друг източник\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Обаче следните пакети го заместват:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Пакетът %s няма кандидат за инсталиране"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Преинсталацията на %s не е възможна, не може да бъде изтеглен.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s вече е най-новата версия.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Не е намерено издание „%s“ на „%s“"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Не е намерена версия „%s“ на „%s“"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Избрана е версия %s (%s) за %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr ""
 "Неуспех при получаването на атрибути на списъка с пакети с изходен код %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Командата „update“ не възприема аргументи"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Не би трябвало да се изтрива. AutoRemover няма да бъде стартиран"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1068,7 +1066,7 @@
 msgstr[1] ""
 "Следните пакети са били инсталирани автоматично и вече не са необходими:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1078,11 +1076,11 @@
 msgstr[1] ""
 "Следните пакети са били инсталирани автоматично и вече не са необходими:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Използвайте „apt-get autoremove“ за да ги премахнете."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1100,44 +1098,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr ""
 "Следната информация може да помогне за намиране на изход от ситуацията:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Вътрешна грешка, AutoRemover счупи нещо в системата"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Вътрешна грешка, „AllUpgrade“ счупи нещо в системата"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Неуспех при намирането на задача %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Неуспех при намирането на пакет %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Забележете, избиране на %s за регулярен израз „%s“\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s е отбелязан като ръчно инсталиран.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Възможно е да изпълните „apt-get -f install“, за да коригирате:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1145,7 +1138,7 @@
 "Неудовлетворени зависимости. Опитайте „apt-get -f install“ без пакети (или "
 "укажете разрешение)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1157,127 +1150,142 @@
 "дистрибуция, че някои необходими пакети още не са създадени или пък\n"
 "са били преместени от Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Счупени пакети"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Следните допълнителни пакети ще бъдат инсталирани:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Предложени пакети:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Препоръчвани пакети:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s е отбелязан като ръчно инсталиран.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Изчисляване на актуализацията..."
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Неуспех"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Готово"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Вътрешна грешка, „problem resolver“ счупи нещо в системата"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Неуспех при заключването на директорията за изтегляне"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Трябва да укажете поне един пакет за изтегляне на изходния му код"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Неуспех при намирането на изходен код на пакет %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Пропускане на вече изтегления файл „%s“\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Нямате достатъчно свободно пространство в %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Необходимо е да се изтеглят %sB/%sB архиви изходен код.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Необходимо е да се изтеглят %sB архиви изходен код.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Изтегляне на изходен код %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Неуспех при изтеглянето на някои архиви."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 "Пропускане на разпакетирането на вече разпакетирания изходен код в %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Командата за разпакетиране „%s“ пропадна.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Проверете дали имате инсталиран пакета „dpkg-dev“.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Командата за компилиране „%s“ пропадна.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Процесът-потомък пропадна"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Трябва да укажете поне един пакет за проверка на зависимости за компилиране"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr ""
 "Неуспех при получаването на информация за зависимостите за компилиране на %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s няма зависимости за компилиране.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1286,7 +1294,7 @@
 "Зависимост %s за пакета %s не може да бъде удовлетворена, понеже пакета %s "
 "не може да бъде намерен"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1296,32 +1304,32 @@
 "налични версии на пакета %s, които могат да удовлетворят изискването за "
 "версия"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Неуспех при удовлетворяването на зависимост %s за пакета %s: Инсталираният "
 "пакет %s е твърде нов"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Неуспех при удовлетворяването на зависимост %s за пакета %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Зависимостите за компилиране на %s не можаха да бъдат удовлетворени."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Неуспех при обработката на зависимостите за компилиране"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Поддържани модули:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1659,8 +1667,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Неуспех при четенето на %s"
@@ -1690,10 +1699,9 @@
 msgstr ""
 "Директориите info и temp трябва да бъдат на една и съща файлова система"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Четене на списъците с пакети"
 
@@ -1909,175 +1917,175 @@
 msgid "Write error"
 msgstr "Грешка при запис"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Неуспех при създаването на гнездо"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 "Неуспех при свързването на гнездо за данни, допустимото време за свъзрзване "
 "изтече"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Неуспех при свързването на пасивно гнездо."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo не успя да се добере до слушащо гнездо"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Неуспех при свързването на гнездо"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Неуспех при слушането на гнездото"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Неуспех при определянето на името на гнездото"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Неуспех при изпращането на командата PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Неизвестно семейство адреси %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT се провали, сървърът съобщи: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Времето за установяване на връзка с гнездо за данни изтече"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Невъзможно е да се приеме свързването"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Проблем при хеширане на файла"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Неуспех при изтеглянето на файла, сървърът съобщи „%s“"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Времето за връзка с гнездо за данни изтече"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Неуспех при прехвърлянето на данни, сървърът съобщи: „%s“"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Запитване"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Неуспех при извикването на "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Свързване с %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Неуспех при създаването на гнездо за %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Не може да се започне свързване с %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Неуспех при свързване с %s:%s (%s), допустимото време изтече"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Неуспех при свързване с %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Свързване с %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Неуспех при намирането на IP адреса на „%s“"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Временен неуспех при намирането на IP адреса на „%s“"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Нещо лошо се случи при намирането на IP адреса на „%s:%s“ (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Неуспех при свързването с %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Прекъсване на инсталирането."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Вътрешна грешка: Валиден подпис, но не може да се провери отпечатъка на "
 "ключа?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Намерен е поне един невалиден подпис."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Неуспех при изпълнението на „%s“ за проверка на подписа (инсталиран ли е "
 "gpgv?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Неизвестна грешка при изпълнението на gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Следните подписи са невалидни:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2156,19 +2164,19 @@
 msgid "Error reading from server"
 msgstr "Грешка при четене от сървъра"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Неуспех при отрязване на края на файла"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Невалидни данни на заглавната част"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Неуспех при свързването"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Вътрешна грешка"
 
@@ -2234,7 +2242,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Изборът %s не е намерен"
@@ -2361,6 +2369,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Неуспех при преминаването в %s"
@@ -2547,7 +2556,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Неуспех при запис на временен StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2690,7 +2699,7 @@
 msgstr ""
 "Неуспех при коригирането на проблемите, имате задържани счупени пакети."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2740,12 +2749,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Сложете диска, озаглавен „%s“ в устройство „%s“ и натиснете „Enter“."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Пакетната система „%s“ не е поддържана"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Неуспех при определянето на подходяща пакетна система"
 
@@ -2758,28 +2767,28 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Трябва да добавите адреси-URI от тип „source“ в sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Списъците с пакети или файлът за състояние не можаха да бъдат анализирани "
 "или отворени."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Може да искате да изпълните „apt-get update“, за да коригирате тези проблеми"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Невалиден запис във файла с настройки, няма заглавна част Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Неизвестен тип за отбиване %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Няма указан приоритет (или е нула) на отбиването"
 
@@ -2873,32 +2882,57 @@
 msgstr ""
 "Неуспех при получаването на атрибути на списъка с пакети с изходен код %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Събиране на информация за „Осигурява“"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Входно/изходна грешка при запазването на кеша на пакети с изходен код"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "преименуването се провали, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Несъответствие на контролна сума MD5"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Несъответствие на контролната сума"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Няма налични публични ключове за следните идентификатори на ключове:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2907,7 +2941,7 @@
 "Неуспех при намирането на файл за пакет %s. Това може да означава, че трябва "
 "ръчно да оправите този пакет (поради пропусната архитектура)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2916,32 +2950,42 @@
 "Неуспех при намирането на файл за пакет %s. Това може да означава, че трябва "
 "ръчно да оправите този пакет."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "Индексните файлове на пакета са повредени. Няма поле Filename: за пакет %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Несъответствие на размера"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Неуспех при анализирането на пакетен файл %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Забележете, избиране на %s вместо %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Неправилен ред във файла с отклонения: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Неуспех при анализирането на пакетен файл %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3036,153 +3080,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Записите в списъка с източници за този диск са:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Записани са %i записа.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Записани са %i записа с %i липсващи файла.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Записани са %i записа с %i несъответстващи файла\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Записани са %i записа с %i липсващи и %i несъответстващи файла\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Отваряне на конфигурационен файл %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Несъответствие на контролната сума"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Забележете, избиране на %s за регулярен израз „%s“\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Избрана е версия %s (%s) за %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Инсталиране на %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Конфигуриране на %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Премахване на %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s е напълно премахнат"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Изпълнение на тригер след инсталиране %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Директорията „%s“ липсва"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Неуспех при отварянето на файла %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Подготвяне на %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Разпакетиране на %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Подготвяне на %s за конфигуриране"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s е инсталиран"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Подготвяне за премахване на %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s е премахнат"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Подготовка за пълно премахване на %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s е напълно премахнат"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Неуспех при запис в журнала, openpty() се провали (дали /dev/pts е "
 "монтирана?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Неуспех при заключването на директорията със списъка на пакетите"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3197,7 +3324,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Връзката прекъсна преждевременно"
 

=== modified file 'po/bs.po'
--- po/bs.po	2010-05-25 16:01:42 +0000
+++ po/bs.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.5.26\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2004-05-06 15:25+0100\n"
 "Last-Translator: Safir Šećerović <sapphire@linux.org.ba>\n"
 "Language-Team: Bosnian <lokal@lugbih.org>\n"
@@ -14,149 +14,146 @@
 "Content-Type: text/plain; charset=utf-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Paket %s verzije %s ima nezadovoljenu zavisnost:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Ne mogu pronaći paket %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Ukupno naziva paketa:"
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Ukupno naziva paketa:"
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normalni paketi:"
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Čisto virtuelni paketi:"
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Pojedinačni virutuelni paketi:"
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Miješani virtuelni paketi:"
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Nedostajući:"
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Ukupno različitih verzija:"
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "Ukupno različitih verzija:"
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Ukupno zavisnosti:"
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Ukupno Verzija/Datoteka odnosa:"
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "Ukupno Verzija/Datoteka odnosa:"
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr ""
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+msgid "You must give at least one search pattern"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Paketi nisu pronađeni"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Ne mogu pronaći paket %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Datoteke paketa:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalirano:"
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr ""
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 msgid ""
 "Usage: apt-cache [options] command\n"
 "       apt-cache [options] add file1 [file2 ...]\n"
@@ -264,12 +261,12 @@
 "  -o=? Set an arbitrary configuration option, eg -o dir::cache=/tmp\n"
 msgstr ""
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Ne mogu zapisati na %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr ""
 "Ne mogu odrediti verziju debconf programa. Da li je debconf instaliran?"
@@ -564,220 +561,220 @@
 msgid "Failed to rename %s to %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr ""
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr ""
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "ali je %s instaliran"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "ali se %s treba instalirati"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ali se ne može instalirati"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ali je virtuelni paket"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ali nije instaliran"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "ali se neće instalirati"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " ili"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Slijedeći NOVI paketi će biti instalirani:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Slijedeći paketi će biti UKLONJENI:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 #, fuzzy
 msgid "The following packages have been kept back:"
 msgstr "Slijedeći paketi su zadržani:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Slijedeći paketi će biti nadograđeni:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr ""
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr ""
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr ""
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
 msgstr ""
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr ""
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr ""
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr ""
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Ispravljam zavisnosti..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr ""
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Ne mogu ispraviti zavisnosti"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr ""
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Urađeno"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Nezadovoljene zavisnosti. Pokušajte koristeći -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 #, fuzzy
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "Slijedeći paketi će biti nadograđeni:"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr ""
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr ""
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr ""
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr ""
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr ""
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr ""
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr ""
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Da, uradi kako kažem!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -785,47 +782,47 @@
 " ?] "
 msgstr ""
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Odustani."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 #, fuzzy
 msgid "Do you want to continue [Y/n]? "
 msgstr "Da li želite nastaviti? [Y/n]"
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr ""
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr ""
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
 msgstr ""
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr ""
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr ""
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Odustajem od instalacije."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -835,49 +832,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr "[Instalirano]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Verzije kandidata"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr ""
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -885,65 +882,65 @@
 "is only available from another source\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Međutim, slijedeći paketi ga zamjenjuju:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr ""
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr ""
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr ""
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr ""
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr ""
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -953,7 +950,7 @@
 msgstr[0] "Slijedeći NOVI paketi će biti instalirani:"
 msgstr[1] "Slijedeći NOVI paketi će biti instalirani:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -961,11 +958,11 @@
 msgstr[0] "Slijedeći NOVI paketi će biti instalirani:"
 msgstr[1] "Slijedeći NOVI paketi će biti instalirani:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -981,49 +978,44 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr ""
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr ""
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "ali se %s treba instalirati"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
 msgstr ""
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1031,161 +1023,176 @@
 "or been moved out of Incoming."
 msgstr ""
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Oštećeni paketi"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Slijedeći dodatni paketi će biti instalirani:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Predloženi paketi:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Preporučeni paketi:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "ali se %s treba instalirati"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Računam nadogradnju..."
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Neuspješno"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Urađeno"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr ""
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr ""
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr ""
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr ""
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
 "package %s can satisfy version requirements"
 msgstr ""
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr ""
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr ""
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Podržani moduli:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 msgid ""
 "Usage: apt-get [options] command\n"
 "       apt-get [options] install|remove pkg1 [pkg2 ...]\n"
@@ -1463,8 +1470,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Ne mogu čitati %s"
@@ -1493,10 +1501,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr ""
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Čitam spiskove paketa"
 
@@ -1708,170 +1715,169 @@
 msgid "Write error"
 msgstr "Greška pri pisanju"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr ""
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr ""
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr ""
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr ""
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr ""
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr ""
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr ""
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr ""
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr ""
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr ""
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr ""
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr ""
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr ""
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr ""
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr ""
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr ""
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr ""
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr ""
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr ""
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr ""
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr ""
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr ""
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr ""
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Povezujem se sa %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr ""
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr ""
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr ""
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Ne mogu se povezati sa %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Odustajem od instalacije."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr ""
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr ""
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 #, fuzzy
 msgid "The following signatures were invalid:\n"
 msgstr "Slijedeći dodatni paketi će biti instalirani:"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -1948,20 +1954,20 @@
 msgid "Error reading from server"
 msgstr ""
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Ne mogu ukloniti %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr ""
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Povezivanje neuspješno"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Unutrašnja greška"
 
@@ -2027,7 +2033,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr ""
@@ -2150,6 +2156,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr ""
@@ -2335,7 +2342,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Ne mogu ukloniti %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2463,7 +2470,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr ""
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2511,12 +2518,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr ""
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr ""
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr ""
 
@@ -2529,25 +2536,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr ""
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr ""
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr ""
 
@@ -2636,70 +2643,105 @@
 msgid "Couldn't stat source package list %s"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
 "to manually fix this package. (due to missing arch)"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
 "manually fix this package."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr ""
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Ne mogu otvoriti DB datoteku %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr ""
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr ""
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Ne mogu otvoriti DB datoteku %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2791,151 +2833,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, c-format
 msgid "Hash mismatch for: %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:194
+#, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "  Instalirano:"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, fuzzy, c-format
 msgid "Configuring %s"
 msgstr "Povezujem se sa %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, fuzzy, c-format
 msgid "Removing %s"
 msgstr "Otvaram %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Ne mogu ukloniti %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Ne mogu otvoriti %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, fuzzy, c-format
 msgid "Preparing %s"
 msgstr "Otvaram %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, fuzzy, c-format
 msgid "Unpacking %s"
 msgstr "Otvaram %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, fuzzy, c-format
 msgid "Installed %s"
 msgstr "  Instalirano:"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, fuzzy, c-format
 msgid "Removed %s"
 msgstr "Preporučuje"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, fuzzy, c-format
 msgid "Completely removed %s"
 msgstr "Ne mogu ukloniti %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -2950,7 +3075,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr ""
 

=== modified file 'po/ca.po'
--- po/ca.po	2010-05-25 16:01:42 +0000
+++ po/ca.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.22\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-06-06 02:17+0200\n"
 "Last-Translator: Jordi Mallach <jordi@debian.org>\n"
 "Language-Team: Catalan <debian-l10n-catalan@lists.debian.org>\n"
@@ -16,148 +16,146 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "El paquet %s versió %s té una dependència sense satisfer:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "No s'ha trobat el paquet %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Nombre total de paquets: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Nombre total de paquets: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Paquets normals: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Paquets virtuals purs: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Paquets virtuals únics: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Paquets virtuals mixtes: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Falten: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Total de versions diferents: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Total de descripcions diferents: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Total de dependències: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Total de relacions versió/fitxer: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Total de relacions descripció/fitxer: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Total dels mapes aportats: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Total de cadenes globals: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Total de l'espai per a dependències de versió: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Total de l'espai desperdiciat: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Total de l'espai atribuït a: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "El fitxer %s del paquet està desincronitzat."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Heu de donar exactament un patró"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "No s'han trobat paquets"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "No s'ha trobat el paquet %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Fitxers de paquets:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Memòria cau no sincronitzada, no es pot fer x-ref a un fitxer del paquet"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Paquets etiquetats:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(no trobat)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instal·lat: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidat: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(cap)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Etiqueta del paquet: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Taula de versió:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s per a %s compilat el %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -313,12 +311,12 @@
 "  -c=? Llegeix aquest fitxer de configuració\n"
 "  -o=? Estableix una opció de conf arbitrària, p.e. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "No es pot escriure en %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "No es pot determinar la versió de debconf. Està instal·lat debconf?"
 
@@ -654,79 +652,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "No s'ha pogut canviar el nom de %s a %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "S"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "S'ha produït un error de compilació de l'expressió regular - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Els següents paquets tenen dependències sense satisfer:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "però està instal·lat %s"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "però s'instal·larà %s"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "però no és instal·lable"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "però és un paquet virtual"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "però no està instal·lat"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "però no serà instal·lat"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " o"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "S'instal·laran els paquets NOUS següents:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Es SUPRIMIRAN els paquets següents:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "S'han mantingut els paquets següents:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "S'actualitzaran els paquets següents:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Es DESACTUALITZARAN els paquets següents:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Es canviaran els paquets retinguts següents:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (per %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -734,145 +732,145 @@
 "AVÍS: Es suprimiran els paquets essencials següents.\n"
 "Això NO s'ha de fer a menys que sapigueu exactament el que esteu fent!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu actualitzats, %lu nous a instal·lar, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstal·lats, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu desactualitzats, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu a suprimir i %lu no actualitzats.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu no instal·lats o suprimits completament.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "S'estan corregint les dependències..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " ha fallat."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "No es poden corregir les dependències"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "No es pot minimitzar el joc de versions revisades"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Fet"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Potser voldreu executar 'apt-get -f install' per a corregir-ho."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dependències sense satisfer. Proveu-ho emprant -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "AVÍS: No es poden autenticar els següents paquets!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "S'ha descartat l'avís d'autenticació.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Voleu instal·lar aquests paquets sense verificar-los [s/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "No s'ha pogut autenticar alguns paquets"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Hi ha problemes i s'ha emprat -y sense --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 "S'ha produït un error intern, s'ha cridat a InstallPackages amb paquets "
 "trencats!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr ""
 "Els paquets necessiten ser suprimits però s'ha inhabilitat la supressió."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "S'ha produït un error intern, l'ordenació no ha acabat"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "No s'ha pogut llegir la llista de les fonts."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Què estrany... les mides no coincideixen, informeu a apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Es necessita obtenir %sB/%sB d'arxius.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Es necessita obtenir %sB d'arxius.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "Després d'aquesta operació s'empraran %sB d'espai en disc addicional.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Després d'aquesta operació s'alliberaran %sB d'espai en disc.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "No s'ha pogut determinar l'espai lliure en %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "No teniu prou espai lliure en %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Es va especificar Trivial Only però aquesta operació no és trivial."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Sí, fes el que et dic!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -883,28 +881,28 @@
 "Per a continuar escriviu la frase «%s»\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Avortat."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Voleu continuar [S/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "No s'ha pogut obtenir %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Alguns fitxers no s'han pogut baixar"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Descàrrega completa i en mode de només descàrrega"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -912,19 +910,19 @@
 "No es poden baixar alguns arxius, proveu a executar apt-get update o "
 "intenteu-ho amb --fix-missing."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing i els medi intercanviables actualment no estan suportats"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "No es poden corregir els paquets que falten."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "S'està avortant la instal·lació."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -934,51 +932,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Nota: s'està seleccionant %s en comptes de %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "S'està ometent %s, ja està instal·lat i l'actualització no està establerta.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "S'està ometent %s, ja està instal·lat i l'actualització no està establerta.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "El paquet %s no està instal·lat, així doncs no es suprimirà\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "El paquet %s és un paquet virtual proveït per:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Instal·lat]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versions candidates"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Necessiteu seleccionar-ne un explícitament per a instal·lar-lo."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -989,67 +987,67 @@
 "en fa referència. Això normalment vol dir que el paquet falta,\n"
 "s'ha tornat obsolet o només és disponible des d'una altra font.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Tot i que els següents paquets el reemplacen:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "El paquet %s no té candidat d'instal·lació"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "No es possible la reinstal·lació del paquet %s, no es pot baixar.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s ja es troba en la versió més recent.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "No s'ha trobat la versió puntual «%s» per a «%s»"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "No s'ha trobat la versió «%s» per a «%s»"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Versió seleccionada %s (%s) per a %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "No s'ha pogut llegir la llista de paquets font %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "L'ordre update no pren arguments"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Es suposa que no hauriem de suprimir coses, no es pot iniciar el supressor "
 "automàtic"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1061,7 +1059,7 @@
 msgstr[1] ""
 "Els paquets següents s'instal·laren automàticament i ja no són necessaris:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1071,11 +1069,11 @@
 msgstr[1] ""
 "Els paquets següents s'instal·laren automàticament i ja no són necessaris:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Empreu «apt-get autoremove» per a suprimir-los."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1093,43 +1091,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "La informació següent pot ajudar-vos a resoldre la situació:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "S'ha produït un error intern, el supressor automàtic ha trencat coses"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Error intern, AllUpgrade ha trencat coses"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "No s'ha pogut trobar la tasca %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "No s'ha pogut trobar el paquet %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Nota: s'està seleccionant %s per a l'expressió regular '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "S'ha marcat %s com instal·lat manualment.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Potser voldreu executar 'apt-get -f install' per a corregir-ho:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1137,7 +1130,7 @@
 "Dependències insatisfetes. Intenteu 'apt-get -f install' sense paquets (o "
 "especifiqueu una solució)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1149,129 +1142,144 @@
 "unstable i alguns paquets requerits encara no han estat creats o bé\n"
 "encara no els hi han afegit."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Paquets trencats"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "S'instal·laran els següents paquets extres:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Paquets suggerits:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Paquets recomanats:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "S'ha marcat %s com instal·lat manualment.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "S'està calculant l'actualització... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Ha fallat"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Fet"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 "S'ha produït un error intern, el solucionador de problemes ha trencat coses"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "No és possible blocar el directori de descàrrega"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Haureu d'especificar un paquet de codi font per a baixar"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "No es pot trobar un paquet de fonts per a %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "S'està ometent el fitxer ja baixat «%s»\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "No teniu prou espai lliure en %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Es necessita baixar %sB/%sB d'arxius font.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Es necessita baixar %sB d'arxius font.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Obté el font %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "No s'ha pogut baixar alguns arxius."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 "S'està ometent el desempaquetament de les fonts que ja ho estan en %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "L'ordre de desempaquetar «%s» ha fallat.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Comproveu si el paquet «dpkgdev» està instal·lat.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "L'ordre de construir «%s» ha fallat.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Ha fallat el procés fill"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "S'ha d'especificar un paquet per a verificar les dependències de construcció "
 "per a"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr ""
 "No es pot obtenir informació sobre les dependències de construcció per a %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s no té dependències de construcció.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1280,7 +1288,7 @@
 "La dependència %s en %s no es pot satisfer per que no es pot trobar el "
 "paquet %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1289,32 +1297,32 @@
 "La dependència %s per a %s no es pot satisfer per que cap versió del paquet %"
 "s pot satisfer els requeriments de versions"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "No s'ha pogut satisfer la dependència %s per a %s: El paquet instal·lat %s "
 "és massa nou"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "No s'ha pogut satisfer la dependència %s per a %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "No s'han pogut satisfer les dependències de construcció per a %s"
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "No es poden processar les dependències de construcció"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Mòduls suportats:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1654,8 +1662,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "No es pot llegir %s"
@@ -1686,10 +1695,9 @@
 "La info i els directoris temp necessiten estar en el mateix sistema de "
 "fitxers"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "S'està llegint la llista de paquets"
 
@@ -1905,174 +1913,174 @@
 msgid "Write error"
 msgstr "Error d'escriptura"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "No s'ha pogut crear un sòcol"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "No s'ha pogut connectar amb el sòcol de dades, connexió finalitzada"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "No s'ha pogut connectar amb el sòcol passiu."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "gettaddrinfo no es pot obtenir un sòcol que escolte"
 
 # abastar? huh? jm
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "No s'ha pogut abastar un connector"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "No s'ha pogut escoltar sobre el sòcol"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "No s'ha pogut determinar el nom del sòcol"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "No es pot enviar l'ordre PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "La família d'adreces %u és desconeguda (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT ha fallat, el servidor ha dit: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "S'ha esgotat el temps de connexió al sòcol de dades"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "No es pot acceptar la connexió"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problema escollint el fitxer"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "No és possible reprendre el fitxer, el servidor ha dit '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "S'ha esgotat el temps d'espera per al sòcol de dades"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Ha fallat la transferència de dades, el servidor ha dit '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Consulta"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "No es pot invocar"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "S'està connectant amb %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "No s'ha pogut crear un sòcol per a %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "No es pot iniciar la connexió amb %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "No s'ha pogut connectar amb %s:%s (%s), temps de connexió excedit"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "No s'ha pogut connectar amb %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "S'està connectant amb %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "No s'ha pogut resoldre '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "S'ha produït un error temporal en resoldre '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Ha passat alguna cosa estranya en resoldre «%s:%s» (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "No es pot connectar amb %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "S'està avortant la instal·lació."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Error intern: La signatura és correcta, però no s'ha pogut determinar "
 "l'emprempta digital de la clau!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "S'ha trobat almenys una signatura invàlida."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "No s'ha pogut executar «%s» per a verificar la signatura (està instal·lat el "
 "gpgv?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "S'ha produït un error desconegut en executar el gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Les signatures següents són invàlides:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2152,19 +2160,19 @@
 msgid "Error reading from server"
 msgstr "S'ha produït un error en llegir des del servidor"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "No s'ha pogut truncar el fitxer %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Capçalera de dades no vàlida"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Ha fallat la connexió"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Error intern"
 
@@ -2232,7 +2240,7 @@
 msgid "%lis"
 msgstr "%lis"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "No s'ha trobat la selecció %s"
@@ -2355,6 +2363,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "No es pot canviar a %s"
@@ -2539,7 +2548,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "No s'ha pogut escriure el fitxer d'estat temporal %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2676,7 +2685,7 @@
 "No es poden corregir els problemes, teniu paquets retinguts que estan "
 "trencats."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2726,12 +2735,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Inseriu el disc amb l'etiqueta: «%s» en la unitat «%s» i premeu Intro."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "El sistema d'empaquetament «%s» no està suportat"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "No es pot determinar un tipus de sistema d'empaquetament adequat."
 
@@ -2744,27 +2753,27 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Heu de posar algunes URI 'font' en el vostre sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "No s'han pogut analitzar o obrir les llistes de paquets o el fitxer d'estat."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Potser voldreu executar apt-get update per a corregir aquests problemes"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Registre no vàlid al fitxer de preferències, paquet sense capçalera"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "No s'ha entès el pin de tipus %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "No hi ha prioritat especificada per al pin (o és zero)"
 
@@ -2861,32 +2870,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "No s'ha pogut llegir la llista de paquets font %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "S'estan recollint els fitxers que proveeixen"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Error d'E/S en desar la memòria cau de la font"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "no s'ha pogut canviar el nom, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "La suma MD5 no concorda"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "La suma resum no concorda"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "No hi ha cap clau pública disponible per als següents ID de clau:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, fuzzy, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr "El fitxer Release ha caducat, s'està ignorant %s (vàlid fins a %s)"
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr "Distribució en conflicte: %s (s'esperava %s però s'ha obtingut %s)"
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2896,7 +2930,7 @@
 "significar que haureu d'arreglar aquest paquet manualment (segons "
 "arquitectura)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2905,7 +2939,7 @@
 "No s'ha trobat un fitxer pel paquet %s. Això podria significar que haureu "
 "d'arreglar aquest paquet manualment."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2913,25 +2947,35 @@
 "L'índex dels fitxers en el paquet està corromput. Fitxer no existent: camp "
 "per al paquet %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "La mida no concorda"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "No es pot analitzar el fitxer Release %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "No hi ha seccions al fitxer Release %s"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "No hi ha una entrada Hash al fitxer Release %s"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "No hi ha una entrada Hash al fitxer Release %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "No hi ha una entrada Hash al fitxer Release %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3026,155 +3070,238 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Les entrades de la llista de fonts per a aquest disc són:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "S'han escrit %i registres.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "S'han escrit %i registres, on falten %i fitxers.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "S'han escrit %i registres, on hi ha %i fitxers no coincidents\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "S'han escrit %i registres, on falten %i fitxers i hi ha %i fitxers no "
 "coincidents\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "S'està obrint el fitxer de configuració %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "La suma resum no concorda"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Nota: s'està seleccionant %s per a l'expressió regular '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Versió seleccionada %s (%s) per a %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "S'està instal·lant %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "S'està configurant el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "S'està suprimint el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "S'ha suprimit completament el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "S'està executant l'activador de postinstal·lació %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Manca el directori «%s»"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "No s'ha pogut obrir el fitxer %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "S'està preparant el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "S'està desempaquetant %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "S'està preparant per a configurar el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "S'ha instal·lat el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "S'està preparant per a la supressió del paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "S'ha suprimit el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "S'està preparant per a suprimir completament el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "S'ha suprimit completament el paquet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "No es pot escriure el registre, ha fallat openpty() (no s'ha muntat /dev/"
 "pts?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "No es pot blocar el directori de la llista"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "No blocat"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3189,7 +3316,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "La connexió s'ha tancat prematurament"
 
@@ -3223,12 +3350,6 @@
 #~ msgid "Dynamic MMap ran out of room"
 #~ msgstr "L'MMap dinàmic s'ha quedat sense espai"
 
-#~ msgid "Release file expired, ignoring %s (valid until %s)"
-#~ msgstr "El fitxer Release ha caducat, s'està ignorant %s (vàlid fins a %s)"
-
-#~ msgid "Conflicting distribution: %s (expected %s but got %s)"
-#~ msgstr "Distribució en conflicte: %s (s'esperava %s però s'ha obtingut %s)"
-
 #~ msgid ""
 #~ "Since you only requested a single operation it is extremely likely that\n"
 #~ "the package is simply not installable and a bug report against\n"

=== modified file 'po/cs.po'
--- po/cs.po	2010-05-25 16:01:42 +0000
+++ po/cs.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-16 18:05+0100\n"
 "Last-Translator: Miroslav Kure <kurem@debian.cz>\n"
 "Language-Team: Czech <debian-l10n-czech@lists.debian.org>\n"
@@ -15,147 +15,145 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Balík %s verze %s má nesplněné závislosti:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Nemohu najít balík %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Celkem názvů balíků: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Celkem názvů balíků: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normálních balíků: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Čistě virtuálních balíků: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Jednoduchých virtuálních balíků: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Smíšených virtuálních balíků: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Chybějících: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Celkem různých verzí: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Celkem různých popisů: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Celkem závislostí: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Celkem vztahů ver/soubor: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Celkem vztahů popis/soubor: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Celkem poskytnutých mapování: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Celkem globovaných řetězců: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Celkem místa závislých verzí: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Celkem jalového místa: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Celkem přiřazeného místa: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Soubor balíku %s je špatně synchronizovaný."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Musíte zadat právě jeden vzor"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Nebyly nalezeny žádné balíky"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Nemohu najít balík %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Soubory balíku:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Cache není synchronizovaná, nemohu se odkázat na soubor balíku"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Vypíchnuté balíky:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(nenalezeno)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalovaná verze: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidát: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(žádná)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Vypíchnutý balík: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabulka verzí:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s pro %s zkompilován na %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -309,12 +307,12 @@
 "  -c=? Načte tento konfigurační soubor\n"
 "  -o=? Nastaví libovolnou volbu, např. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Nemohu zapsat do %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Nemohu určit verzi programu debconf. Je debconf nainstalován?"
 
@@ -649,79 +647,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Selhalo přejmenování %s na %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Chyba při kompilaci regulárního výrazu - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Následující balíky mají nesplněné závislosti:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "ale %s je nainstalován"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "ale %s se bude instalovat"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ale nedá se nainstalovat"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ale je to virtuální balík"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ale není nainstalovaný"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "ale nebude se instalovat"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " nebo"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Následující NOVÉ balíky budou nainstalovány:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Následující balíky budou ODSTRANĚNY:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Následující balíky jsou podrženy v aktuální verzi:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Následující balíky budou aktualizovány:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Následující balíky budou DEGRADOVÁNY:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Následující podržené balíky budou změněny:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (kvůli %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -729,141 +727,141 @@
 "VAROVÁNÍ: Následující nezbytné balíky budou odstraněny.\n"
 "Pokud přesně nevíte, co děláte, NEDĚLEJTE to!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu aktualizováno, %lu nově instalováno, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstalováno, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu degradováno, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu k odstranění a %lu neaktualizováno.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu instalováno nebo odstraněno pouze částečně.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Opravuji závislosti..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " selhalo."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Nemohu opravit závislosti"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Nemohu minimalizovat sadu pro aktualizaci"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Hotovo"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Pro opravení můžete spustit „apt-get -f install“."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Nesplněné závislosti. Zkuste použít -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "VAROVÁNÍ: Následující balíky nemohou být autentizovány!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Autentizační varování potlačeno.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Instalovat tyto balíky bez ověření [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Některé balíky nemohly být autentizovány"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Vyskytly se problémy a -y bylo použito bez --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Vnitřní chyba, InstallPackages byl zavolán s porušenými balíky!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Balík je potřeba odstranit ale funkce Odstranit je vypnuta."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Vnitřní chyba, třídění nedoběhlo do konce"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Nelze přečíst seznam zdrojů."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Jak podivné... velikosti nesouhlasí, ohlaste to na apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Potřebuji stáhnout %sB/%sB archivů.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Potřebuji stáhnout %sB archivů.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Po této operaci bude na disku použito dalších %sB.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Po této operaci bude na disku uvolněno %sB.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Nemohu určit volné místo v %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "V %s nemáte dostatek volného místa."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Udáno „pouze triviální“, ovšem toto není triviální operace."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ano, udělej to tak, jak říkám!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -874,28 +872,28 @@
 "Pro pokračování opište frázi „%s“\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Přerušeno."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Chcete pokračovat [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Selhalo stažení %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Některé soubory nemohly být staženy"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Stahování dokončeno v režimu pouze stáhnout"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -903,19 +901,19 @@
 "Nemohu stáhnout některé archivy. Možná spusťte apt-get update nebo zkuste --"
 "fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing a výměna média nejsou momentálně podporovány"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Nemohu opravit chybějící balíky."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Přerušuji instalaci."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -925,49 +923,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Pozn: Vybírám %s místo %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Přeskakuji %s, protože je již nainstalován.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Přeskakuji %s, protože je již nainstalován.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Balík %s není nainstalován, nelze tedy odstranit\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Balík %s je virtuální balík poskytovaný:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr "[Instalovaný]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Kandidátské verze"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Měli byste explicitně vybrat jeden k instalaci."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -978,65 +976,65 @@
 "To může znamenat že balík chybí, byl zastarán, nebo je dostupný\n"
 "pouze z jiného zdroje\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Nicméně následující balíky jej nahrazují:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Balík %s nemá kandidáta pro instalaci"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Reinstalace %s není možná, protože nelze stáhnout.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s je již nejnovější verze.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Vydání „%s“ pro „%s“ nebylo nalezeno"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Verze „%s“ pro „%s“ nebyla nalezena"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Vybraná verze %s (%s) pro %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Nešlo vyhodnotit seznam zdrojových balíků %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Příkaz update neakceptuje žádné argumenty"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Neměli bychom mazat věci, nemůžu spustit AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1048,7 +1046,7 @@
 msgstr[1] ""
 "Následující balíky byly nainstalovány automaticky a již nejsou potřeba:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1058,11 +1056,11 @@
 msgstr[1] ""
 "Následující balíky byly nainstalovány automaticky a již nejsou potřeba:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Pro jejich odstranění použijte „apt-get autoremove“."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1080,43 +1078,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Následující informace vám mohou pomoci vyřešit tuto situaci:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Vnitřní chyba, AutoRemover pokazil věci"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Vnitřní chyba, AllUpgrade pokazil věci"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Nemohu najít úlohu %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Nemohu najít balík %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Pozn: vybírám %s pro regulární výraz „%s“\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s nastaven jako instalovaný ručně.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Pro opravení následujících můžete spustit „apt-get -f install“:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1124,7 +1117,7 @@
 "Nesplněné závislosti. Zkuste spustit „apt-get -f install“ bez balíků (nebo "
 "navrhněte řešení)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1135,133 +1128,148 @@
 "nemožnou situaci, nebo, pokud používáte nestabilní distribuci, že\n"
 "vyžadované balíky ještě nebyly vytvořeny nebo přesunuty z Příchozí fronty."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Poškozené balíky"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Následující extra balíky budou instalovány:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Navrhované balíky:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Doporučované balíky:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s nastaven jako instalovaný ručně.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Propočítávám aktualizaci... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Selhalo"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Hotovo"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Vnitřní chyba, řešitel problémů pokazil věci"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Nemohu zamknout adresář pro stahování"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Musíte zadat aspoň jeden balík, pro který se stáhnou zdrojové texty"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Nemohu najít zdrojový balík pro %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Přeskakuji dříve stažený soubor „%s“\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Na %s nemáte dostatek volného místa"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Potřebuji stáhnout %sB/%sB zdrojových archivů.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Potřebuji stáhnout %sB zdrojových archivů.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Stáhnout zdroj %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Stažení některých archivů selhalo."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Přeskakuji rozbalení již rozbaleného zdroje v %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Příkaz pro rozbalení „%s“ selhal.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Zkontrolujte, zda je nainstalován balíček „dpkg-dev“.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Příkaz pro sestavení „%s“ selhal.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Synovský proces selhal"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Musíte zadat alespoň jeden balík, pro který budou kontrolovány závislosti "
 "pro sestavení"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Nemohu získat závislosti pro sestavení %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s nemá žádné závislosti pro sestavení.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "%s závislost pro %s nemůže být splněna, protože balík %s nebyl nalezen"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1270,31 +1278,31 @@
 "%s závislost pro %s nemůže být splněna protože není k dispozici verze balíku "
 "%s, která odpovídá požadavku na verzi"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Selhalo splnění %s závislosti pro %s: Instalovaný balík %s je příliš nový"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Selhalo splnění %s závislosti pro %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Závislosti pro sestavení %s nemohly být splněny."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Chyba při zpracování závislostí pro sestavení"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Podporované moduly:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1627,8 +1635,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Nemohu číst %s"
@@ -1657,10 +1666,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Adresáře info a temp musí být na stejném souborovém systému"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Čtu seznamy balíků"
 
@@ -1876,170 +1884,170 @@
 msgid "Write error"
 msgstr "Chyba zápisu"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Nemohu vytvořit socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Nemohu připojit datový socket, čas spojení vypršel"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Nemohu připojit pasivní socket."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo nezískal naslouchající socket"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Nemohu navázat socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Nemohu naslouchat na socketu"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Nemohu určit jméno socketu"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Nemohu odeslat příkaz PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Neznámá rodina adres %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT selhal, server řekl: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Spojení datového socketu vypršelo"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Nemohu přijmout spojení"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problém s hashováním souboru"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Nemohu stáhnout soubor, server řekl „%s“"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Datový socket vypršel"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Přenos dat selhal, server řekl „%s“"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Dotaz"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Nemohu vyvolat "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Připojuji se k %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Nemohu vytvořit socket pro %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Nemohu navázat spojení na %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Nemohu se připojit k %s:%s (%s), čas spojení vypršel"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Nemohu se připojit k %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Připojuji se k %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nemohu zjistit „%s“"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Dočasné selhání při zjišťování „%s“"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Něco hodně ošklivého se přihodilo při zjišťování „%s:%s“ (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Nemohu se připojit k %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Přerušuji instalaci."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "Vnitřní chyba: Dobrý podpis, ale nemohu zjistit otisk klíče?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Byl zaznamenán nejméně jeden neplatný podpis. "
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Nepodařilo se spustit „%s“ pro ověření podpisu (je gpgv nainstalováno?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Neznámá chyba při spouštění gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Následující podpisy jsou neplatné:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2118,19 +2126,19 @@
 msgid "Error reading from server"
 msgstr "Chyba čtení ze serveru"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Nelze zmenšit soubor"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Špatné datové záhlaví"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Spojení selhalo"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Vnitřní chyba"
 
@@ -2196,7 +2204,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Výběr %s nenalezen"
@@ -2321,6 +2329,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Nemohu přejít do %s"
@@ -2504,7 +2513,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Nelze zapsat dočasný stavový soubor %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2637,7 +2646,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Nemohu opravit problémy, některé balíky držíte v porouchaném stavu."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2687,12 +2696,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Vložte prosím disk nazvaný „%s“ do mechaniky „%s“ a stiskněte enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Balíčkovací systém „%s“ není podporován"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Nebylo možno určit vhodný typ balíčkovacího systému"
 
@@ -2705,26 +2714,26 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Do sources.list musíte zadat „zdrojové“ URI"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Seznamy balíků nebo stavový soubor nemohly být zpracovány nebo otevřeny."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Pro nápravu těchto problémů můžete zkusit spustit apt-get update"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Neplatný záznam v souboru preferencí, žádné záhlaví balíku"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Nerozumím vypíchnutí typu %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Pro vypíchnutí nebyla zadána žádná (nebo nulová) priorita"
 
@@ -2813,32 +2822,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Nešlo vyhodnotit seznam zdrojových balíků %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Collecting File poskytuje"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Chyba IO při ukládání zdrojové cache"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "přejmenování selhalo, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Neshoda MD5 součtů"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Neshoda kontrolních součtů"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "K následujícím ID klíčů není dostupný veřejný klíč:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2847,7 +2881,7 @@
 "Nebyl jsem schopen nalézt soubor s balíkem %s. To by mohlo znamenat, že "
 "tento balík je třeba opravit ručně (kvůli chybějící architektuře)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2856,32 +2890,42 @@
 "Nebyl jsem schopen nalézt soubor s balíkem %s. Asi budete muset tento balík "
 "opravit ručně."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "Indexové soubory balíku jsou narušeny. Chybí pole Filename: u balíku %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Velikosti nesouhlasí"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Nelze zpracovat soubor %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Pozn: Vybírám %s místo %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Neplatná řádka v diverzním souboru: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Nelze zpracovat soubor %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2976,152 +3020,235 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Seznamy zdrojů na tomto disku jsou:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Zapsal jsem %i záznamů.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Zapsal jsem %i záznamů s chybějícími soubory (%i).\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Zapsal jsem %i záznamů s nesouhlasícími soubory (%i).\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Zapsal jsem %i záznamů s chybějícími (%i) a nesouhlasícími (%i) soubory.\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Otevírám konfigurační soubor %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Neshoda kontrolních součtů"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Pozn: vybírám %s pro regulární výraz „%s“\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Vybraná verze %s (%s) pro %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Instaluji %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Nastavuji %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Odstraňuji %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Kompletně odstraněn %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Spouštím poinstalační spouštěč %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Adresář „%s“ chybí"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Nemohu otevřít soubor %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Připravuji %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Rozbaluji %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Připravuji nastavení %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Nainstalován %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Připravuji odstranění %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Odstraněn %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Připravuji úplné odstranění %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Kompletně odstraněn %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "Nelze zapsat log, volání openpty() selhalo (/dev/pts není připojen?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Nemohu uzamknout list adresář"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3136,7 +3263,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Spojení bylo předčasně ukončeno"
 

=== modified file 'po/cy.po'
--- po/cy.po	2010-05-25 16:01:42 +0000
+++ po/cy.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: APT\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2005-06-06 13:46+0100\n"
 "Last-Translator: Dafydd Harries <daf@muse.19inch.net>\n"
 "Language-Team: Welsh <cy@pengwyn.linux.org.uk>\n"
@@ -14,166 +14,164 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Mae gan y pecyn %s fersiwn %s ddibyniaeth heb ei gwrdd:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Ni ellir lleoli'r pecyn %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 #, fuzzy
 msgid "Total package names: "
 msgstr "Cyfanswm Enwau Pecynnau : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Cyfanswm Enwau Pecynnau : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 #, fuzzy
 msgid "  Normal packages: "
 msgstr "  Pecynnau Normal: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 #, fuzzy
 msgid "  Pure virtual packages: "
 msgstr "  Pecynnau Cwbl Rhithwir: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 #, fuzzy
 msgid "  Single virtual packages: "
 msgstr "  Pecynnau Rhithwir Sengl: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 #, fuzzy
 msgid "  Mixed virtual packages: "
 msgstr "  Pecynnau Rhithwir Cymysg: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Ar Goll: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 #, fuzzy
 msgid "Total distinct versions: "
 msgstr "Cyfanswm Fersiynau Gwahanol: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "Cyfanswm Fersiynau Gwahanol: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 #, fuzzy
 msgid "Total dependencies: "
 msgstr "Cyfanswm Dibyniaethau: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 #, fuzzy
 msgid "Total ver/file relations: "
 msgstr "Cyfanswm perthyniadau fersiwn/ffeil: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "Cyfanswm perthyniadau fersiwn/ffeil: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 #, fuzzy
 msgid "Total Provides mappings: "
 msgstr "Cyfanswm Mapiau Darpariath: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 #, fuzzy
 msgid "Total globbed strings: "
 msgstr "Cyfanswm Llinynau Glob: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 #, fuzzy
 msgid "Total dependency version space: "
 msgstr "Cyfanswm gofod Fersiwn Dibyniaeth: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 #, fuzzy
 msgid "Total slack space: "
 msgstr "Cyfanswm gofod Slac: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 #, fuzzy
 msgid "Total space accounted for: "
 msgstr "Cyfanswm Gofod Cyfrifwyd: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Nid yw'r ffeil pecyn %s yn gydamseredig."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Rhaid i chi ddarparu un patrwm yn union"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Canfuwyd dim pecyn"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Ni ellir lleoli'r pecyn %s"
+
+#: cmdline/apt-cache.cc:1550
 #, fuzzy
 msgid "Package files:"
 msgstr "Ffeiliau Pecynnau:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Nid yw'r storfa yn gydamserol, ni ellir croesgyfeirio ffeil pecym"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 #, fuzzy
 msgid "Pinned packages:"
 msgstr "Pecynnau wedi eu Pinio:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(heb ganfod)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Wedi Sefydlu: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Ymgeisydd: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(dim)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 #, fuzzy
 msgid "  Package pin: "
 msgstr "  Pin Pecyn: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 #, fuzzy
 msgid "  Version table:"
 msgstr "  Tabl Fersiynnau:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s ar gyfer %s %s wedi ei grynhow ar %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -334,12 +332,12 @@
 "  -c=? Darllen y ffeil cyfluniad hwn\n"
 "  -o=? Gosod opsiwn cyfluniad mympwyol e.e. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Ni ellir ysgrifennu i %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Ni ellir cael fersiwn debconf. Ydi debconf wedi ei sefydlu?"
 
@@ -676,82 +674,82 @@
 msgid "Failed to rename %s to %s"
 msgstr "Methwyd ailenwi %s at %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "I"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Gwall crynhoi patrwm - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Mae gan y pecynnau canlynol ddibyniaethau heb eu bodloni:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "ond mae %s wedi ei sefydlu"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "ond mae %s yn mynd i gael ei sefydlu"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ond ni ellir ei sefydlu"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ond mae'n becyn rhithwir"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ond nid yw wedi ei sefydlu"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "ond nid yw'n mynd i gael ei sefydlu"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " neu"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Caiff y pecynnau NEWYDD canlynol eu sefydlu:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Caiff y pecynnau canlynol eu TYNNU:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 #, fuzzy
 msgid "The following packages have been kept back:"
 msgstr "Mae'r pecynnau canlynol wedi eu dal yn ôl"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 #, fuzzy
 msgid "The following packages will be upgraded:"
 msgstr "Caiff y pecynnau canlynol eu uwchraddio"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 #, fuzzy
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Caiff y pecynnau canlynol eu ISRADDIO"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Caiff y pecynnau wedi eu dal canlynol eu newid:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (oherwydd %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 #, fuzzy
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
@@ -761,144 +759,144 @@
 "NI DDYLIR gwneud hyn os nad ydych chi'n gwybod yn union beth rydych chi'n\n"
 "ei wneud!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu wedi uwchraddio, %lu newydd eu sefydlu, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu wedi ailsefydlu, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu wedi eu israddio, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu i'w tynnu a %lu heb eu uwchraddio.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu  heb eu sefydlu na tynnu'n gyflawn.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Yn cywiro dibyniaethau..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " wedi methu."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Ni ellir cywiro dibyniaethau"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Ni ellir bychanu y set uwchraddio"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Wedi Gorffen"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Efallai hoffech rhedeg 'apt-get -f install' er mwyn cywiro'r rhain."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dibyniaethau heb eu bodloni. Ceisiwch ddefnyddio -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 #, fuzzy
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "RHYBUDD: Ni ellir dilysu'r pecynnau canlynol yn ddiogel!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr ""
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 #, fuzzy
 msgid "Some packages could not be authenticated"
 msgstr "RHYBUDD: Ni ellir dilysu'r pecynnau canlynol yn ddiogel!"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Mae problemau a defnyddwyd -y heb --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 #, fuzzy
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Rhaid tynnu pecynnau on mae Tynnu wedi ei analluogi."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 #, fuzzy
 msgid "Internal error, Ordering didn't finish"
 msgstr "Gwall Mewnol wrth ychwanegu dargyfeiriad"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Methwyd darllen y rhestr ffynhonellau."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Mae angeyn cyrchu %sB/%sB o archifau.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Mae angen cyrchu %sB o archifau.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Ar ôl dadbacio defnyddir %sB o ofod disg ychwanegol.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Ar ôl dadbactio caiff %sB o ofod disg ei rhyddhau.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, fuzzy, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Does dim digon o le rhydd yn %s gennych"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Does dim digon o le rhydd gennych yn %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Penodwyd Syml Yn Unig ond nid yw hyn yn weithred syml."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ie, gwna fel rydw i'n dweud!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, fuzzy, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -909,29 +907,29 @@
 "Er mwyn mynd ymlaen, teipiwch y frawddeg '%s'\n"
 " ?]"
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Erthylu."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 #, fuzzy
 msgid "Do you want to continue [Y/n]? "
 msgstr "Ydych chi eisiau mynd ymlaen? [Y/n] "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Methwyd cyrchu %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Methodd rhai ffeiliau lawrlwytho"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Lawrlwytho yn gyflawn ac yn y modd lawrlwytho'n unig"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -939,20 +937,20 @@
 "Ni ellir cyrchu rhai archifau, efallai dylwch rhedeg apt-get update, neu "
 "geidio defnyddio --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "Ni chynhelir cyfnewid cyfrwng efo --fix-missing ar hyn o bryd"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Ni ellir cywiro pecynnau ar goll."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 #, fuzzy
 msgid "Aborting install."
 msgstr "Yn Erthylu'r Sefydliad."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -962,50 +960,50 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Sylwer, yn dewis %s yn hytrach na %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Yn hepgor %s, mae wedi ei sefydlu a nid yw uwchraddio wedi ei osod.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Yn hepgor %s, mae wedi ei sefydlu a nid yw uwchraddio wedi ei osod.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Nid yw'r pecyn %s wedi ei sefydlu, felly ni chaif ei dynnu\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Mae'r pecyn %s yn becyn rhithwir a ddarparir gan:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Sefydliwyd]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Fersiynau Posib"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Dylech ddewis un yn benodol i'w sefydlu."
 
 # FIXME: punctuation
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, fuzzy, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -1017,65 +1015,65 @@
 "gael ei uwchlwytho, cafodd ei ddarfod neu nid yw ar gael drwy gynnwys y\n"
 "ffeil sources.list.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Fodd bynnag, mae'r pecynnau canlynol yn cymryd ei le:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Does dim ymgeisydd sefydlu gan y pecyn %s"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Nid yw ailsefydlu %s yn bosib, gan ni ellir ei lawrlwytho.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "Mae %s y fersiwn mwyaf newydd eisioes.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Ni chanfuwyd y rhyddhad '%s' o '%s'"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Ni chanfuwyd y fersiwn '%s' o '%s' "
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Dewiswyd fersiwn %s (%s) ar gyfer %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Methwyd stat() o'r rhestr pecyn ffynhonell %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Nid yw'r gorchymyn diweddaru yn derbyn ymresymiadau"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1085,7 +1083,7 @@
 msgstr[0] "Caiff y pecynnau NEWYDD canlynol eu sefydlu:"
 msgstr[1] "Caiff y pecynnau NEWYDD canlynol eu sefydlu:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1093,11 +1091,11 @@
 msgstr[0] "Caiff y pecynnau NEWYDD canlynol eu sefydlu:"
 msgstr[1] "Caiff y pecynnau NEWYDD canlynol eu sefydlu:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1113,46 +1111,41 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Gall y wybodaeth canlynol gynorthwyo'n datrys y sefyllfa:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Gwall Mewnol, torrodd AllUpgrade bethau"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 #, fuzzy
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Gwall Mewnol, torrodd AllUpgrade bethau"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "Methwyd canfod pecyn %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Methwyd canfod pecyn %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Sylwer, yn dewis %s ar gyfer y patrwm '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "ond mae %s yn mynd i gael ei sefydlu"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Efallai hoffech rhedeg 'apt-get -f install' er mwyn cywiro'r rhain:"
 
 # FIXME
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1161,7 +1154,7 @@
 "pecyn (neu penodwch ddatrys)"
 
 # FIXME: needs commas
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1173,127 +1166,142 @@
 "ansefydlog, fod rhai pecynnau angenrheidiol heb gael eu creu eto neu\n"
 "heb gael eu symud allan o Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Pecynnau wedi torri"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Caiff y pecynnau canlynol ychwanegol eu sefydlu:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Pecynnau a awgrymmir:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Pecynnau a argymhellir:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "ond mae %s yn mynd i gael ei sefydlu"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 #, fuzzy
 msgid "Calculating upgrade... "
 msgstr "Yn Cyfrifo'r Uwchraddiad... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Methwyd"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Wedi Gorffen"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 #, fuzzy
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Gwall Mewnol, torrodd AllUpgrade bethau"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Ni ellir cloi'r cyfeiriadur lawrlwytho"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Rhaid penodi o leiaf un pecyn i gyrchi ffynhonell ar ei gyfer"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Ni ellir canfod pecyn ffynhonell ar gyfer %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, fuzzy, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Yn hepgor dadbacio y ffynhonell wedi ei dadbacio eisioes yn %s\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Does dim digon o le rhydd yn %s gennych"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Rhaid cyrchu %sB/%sB o archifau ffynhonell.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Rhaid cyrchu %sB o archifau ffynhonell.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, fuzzy, c-format
 msgid "Fetch source %s\n"
 msgstr "Cyrchu Ffynhonell %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Methwyd cyrchu rhai archifau."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Yn hepgor dadbacio y ffynhonell wedi ei dadbacio eisioes yn %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Methodd y gorchymyn dadbacio '%s'.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Methodd y gorchymyn adeiladu '%s'.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Methodd proses plentyn"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Rhaid penodi o leiaf un pecyn i wirio dibyniaethau adeiladu ar eu cyfer"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Ni ellir cyrchu manylion dibyniaeth adeiladu ar gyfer %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "Nid oes dibyniaethau adeiladu gan %s.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1302,7 +1310,7 @@
 "Ni ellir bodloni dibyniaeth %s ar gyfer %s oherwydd ni ellir canfod y pecyn %"
 "s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1311,34 +1319,34 @@
 "Ni ellir bodloni'r dibyniaeth %s ar gyfer %s oherwydd does dim fersiwn sydd "
 "ar gael o'r pecyn %s yn gallu bodloni'r gofynion ferswin"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Methwyd bodloni dibynniaeth %s am %s: Mae'r pecyn sefydliedig %s yn rhy "
 "newydd"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Methwyd bodloni dibyniaeth %s am %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Methwyd bodloni'r dibyniaethau adeiladu ar gyfer %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Methwyd prosesu dibyniaethau adeiladu"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 #, fuzzy
 msgid "Supported modules:"
 msgstr "Modylau a Gynhelir:"
 
 # FIXME: split
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1681,8 +1689,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Ni ellir darllen %s"
@@ -1711,10 +1720,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Rhaid i'r cyfeiriaduron 'info' a 'temp' for ar yr un system ffeiliau"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 #, fuzzy
 msgid "Reading package lists"
 msgstr "Yn Darllen Rhestrau Pecynnau"
@@ -1945,173 +1953,172 @@
 msgid "Write error"
 msgstr "Gwall ysgrifennu"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Methwyd creu soced"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Methwyd cysylltu soced data, goramserodd y cyslltiad"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 #, fuzzy
 msgid "Could not connect passive socket."
 msgstr "Methwyd cysylltu soced goddefol"
 
 # FIXME
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "Methodd getaddrinfo gael soced gwrando"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Methwyd rhwymo soced"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Methwyd gwrando ar y soced"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Methwyd canfod enw'r soced"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Methwyd danfod gorchymyn PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Teulu cyfeiriad anhysbys %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Methodd gorchymyn EPRT; meddai'r gweinydd: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Goramserodd cysylltiad y soced data"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Methwyd derbyn cysylltiad"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problem wrth stwnshio ffeil"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Methwyd cyrchu ffeil; meddai'r gweinydd '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Goramserodd soced data"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Methodd trosgludiad data; meddai'r gweinydd '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Ymholiad"
 
 # FIXME
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Methwyd gweithredu "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Yn cysylltu i %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Methwyd creu soced ar gyfer %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Ni ellir cychwyn y cysylltiad i %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Methwyd cysylltu i %s:%s (%s), goramserodd y cysylltiad"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Methwyd cysylltu i %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Yn cysylltu i %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Methwyd datrys '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Methiant dros dro yn datrys '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Digwyddodd rhywbweth hyll wrth ddatrys '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Methwyd cysylltu i %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Yn Erthylu'r Sefydliad."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr ""
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr ""
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 #, fuzzy
 msgid "The following signatures were invalid:\n"
 msgstr "Caiff y pecynnau canlynol ychwanegol eu sefydlu:"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2193,21 +2200,21 @@
 msgid "Error reading from server"
 msgstr "Gwall wrth ddarllen o'r gweinydd"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Methwyd ysgrifennu ffeil %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 #, fuzzy
 msgid "Bad header data"
 msgstr "Data pennawd gwael"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Methodd y cysylltiad"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Gwall mewnol"
 
@@ -2274,7 +2281,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Ni chanfuwyd y dewis %s"
@@ -2402,6 +2409,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Ni ellir newid i %s"
@@ -2592,7 +2600,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Methwyd ysgrifennu ffeil %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2735,7 +2743,7 @@
 msgstr ""
 "Ni ellir cywiro'r problemau gan eich bod chi wedi dal pecynnau torredig."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2788,12 +2796,12 @@
 " '%s'\n"
 "yn y gyrriant '%s' a gwasgwch Enter\n"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Ni chynhelir y system pecynnu '%s'"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 #, fuzzy
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Ni ellir canfod math system addas"
@@ -2808,27 +2816,27 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Rhaid i chi rhoi rhai URI 'source' yn eich ffeil sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Methwyd agor neu ramadegu'r ffeil rhestrau neu statws."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Efallai hoffech rhedege apt-get update er mwyn cywiro'r problemau hyn."
 
 # FIXME: literal
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Cofnod annilys yn y ffeil hoffterau, dim pennawd 'Package'"
 
 # FIXME: tense
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Methwyd daeall y math pin %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Dim blaenoriath (neu sero) wedi ei benodi ar gyfer pin"
 
@@ -2920,34 +2928,59 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Methwyd stat() o'r rhestr pecyn ffynhonell %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Yn Casglu Darpariaethau Ffeil"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Gwall M/A wrth gadw'r storfa ffynhonell"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "methwyd ailenwi, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Camgyfatebiaeth swm MD5"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "Camgyfatebiaeth swm MD5"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
 # FIXME: case
-#: apt-pkg/acquire-item.cc:1260
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2956,7 +2989,7 @@
 "Methais i leoli ffeila r gyfer y pecyn %s. Fa all hyn olygu bod rhaid i chi "
 "drwsio'r pecyn hyn a law. (Oherwydd pensaerniaeth coll.)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2965,33 +2998,44 @@
 "Methais i leoli ffeila r gyfer y pecyn %s. Fa all hyn olygu bod rhaid i chi "
 "drwsio'r pecyn hyn a law."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "Mae'r ffeiliau mynegai pecyn yn llygr. Dim maes Filename: gan y pecyn %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Camgyfatebiaeth maint"
 
 # FIXME: number?
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Ni ellir gramadegu ffeil becynnau %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Sylwer, yn dewis %s yn hytrach na %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Llinell annilys yn y ffeil dargyfeirio: %s"
+
+# FIXME: number?
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Ni ellir gramadegu ffeil becynnau %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3084,151 +3128,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Yn agor y ffeil cyfluniad %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Camgyfatebiaeth swm MD5"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Sylwer, yn dewis %s ar gyfer y patrwm '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Dewiswyd fersiwn %s (%s) ar gyfer %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "  Wedi Sefydlu: "
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, fuzzy, c-format
 msgid "Configuring %s"
 msgstr "Yn cysylltu i %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, fuzzy, c-format
 msgid "Removing %s"
 msgstr "Yn agor %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Methwyd dileu %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "Mae'r cyfeiriadur rhestrau %spartial ar goll."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Methwyd agor ffeil %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, fuzzy, c-format
 msgid "Preparing %s"
 msgstr "Yn agor %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, fuzzy, c-format
 msgid "Unpacking %s"
 msgstr "Yn agor %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, fuzzy, c-format
 msgid "Preparing to configure %s"
 msgstr "Yn agor y ffeil cyfluniad %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, fuzzy, c-format
 msgid "Installed %s"
 msgstr "  Wedi Sefydlu: "
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, fuzzy, c-format
 msgid "Removed %s"
 msgstr "Argymell"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, fuzzy, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Yn agor y ffeil cyfluniad %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, fuzzy, c-format
 msgid "Completely removed %s"
 msgstr "Methwyd dileu %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Ni ellir cloi'r cyfeiriadur rhestr"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3243,7 +3370,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Caewyd y cysylltiad yn gynnar"
 

=== modified file 'po/da.po'
--- po/da.po	2010-05-25 16:01:42 +0000
+++ po/da.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: apt-da\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2007-09-06 21:40+0200\n"
 "Last-Translator: Claus Hindsgaul <claus.hindsgaul@gmail.com>\n"
 "Language-Team: Danish\n"
@@ -19,149 +19,147 @@
 "X-Generator: KBabel 1.11.4\n"
 "Plural-Forms:  nplurals=2; plural=(n != 1);\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "<Pakken %s version %s har en uopfyldt afhngighed:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Kunne ikke lokalisere pakken %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Totale pakkenavne : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Totale pakkenavne : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normale pakker: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Rene virtuelle pakker: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Enkelte virtuelle pakker: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Blandede virtuelle pakker: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Manglende: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Totale forskellige versioner: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Sammenlagt forskellige beskrivelser: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Sammenlagt afhngigheder: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Sammenlagt version/fil-relationer: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Sammenlagt version/fil-relationer: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Sammenlagt 'Tilbyder'-markeringer: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Totalle sgemnsterstrenge: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Total afhngighedsversions-plads: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Total 'Slack'-plads: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Total plads, der kan gres rede for: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Pakkefilen %s er ude af trit."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
-msgstr "Du skal angive njagtig t mnster"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
+msgstr "Du skal angive mindst t filnavn"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Fandt ingen pakker"
 
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Kunne ikke lokalisere pakken %s"
+
 # Overskriften til apt-cache policy,
 # forkorter "Package" vk. CH
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Pakkefiler:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Mellemlageret er ude af trit, kan ikke krydsreferere en pakkefil"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "'Pinned' pakker:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(ikke fundet)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Installeret: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidat: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ingen)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Pakke-pin: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Versionstabel:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s for %s oversat %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -316,12 +314,12 @@
 "  -c=? Ls denne opstningsfil\n"
 "  -o=? Angiv et opstningstilvalg. F.eks. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Kunne ikke skrive til %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Kan ikke finde debconfs version. Er debconf installeret?"
 
@@ -657,79 +655,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Kunne ikke omdbe %s til %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "J"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Fejl ved tolkning af regulrt udtryk - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Flgende pakker har uopfyldte afhngigheder:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "men %s er installeret"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "men %s forventes installeret"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "men den kan ikke installeres"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "men det er en virtuel pakke"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "men den er ikke installeret"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "men den bliver ikke installeret"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " eller"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Flgende NYE pakker vil blive installeret:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Flgende pakker vil blive AFINSTALLERET:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Flgende pakker er blevet holdt tilbage:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Flgende pakker vil blive opgraderet:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Flgende pakker vil blive NEDGRADERET:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Flgende tilbageholdte pakker vil blive ndret:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (grundet %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -737,140 +735,140 @@
 "ADVARSEL: Flgende essentielle pakker vil blive afinstalleret\n"
 "Dette br IKKE ske medmindre du er helt klar over, hvad du laver!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu opgraderes, %lu nyinstalleres, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu geninstalleres, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu nedgraderes, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu afinstalleres og %lu opgraderes ikke.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu ikke fuldstndigt installerede eller afinstallerede.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Retter afhngigheder..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " mislykkedes."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Kunne ikke rette afhngigheder"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Kunne ikke minimere opgraderingssttet"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Frdig"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Du kan muligvis rette dette ved at kre 'apt-get -f install'."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Uopfyldte afhngigheder. Prv med -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ADVARSEL: Flgende pakkers autenticitet kunne ikke verificeres!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Autentifikationsadvarsel tilsidesat.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Installr disse pakker uden verifikation (y/N)? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Nogle pakker kunne ikke autentificeres"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Der er problemer og -y blev brugt uden --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Intern fejl. InstallPackages blev kaldt med delagte pakker!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Pakker skal afinstalleres, men Remove er deaktiveret."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Intern fejl. Sortering blev ikke fuldfrt"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Listen med kilder kunne ikke lses."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "Mystisk.. Strrelserne passede ikke, skriv til apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "%sB/%sB skal hentes fra arkiverne.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "%sB skal hentes fra arkiverne.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Efter udpakning vil %sB yderligere diskplads vre brugt.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Efter udpakning vil %sB diskplads blive frigjort.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Kunne ikke bestemme ledig plads i %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Du har ikke nok ledig plads i %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "'Trivial Only' angivet, men dette er ikke en triviel handling."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ja, gr som jeg siger!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -881,28 +879,28 @@
 "For at fortstte, skal du skrive '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Afbryder."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Vil du fortstte [J/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Kunne ikke hente %s %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Nedhentningen af filer mislykkedes"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Nedhentning afsluttet i 'hent-kun'-tilstand"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -910,19 +908,19 @@
 "Kunne ikke hente nogle af arkiverne. Prv evt. at kre 'apt-get update' "
 "eller prv med --fix-missing."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing og medieskift understttes endnu ikke"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Kunne ikke rette manglende pakker."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Afbryder installationen."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -932,53 +930,53 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Bemrk, at %s vlges fremfor %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Overspringer %s, da den allerede er installeret og opgradering er "
 "deaktiveret.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Overspringer %s, da den allerede er installeret og opgradering er "
 "deaktiveret.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Pakken %s er ikke installeret, s den afinstalleres ikke\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Pakken %s er en virtuel pakke, der kan leveres af:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Installeret]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Kandidatversioner"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Du br eksplicit vlge en at installere."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -989,67 +987,67 @@
 "anden pakke. Det kan betyde at denne pakke blevet overfldiggjort eller \n"
 "kun kan hentes fra andre kilder\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Dog kan flgende pakker erstatte den:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Pakken %s har ingen installationskandidat"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Geninstallering af %s er ikke mulig, da den ikke kan hentes.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s er i forvejen den nyeste version.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Udgaven '%s' for '%s' blev ikke fundet"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Versionen '%s' for '%s' blev ikke fundet"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Valgte version %s (%s) af %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Kunne ikke finde kildepakkelisten %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "'update'-kommandoen benytter ingen parametre"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Det er ikke meningen, at vi skal slette ting og sager, kan ikke starte "
 "AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1061,7 +1059,7 @@
 msgstr[1] ""
 "Flgende pakker blev installeret automatisk, og behves ikke lngere:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1071,11 +1069,11 @@
 msgstr[1] ""
 "Flgende pakker blev installeret automatisk, og behves ikke lngere:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Brug 'apt-get autoremove' til at fjerne dem."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1093,43 +1091,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Flgende oplysninger kan hjlpe dig med at klare situationen:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Intern fejl. AutoRemover delagde noget"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Intern fejl, AllUpgrade delagde noget"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Kunne ikke finde opgaven %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Kunne ikke finde pakken %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Bemrk, vlger %s som regulrt udtryk '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s sat til manuelt installeret.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Du kan muligvis rette det ved at kre 'apt-get -f install':"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1137,7 +1130,7 @@
 "Uopfyldte afhngigheder. Prv 'apt-get -f install' uden pakker (eller angiv "
 "en lsning)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1148,124 +1141,139 @@
 "en umulig situation eller bruger den ustabile distribution, hvor enkelte\n"
 "pakker endnu ikke er lavet eller gjort tilgngelige."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "delagte pakker"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Flgende yderligere pakker vil blive installeret:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Foreslede pakker:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Anbefalede pakker:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s sat til manuelt installeret.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Beregner opgraderingen... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Mislykkedes"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Frdig"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Intern fejl. Problemlseren delagde noget"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Kunne ikke lse nedhentningsmappen"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Du skal angive mindst n pakke at hente kildeteksten til"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Kunne ikke finde kildetekstpakken for %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Overspringer allerede hentet fil '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Du har ikke nok ledig plads i %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "%sB/%sB skal hentes fra kildetekst-arkiverne.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "%sB skal hentes fra kildetekst-arkiverne.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Henter kildetekst %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Nogle arkiver kunne ikke hentes."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Overspringer udpakning af allerede udpakket kildetekst i %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Udpakningskommandoen '%s' fejlede.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Tjek om pakken 'dpkg-dev' er installeret.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Opbygningskommandoen '%s' fejlede.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Barneprocessen fejlede"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "Skal angive mindst n pakke at tjekke opbygningsafhngigheder for"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Kunne ikke hente oplysninger om opbygningsafhngigheder for %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s har ingen opbygningsafhngigheder.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1273,7 +1281,7 @@
 msgstr ""
 "%s-afhngigheden for %s kan ikke opfyldes, da pakken %s ikke blev fundet"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1282,32 +1290,32 @@
 "%s-afhngigheden for %s kan ikke opfyldes, da ingen af de tilgngelige "
 "udgaver af pakken %s kan tilfredsstille versions-kravene"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Kunne ikke opfylde %s-afhngigheden for %s: Den installerede pakke %s er for "
 "ny"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Kunne ikke opfylde %s-afhngigheden for %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Opbygningsafhngigheden for %s kunne ikke opfyldes."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Kunne ikke behandler opbygningsafhngighederne"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Understttede moduler:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1645,8 +1653,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Kunne ikke lse %s"
@@ -1675,10 +1684,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Mapperne info og temp skal ligge i samme filsystem"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Indlser pakkelisterne"
 
@@ -1896,171 +1904,171 @@
 msgid "Write error"
 msgstr "Skrivefejl"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Kunne ikke oprette sokkel"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Kunne ikke forbinde datasokkel, tidsudlb p forbindelsen"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Kunne ikke forbinde passiv sokkel."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo kunne ikke f en lyttesokkel"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Kunne ikke tilknytte en sokkel"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Kunne ikke lytte p soklen"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Kunne ikke finde soklens navn"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Kunne ikke sende PORT-kommando"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Ukendt adressefamilie %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT mislykkedes. Serveren sagde: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Tidsudlb p datasokkel-forbindelse"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Kunne ikke acceptere forbindelse"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problem ved \"hashing\" af fil"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Kunne ikke hente fil. Serveren sagde '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Tidsudlb ved datasokkel"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Dataoverfrsel mislykkedes, serveren sagde '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Foresprgsel"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Kunne ikke udfre "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Forbinder til %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Kunne ikke oprette sokkel til %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Kan ikke oprette forbindelse til %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Kunne ikke forbinde til %s:%s (%s) grundet tidsudlb"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Kunne ikke forbinde til %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Forbinder til %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Kunne ikke omstte navnet '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Midlertidig fejl ved omstning af navnet '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Der skete noget underligt under navneomstning af '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Kunne ikke forbinde til %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Afbryder installationen."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Intern fejl: Gyldig signatur, men kunne ikke afgre ngle-fingeraftryk?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Stdte p mindst n ugyldig signatur."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Kunne ikke kre '%s' for at verificere signaturen (er gpgv installeret?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Ukendt fejl ved krsel af gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Flgende signaturer var ugyldige:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2140,20 +2148,20 @@
 msgid "Error reading from server"
 msgstr "Fejl ved lsning fra server"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Kunne ikke skrive filen %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Ugyldige hoved-data"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Forbindelsen mislykkedes"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Intern fejl"
 
@@ -2219,7 +2227,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Det valgte %s blev ikke fundet"
@@ -2342,6 +2350,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Kunne ikke skifte til %s"
@@ -2525,7 +2534,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Kunne ikke skrive den midlertidige StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, fuzzy, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr "Intern fejl. Kunne ikke tolke pakkeindgangen"
@@ -2661,7 +2670,7 @@
 msgstr ""
 "Kunne ikke korrigere problemerne, da du har tilbageholdt delagte pakker."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2711,12 +2720,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Indst disken med navnet: '%s' i drevet '%s' og tryk retur."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Pakkesystemet '%s' understttes ikke"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Kunne ikke bestemme en passende pakkesystemtype"
 
@@ -2729,25 +2738,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Du skal have nogle 'source'-URI'er i din sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Pakkelisterne eller statusfilen kunne ikke tolkes eller bnes."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Du kan muligvis rette problemet ved at kre 'apt-get update'"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Ugyldig indgang i indstillingsfilen. Pakkehovedet mangler"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Kunne ikke forst pin-type %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Ingen prioritet (eller prioritet nul) angivet ved pin"
 
@@ -2838,34 +2847,59 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Kunne ikke finde kildepakkelisten %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Samler filudbud"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IO-fejl ved gemning af kilde-mellemlageret"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "omdbning mislykkedes, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum stemmer ikke"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "MD5Sum stemmer ikke"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Der er ingen tilgngelige offentlige ngler for flgende ngle-ID'er:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2874,7 +2908,7 @@
 "Jeg kunne ikke lokalisere filen til %s-pakken. Det betyder muligvis at du er "
 "ndt til manuelt at reparere denne pakke. (grundet manglende arch)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2883,31 +2917,41 @@
 "Jeg kunne ikke lokalisere filen til %s-pakken. Det betyder muligvis at du er "
 "ndt til manuelt at reparere denne pakke."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "Pakkeindeksfilerne er i stykker. Intet 'Filename:'-felt for pakken %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Strrelsen stemmer ikke"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Kunne ikke tolke pakkefilen %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Bemrk, at %s vlges fremfor %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Ugyldig linje i omrokeringsfilen: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Kunne ikke tolke pakkefilen %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3003,151 +3047,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Denne disk har flgende kildeliste-indgange:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Skrev %i poster.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Skrev %i poster med %i manglende filer.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Skrev %i poster med %i ikke-trufne filer\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Skrev %i poster med %i manglende filer og %i ikke-trufne filer\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "bner konfigurationsfilen %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "MD5Sum stemmer ikke"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Bemrk, vlger %s som regulrt udtryk '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Valgte version %s (%s) af %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "Installerede %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Stter %s op"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Fjerner %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Fjernede %s helt"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "Listemappen %spartial mangler."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Kunne ikke bne filen %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Klargr %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Pakker %s ud"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Gr klar til at stte %s op"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Installerede %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Gr klar til afinstallation af %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Fjernede %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Gr klar til at fjerne %s helt"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Fjernede %s helt"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Kunne ikke lse listemappen"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3162,10 +3289,13 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Forbindelsen lukkedes for hurtigt"
 
+#~ msgid "You must give exactly one pattern"
+#~ msgstr "Du skal angive njagtig t mnster"
+
 #~ msgid "E: Argument list from Acquire::gpgv::Options too long. Exiting."
 #~ msgstr ""
 #~ "F: Argumentlisten fra Acquire::gpgv::Options er for lang. Afslutter."
@@ -3301,9 +3431,6 @@
 #~ msgid "Unimplemented"
 #~ msgstr "Ikke implementeret"
 
-#~ msgid "You must give at least one file name"
-#~ msgstr "Du skal angive mindst t filnavn"
-
 #~ msgid "Generating cache"
 #~ msgstr "Opretter mellemlager"
 

=== modified file 'po/de.po'
--- po/de.po	2010-05-25 16:01:42 +0000
+++ po/de.po	2010-06-10 14:02:22 +0000
@@ -10,7 +10,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.21\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2010-02-27 13:17+0100\n"
 "Last-Translator: Holger Wansing <linux@wansing-online.de>\n"
 "Language-Team: Debian German <debian-l10n-german@lists.debian.org>\n"
@@ -19,147 +19,145 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);>\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Paket %s Version %s hat eine nicht erfüllte Abhängigkeit:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Paket %s kann nicht gefunden werden"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Gesamtzahl an Paketnamen: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Gesamtzahl an Paketnamen: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  davon gewöhnliche Pakete: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  davon rein virtuelle Pakete: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  davon einzelne virtuelle Pakete: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  davon gemischte virtuelle Pakete: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  davon fehlend: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Gesamtzahl an unterschiedlichen Versionen: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Gesamtzahl an unterschiedlichen Beschreibungen: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Gesamtzahl an Abhängigkeiten: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Gesamtzahl an Version/Datei-Beziehungen: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Gesamtzahl an Beschreibung/Datei-Beziehungen: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Gesamtzahl an Bereitstellungen: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Gesamtzahl an Mustern: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Gesamtmenge des Abhängigkeits-/Versionsspeichers: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Gesamtmenge an Slack: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Gesamtmenge an Speicher: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Paketdatei %s ist nicht synchronisiert."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Sie müssen genau ein Muster angeben"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Keine Pakete gefunden"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Paket %s kann nicht gefunden werden"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Paketdateien:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Cache ist nicht synchron, Querverweisen einer Paketdatei nicht möglich"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Mit Pinning verwaltete Pakete:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(nicht gefunden)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Installiert: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidat: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(keine)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Paket-Pinning: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Versionstabelle:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s für %s, kompiliert am %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -319,12 +317,12 @@
 "  -c=?  Diese Konfigurationsdatei lesen\n"
 "  -o=?  Eine beliebige Konfigurationsoption setzen, z.B. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Schreiben nach %s nicht möglich"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr ""
 "Debconf-Version konnte nicht ermittelt werden. Ist debconf installiert?"
@@ -669,80 +667,80 @@
 msgid "Failed to rename %s to %s"
 msgstr "%s konnte nicht in %s umbenannt werden"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "J"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Fehler beim Kompilieren eines regulären Ausdrucks - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Die folgenden Pakete haben nicht erfüllte Abhängigkeiten:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "aber %s ist installiert"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "aber %s soll installiert werden"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ist aber nicht installierbar"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ist aber ein virtuelles Paket"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ist aber nicht installiert"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "soll aber nicht installiert werden"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " oder"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Die folgenden NEUEN Pakete werden installiert:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Die folgenden Pakete werden ENTFERNT:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Die folgenden Pakete sind zurückgehalten worden:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Die folgenden Pakete werden aktualisiert (Upgrade):"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr ""
 "Die folgenden Pakete werden DEAKTUALISIERT (ältere Version wird installiert):"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Die folgenden gehaltenen Pakete werden verändert:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (wegen %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -750,142 +748,142 @@
 "WARNUNG: Die folgenden essentiellen Pakete werden entfernt.\n"
 "Dies sollte NICHT geschehen, außer Sie wissen genau, was Sie tun!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu aktualisiert, %lu neu installiert, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu erneut installiert, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu deaktualisiert, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu zu entfernen und %lu nicht aktualisiert.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu nicht vollständig installiert oder entfernt.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Abhängigkeiten werden korrigiert..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " fehlgeschlagen."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Abhängigkeiten konnten nicht korrigiert werden"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Menge der zu aktualisierenden Pakete konnte nicht minimiert werden"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Fertig"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Probieren Sie »apt-get -f install«, um dies zu korrigieren."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Nicht-erfüllte Abhängigkeiten. Versuchen Sie, -f zu benutzen."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "WARNUNG: Die folgenden Pakete können nicht authentifiziert werden!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Authentifizierungswarnung überstimmt.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Diese Pakete ohne Überprüfung installieren [j/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Einige Pakete konnten nicht authentifiziert werden"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Es gab Probleme und -y wurde ohne --force-yes verwendet"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Interner Fehler, InstallPackages mit defekten Paketen aufgerufen!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Pakete müssen entfernt werden, aber Entfernen ist abgeschaltet."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Interner Fehler, Anordnung beendete nicht"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Die Liste der Quellen konnte nicht gelesen werden."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Wie merkwürdig ... die Größen haben nicht übereingestimmt; schreiben Sie "
 "eine E-Mail an apt@packages.debian.org (auf Englisch bitte)."
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Es müssen noch %s B von %s B an Archiven heruntergeladen werden.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Es müssen %s B an Archiven heruntergeladen werden.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Nach dieser Operation werden %s B Plattenplatz zusätzlich benutzt.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Nach dieser Operation werden %s B Plattenplatz freigegeben.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Freier Platz in %s konnte nicht bestimmt werden"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Sie haben nicht genug Platz in %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "»Nur triviale« angegeben, aber dies ist keine triviale Operation."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ja, tue was ich sage!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -896,28 +894,28 @@
 "Zum Fortfahren geben Sie bitte »%s« ein.\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Abbruch."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Möchten Sie fortfahren [J/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Fehlschlag beim Holen von %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Einige Dateien konnten nicht heruntergeladen werden"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Herunterladen abgeschlossen; Nur-Herunterladen-Modus aktiv"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -925,19 +923,19 @@
 "Einige Archive konnten nicht heruntergeladen werden; vielleicht »apt-get "
 "update« ausführen oder mit »--fix-missing« probieren?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing und Wechselmedien werden derzeit nicht unterstützt"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Fehlende Pakete konnten nicht korrigiert werden."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Installation abgebrochen."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -947,53 +945,53 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Hinweis: %s wird an Stelle von %s gewählt\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "%s wird übersprungen; es ist schon installiert und »upgrade« ist nicht "
 "gesetzt.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "%s wird übersprungen; es ist schon installiert und »upgrade« ist nicht "
 "gesetzt.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Paket %s ist nicht installiert, wird also auch nicht entfernt.\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Paket %s ist ein virtuelles Paket, das bereitgestellt wird von:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Installiert]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Mögliche Versionen"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Sie sollten eines explizit zum Installieren auswählen."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -1004,68 +1002,68 @@
 "referenziert. Das kann heißen, dass das Paket fehlt, dass es veraltet\n"
 "ist oder nur aus einer anderen Quelle verfügbar ist.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Doch die folgenden Pakete ersetzen es:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Paket %s hat keinen Installationskandidaten"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 "Erneute Installation von %s ist nicht möglich,\n"
 "es kann nicht heruntergeladen werden.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s ist schon die neueste Version.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Veröffentlichung »%s« für »%s« konnte nicht gefunden werden"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Version »%s« für »%s« konnte nicht gefunden werden"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Gewählte Version %s (%s) für %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr "Nicht verfügbare Veröffentlichung »%s« von Paket »%s« wird ignoriert"
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Als Quellpaket wird »%s« statt »%s« gewählt\n"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr "Nicht verfügbare Version »%s« von Paket »%s« wird ignoriert"
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Der Befehl »update« akzeptiert keine Argumente"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Es soll nichts gelöscht werden, AutoRemover kann nicht gestartet werden"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1079,7 +1077,7 @@
 "Die folgenden Pakete wurden automatisch installiert und werden nicht länger "
 "benötigt:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1089,11 +1087,11 @@
 msgstr[1] ""
 "%lu Pakete wurden automatisch installiert und werden nicht mehr benötigt.\n"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Verwenden Sie »apt-get autoremove«, um sie zu entfernen."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1112,44 +1110,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr ""
 "Die folgenden Informationen helfen Ihnen vielleicht, die Situation zu lösen:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Interner Fehler, AutoRemover hat etwas beschädigt"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Interner Fehler, AllUpgrade hat etwas beschädigt"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Task %s konnte nicht gefunden werden"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Paket %s konnte nicht gefunden werden"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Hinweis: %s wird für regulären Ausdruck »%s« gewählt.\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s wurde als manuell installiert festgelegt.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Probieren Sie »apt-get -f install«, um dies zu korrigieren:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1157,7 +1150,7 @@
 "Nicht erfüllte Abhängigkeiten. Versuchen Sie »apt-get -f install« ohne Angabe "
 "eines Pakets (oder geben Sie eine Lösung an)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1169,130 +1162,145 @@
 "Unstable-Distribution verwenden, dass einige erforderliche Pakete noch\n"
 "nicht erstellt wurden oder Incoming noch nicht verlassen haben."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Beschädigte Pakete"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Die folgenden zusätzlichen Pakete werden installiert:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Vorgeschlagene Pakete:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Empfohlene Pakete:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s wurde als manuell installiert festgelegt.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Paketaktualisierung (Upgrade) wird berechnet... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Fehlgeschlagen"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Fertig"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Interner Fehler, der Problemlöser hat etwas beschädigt"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Das Downloadverzeichnis konnte nicht gesperrt werden."
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "Es muss mindestens ein Paket angegeben werden, dessen Quellen geholt werden "
 "sollen"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Quellpaket für %s kann nicht gefunden werden"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Bereits heruntergeladene Datei »%s« wird übersprungen.\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Sie haben nicht genügend freien Speicherplatz in %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr ""
 "Es müssen noch %s B von %s B an Quellarchiven heruntergeladen werden.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Es müssen %s B an Quellarchiven heruntergeladen werden.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Quelle %s wird heruntergeladen.\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Einige Archive konnten nicht heruntergeladen werden."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Das Entpacken der bereits entpackten Quelle in %s wird übersprungen.\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Entpackbefehl »%s« fehlgeschlagen.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Überprüfen Sie, ob das Paket »dpkg-dev« installiert ist.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Build-Befehl »%s« fehlgeschlagen.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Kindprozess fehlgeschlagen"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Es muss mindestens ein Paket angegeben werden, dessen Bauabhängigkeiten "
 "überprüft werden sollen."
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr ""
 "Informationen zu Bauabhängigkeiten für %s konnten nicht gefunden werden."
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s hat keine Bauabhängigkeiten.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1301,7 +1309,7 @@
 "»%s«-Abhängigkeit für %s kann nicht erfüllt werden, da Paket %s nicht "
 "gefunden werden kann."
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1310,32 +1318,32 @@
 "»%s«-Abhängigkeit für %s kann nicht erfüllt werden, da keine verfügbare "
 "Version des Pakets %s die Versionsanforderungen erfüllen kann."
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "»%s«-Abhängigkeit für %s kann nicht erfüllt werden: Installiertes Paket %s "
 "ist zu neu."
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "»%s«-Abhängigkeit für %s konnte nicht erfüllt werden: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Bauabhängigkeiten für %s konnten nicht erfüllt werden."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Verarbeitung der Bauabhängigkeiten fehlgeschlagen"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Unterstützte Module:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1682,8 +1690,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "%s kann nicht gelesen werden"
@@ -1713,10 +1722,9 @@
 msgstr ""
 "Die »info«- und »temp«-Verzeichnisse müssen in demselben Dateisystem liegen"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Paketlisten werden gelesen"
 
@@ -1936,177 +1944,177 @@
 msgid "Write error"
 msgstr "Schreibfehler"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Socket konnte nicht erzeugt werden"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Daten-Socket konnte wegen Zeitüberschreitung nicht verbunden werden"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Passiver Socket konnte nicht verbunden werden."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr ""
 "Von der Funktion getaddrinfo wurde kein auf Verbindungen wartender Socket "
 "gefunden"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Verbindung des Sockets nicht möglich"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Warten auf Verbindungen auf dem Socket nicht möglich"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Name des Sockets konnte nicht bestimmt werden"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "PORT-Befehl konnte nicht gesendet werden"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Unbekannte Adressfamilie %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Befehl EPRT fehlgeschlagen: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Zeitüberschreitung bei Datenverbindungsaufbau"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Verbindung konnte nicht angenommen werden"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Bei Bestimmung des Hashwertes einer Datei trat ein Problem auf"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Datei konnte nicht heruntergeladen werden; Server meldet: »%s«"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Zeitüberschreitung bei Datenverbindung"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Datenübertragung fehlgeschlagen; Server meldet: »%s«"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Abfrage"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Aufruf nicht möglich: "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Verbindung mit %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Socket für %s konnte nicht erzeugt werden (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Verbindung mit %s:%s kann nicht aufgebaut werden (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr ""
 "Verbindung mit %s:%s konnte nicht aufgebaut werden (%s), eine "
 "Zeitüberschreitung trat auf"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Verbindung mit %s:%s nicht möglich (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Verbindung mit %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "»%s« konnte nicht aufgelöst werden"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Temporärer Fehlschlag beim Auflösen von »%s«"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Beim Auflösen von »%s:%s« ist etwas Schlimmes passiert (%i - %s)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Verbindung mit %s:%s nicht möglich:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, c-format
 msgid "No keyring installed in %s."
 msgstr "Kein Schlüsselring in %s installiert."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Interner Fehler: Gültige Signatur, Fingerabdruck des Schlüssels konnte "
 "jedoch nicht ermittelt werden?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Mindestens eine ungültige Signatur wurde entdeckt."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "»%s« zur Überprüfung der Signatur konnte nicht ausgeführt werden (ist gpgv "
 "installiert?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Unbekannter Fehler beim Ausführen von gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Die folgenden Signaturen waren ungültig:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2189,19 +2197,19 @@
 msgid "Error reading from server"
 msgstr "Fehler beim Lesen vom Server"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Datei konnte nicht eingekürzt werden"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Fehlerhafte Kopfzeilendaten"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Verbindung fehlgeschlagen"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Interner Fehler"
 
@@ -2269,7 +2277,7 @@
 msgid "%lis"
 msgstr "%li s"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Auswahl %s nicht gefunden"
@@ -2395,6 +2403,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Es konnte nicht nach %s gewechselt werden"
@@ -2580,7 +2589,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Temporäres StateFile %s konnte nicht geschrieben werden"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2722,7 +2731,7 @@
 msgstr ""
 "Probleme können nicht korrigiert werden, Sie haben gehaltene defekte Pakete."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2774,12 +2783,12 @@
 "Bitte legen Sie das Medium mit dem Namen »%s« in Laufwerk »%s« ein und drücken "
 "Sie die Eingabetaste (Enter)."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Paketierungssystem »%s« wird nicht unterstützt"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Bestimmung eines passenden Paketierungssystemtyps nicht möglich"
 
@@ -2794,28 +2803,28 @@
 "Sie müssen einige »source«-URIs für Quellpakete in die sources.list-Datei "
 "eintragen"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Die Paketliste oder die Statusdatei konnte nicht eingelesen oder geöffnet "
 "werden."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Probieren Sie »apt-get update«, um diese Probleme zu korrigieren"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "Ungültiger Eintrag in Einstellungsdatei %s, keine »Package«-Kopfzeile(n)"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Pinning-Typ %s kann nicht interpretiert werden"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Keine Priorität (oder Null) für Pin angegeben"
 
@@ -2913,33 +2922,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "»stat« konnte nicht auf die Liste %s der Quellpakete ausgeführt werden"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Sammeln der angebotenen Funktionalitäten (Provides) aus den Dateien"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "E/A-Fehler beim Speichern des Quell-Caches"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "Umbenennen fehlgeschlagen, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5-Summe stimmt nicht überein"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash-Summe stimmt nicht überein"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Es gibt keine öffentlichen Schlüssel für die folgenden Schlüssel-IDs:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2948,7 +2982,7 @@
 "Es konnte keine Datei für Paket %s gefunden werden. Das könnte heißen, dass "
 "Sie dieses Paket von Hand korrigieren müssen (aufgrund fehlender Architektur)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2957,32 +2991,42 @@
 "Es konnte keine Datei für Paket %s gefunden werden. Das könnte heißen, dass "
 "Sie dieses Paket von Hand korrigieren müssen."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "Die Paketindexdateien sind beschädigt: Kein Filename:-Feld für Paket %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Größe stimmt nicht überein"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Release-Datei %s kann nicht verarbeitet werden"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "Keine Bereiche (Sections) in Release-Datei %s"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "Kein Hash-Eintrag in Release-Datei %s"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Kein Hash-Eintrag in Release-Datei %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Kein Hash-Eintrag in Release-Datei %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3079,134 +3123,203 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Quelllisteneinträge für dieses Medium sind:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Es wurden %i Datensätze geschrieben.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Es wurden %i Datensätze mit %i fehlenden Dateien geschrieben.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Es wurden %i Datensätze mit %i nicht passenden Dateien geschrieben.\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Es wurden %i Datensätze mit %i fehlenden und %i nicht passenden Dateien "
 "geschrieben.\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Nicht vorhandene Datei %s wird übersprungen"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr "Authentifizierungs-Datensatz konnte nicht gefunden werden für: %s"
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash-Summe stimmt nicht überein für: %s"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Hinweis: %s wird für regulären Ausdruck »%s« gewählt.\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Gewählte Version %s (%s) für %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "%s wird installiert"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s wird konfiguriert"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s wird entfernt"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, c-format
 msgid "Completely removing %s"
 msgstr "%s wird vollständig entfernt"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Aufruf des Nach-Installations-Triggers %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Verzeichnis »%s« fehlt"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Datei %s konnte nicht geöffnet werden"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s wird vorbereitet"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "%s wird entpackt"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Konfiguration von %s wird vorbereitet"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s installiert"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Entfernen von %s wird vorbereitet"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s entfernt"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Vollständiges Entfernen von %s wird vorbereitet"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s vollständig entfernt"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Schreiben des Protokolls nicht möglich, openpty() fehlgeschlagen (/dev/pts "
 "nicht eingebunden?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr "Ausführen von dpkg"
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
@@ -3215,24 +3328,38 @@
 "Sperren des Administrationsverzeichnisses (%s) nicht möglich, wird es von "
 "einem anderen Prozess verwendet?"
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr ""
 "Sperren des Administrationsverzeichnisses (%s) nicht möglich, sind Sie root?"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, fuzzy, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 "Der dpkg-Prozess wurde unterbrochen; Sie müssen »dpkg --configure -a« manuell "
 "ausführen, um das Problem zu beheben."
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "Nicht gesperrt"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3251,7 +3378,7 @@
 "Patch konnte nicht mit mmap auf %s angewendet werden (es ist jedoch nichts "
 "mmap-spezifisches fehlgeschlagen) - der Patch scheint beschädigt zu sein."
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Verbindung vorzeitig beendet"
 

=== modified file 'po/dz.po'
--- po/dz.po	2010-05-25 16:01:42 +0000
+++ po/dz.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: apt_po.pot\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2006-09-19 09:49+0530\n"
 "Last-Translator: Kinley Tshering <gasepkuenden2k3@hotmail.com>\n"
 "Language-Team: Dzongkha <pgeyleg@dit.gov.bt>\n"
@@ -18,150 +18,148 @@
 "X-Poedit-Country: Bhutan\n"
 "X-Poedit-SourceCharset: utf-8\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "ཐུམ་སྒྲིལ་ %s ཐོན་རིམ་ %s ལུ་ ཌེཔ་མ་ཚང་ཅིག་འདུག:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "%sཐུམ་སྒྲིལ་འདི་ག་ཡོད་ཟཚོལ་མ་ཐོབ།"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "ཐུམ་སྒྲིལ་བསྡོམས་ཀྱི་མིང་ཚུ:"
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "ཐུམ་སྒྲིལ་བསྡོམས་ཀྱི་མིང་ཚུ:"
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "སྤྱིར་བཏང་ཐུམ་སྒྲིལ་ཚུ།"
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "བར་ཅུ་ཡལ་ཐུམ་སྒྲིལ་གཙང་མ་ཚུ:"
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "བར་ཅུ་ཡལ་ཐུམ་སྒྲིལ་རྐྱང་པ་ཚུ:"
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "བར་ཅུ་ཡལ་ཐུམ་སྒྲིལ་སླ་བསྲེ་ཡོད་མི་ཚུ:"
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "བརླག་སྟོར་ཞུགས་པ:"
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "ཁྱད་རྟགས་ཅན་གྱི་ཐོན་རིམ་ཚུ་གི་བསྡོམས:"
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "ཁྱད་རྟགས་ཅན་གྱི་ཐོན་རིམ་ཚུ་གི་བསྡོམས:"
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "རྟེན་འབྲེལ་བསྡོམས:"
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "ཐེན་རིམ་/ཡིག་སྣོད་ མཐུན་འབྲེལ་གྱི་བསྡོམས:"
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "ཐེན་རིམ་/ཡིག་སྣོད་ མཐུན་འབྲེལ་གྱི་བསྡོམས:"
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "ཡོངས་བསྡོམས་ཀྱིས་ས་ཁྲ་བཟོ་བ་ཚུ་བྱིནམ་ཨིན:"
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "སྤུངས་ཡོད་པའི་ཡིག་རྒྱུན་གྱི་བསྡོམས:"
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "རྟེན་འབྲེལ་ཐོན་རིམ་བར་སྟོང་གྱི་བསྡོམས:"
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "བར་སྟོང་ལྷུག་ལྷུག་གི་བསྡོམས:"
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "གི་དོན་ལུ་རྩིས་ཐོ་བཏོན་ཡོད་པའི་བར་སྟོང:"
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "ཐུམ་སྒྲིལ་ཡིག་སྣོད་ %sའདི་མཉམ་འབྱུང་གི་ཕྱི་ཁར་ཨིན་པས།"
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "ཁྱོད་ཀྱིས་ཏག་ཏག་སྦེ་དཔེ་གཞི་གཅིག་བྱིན་དགོ"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "ཐུམ་སྒྲིལ་ཚུ་མ་ཐོབ།"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "%sཐུམ་སྒྲིལ་འདི་ག་ཡོད་ཟཚོལ་མ་ཐོབ།"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "ཐུམ་སྒྲིལ་གྱི་ཡིག་སྣོད:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "འདྲ་མཛོད་འདི་མཉམ་བྱུང་གི་ཕྱི་ཁར་ཨིན་པས་  ཐུམ་སྒྲིལ་ཡིག་སྣོད་ཅིག་ལུ་ ཨེགསི་-རེཕ་འབད་མི་ཚུགས་པས།"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "ཁབ་གཟེར་བཏབ་ཡོད་པའི་ཐུམ་སྒྲིལ་ཚུ:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(མ་ཐོབ།)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "གཞི་བཙུགས་འབད་ཡོདཔ།"
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "མི་ངོ:"
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ཅི་མེད།)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "ཐུམ་སྒྲིལ་གྱི་ཁབ་གཟེར:"
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "ཐོན་རིམ་ཐིག་ཁྲམ།:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s་གི་དོན་ལུ་%s %sགུར་ཕྱོགས་སྒྲིག་འབད་ཡོད་པའི་%s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -318,12 +316,12 @@
 "  -o=? འདི་གིས་མཐུན་སྒྲིག་རིམ་སྒྲིག་གདམ་ཁ་ཅིག་གཞི་སྒྲིག་འབདཝ་ཨིན་  དཔེར་ན་-o dir::cache=/tmp་"
 "བཟུམ།\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr " %sལུ་འབྲི་མ་ཚུགས།"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "debconf ་་འཐོན་རིམ་འདི་ལེན་མ་ཚུགས། debconf འདི་གཞི་བཙུགས་འབད་ཡི་ག་?"
 
@@ -662,79 +660,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "%s་ལུ་%s་བསྐྱར་མིང་བཏགས་ནི་ལུ་འཐུས་ཤོར་བྱུང་ཡོད།"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "ཝའི།"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "རི་ཇེགསི་ཕྱོགས་སྒྲིག་འཛོལ་བ་- %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "འོག་གི་ཐུམ་སྒྲིལ་ཚུ་ལུ་རྟེན་འབྲེལ་མ་ཚང་པས:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "འདི་འབདཝ་ད་%s་འདི་གཞི་བཙུགས་འབད་ཡོད།"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "འདི་འབདཝ་ད་%sའདི་གཞི་བཙུགས་འབད་ནི་ཨིན།"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "འདི་འབདཝ་ད་%s་འདི་གཟི་བཙུགས་འབད་མི་བཏུབ་པས།"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "འདི་འབདཝ་ད་ འདི་བར་ཅུ་ཡལ་ཐུམ་སྒྲིལ་ཅིག་ཨིན་པས།"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "འདི་འབདཝ་ད་འདི་གཞི་བཙུགས་མ་འབད་བས།"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "འདི་འབདཝ་ད་འདི་གཞི་བཙུགས་མི་འབད་ནི་ཨིན་པས།"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr "ཡང་ན།"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "འོག་གི་ཐུམ་སྒྲིས་གསརཔ་འདི་ཚུ་ཁཞི་བཙུགས་འབད་འོང་:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "འོག་གི་ཐུམ་སྒྲིལ་འདི་ཚུ་རྩ བསྐྲད་གཏང་འོང་:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "འོག་གི་ཐུམ་སྒྲིལ་འདི་ཚུ་ལོག་སྟེ་རང་བཞག་ནུག:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "འོག་གི་ཐུམ་སྒྲིལ་འདི་ཚུ་ཡར་བསྐྱེད་འབད་འོང་:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "འོག་གི་ཐུམ་སྒྲལ་འདི་ཚུ་མར་ཕབ་འབད་འོང་:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "འོག་གི་འཆང་ཡོད་པའི་ཐུམ་སྒྲིལ་ཚུ་བསྒྱུར་བཅོས་འབད་འོང་:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s( %s་གིས་སྦེ)"
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -742,144 +740,144 @@
 "ཉེན་བརྡ:འོག་གི་ཉོ་མཁོ་བའི་ཐུམ་སྒྲིལ་ཚུ་རྩ་བསྐྲད་གཏང་འོང་།\n"
 "ཁྱོད་ཀྱིས་ཁྱོད་རང་ག་ཅི་འབདཝ་ཨིན་ན་ངེས་སྦེ་མ་ཤེས་ཚུན་འདི་འབད་ནི་མི་འོང་།!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu་ཡར་བསྐྱེད་འབད་ཡོད་ %lu་འདི་གསརཔ་སྦེ་གཞི་བཙུགས་འབད་ཡོད།"
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu་འདི་ལོག་གཞི་བཙུགས་འབད་ཡོད།"
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu་འདི་མར་ཕབ་འབད་ཡོད།"
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "རྩ་བསྐྲད་འབད་ནི་ལུ་%lu་དང་%lu་ཡར་བསྐྱེད་མ་འབད་བས།\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu་འདི་ཆ་ཚང་སྦེ་གཞི་བཙུགས་མ་འབད་ཡང་ན་རྩ་བསྐྲད་མ་གཏང་པས།\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "རྟེན་འབྲེལ་ནོར་བཅོས་འབད་དོ།"
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr "འཐུས་ཤོར་བྱུང་ཡོད།"
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "རྟེན་འབྲེལ་འདི་ནོར་བཅོས་འབད་མི་ཚུགས་པས།"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "ཡར་བསྐྱེད་འབད་ཡོད་པའི་ཆ་ཚན་འདི་ཆུང་ཀུ་བཟོ་མི་ཚུགས་པས།"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr "འབད་ཚར་ཡི།"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "འ་ནི་འདི་ཚུ་ནོར་བཅོས་འབད་ནི་ལུ་ཁྱོད་ཀྱི་'apt-get -f install'དེ་གཡོག་བཀོལ་དགོཔ་འོང་།"
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "མ་ཚང་པའི་རྟེན་འབྲེལ་ཚུ། -f ལག་ལེན་འཐབ་སྟེ་འབད་རྩོལ་བསྐྱེད།"
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ཉེན་བརྡ:འོག་གི་ཐུམ་སྒྲིལ་འདི་ཚུ་བདེན་བཤད་འབད་མི་བཏུབ་པས།"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "བདེན་བཤད་ཉེན་བརྡ་འདི་ཟུར་འབད་ཡོད།\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "བདེན་སྦྱོར་མ་འབད་བར་འ་ནི་ཐུམ་སྒྲིལ་འདི་ཚུ་གཞི་བཙུགས་འབད་ནི་ཨིན་ན་[y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "ཐུམ་སྒྲིལ་ལ་ལུ་ཅིག་བདེན་བཤད་འབད་མ་ཚུགས།"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "དཀའ་ངལ་ཚུ་ཡོདཔ་ལས་-y ་འདི་ --force-yes་མེདཐོག་ལས་ལག་ལེན་འཐབ་སྟེ་ཡོད།"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 "ནང་འཁོད་ཀྱི་འཛོལ་བ་  གཞི་བཙུགས་ཐུམ་སྒྲིལ་ཚུ་ ཆད་པ་ཡོད་པའི་ཐུམ་སྒྲིལ་ཚུ་དང་གཅིག་ཁར་བོད་བརྡ་འབད་འདི་"
 "ཡོད!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "ཐུམ་སྒྲིལ་ཚུ་རྩ་བསྐྲད་བཏང་དགོཔ་འདུག་འདི་འབདགཝ་ད་རྩ་བསྐྲད་གཏང་ནི་འདི་ལྕོགས་མིན་ཐལ་ཏེ་འདུག"
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "ནང་འཁོད་འཛོལ་བ་  གོ་རིམ་བཟོ་ནི་ཚུ་མཇུག་མ་བསྡུ་བས།"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "འབྱུང་ཁུངས་ཚུ་ཀྱི་ཐོ་ཡིག་དེ་ལྷག་མི་ཚུགས་པས།"
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "ག་ཅི་གི་ཡ་མཚན་ཆེ་མི་ཆེ་  ཚད་འདི་གིས་ email apt@packages.debian.org་ལུ་མཐུན་སྒྲིག་མི་འབད་"
 "བས།"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "%sBལེན་ནི་ལུ་དགོཔ་པས། ཡིག་མཛོད་ཚི་གི་%sB་\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "ཡིག་མཛོད་ཀྱི་%sB་འདི་ལེན་དགོ་པས།\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "ཁ་སྐོང་གི་%sB་འདི་བཤུབ་པའི་ཤུལ་ལས་ཌིཀསི་གི་བར་སྟོང་དེ་ལག་ལེན་འཐབ་འོང་།\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "%sB་འདི་ཤུབ་པའི་ཤུལ་ལས་ཀྱི་བར་སྟོང་དེ་དལཝ་སྦེ་ལུས་འོང་།\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "%s་ནང་བར་སྟོང་"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "%s ནང་ཁྱོད་ལུ་བར་སྟོང་དལཝ་ལངམ་སྦེ་མིན་འདུག"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "གལ་ཆུང་རྐྱངམ་ཅིག་ཁསལ་བཀོད་འབད་ནུག་ འདི་འབདཝ་ད་འ་ནི་འདི་གལ་ཆུང་གི་བཀོལ་སྤྱོད་མེན།"
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "ཨིན་ ང་གིས་སླབ་དོ་བཟུམ་སྦེ་རང་འབད!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -890,28 +888,28 @@
 "འཕྲོ་མཐུད་འབད་ནིའི་དོན་ལུ་'%s'ཚིག་ཚན་ནང་ལུ་ཡིག་དཔར་རྐྱབས།\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "བར་བཤོལ་འབད།"
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "ཁྱོན་ཀྱི་འཕྲོ་མཐུད་ནི་འབད་ནི་ཨིན་ན་[Y/n]?"
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "%s  %s་ ལེན་ནི་ལུ་འཐུས་ཤོར་བྱུང་ཡོད།\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "ཡིག་སྣོད་ལ་ལུ་ཅིག་ཕབ་ལེན་འབད་ནི་ལུ་འཐུས་ཤོར་བྱུང་ཡོད།"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "ཕབ་ལེན་ཐབས་ལམ་རྐྱངམ་གཅིག་ནང་མཇུག་བསྡུཝ་སྦེ་རང་ཕབ་ལེན་འབད།"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -919,19 +917,19 @@
 "ཡིག་མཛོད་ལ་ལུ་ཅིག་ལེན་མི་ཚུགས་པས་  apt-get་དུས་མཐུན་བཟོ་ནི་གཡོག་བཀོལ་ནི་ཨིན་ན་ཡང་ན་--fix-"
 "missing་དང་གཅིག་ཁར་འབད་རྩོལ་བསྐྱེད་ནི་ཨིན་ན་?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing་དང་བརྡ་ལམ་བརྗེ་སོར་འབད་ནི་འདི་ད་ལྟོ་ལས་རང་རྒྱབ་སྐྱོར་མི་འབད་བས།"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "བརླག་སྟོར་ཞུགས་ཡོད་པའི་ཐུམ་སྒྲིལ་ཚུ་ནོར་བཅོས་འབད་མི་ཚུགས་པས།"
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "གཞི་བཙུགས་བར་བཤོལ་འབད་དོ།"
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -941,53 +939,53 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "%s་གི་ཚབ་ལུ་%s་སེལ་འཐུ་འབད་ནི་སེམས་ཁར་བཞག\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "%s་གོམ་འགྱོ་འབད་དོ་  འདི་ཧེ་མ་ལས་རང་གཞི་བཙུགས་འབད་འོདཔ་དང་དུས་ཡར་བསྐྱེད་འབད་ནི་འདི་གཞི་སྒྲིག་མ་"
 "འབད་བས།\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "%s་གོམ་འགྱོ་འབད་དོ་  འདི་ཧེ་མ་ལས་རང་གཞི་བཙུགས་འབད་འོདཔ་དང་དུས་ཡར་བསྐྱེད་འབད་ནི་འདི་གཞི་སྒྲིག་མ་"
 "འབད་བས།\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "ཐུམ་སྒྲིལ་%s་འདི་གཞི་བཙུགས་མ་འབད་བས་  འདི་འབད་ནི་དི་གིས་རྩ་བསྐྲད་མ་གཏང་པས།་\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "གྱིས་བྱིན་ཏེ་ཡོད་པའི་ཐུམ་སྒྲིལ་%s་འདི་བར་ཅུ་ཡལ་ཐུམ་སྒྲིལ་ཅིག་ཨིན།\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [གཞི་བཙུགས་འབད་ཡོད།]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "མི་ངོ་འཐོན་རིམཚུ།"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "ཁྱོད་ཀྱི་གཞི་བཙུགས་འབད་ནི་ལུ་གཏན་འཁལ་སྦེ་གཅིག་སེལ་འཐུ་འབད་དགོ"
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -998,65 +996,65 @@
 "འདི་གིས་ཐུམ་སྒྲིལ་ཅིག་བརླག་སྟོར་ཞུགས་ཡོདཔ་ཨིནམ་སྟོནམ་ཨིནམ་དང་ ཕན་མེད་སྦེ་གནས་ཡོདཔ་  ཡང་ན་\n"
 "འདི་གཞན་འབྱུང་ཅིག་ནང་ལས་ལས་རྐྱངམ་ཅིག་འཐོབ་ཚུགསཔ་ཨིན་པས།\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "ག་དེ་སྦེ་ཨིན་རུང་འོག་གི་ཐུམ་སྒྲིལ་ཚུ་གིས་ འདི་ཚབ་བཙུགསཔ་ཨིན:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "ཐུམ་སྒྲིལ་%s་ལུ་གཞི་བཙུགས་ཀྱི་མི་ངོ་མིན་འདུག"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "%s ་ལོག་གཞི་བཙུགས་འབད་ནི་འདི་མི་སྲིད་པ་ཅིག་ཨིན་པས་ འདི་ཕབ་ལེན་འབད་མི་བཏུབ་པས།\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s ་འདི་ཧེ་མ་ལས་རང་འཐོན་རིམ་གསར་ཤོས་ཅིག་ཨིན།\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "%sགི་དོན་ལུ་འཛིན་གྲོལ་'%s'་དེ་མ་འཐོབ་པས།"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "'%s'་གི་དོན་ལུ་འཐོན་རིམ་'%s'་དེ་མ་འཐོབ་པས།"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "(%s)གི་དོན་ལུ་སེལ་འཐུ་འབད་ཡོད་པའི་འཐོན་རིམ་'%s'(%s)\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "འབྱུང་ཁུངས་ཐུམ་སྒྲིལ་གྱི་ཐོ་ཡིག་%s་དེ་ངོ་བཤུས་འབད་མ་ཚུགས།"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "དུས་མཐུན་བཟོ་བའི་བརྡ་བཀོད་འདི་གིས་སྒྲུབ་རྟགས་ཚུ་མི་འབག་འབད།"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1066,7 +1064,7 @@
 msgstr[0] "འོག་གི་ཐུམ་སྒྲིས་གསརཔ་འདི་ཚུ་ཁཞི་བཙུགས་འབད་འོང་:"
 msgstr[1] "འོག་གི་ཐུམ་སྒྲིས་གསརཔ་འདི་ཚུ་ཁཞི་བཙུགས་འབད་འོང་:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1074,11 +1072,11 @@
 msgstr[0] "འོག་གི་ཐུམ་སྒྲིས་གསརཔ་འདི་ཚུ་ཁཞི་བཙུགས་འབད་འོང་:"
 msgstr[1] "འོག་གི་ཐུམ་སྒྲིས་གསརཔ་འདི་ཚུ་ཁཞི་བཙུགས་འབད་འོང་:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1094,44 +1092,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "འོག་གི་བརྡ་དོན་དེ་གིས་དུས་སྐབས་འདི་མོས་མཐུན་བཟོ་ནི་ལུ་གྲོགས་རམ་འབད་འོང་:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "ནང་འཁོད་འཛོལ་བ་ དཀའ་ངལ་མོས་མཐུན་འབད་མི་ཅ་ཆས་ཚུ་མེདཔ་ཐལ་ཡོད།"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "ནང་འགོད་འཛོལ་བ་  ཡར་བསྐྱེད་ཀྱི་ཅ་ཆས་ཆ་མཉམ་མེདཔ་ཐལ་ཡོད།"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "%s་ཐུམ་སྒྲིལ་འཚོལ་མ་ཐོབ།"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "%s་ཐུམ་སྒྲིལ་འཚོལ་མ་ཐོབ།"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "དྲན་འཛིན་ རི་ཇེགསི་'%s'གི་དོན་ལུ་%s་སེལ་འཐུ་འབད་དོ།\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "འདི་འབདཝ་ད་%sའདི་གཞི་བཙུགས་འབད་ནི་ཨིན།"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "འདི་ཚུ་ནོར་བཅོས་འབད་ནིའི་དོན་ལུ་ཁྱོད་ཀྱི་'apt-get -f install'དེ་གཡོག་བཀོལ་དགོཔ་འོང་:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1139,7 +1132,7 @@
 "མ་ཚང་བའི་རྟེན་འབྲེལ་  ཐུས་སྒྲིལ་མེད་མི་ཚུ་དང་གཅིག་ཁར་ 'apt-get -f install'དེ་འབཐ་རྩོལ་བསྐྱེདཔ།"
 "(ཡང་ན་ཐབས་ཤེས་ཅིག་གསལ་བཀོད་འབད།)"
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1150,131 +1143,146 @@
 "འབད་འབདཝ་འོང་ནི་མས་ ཡང་ན་ད་ལྟོ་ཡང་གསར་བསྐྲུན་མ་འབད་བར་ཡོད་པའི་ཐུམ་སྒྲིལ་ལ་ལུ་ཅིག་ཡང་ན་ནང་"
 "འབྱོར་གྱི་ཕྱི་ཁར་རྩ་བསྐྲད་བཏང་ཡོད་པའི་རྩ་བརྟན་མེད་པའི་བགོ་འགྲེམ་ཚུ་ལག་ལེན་འཐབ་དོ་ཡོདཔ་འོང་ནི་ཨིན་པས།"
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "ཆད་པ་ཡོད་པའི་ཐུམ་སྒྲིལ་ཚུ།"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "འོག་གི་ཐུམ་སྒྲིལ་ཐེབས་ཚུ་གཞི་བཙུགས་འབད་འོང་:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "བསམ་འཆར་བཀོད་ཡོད་པའི་ཐུམ་སྒྲིལ་ཚུ:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "འོས་སྦྱོར་འབད་ཡོད་པའི་ཐུམ་སྒྲིལ་ཚུ:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "འདི་འབདཝ་ད་%sའདི་གཞི་བཙུགས་འབད་ནི་ཨིན།"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "ཡར་བསྐྱེད་རྩིས་བཏོན་དོ་... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "འཐུས་ཤོར་བྱུང་ཡོད།"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "འབད་ཚར་ཡི།"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "ནང་འཁོད་འཛོལ་བ་ དཀའ་ངལ་མོས་མཐུན་འབད་མི་ཅ་ཆས་ཚུ་མེདཔ་ཐལ་ཡོད།"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "ཕབ་ལེན་འབད་ནིའི་སྣོད་ཡིག་འདི་ལྡེ་མིག་རྐྱབས་མ་ཚུགས་པས།"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "གི་དོན་ལུ་འབྱུང་ཁུངས་ལེན་ནི་ལུ་ཉུང་མཐའ་རང་ཐུམ་སྒྲིལ་གཅིག་ལེན་དགོ"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "%s་གི་དོན་ལུ་འབྱུང་ཁུངས་ཐུམ་སྒྲིལ་ཅིག་འཚོལ་མ་འཐོབ"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "གོམ་འགྱོ་གིས་ཧེ་མ་ལས་རང་'%s'་ཡིག་སྣོད་དེ་ཕབ་ལེན་འབད་ནུག\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr " %s་ནང་ཁྱོད་ལུ་བར་སྟོང་ཚུ་ལངམ་སྦེ་མིན་འདུག་"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "%sB་ལེན་དགོཔ་འདུག་  འབྱུང་ཁུངས་ཡིག་མཛོད་ཀྱི་%sB།\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "འབྱུང་ཁུངས་ཡིག་མཛོད་ཚུ་ཀྱི་%sB་ལེན་དགོ་པསས།\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "%s་འབྱུང་ཁུངས་ལེན།\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "ཡིག་མཛོད་ལ་ལུ་ཅིག་ལེན་ནི་ལུ་འཐུས་ཤོར་བྱུང་ཡོད།"
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "%s་ནང་ཧེ་མ་ལས་སྦུང་ཚན་བཟོ་བཤོལ་ཨིན་མའི་སྦུང་ཚན་བཟོ་བཤོལ་གོམ་འགྱོ་འབད་དོ།\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "'%s'སྦུང་ཚན་བཟོ་བཤོལ་འཐུས་ཤོར་བྱུང་ཡོད།\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "'dpkg-dev'་ཐུམ་སྒྲིལ་དེ་གཞི་བཙུགས་འབད་ཡོད་པ་ཅིན་ཨེབ་གཏང་འབད།\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "'%s'་བཟོ་བརྩིགས་བརྡ་བཀོད་འཐུས་ཤོར་བྱུང་ཡོད།\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "ཆ་ལག་ལས་སྦྱོར་དེ་འཐུས་ཤོར་བྱུང་ནུག"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "builddeps ཞིབ་དཔྱད་འབད་ནིའི་དོན་ལུ་ཉུང་མཐའ་རང་ཐུམ་སྒྲིལ་གཅིག་གསལ་བཀོད་འབད་དགོ"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "%s་གི་དོན་ལུ་བཟོ་བརྩིགས་-རྟེན་འབྲེལ་བརྡ་དོན་དེ་ལེན་མ་ཚུགས།"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s ལུ་བཟོ་བརྩིགས་རྟེན་འབྲེལ་མིན་འདུག\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "%sཐུམ་སྒྲིལ་འདི་འཐོབ་མ་ཚུགསཔ་ལས་བརྟེན་ %sགི་དོན་ལུ་%s རྟེན་འབྲེལ་དེ་ངལ་རང་མ་ཚུགས་པས།"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1283,32 +1291,32 @@
 "%s གི་དོན་ལུ་%s་རྟེན་འབྲེལ་འདི་གི་རེ་བ་སྐོང་མི་ཚུགས་ནུག་ག་ཅི་འབད་ཟེར་བ་ཅིན་ཐུམ་སྒརིལ་%s་གི་འཐོན་རིམ་"
 "ཚུ་འཐོབ་མ་ཚུགསཔ་ལས་བརྟེན་འཐོན་རིམ་དགོས་མཁོ་ཚུ་གི་རེ་བ་དོ་སྐོང་མ་ཚུགས་པས།"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "%s:གི་དོན་ལུ་%s་རྟེན་འབྲེལ་དེ་གི་རེ་བ་སྐོང་ནི་འདི་འཐུས་ཤོར་བྱུང་ཡོདཔ་ཨིན་  གཞི་བཙུགས་འབད་ཡོད་པའི་ཐུམ་"
 "སྒྲིལ་%s་དེ་གནམ་མེད་ས་མེད་གསརཔ་ཨིན་པས།"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "%s: %s་གི་དོན་ལུ་་%s་རྟེན་འབྲེལ་འདི་ངལ་རངས་འབད་ནི་འཐུས་ཤོར་བྱུང་ནུག"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr " %s་གི་དོན་ལུ་བཟོ་བརྩིགས་-རྟེན་འབྲེལ་འདི་ངལ་རངས་མ་ཚུགས་པས།"
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "བཟོ་བརྩིགས་རྟེན་འབྲེལ་འདི་ལས་སྦྱོར་འབད་ནི་ལུ་འཐུས་ཤོར་བྱུང་ཡོདཔ་ཨིན།"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "རྒྱབ་སྐྱོར་འབད་ཡོད་པའི་ཚད་གཞི་ཚུ:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1650,8 +1658,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "%s་འདི་ལུ་ལྷག་མ་ཚུགས།"
@@ -1680,10 +1689,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "info ་དང་ temp་སྣོད་ཐོ་ཚུ་ཡིག་སྣོད་རིམ་ལུགས་གཅིག་གུར་ལུ་བཞག་དགོཔ་ཨིན།"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "ཐུམ་སྒྲིལ་ཐོ་ཡིག་ཚུ་ལྷག་དོ།"
 
@@ -1899,172 +1907,172 @@
 msgid "Write error"
 msgstr "འཛོལ་བ་འབྲི།"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "སོ་ཀེཊི་ཅིག་གསར་བསྐྲུན་འབད་མ་ཚུགས་པར་ཡོདཔ་ཨིན།"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "གནད་སྡུད་སོ་ཀེཊི་མཐུད་མ་ཚུགས་པར་ཡོདཔ་ཨིན་  མཐུད་ལམ་ངལ་མཚམས།"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "བྱ་ཡུལ་གྱི་སོ་ཀེཊི་མཐུད་མ་ཚུགས།"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo་འདི་གིས་ཉན་ནིའི་སོ་ཀེཊི་ཅིག་ལེན་མ་ཚུགས།"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "སོ་ཀེཊི་ཅིག་བསྡམས་མ་ཚུགས།"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "སོ་ཀེཊི་གུར་ཉེན་མ་ཚུགས།"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "སོ་ཀེཊི་གི་མིང་འདི་གཏན་འབེབས་བཟོ་མ་ཚུགས།"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "འདྲེན་ལམ་གྱི་བརྡ་བཀོད་འདི་བཏང་མ་ཚུགས།"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "མ་ཤེས་པའི་ཁ་བྱང་གི་རིགས་ཚན་%u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "ཨི་པི་ཨར་ཊི་ འཐུས་ཤོར་བྱུང་ཡོད་  སར་བར་གིས་སླབ་མས:%s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "གནད་སྡུད་སོ་ཀེཊི་ མཐུད་ནི་ངལ་མཚམས་བྱུང་ནུག"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "མཐུད་ལམ་འདི་དང་ལེན་འབད་མ་ཚུགས།"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "ཡིག་སྣོད་ལུ་་དྲྭ་རྟགས་བཀལ་བའི་བསྒང་དཀའ་ངལ།"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "ཡིག་སྣོད་ལེན་མ་ཚུགས་ སར་བར་'%s'གིས་སླབ་མས"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "གནད་སྡུད་སོ་ཀེཊི་ངལ་མཚམས།"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "གནད་སྡུད་གནས་སོར་དེ་འཐུས་ཤོར་བྱུང་ཡོད་  སར་བར་'%s'་གིས་སླབ་མས།"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "འདྲི་དཔྱད།"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "ལས་བཀོལ་འབད་མ་ཚུགས།"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "%s (%s)་ལུ་མཐུད་དོ།"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "%s (f=%u t=%u p=%u)གི་དོན་ལུ་སོ་ཀེཊི་ཅིག་གསར་བསྐྲུན་འབད་མ་ཚུགས།"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "%s:%s (%s)ལུ་མཐུད་ལམ་དེ་འགོ་འབྱེད་འབད་མ་ཚུགས།"
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr " %s:%s (%s)ལུ་མཐུད་མ་ཚུགས་  མཐུད་ལམ་ངལ་མཚམས།"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr " %s:%s (%s)ལུ་མཐུད་མ་ཚུགས།"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "%s་ལུ་མཐུད་དོ།"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "'%s'མོས་མཐུན་འབད་མ་ཚུགས།"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "'%s'མོས་མཐུན་འབད་ནི་ལུ་གནས་སྐབས་ཀྱི་འཐུས་ཤོར།"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "'%s:%s' (%i)་མོས་མཐུན་འབདཝ་ད་ངན་པ་ཅིག་བྱུང་ཡི།"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "%s %s:ལུ་མཐུད་མ་ཚུགས།"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "གཞི་བཙུགས་བར་བཤོལ་འབད་དོ།"
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "ནང་འཁོད་འཛོལ་བ: མིང་རྟགས་འདི་ལེགས་ཤོམ་ཅིག་འདུག་  འདི་འབདཝ་ད་མཛུབ་རྗེས་ལྡེ་མིག་དེ་གཏན་འབེབས་བཟོ་"
 "མ་ཚུགས?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "ཉུང་མཐའ་རང་ནུས་མེད་ཀྱི་མིང་རྟགས་ཅིག་གདོང་ཐུག་བྱུང་སྟེ་ཡོདཔ་ཨིན།"
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "མིང་རྟགས་བདེན་སྦྱོར་འབད་ནི་ལུ་'%s'འདི་ལག་ལེན་འཐབ་མ་ཚུགས། (gpgv་དེ་ཁཞི་བཙུགས་འབད་ཡོདཔ་ཨིན་ན།?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "gpgv་ལག་ལེན་འཐབ་ནི་ལུ་མ་ཤེས་པའི་འཛོལ་བ་།"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "འོག་གི་མིང་རྟགས་ཚུ་ནུས་མེད་ཨིན་པས།:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2142,20 +2150,20 @@
 msgid "Error reading from server"
 msgstr "སར་བར་ནང་ལས་ལྷག་པའི་བསྒང་འཛོལ་བ།"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "%s་ཡིག་སྣོད་འདི་འབྲི་ནི་ལུ་འཐུས་ཤོར་བྱུང་ཡོད།"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "མགོ་ཡིག་གནད་སྡུད་བྱང་ཉེས།"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "བཐུད་ལམ་འཐུས་ཤོར་བྱུང་ཡོད།"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "ནང་འཁོད་འཛོལ་བ།"
 
@@ -2221,7 +2229,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "སེལ་འཐུ་%s ་མ་འཐོབ།"
@@ -2344,6 +2352,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "%s་ལུ་བསྒྱུར་བཅོས་འབད་མ་ཚུགས།"
@@ -2529,7 +2538,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "%s་ཡིག་སྣོད་འདི་འབྲི་ནི་ལུ་འཐུས་ཤོར་བྱུང་ཡོད།"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2665,7 +2674,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "དཀའ་ངལ་འདི་ནོར་བཅོས་འབད་མ་ཚུགས་ ཁྱོད་ཀྱི་ཐུམ་སྒྲིལ་ཆད་པ་ཚུ་འཆང་འདི་འདུག"
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2715,12 +2724,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "ཁ་ཡིག་བཀོད་ཡོད་པའི་ ཌིསི་འདི་བཙུགས་གནང་། '%s'འདྲེན་འཕྲུལ་ནང་'%s' དང་ལོག་ལྡེ་འདི་ཨེབ།་"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "སྦུང་ཚན་བཟོ་ནིའི་རིམ་ལུགས་ '%s' འདི་ལུ་རྒྱབ་སྐྱོར་མ་འབད་བས།"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "འོས་འབབ་དང་ལྡན་པའི་སྦུང་ཚན་རིམ་ལུགས་ཀྱི་དབྱེ་བ་ཅིག་གཏན་འབེབས་བཟོ་མི་ཚུགས་པས།"
 
@@ -2734,25 +2743,25 @@
 msgstr ""
 "ཁྱོད་རའི་sources.listགི་ཐོ་ཡིག་ནང་ལུ་ཁྱོད་ཀྱི་ 'འབྱུང་ཁུངས་' ཡུ་ཨར་ཨའི་ཚུ་་ལ་ལུ་ཅིག་བཙུགས་དགོ"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "ཐུམ་སྒྲིལ་གྱི་ཐོ་ཡིག་ཡང་ན་གནས་ཚད་ཡིག་སྣོད་ཚུ་ མིང་དཔྱད་ཡང་ན་ཁ་ཕྱེ་མ་ཚུགས།"
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "འ་ནི་དཀའ་ངལ་འདི་ཚུ་སེལ་ནིའི་ལུ་ ཁྱོད་ཀྱི་ apt-get update་དེ་གཡོག་བཀོལ་དགོཔ་འོང་།"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "དགའ་གདམ་ཡིག་སྣོད་ནང་ལུ་ནུས་མེད་ཀྱི་དྲན་ཐོ་  ཐུམ་སྒྲིལ་མགོ་ཡིག་མིན་འདུག"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "ངོ་རྟགས་ཨང་གི་དབྱེ་བ་ %s འདི་ཧ་གོ་མ་ཚུགས།"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "གོ་རྟགས་ཨང་གི་དོན་ལུ་ གཙོ་རིམ་(ཡང་ན་ ཀླད་ཀོར་)ཚུ་གསལ་བཀོད་མ་འབད་བས།"
 
@@ -2842,33 +2851,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "འབྱུང་ཁུངས་ཐུམ་སྒྲིལ་གྱི་ཐོ་ཡིག་%s་དེ་ངོ་བཤུས་འབད་མ་ཚུགས།"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "ཡིག་སྣོད་བྱིན་མི་ཚུ་བསྡུ་ལེན་འབད་དོ།"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IO འཛོལ་བ་འབྱུང་ཁུངས་འདྲ་མཛོད་སྲུང་བཞག་འབད་དོ།"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "%s (%s -> %s)བསྐྱར་མིང་བཏགས་ནི་འདི་འཐུས་ཤོར་བྱུང་ཡོདཔ་ཨིན།"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "ཨེམ་ཌི་༥་ ཁྱོན་བསྡོམས་མ་མཐུན་པ།"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "ཨེམ་ཌི་༥་ ཁྱོན་བསྡོམས་མ་མཐུན་པ།"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "འོག་གི་ ཨའི་ཌི་་ ལྡེ་མིག་ཚུ་གི་དོན་ལུ་མི་དམང་གི་ལྡེ་མིག་འདི་འཐོབ་མི་ཚུགས་པས:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2877,7 +2911,7 @@
 " %s་ཐུམ་སྒྲིལ་གི་དོན་ལུ་ང་་གི་ཡིག་སྣོད་ཅིག་ག་ཡོད་འཚོལ་མི་འཐོབ་པས། འདི་འབདཝ་ལས་ཁྱོད་ཀྱི་ལག་ཐོག་ལས་ "
 "འ་ནི་ཐུམ་སྒྲིལ་འདི་གི་དཀའ་ངལ་སེལ་དགོཔ་འདུག (arch འདི་བྱིག་སོངམ་ལས་བརྟེན།)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2886,32 +2920,42 @@
 " %s་ཐུམ་སྒྲིལ་གི་དོན་ལུ་ང་་གི་ཡིག་སྣོད་ཅིག་ག་ཡོད་འཚོལ་མི་འཐོབ་པས། འདི་འབདཝ་ལས་ཁྱོད་ཀྱི་ལག་ཐོག་ལས་ "
 "འ་ནི་ཐུམ་སྒྲིལ་འདི་གི་དཀའ་ངལ་སེལ་དགོཔ་འདུག "
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "ཐུམ་སྒྲིལ་ ཟུར་ཐོ་ཡིག་སྣོད་ཚུ་ངན་ཅན་འགྱོ་ནུག  ཡིག་སྣོད་ཀྱི་མིང་མིན་འདུག: %s་ཐུམ་སྒྲིལ་གྱི་དོན་ལུ་ས་སྒོ།"
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "ཚད་མ་མཐུན།"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "%s (༡་)་ཐུམ་སྒྲིལ་ཡིག་སྣོད་འདི་མིང་དཔྱད་འབད་མ་ཚུགས།"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "%s་གི་ཚབ་ལུ་%s་སེལ་འཐུ་འབད་ནི་སེམས་ཁར་བཞག\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "%s་ཁ་ཕྱོགས་ཡིག་སྣོད་ནང་ནུས་མེད་གྲལ་ཐིག"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "%s (༡་)་ཐུམ་སྒྲིལ་ཡིག་སྣོད་འདི་མིང་དཔྱད་འབད་མ་ཚུགས།"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3005,153 +3049,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "འ་ནི་ ཌིསིཀ་གི་དོན་ལུ་ འབྱུང་ཁུངས་ཧྲིལ་བུ་ཚུ་:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i་དྲན་མཐོ་དེ་ཚུ་བྲིས་ཡོད།\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i བྱིག་འགྱོ་ཡོད་པའི་ཡིག་སྣོད་ཚུ་དང་གཅིག་ཁར་ %i དྲན་ཐོ་འདི་ཚུ་བྲིས་ཡོད།\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i་མཐུན་སྒྲིག་མེདཔ་པའི་ཡིག་སྣོད་ཚུ་དང་གཅིག་ཁར་ %i་དྲན་ཐོ་ཚུ་བྲིས་བཞག་ཡོདཔ་ཨིན།\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "%i བྱིག་འགྱོ་ཡོད་པའི་ཡིག་སྣོད་ཚུ་དང་ %iམཐུན་སྒྲིག་མེད་པའི་ཡིག་སྣོད་ཚུ་དང་གཅིག་ཁར་ %i དྲན་ཐོ་འདི་ཚུ་བྲིས་"
 "ཡོདཔ་ཨིན།\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "རིམ་སྒྲིག་ཡིག་སྣོད་%s་འདི་ཁ་ཕྱེ་དོ།"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "ཨེམ་ཌི་༥་ ཁྱོན་བསྡོམས་མ་མཐུན་པ།"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "དྲན་འཛིན་ རི་ཇེགསི་'%s'གི་དོན་ལུ་%s་སེལ་འཐུ་འབད་དོ།\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "(%s)གི་དོན་ལུ་སེལ་འཐུ་འབད་ཡོད་པའི་འཐོན་རིམ་'%s'(%s)\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "གཞི་བཙུགས་འབད་ཡོད་པའི་%s།"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s་རིམ་སྒྲིག་འབད་དོ།"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s་རྩ་བསྐྲད་གཏང་དོ།"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s མཇུག་བསྡུཝ་སྦེ་རང་རྩ་བསྐྲད་བཏང་ཡོད།"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "ཐོ་བཀོད་འབད་མི་སྣོད་ཐོ་%s་ཆ་ཤས་འདི་བརླག་སྟོར་ཟུགས་ཏེ་འདུག"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "%s་ཡིག་སྣོད་འདི་ཁ་ཕྱེ་མ་ཚུགས།"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s་ གྲ་སྒྲིག་འབད་དོ།"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr " %s་ གི་སྦུང་ཚན་བཟོ་བཤོལ་འབད་དོ།"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "%s་ རིམ་སྒྲིག་ལུ་གྲ་སྒྲིག་འབད་དོ།"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "གཞི་བཙུགས་འབད་ཡོད་པའི་%s།"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "%s་ རྩ་བསྐྲད་གཏང་ནིའི་དོན་ལུ་གྲ་སྒྲིག་འབད་དོ།"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "རྩ་བསྐྲད་བཏང་ཡོད་པའི་%s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "%s མཇུག་བསྡུཝ་སྦེ་རང་རྩ་བསྐྲད་གཏང་ནིའི་དོན་ལུ་གྲ་སྒྲིག་འབད་དོ།"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s མཇུག་བསྡུཝ་སྦེ་རང་རྩ་བསྐྲད་བཏང་ཡོད།"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "ཐོ་བཀོད་འབད་ཡོད་པའི་སྣོད་ཡིག་འདི་ལྡེ་མིག་རྐྱབ་མ་ཚུགས།"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3166,7 +3293,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "དུས་སུ་མ་འབབ་པ་རང་མཐུད་ལམ་འདི་ག་བསྡམས་ཡོད།"
 

=== modified file 'po/el.po'
--- po/el.po	2010-05-25 16:01:42 +0000
+++ po/el.po	2010-06-10 14:02:22 +0000
@@ -15,7 +15,7 @@
 msgstr ""
 "Project-Id-Version: apt_po_el\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-08-26 18:25+0300\n"
 "Last-Translator: quad-nrg.net <yodesy@quad-nrg.net>\n"
 "Language-Team: Greek <debian-l10n-greek@lists.debian.org>\n"
@@ -26,148 +26,146 @@
 "X-Generator: KBabel 1.11.4\n"
 "Plural-Forms:  nplurals=2; plural=(n != 1);\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Το πακέτο %s με έκδοση %s έχει ανικανοποίητες εξαρτήσεις:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Αδυναμία εντοπισμού του πακέτου %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Συνολικά Ονόματα Πακέτων : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Συνολικά Ονόματα Πακέτων : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Κανονικά Πακέτα: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr " Πλήρως Εικονικά Πακέτα: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr " Μονά Εικονικά Πακέτα: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr " Μικτά Εικονικά Πακέτα: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "Αγνοούμενα: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Σύνολο Διαφορετικών Εκδόσεων: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Σύνολο Διαφορετικών Εκδόσεων: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Σύνολο Εξαρτήσεων: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Σύνολο σχέσεων Εκδ/Αρχείων: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Σύνολο σχέσεων Εκδ/Αρχείων: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Σύνολο Αντιστοιχίσεων Παροχών: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Σύνολο Κοινών Στοιχειοσειρών : "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Συνολικός χώρος Εξαρτήσεων Εκδόσεων: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Σύνολο χώρου ασφαλείας: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Συνολικός Καταμετρημένος Χώρος: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Το αρχείο πακέτου %s δεν είναι ενημερωμένο."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Πρέπει να δώσετε ακριβώς μία παράσταση"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Δε βρέθηκαν πακέτα"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Αδυναμία εντοπισμού του πακέτου %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Αρχεία Πακέτου:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Η cache δεν είναι ενημερωμένη, αδυναμία παραπομπής σε ένα αρχείο πακέτου"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Καθηλωμένα Πακέτα:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(δε βρέθηκαν)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Εγκατεστημένα: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Υποψήφιο: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(κανένα)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr " Καθήλωση Πακέτου: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Πίνακας Έκδοσης:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s για %s είναι μεταγλωττισμένο σε %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -326,12 +324,12 @@
 "  -c=? Ανάγνωση αυτού του αρχείου ρυθμίσεων\n"
 "  -o=? Καθορισμός αυθαίρετης επιλογής παραμέτρου, πχ -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Αδύνατη η εγγραφή στο %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Δεν βρέθηκε η έκδοση του debconf. Είναι το debconf εγκατεστημένο;"
 
@@ -670,79 +668,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Αποτυχία μετονομασίας του %s σε %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "σφάλμα μεταγλωτισμου - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Τα ακόλουθα πακέτα έχουν ανεπίλυτες εξαρτήσεις:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "αλλά το %s είναι εγκατεστημένο"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "αλλά το %s πρόκειται να εγκατασταθεί"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "αλλά δεν είναι εγκαταστάσημο"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "αλλά είναι ένα εικονικό πακέτο"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "αλλά δεν είναι εγκατεστημένο"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "αλλά δεν πρόκειται να εγκατασταθεί"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " η"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Τα ακόλουθα ΝΕΑ πακέτα θα εγκατασταθούν:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Τα ακόλουθα πακέτα θα ΑΦΑΙΡΕΘΟΥΝ:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Τα ακόλουθα πακέτα θα μείνουν ως έχουν:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Τα ακόλουθα πακέτα θα αναβαθμιστούν:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Τα ακόλουθα πακέτα θα ΥΠΟΒΑΘΜΙΣΤΟΥΝ:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Τα ακόλουθα κρατημένα πακέτα θα αλλαχθούν:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (λόγω του %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -750,146 +748,146 @@
 "ΠΡΟΕΙΔΟΠΟΙΗΣΗ: Τα ακόλουθα απαραίτητα πακέτα θα αφαιρεθούν\n"
 "Αυτό ΔΕΝ θα έπρεπε να συμβεί, εκτός αν ξέρετε τι ακριβώς κάνετε!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu αναβαθμίστηκαν, %lu νέο εγκατεστημένα, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu επανεγκατεστημένα,"
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu υποβαθμισμένα, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu θα αφαιρεθούν και %lu δεν αναβαθμίζονται.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu μη πλήρως εγκατεστημένα ή αφαιρέθηκαν.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Διόρθωση εξαρτήσεων..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " απέτυχε."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Αδύνατη η διόρθωση των εξαρτήσεων"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Αδύνατη η ελαχιστοποίηση του συνόλου αναβαθμίσεων"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Ετοιμο"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 "Ίσως να πρέπει να τρέξετε apt-get -f install για να διορθώσετε αυτά τα "
 "προβλήματα."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Ανεπίλυτες εξαρτήσεις. Δοκιμάστε με το -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ΠΡΟΕΙΔΟΠΟΙΗΣΗ: Τα ακόλουθα πακέτα δεν εξακριβώθηκαν!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Παράκαμψη προειδοποίησης ταυτοποίησης.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Εγκατάσταση των πακέτων χωρίς επαλήθευση [ν/Ο]; "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Μερικά πακέτα δεν εξαακριβώθηκαν"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Υπάρχουν προβλήματα και δώσατε -y  χωρίς το --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Εσωτερικό σφάλμα, έγινε κλήση του Install Packages με σπασμένα πακέτα!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr ""
 "Μερικά πακέτα πρέπει να αφαιρεθούν αλλά η Αφαίρεση είναι απενεργοποιημένη."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Εσωτερικό Σφάλμα, η Ταξινόμηση δεν ολοκληρώθηκε"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Αδύνατη η ανάγνωση της λίστας πηγών."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Πολύ περίεργο! Τα μεγέθη δεν ταιριάζουν, στείλτε μήνυμα στο apt@packages."
 "debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Χρειάζεται να μεταφορτωθούν %sB/%sB από αρχεία.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Χρειάζεται να μεταφορτωθούν %sB από αρχεία.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "Μετά από αυτή τη λειτουργία, θα χρησιμοποιηθούν %sB χώρου από το δίσκο.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Μετά από αυτή τη λειτουργία, θα ελευθερωθούν %sB χώρου από το δίσκο.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Δεν μπόρεσα να προσδιορίσω τον ελεύθερο χώρο στο %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Δεν διαθέτετε αρκετό ελεύθερο χώρο στο  %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Καθορίσατε συνηθισμένο, αλλά αυτή δεν είναι μια συνηθισμένη εργασία"
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ναι, κανε ότι λέω!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -900,28 +898,28 @@
 "Για να συνεχίσετε πληκτρολογήστε τη φράση '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Εγκατάλειψη."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Θέλετε να συνεχίσετε [Ν/ο]; "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Αποτυχία ανάκτησης του %s   %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Για μερικά αρχεία απέτυχε η μεταφόρτωση"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Ολοκληρώθηκε η μεταφόρτωση μόνο"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -929,20 +927,20 @@
 "Αδύνατη η μεταφόρτωση μερικών αρχείων, ίσως αν δοκιμάζατε με apt-get update "
 "ή το --fix-missing;"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr ""
 "ο συνδυασμός --fix-missing με εναλλαγή μέσων δεν υποστηρίζεται για την ώρα"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Αδύνατη η επίλυση των χαμένων πακέτων."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Εγκατάλειψη της εγκατάστασης."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -952,51 +950,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Σημείωση, επιλέχθηκε το %s αντί του%s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Παράκαμψη του %s, είναι εγκατεστημένο και η αναβάθμιση δεν έχει οριστεί.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Παράκαμψη του %s, είναι εγκατεστημένο και η αναβάθμιση δεν έχει οριστεί.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Το πακέτο %s δεν είναι εγκατεστημένο και δεν θα αφαιρεθεί\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Το πακέτο %s είναι εικονικό και παρέχεται από τα:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Εγκατεστημένα]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Υποψήφιες Εκδόσεις"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Θα πρέπει επακριβώς να επιλέξετε ένα για εγκατάσταση."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -1008,68 +1006,68 @@
 "Αυτό σημαίνει ότι το πακέτο αυτό λείπει, είναι παλαιωμένο, ή είναι διαθέσιμο "
 "από άλλη πηγή\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Πάραυτα το ακόλουθο πακέτο το αντικαθιστά:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Το πακέτο %s δεν είναι υποψήφιο για εγκατάσταση"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 "Η επανεγκατάσταση του %s δεν είναι εφικτή, δεν είναι δυνατή η μεταφόρτωσή "
 "του\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "το %s είναι ήδη η τελευταία έκδοση.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Η έκδοση %s για το %s δεν βρέθηκε"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Η έκδοση %s για το %s δεν βρέθηκε"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Επιλέχθηκε η έκδοση %s (%s) για το%s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Αδύνατη η εύρεση της κατάστασης της λίστας πηγαίων πακέτων %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Η εντολή update δεν παίρνει ορίσματα"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Δεν επιτρέπεται οποιαδήποτε διαγραφή· αδυναμία εκκίνησης του AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1081,7 +1079,7 @@
 msgstr[1] ""
 "Τα ακόλουθα πακέτα εγκαταστάθηκαν αυτόματα και δεν χρειάζονται πλέον:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1091,11 +1089,11 @@
 msgstr[1] ""
 "Τα ακόλουθα πακέτα εγκαταστάθηκαν αυτόματα και δεν χρειάζονται πλέον:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Χρησιμοποιήστε 'apt-get autoremove' για να τα διαγράψετε."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1113,43 +1111,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Οι ακόλουθες πληροφορίες ίσως βοηθήσουν στην επίλυση του προβλήματος:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Εσωτερικό Σφάλμα, το AutoRemover δημιούργησε κάποιο πρόβλημα"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Εσωτερικό Σφάλμα, η διαδικασία αναβάθμισης χάλασε"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Αδύνατη η εύρεση του συνόλου πακέτων %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Αδύνατη η εύρεση του πακέτου %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Σημείωση, επιλέχτηκε το %s στη θέση του '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "το %s έχει εγκατασταθεί με το χέρι\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Aν τρέξετε 'apt-get -f install' ίσως να διορθώσετε αυτά τα προβλήματα:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1157,7 +1150,7 @@
 "Ανεπίλυτες εξαρτήσεις. Δοκιμάστε 'apt-get -f install' χωρίς να ορίσετε "
 "πακέτο (ή καθορίστε μια λύση)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1169,129 +1162,144 @@
 "διανομή, ότι μερικά από τα πακέτα δεν έχουν ακόμα δημιουργηθεί ή έχουν\n"
 "μετακινηθεί από τα εισερχόμενα."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Χαλασμένα πακέτα"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Τα ακόλουθα επιπλέον πακέτα θα εγκατασταθούν:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Προτεινόμενα πακέτα:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Συνιστώμενα πακέτα:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "το %s έχει εγκατασταθεί με το χέρι\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Υπολογισμός της αναβάθμισης... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Απέτυχε"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Ετοιμο"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 "Εσωτερικό Σφάλμα, η προσπάθεια επίλυσης του προβλήματος \"έσπασε\" κάποιο "
 "υλικό"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Αδύνατο το κλείδωμα του καταλόγου μεταφόρτωσης"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "Θα πρέπει να καθορίσετε τουλάχιστον ένα πακέτο για να μεταφορτώσετε τον "
 "κωδικάτου"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Αδυναμία εντοπισμού του κώδικά του πακέτου %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Παράκαμψη του ήδη μεταφορτωμένου αρχείου `%s`\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Δεν διαθέτετε αρκετό ελεύθερο χώρο στο %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Χρειάζεται να μεταφορτωθούν %sB/%sB πηγαίου κώδικα.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Χρειάζεται να μεταφορτωθούν %sB πηγαίου κώδικα.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Μεταφόρτωση Κωδικα %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Αποτυχία μεταφόρτωσης μερικών αρχειοθηκών."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Παράκαμψη της αποσυμπίεσης ήδη μεταφορτωμένου κώδικα στο %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Απέτυχε η εντολή αποσυμπίεσης %s\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Ελέγξτε αν είναι εγκαταστημένο το πακέτο 'dpkg-dev'.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Απέτυχε η εντολή χτισίματος %s.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Η απογονική διεργασία απέτυχε"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Θα πρέπει να καθορίσετε τουλάχιστον ένα πακέτο για έλεγχο των εξαρτήσεων του"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Αδύνατη η εύρεση πληροφοριών χτισίματος για το %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "το %s δεν έχει εξαρτήσεις χτισίματος.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1299,7 +1307,7 @@
 msgstr ""
 "%s εξαρτήσεις για το %s δεν ικανοποιούνται επειδή το πακέτο %s δεν βρέθηκε"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1308,32 +1316,32 @@
 "%s εξαρτήσεις για το %s δεν ικανοποιούνται επειδή δεν υπάρχουν διαθέσιμες "
 "εκδόσεις του πακέτου %s που να ικανοποιούν τις απαιτήσεις έκδοσης"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Αποτυχία ικανοποίησης %s εξαρτήσεων για το %s: Το εγκατεστημένο πακέτο %s "
 "είναι νεώτερο"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Αποτυχία ικανοποίησης %s εξάρτησης για το %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Οι εξαρτήσεις χτισίματος για το %s δεν ικανοποιούνται."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Αποτυχία επεξεργασίας εξαρτήσεων χτισίματος"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Υποστηριζόμενοι Οδηγοί:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1670,8 +1678,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Αδύνατη η ανάγνωση του %s"
@@ -1700,10 +1709,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Οι φάκελοι info και temp πρέπει να βρίσκονται στο ίδιο σύστημα αρχείων"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Ανάγνωση Λιστών Πακέτων"
 
@@ -1920,173 +1928,173 @@
 msgid "Write error"
 msgstr "Σφάλμα εγγραφής"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Αδύνατη η δημιουργία μιας υποδοχής (socket)"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Αδύνατη η σύνδεση υποδοχής δεδομένων, λήξη χρόνου σύνδεσης"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Αδύνατη η σύνδεση σε παθητική υποδοχή (socket)."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "Το getaddrinfo ήταν αδύνατο να δέσμευση υποδοχή παρακολούθησης"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Αδύνατη η πρόσδεση στην υποδοχή (socket)"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Αδύνατη η παρακολούθηση της υποδοχής (socket)"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Αδύνατος ο καθορισμός του ονόματος της υποδοχής (socket)"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Αδύνατη η αποστολή της εντολής PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Άγνωστη οικογένεια διευθύνσεων %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Το EPRT απέτυχε, ο διακομιστής απάντησε: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Λήξη χρόνου σύνδεσης στην υποδοχή δεδομένων"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Αδύνατη η αποδοχή συνδέσεων"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Πρόβλημα κατά το hashing του αρχείου"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Αδυναμία λήψης του αρχείου, ο διακομιστής απάντησε '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Λήξη χρόνου υποδοχής δεδομένων"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Αποτυχία κατά τη μεταφορά δεδομένων, ο διακομιστής απάντησε '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Επερώτηση"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Αδύνατη η εκτέλεση"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Σύνδεση στο %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Αδύνατη η δημιουργία υποδοχής για το %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Αδύνατη η αρχικοποίηση της σύνδεσης στο %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Αδύνατη η σύνδεση στο %s:%s (%s), λήξη χρόνου σύνδεσης"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Αδύνατη η σύνδεση στο %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Σύνδεση στο %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Αδύνατη η εύρεση του '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Προσωρινή αποτυχία στην εύρεση του '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Κάτι παράξενο συνέβη κατά την εύρεση του '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Αδύνατη η σύνδεση στο %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Εγκατάλειψη της εγκατάστασης."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Εσωτερικό σφάλμα: Η υπογραφή είναι καλή, αλλά αδυναμία προσδιορισμού του "
 "αποτυπώματος?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Βρέθηκε τουλάχιστον μια μη έγκυρη υπογραφή."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Αδυναμία εκτέλεσης του '%s' για την επαλήθευση της υπογραφής (είναι "
 "εγκατεστημένο το gpgv;)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Άγνωστο σφάλμα κατά την εκτέλεση του gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Οι παρακάτω υπογραφές ήταν μη έγκυρες:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2166,20 +2174,20 @@
 msgid "Error reading from server"
 msgstr "Σφάλμα στην ανάγνωση από το διακομιστή"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Αποτυχία εγγραφής του αρχείου %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Ελαττωματικά δεδομένα επικεφαλίδας"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Η σύνδεση απέτυχε"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Εσωτερικό Σφάλμα"
 
@@ -2245,7 +2253,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Η επιλογή %s δε βρέθηκε"
@@ -2371,6 +2379,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Αδύνατη η αλλαγή σε %s"
@@ -2557,7 +2566,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Αποτυχία εγγραφής του αρχείου κατάστασης %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2693,7 +2702,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Αδύνατη η διόρθωση προβλημάτων, έχετε κρατούμενα ελαττωματικά πακέτα."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2745,12 +2754,12 @@
 "Παρακαλώ εισάγετε το δίσκο με ετικέτα '%s' στη συσκευή '%s' και πατήστε "
 "enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Το σύστημα συσκευασίας '%s' δεν υποστηρίζεται"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Αδύνατος ο καθορισμός ενός κατάλληλου τύπου συστήματος πακέτων"
 
@@ -2763,27 +2772,27 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Πρέπει να τοποθετήσετε μερικά URI 'πηγών' στο sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Αδύνατο το άνοιγμα ή η ανάλυση των λιστών πακέτων ή του αρχείου κατάστασης."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Ίσως να πρέπει να τρέξετε apt-get update για να διορθώσετε αυτά τα προβλήματα"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Μη έγκυρη εγγραφή στο αρχείο προτιμήσεων, καμία επικεφαλίδα Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Αδύνατη η κατανόηση του τύπου καθήλωσης %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr ""
 "Δεν έχει οριστεί προτεραιότητα (ή έχει οριστεί μηδενική) για την καθήλωση"
@@ -2877,32 +2886,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Αδύνατη η εύρεση της κατάστασης της λίστας πηγαίων πακέτων %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Συλλογή Παροχών Αρχείου"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Σφάλμα IO κατά την αποθήκευση της cache πηγών"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "απέτυχε η μετονομασία, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Ανόμοιο MD5Sum"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Ανόμοιο MD5Sum"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Δεν υπάρχει διαθέσιμο δημόσιο κλειδί για τα ακολουθα κλειδιά:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2911,7 +2945,7 @@
 "Αδύνατος ο εντοπισμός ενός αρχείου για το πακέτο %s. Αυτό ίσως σημαίνει ότι "
 "χρειάζεται να διορθώσετε χειροκίνητα το πακέτο. (λόγω χαμένου αρχείου)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2920,7 +2954,7 @@
 "Αδύνατος ο εντοπισμός ενός αρχείου για το πακέτο %s. Αυτό ίσως σημαίνει ότι "
 "χρειάζεται να διορθώσετε χειροκίνητα το πακέτο."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2928,25 +2962,35 @@
 "Κατεστραμμένα αρχεία ευρετηρίου πακέτων. Δεν υπάρχει πεδίο Filename: στο "
 "πακέτο %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Ανόμοιο μέγεθος"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Αδύνατη η ανάλυση του αρχείου πακέτου %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Σημείωση, επιλέχθηκε το %s αντί του%s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Μη έγκυρη γραμμή στο αρχείο παρακάμψεων: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Αδύνατη η ανάλυση του αρχείου πακέτου %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3041,153 +3085,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Οι κατάλογοι με τις πηγές αυτού του δίσκου είναι: \n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Εγιναν %i εγγραφές.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Εγιναν %i εγγραφές με %i απώντα αρχεία.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Εγιναν %i εγγραφές με %i ασύμβατα αρχεία.\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Εγιναν %i εγγραφές με %i απώντα αρχεία και %i ασύμβατα αρχεία\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Άνοιγμα του αρχείου ρυθμίσεων %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Ανόμοιο MD5Sum"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Σημείωση, επιλέχτηκε το %s στη θέση του '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Επιλέχθηκε η έκδοση %s (%s) για το%s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Εγκατάσταση του %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Ρύθμιση του %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Αφαιρώ το %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Το %s διαγράφηκε πλήρως"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Εκτέλεση του post-installation trigger %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Ο φάκελος %s αγνοείται."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Αδύνατο το άνοιγμα του αρχείου %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Προετοιμασία του %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Ξεπακετάρισμα του %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Προετοιμασία ρύθμισης του %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Έγινε εγκατάσταση του %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Προετοιμασία για την αφαίρεση του %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Αφαίρεσα το %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Προετοιμασία πλήρης αφαίρεσης του %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Το %s διαγράφηκε πλήρως"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Αδυναμία εγγραφής στο αρχείο γεγονότων, λόγω αποτυχίας του openpyt() (είναι "
 "προσαρτημένο το /dev/pts;)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Αδύνατο το κλείδωμα του καταλόγου"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3202,7 +3329,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Η σύνδεση έκλεισε πρόωρα"
 

=== modified file 'po/en_GB.po'
--- po/en_GB.po	2010-05-25 16:01:42 +0000
+++ po/en_GB.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.18\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-13 11:47+0000\n"
 "Last-Translator: Neil Williams <linux@codehelp.co.uk>\n"
 "Language-Team: en_GB <en_gb@li.org>\n"
@@ -15,147 +15,145 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Package %s version %s has an unmet dep:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Unable to locate package %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Total package names: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Total package names: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normal packages: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Pure virtual packages: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Single virtual packages: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Mixed virtual packages: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Missing: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Total distinct versions: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Total distinct descriptions: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Total dependencies: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Total ver/file relations: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Total Desc/File relations: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Total Provides mappings: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Total globbed strings: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Total dependency version space: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Total slack space: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Total space accounted for: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Package file %s is out of sync."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "You must give exactly one pattern"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "No packages found"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Unable to locate package %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Package files:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Cache is out of sync, can't x-ref a package file"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pinned packages:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(not found)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Installed: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidate: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(none)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Package pin: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Version table:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s for %s compiled on %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -310,12 +308,12 @@
 "  -c=? Read this configuration file\n"
 "  -o=? Set an arbitrary configuration option, eg -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Unable to write to %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Cannot get debconf version. Is debconf installed?"
 
@@ -650,79 +648,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Failed to rename %s to %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Regex compilation error - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "The following packages have unmet dependencies."
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "but %s is installed"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "but %s is to be installed"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "but it is not installable"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "but it is a virtual package"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "but it is not installed"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "but it is not going to be installed"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " or"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "The following NEW packages will be installed"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "The following packages will be REMOVED"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "The following packages have been kept back:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "The following packages will be upgraded:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "The following packages will be DOWNGRADED:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "The following held packages will be changed:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (due to %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -730,140 +728,140 @@
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu upgraded, %lu newly installed, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstalled, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu downgraded, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu to remove and %lu not upgraded.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu not fully installed or removed.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Correcting dependencies..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " failed."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Unable to correct dependencies"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Unable to minimise the upgrade set"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr "Done"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "You might want to run ‘apt-get -f install’ to correct these."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Unmet dependencies. Try using -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "WARNING: The following packages cannot be authenticated!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Authentication warning overridden.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Install these packages without verification [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Some packages could not be authenticated"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "There are problems and -y was used without --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Internal error, InstallPackages was called with broken packages!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Packages need to be removed but remove is disabled."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Internal error, Ordering didn't finish"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "The list of sources could not be read."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "How odd.. The sizes didn't match, email apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Need to get %sB/%sB of archives.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Need to get %sB of archives.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "After this operation, %sB of additional disk space will be used.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "After this operation, %sB disk space will be freed.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Couldn't determine free space in %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "You don't have enough free space in %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Trivial Only specified but this is not a trivial operation."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Yes, do as I say!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -874,28 +872,28 @@
 "To continue type in the phrase ‘%s’\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Abort."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Do you want to continue [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Failed to fetch %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Some files failed to download"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Download complete and in download only mode"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -903,19 +901,19 @@
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing and media swapping is not currently supported"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Unable to correct missing packages."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Aborting install."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -925,49 +923,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Note, selecting %s instead of %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Skipping %s, it is already installed and upgrade is not set.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Skipping %s, it is already installed and upgrade is not set.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Package %s is not installed, so not removed\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Package %s is a virtual package provided by:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Installed]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Candidate versions"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "You should explicitly select one to install."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -978,65 +976,65 @@
 "This may mean that the package is missing, has been obsoleted, or\n"
 "is only available from another source\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "However the following packages replace it:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Package %s has no installation candidate"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s is already the newest version.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Release ‘%s’ for ‘%s’ was not found"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Version ‘%s’ for ‘%s’ was not found"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Selected version %s (%s) for %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Couldn't stat source package list %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "The update command takes no arguments"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "We are not supposed to delete stuff, cannot start AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1050,7 +1048,7 @@
 "The following packages were automatically installed and are no longer "
 "required:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1062,11 +1060,11 @@
 "The following packages were automatically installed and are no longer "
 "required:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Use 'apt-get autoremove' to remove them."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1084,223 +1082,233 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "The following information may help to resolve the situation:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Internal Error, AutoRemoved broke stuff"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Internal error, AllUpgrade broke stuff"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Couldn't find task %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Couldn't find package %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Note, selecting %s for regex ‘%s’\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s set to manually installed.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "You might want to run 'apt-get -f install' to correct these:"
 
-#: cmdline/apt-get.cc:1865
-msgid ""
-"Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
-"solution)."
-msgstr ""
-"Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
-"solution)."
-
-#: cmdline/apt-get.cc:1877
-msgid ""
-"Some packages could not be installed. This may mean that you have\n"
-"requested an impossible situation or if you are using the unstable\n"
-"distribution that some required packages have not yet been created\n"
-"or been moved out of Incoming."
-msgstr ""
-"Some packages could not be installed. This may mean that you have\n"
-"requested an impossible situation or if you are using the unstable\n"
-"distribution that some required packages have not yet been created\n"
-"or been moved out of Incoming."
-
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1839
+msgid ""
+"Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
+"solution)."
+msgstr ""
+"Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
+"solution)."
+
+#: cmdline/apt-get.cc:1851
+msgid ""
+"Some packages could not be installed. This may mean that you have\n"
+"requested an impossible situation or if you are using the unstable\n"
+"distribution that some required packages have not yet been created\n"
+"or been moved out of Incoming."
+msgstr ""
+"Some packages could not be installed. This may mean that you have\n"
+"requested an impossible situation or if you are using the unstable\n"
+"distribution that some required packages have not yet been created\n"
+"or been moved out of Incoming."
+
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Broken packages"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "The following extra packages will be installed:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Suggested packages:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Recommended packages:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s set to manually installed.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Calculating upgrade... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Failed"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Done"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Internal error, problem resolver broke stuff"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Unable to lock the download directory"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Must specify at least one package for which to fetch source"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Unable to find a source package for %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Skipping already downloaded file '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "You don't have enough free space in %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Need to get %sB/%sB of source archives.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Need to get %sB of source archives.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Fetch source %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Failed to fetch some archives."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Skipping unpack of already unpacked source in %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Unpack command ‘%s’ failed.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Check if the 'dpkg-dev' package is installed.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Build command ‘%s’ failed.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Child process failed"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Must specify at least one package for which you want to check builddeps"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Unable to get build-dependency information for %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s has no build depends.\n"
 
-#: cmdline/apt-get.cc:2633
-#, c-format
-msgid ""
-"%s dependency for %s cannot be satisfied because the package %s cannot be "
-"found"
-msgstr ""
-"%s dependency for %s cannot be satisfied because the package %s cannot be "
-"found"
-
-#: cmdline/apt-get.cc:2686
-#, c-format
-msgid ""
-"%s dependency for %s cannot be satisfied because no available versions of "
-"package %s can satisfy version requirements"
-msgstr ""
-"%s dependency for %s cannot be satisfied because no available versions of "
-"package %s can satisfy version requirements"
-
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2634
+#, c-format
+msgid ""
+"%s dependency for %s cannot be satisfied because the package %s cannot be "
+"found"
+msgstr ""
+"%s dependency for %s cannot be satisfied because the package %s cannot be "
+"found"
+
+#: cmdline/apt-get.cc:2687
+#, c-format
+msgid ""
+"%s dependency for %s cannot be satisfied because no available versions of "
+"package %s can satisfy version requirements"
+msgstr ""
+"%s dependency for %s cannot be satisfied because no available versions of "
+"package %s can satisfy version requirements"
+
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Failed to satisfy %s dependency for %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Build-dependencies for %s could not be satisfied."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Failed to process build dependencies"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Supported modules:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1635,8 +1643,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Unable to read %s"
@@ -1665,10 +1674,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "The info and temp directories need to be on the same filesystem"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Reading package lists"
 
@@ -1884,170 +1892,170 @@
 msgid "Write error"
 msgstr "Write error"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Could not create a socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Could not connect data socket, connection timed out"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Could not connect, passive socket."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo was unable to get a listening socket"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Could not bind a socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Could not listen on the socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Could not determine the name of the socket"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Unable to send PORT command"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Unknown address family %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT failed, server said: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Data socket connect timed out"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Unable to accept connection"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problem hashing file"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Unable to fetch file, server said ‘%s’"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Data socket timed out"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Data transfer failed, server said ‘%s’"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Query"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Unable to invoke"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Connecting to %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Could not create a socket for %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Cannot initiate the connection to %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Could not connect to %s:%s (%s), connection timed out"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Could not connect to %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Connecting to %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Could not resolve ‘%s’"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Temporary failure resolving ‘%s’"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Something wicked happened resolving ‘%s:%s’ (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Unable to connect to %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Aborting install."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "At least one invalid signature was encountered."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "Could not execute '%s' to verify signature (is gpgv installed?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Unknown error executing gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "The following signatures were invalid:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2126,19 +2134,19 @@
 msgid "Error reading from server"
 msgstr "Error reading from server"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Failed to truncate file"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Bad header data"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Connection failed"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Internal error"
 
@@ -2204,7 +2212,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Selection %s not found"
@@ -2327,6 +2335,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Unable to change to %s"
@@ -2510,7 +2519,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Failed to write temporary StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2644,7 +2653,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Unable to correct problems, you have held broken packages."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2695,12 +2704,12 @@
 msgstr ""
 "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Packaging system ‘%s’ is not supported"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Unable to determine a suitable packaging system type"
 
@@ -2713,25 +2722,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "You must put some 'source' URIs in your sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "The package lists or status file could not be parsed or opened."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "You may want to run apt-get update to correct these problems"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Invalid record in the preferences file, no Package header"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Did not understand pin type %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "No priority (or zero) specified for pin"
 
@@ -2820,75 +2829,110 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Couldn't stat source package list %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Collecting File Provides"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IO Error saving source cache"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "rename failed, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum mismatch"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash Sum mismatch"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "There is no public key available for the following key IDs:\n"
 
-#: apt-pkg/acquire-item.cc:1260
-#, c-format
-msgid ""
-"I wasn't able to locate a file for the %s package. This might mean you need "
-"to manually fix this package. (due to missing arch)"
-msgstr ""
-"I wasn't able to locate a file for the %s package. This might mean you need "
-"to manually fix this package. (due to missing arch)"
-
-#: apt-pkg/acquire-item.cc:1319
-#, c-format
-msgid ""
-"I wasn't able to locate file for the %s package. This might mean you need to "
-"manually fix this package."
-msgstr ""
-"I wasn't able to locate file for the %s package. This might mean you need to "
-"manually fix this package."
-
-#: apt-pkg/acquire-item.cc:1374
-#, c-format
-msgid ""
-"The package index files are corrupted. No Filename: field for package %s."
-msgstr ""
-"The package index files are corrupted. No Filename: field for package %s."
-
-#: apt-pkg/acquire-item.cc:1461
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
+#, c-format
+msgid ""
+"I wasn't able to locate a file for the %s package. This might mean you need "
+"to manually fix this package. (due to missing arch)"
+msgstr ""
+"I wasn't able to locate a file for the %s package. This might mean you need "
+"to manually fix this package. (due to missing arch)"
+
+#: apt-pkg/acquire-item.cc:1400
+#, c-format
+msgid ""
+"I wasn't able to locate file for the %s package. This might mean you need to "
+"manually fix this package."
+msgstr ""
+"I wasn't able to locate file for the %s package. This might mean you need to "
+"manually fix this package."
+
+#: apt-pkg/acquire-item.cc:1455
+#, c-format
+msgid ""
+"The package index files are corrupted. No Filename: field for package %s."
+msgstr ""
+"The package index files are corrupted. No Filename: field for package %s."
+
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Size mismatch"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Unable to parse package file %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Note, selecting %s instead of %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Invalid line in the diversion file: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Unable to parse package file %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2983,151 +3027,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Source list entries for this disc are:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Wrote %i records.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Wrote %i records with %i missing files.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Wrote %i records with %i mismatched files\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Wrote %i records with %i missing files and %i mismatched files\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Opening configuration file %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash Sum mismatch"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Note, selecting %s for regex ‘%s’\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Selected version %s (%s) for %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Installing %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Configuring %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Removing %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Completely removed %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Running post-installation trigger %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Directory '%s' missing."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Could not open file %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Preparing %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Unpacking %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Preparing to configure %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Installed %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Preparing for removal of %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Removed %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Preparing to completely remove %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Completely removed %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Unable to lock the list directory"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3142,7 +3269,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Connection closed prematurely"
 

=== modified file 'po/es.po'
--- po/es.po	2010-05-25 16:01:42 +0000
+++ po/es.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.18\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-15 21:52+0100\n"
 "Last-Translator: Javier Fernandez-Sanguino <jfs@debian.org>\n"
 "Language-Team: Debian Spanish <debian-l10n-spanish@lists.debian.org>\n"
@@ -17,149 +17,147 @@
 "Content-Type: text/plain; charset=ISO-8859-1\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "El paquete %s versin %s tiene dependencias incumplidas:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "No se ha podido localizar el paquete %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Nombres de paquetes totales: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Nombres de paquetes totales: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Paquetes normales: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Paquetes virtuales puros: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Paquetes virtuales nicos: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Paquetes virtuales mixtos: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Faltan: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Versiones diferentes totales: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Descipciones diferentes totales: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Dependencias totales: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Relaciones versin/archivo totales: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Relaciones descripcin/archivo totales: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Mapeo Total de Provisiones: "
 
 # globbed -> globalizadas ? (jfs)
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Cadenas globalizadas totales: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Espacio de versin de dependencias total: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Espacio desperdiciado total: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Espacio registrado total: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "El archivo de paquetes %s est desincronizado."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
-msgstr "Debe dar exactamente un patrn"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
+msgstr "Debes dar cuando menos un nombre de archivo"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "No se encontr ningn paquete"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "No se ha podido localizar el paquete %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Archivos de paquetes:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Cach fuera de sincronismo, no se puede hacer x-ref a un archivo de paquetes"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Paquetes con pin:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(no encontrado)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalados: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidato: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ninguno)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Pin del paquete: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabla de versin:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s para %s compilado en %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -320,12 +318,12 @@
 "  -o=? Establece una opcin de configuracin arbitraria, p. ej. -o dir::"
 "cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "No se puede escribir en %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "No se puede encontrar la versin de debconf. Est debconf instalado?"
 
@@ -665,79 +663,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Fall el renombre de %s a %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "S"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Error de compilacin de expresiones regulares - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Los siguientes paquetes tienen dependencias incumplidas:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "pero %s est instalado"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "pero %s va a ser instalado"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "pero no es instalable"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "pero es un paquete virtual"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "pero no est instalado"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "pero no va a instalarse"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " o"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Se instalarn los siguientes paquetes NUEVOS:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Los siguientes paquetes se ELIMINARN:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Los siguientes paquetes se han retenido:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Se actualizarn los siguientes paquetes:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Se DESACTUALIZARN los siguientes paquetes:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Se cambiarn los siguientes paquetes retenidos:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (por %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -745,143 +743,143 @@
 "AVISO: Se van a eliminar los siguientes paquetes esenciales.\n"
 "NO debe hacerse a menos que sepa exactamente lo que est haciendo!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu actualizados, %lu se instalarn, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstalados, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu desactualizados, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu para eliminar y %lu no actualizados.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu no instalados del todo o eliminados.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Corrigiendo dependencias..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " fall."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "No se puede corregir las dependencias"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "No se puede minimizar el conjunto de actualizacin"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Listo"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Tal vez quiera ejecutar 'apt-get -f install' para corregirlo."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dependencias incumplidas. Pruebe de nuevo usando -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "AVISO: No se han podido autenticar los siguientes paquetes!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Aviso de autenticacin ignorado.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Instalar estos paquetes sin verificacin [s/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Algunos paquetes no se pueden autenticar"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Hay problemas y se utiliz -y sin --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Error interno, InstallPackages fue llamado con un paquete roto!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Los paquetes necesitan eliminarse pero Remove est deshabilitado."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Error interno, no termin el ordenamiento"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "No se pudieron leer las listas de fuentes."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Que raro.. Los tamaos no concuerdan, mande un correo a \n"
 "apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Se necesita descargar %sB/%sB de archivos.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Necesito descargar %sB de archivos.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "Se utilizarn %sB de espacio de disco adicional despus de esta operacin.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Se liberarn %sB despus de esta operacin.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "No pude determinar el espacio libre en %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "No tiene suficiente espacio libre en %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Se especific Trivial Only pero sta no es una operacin trivial."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "S, haga lo que le digo!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -892,28 +890,28 @@
 "Para continuar escriba la frase %s\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Abortado."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Desea continuar [S/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Imposible obtener %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Algunos archivos no pudieron descargarse"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Descarga completa y en modo de slo descarga"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -921,19 +919,19 @@
 "No se pudieron obtener algunos archivos, quizs deba ejecutar\n"
 "apt-get update o deba intentarlo de nuevo con --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "Actualmente no estn soportados --fix-missing e intercambio de medio"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "No se pudieron corregir los paquetes que faltan."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Abortando la instalacin."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -943,49 +941,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Nota, seleccionando %s en lugar de %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Ignorando %s, ya esta instalado y la actualizacin no esta activada.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Ignorando %s, ya esta instalado y la actualizacin no esta activada.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "El paquete %s no esta instalado, no se eliminar\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "El paquete %s es un paquete virtual provisto por:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Instalado]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versiones candidatas"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Necesita seleccionar explcitamente uno para instalar."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -996,66 +994,66 @@
 "a l. Esto puede significar que el paquete falta, est obsoleto o slo se\n"
 "encuentra disponible desde alguna otra fuente\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Sin embargo, los siguientes paquetes lo reemplazan:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "El paquete %s no tiene candidato para su instalacin"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "No es posible reinstalar el paquete %s, no se puede descargar.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s ya est en su versin ms reciente.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "No se encontr la Distribucin '%s' para '%s'"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "No se encontr la versin '%s' para '%s'"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Versin seleccionada %s (%s) para %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "No se puede leer la lista de paquetes fuente %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "El comando de actualizacin no toma argumentos"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Se supone que no vamos a eliminar cosas, no se pudo iniciar AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1069,7 +1067,7 @@
 "Se instalaron de forma automtica los siguientes paquetes y ya no son "
 "necesarios."
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1081,11 +1079,11 @@
 "Se instalaron de forma automtica los siguientes paquetes y ya no son "
 "necesarios."
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Utilice apt-get autoremove para eliminarlos."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1103,43 +1101,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "La siguiente informacin puede ayudar a resolver la situacin:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Error interno, AutoRemover rompi cosas"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Error Interno, AllUpgrade rompi cosas"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "No se pudo encontrar la tarea %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "No se pudo encontrar el paquete %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Nota, seleccionando %s para la expresin regular '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "fijado %s como instalado manualmente.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Tal vez quiera ejecutar 'apt-get -f install' para corregirlo:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1147,7 +1140,7 @@
 "Dependencias incumplidas. Intente 'apt-get -f install' sin paquetes (o "
 "especifique una solucin)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1159,128 +1152,143 @@
 "inestable, que algunos paquetes necesarios no han sido creados o han\n"
 "sido movidos fuera de Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Paquetes rotos"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Se instalarn los siguientes paquetes extras:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Paquetes sugeridos:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Paquetes recomendados"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "fijado %s como instalado manualmente.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Calculando la actualizacin... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Fall"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Listo"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 "Error interno, el sistema de solucin de problemas rompi\n"
 "algunas cosas"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "No se puede bloquear el directorio de descarga"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Debe especificar al menos un paquete para obtener su cdigo fuente"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "No se pudo encontrar un paquete de fuentes para %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Ignorando fichero ya descargado '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "No tiene suficiente espacio libre en %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Necesito descargar %sB/%sB de archivos fuente.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Necesito descargar %sB de archivos fuente.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Fuente obtenida %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "No se pudieron obtener algunos archivos."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Ignorando desempaquetamiento de paquetes ya desempaquetados en %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Fall la orden de desempaquetamiento '%s'.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Compruebe que el paquete dpkg-dev est instalado.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Fall la orden de construccin '%s'.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Fall el proceso hijo"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Debe especificar al menos un paquete para verificar sus\n"
 "dependencias de construccin"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "No se pudo obtener informacin de dependencias de construccin para %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s no tiene dependencias de construccin.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1289,7 +1297,7 @@
 "La dependencia %s en %s no puede satisfacerse porque no se puede \n"
 "encontrar el paquete %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1298,32 +1306,32 @@
 "La dependencia %s en %s no puede satisfacerse porque ninguna versin\n"
 "disponible del paquete %s satisface los requisitos de versin"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "No se pudo satisfacer la dependencia %s para %s: El paquete instalado %s es "
 "demasiado nuevo"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "No se pudo satisfacer la dependencia %s para %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "No se pudieron satisfacer las dependencias de construccin de %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "No se pudieron procesar las dependencias de construccin"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Mdulos soportados:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1665,8 +1673,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "No pude leer %s"
@@ -1696,10 +1705,9 @@
 msgstr ""
 "Los directorios info y temp deben de estar en el mismo sistema de archivos"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Leyendo lista de paquetes"
 
@@ -1915,171 +1923,171 @@
 msgid "Write error"
 msgstr "Error de escritura"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "No pude crear un socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "No pude conectar el socket de datos, expir el tiempo de conexin"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "No pude conectar un socket pasivo."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo no pude obtener un socket oyente"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "No pude ligar un socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "No pude escuchar en el socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "No pude determinar el nombre del socket"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "No pude mandar la orden PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Direccin de familia %u desconocida (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT fall, el servidor dijo: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Expir conexin a socket de datos"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "No pude aceptar la conexin"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Hay problemas enlazando fichero"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Imposible traer archivo, el servidor dijo '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Expir el socket de datos"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Fall transferencia de datos, el servidor dijo '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Consulta"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "No pude invocar "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Conectando a %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "No pude crear un socket para %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "No puedo iniciar la conexin a %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "No pude conectarme a %s:%s (%s), expir tiempo para conexin"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "No pude conectarme a %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Conectando a %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "No pude resolver '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Fallo temporal al resolver '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Algo raro pas resolviendo '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "No pude conectarme a %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Abortando la instalacin."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Error interno: Firma correcta, pero no se pudo determinar su huella digital?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Se encontr al menos una firma invlida."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "No se pudo ejecutar '%s'  para verificar la firma (est instalado gpgv?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Error desconocido ejecutando gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Las siguientes firms fueron invlidas:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2158,19 +2166,19 @@
 msgid "Error reading from server"
 msgstr "Error leyendo del servidor"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Fall al truncar el archivo"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Mala cabecera Data"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Fallo la conexin"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Error interno"
 
@@ -2236,7 +2244,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Seleccin %s no encontrada"
@@ -2365,6 +2373,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "No se pudo cambiar a %s"
@@ -2548,7 +2557,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Fall la escritura del fichero de estado temporal %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, fuzzy, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr "Error interno, no pude leer un rcord del paquete"
@@ -2686,7 +2695,7 @@
 "No se pudieron corregir los problemas, usted ha retenido paquetes\n"
 "rotos."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2736,12 +2745,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Por favor, inserte el disco %s en la unidad %s y presione Intro"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "El sistema de paquetes '%s' no est soportado"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "No se pudo determinar un tipo de sistema de paquetes adecuado"
 
@@ -2754,28 +2763,28 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Debe poner algunos URIs 'fuente' en su sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "No se pudieron analizar o abrir las listas de paquetes o el archivo de "
 "estado."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Tal vez quiera ejecutar 'apt-get update' para corregir estos problemas"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "Registro invlido en el archivo de preferencias, no hay cabecera de paquete"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "No se entiende el pin tipo %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "No hay prioridad especificada para pin (o es cero)"
 
@@ -2870,34 +2879,59 @@
 msgid "Couldn't stat source package list %s"
 msgstr "No se puede leer la lista de paquetes fuente %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Recogiendo archivos que proveen"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Error de E/S guardando cach fuente"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "fall el cambio de nombre, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "La suma MD5 difiere"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "La suma hash difiere"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "No existe ninguna clave pblica disponible para los siguientes "
 "identificadores de clave:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2907,7 +2941,7 @@
 "que necesita arreglar manualmente este paquete (debido a que falta una "
 "arquitectura)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2916,7 +2950,7 @@
 "No se pudo localizar un archivo para el paquete %s. Esto puede significar "
 "que necesita arreglar manualmente este paquete."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2924,25 +2958,35 @@
 "Los archivos de ndice de paquetes estn corrompidos. El campo 'Filename:' "
 "no existe para para el paquete %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "El tamao difiere"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "No se pudo tratar el archivo de paquetes %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Nota, seleccionando %s en lugar de %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Linea invlida en el archivo de desviacin: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "No se pudo tratar el archivo de paquetes %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3040,154 +3084,237 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Las entradas de la lista de fuentes para este disco son:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i registros escritos.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i registros escritos con %i fichero de menos.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i registros escritos con %i fichero mal emparejado\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "%i registros escritos con %i fichero de menos y %i ficheros mal emparejados\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Abriendo fichero de configuracin %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "La suma hash difiere"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Nota, seleccionando %s para la expresin regular '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Versin seleccionada %s (%s) para %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Instalando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Configurando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Eliminando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Se borr completamente %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Ejecutando disparador post-instalacin %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Falta el directorio '%s'."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "No pude abrir el fichero %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Preparando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Desempaquetando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Preparndose para configurar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s instalado"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Preparndose para eliminar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s eliminado"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Preparndose para eliminar completamente %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Se borr completamente %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "No se pudo escbribir en el registro, fall la llamada a openpty() (est "
 "montado /dev/pts?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "No se pudo bloquear el directorio de listas"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3202,10 +3329,13 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "La conexin se cerr prematuramente"
 
+#~ msgid "You must give exactly one pattern"
+#~ msgstr "Debe dar exactamente un patrn"
+
 #~ msgid "E: Argument list from Acquire::gpgv::Options too long. Exiting."
 #~ msgstr ""
 #~ "E: Lista de argumentos de Acquire::gpgv::Options demasiado larga. "
@@ -3458,9 +3588,6 @@
 #~ msgid "Unimplemented"
 #~ msgstr "No est implementado"
 
-#~ msgid "You must give at least one file name"
-#~ msgstr "Debes dar cuando menos un nombre de archivo"
-
 #~ msgid "Generating cache"
 #~ msgstr "Generando el cach"
 

=== modified file 'po/eu.po'
--- po/eu.po	2010-05-25 16:01:42 +0000
+++ po/eu.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: apt_po_eu\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-05-17 00:41+0200\n"
 "Last-Translator: Piarres Beobide <pi@beobide.net>\n"
 "Language-Team: Euskara <debian-l10n-basque@lists.debian.org>\n"
@@ -17,149 +17,147 @@
 "X-Generator: KBabel 1.11.4\n"
 "Plural-Forms: nplurals=2; plural=(n != 1)\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "%s paketeak (%s bertsioa) mendekotasun arazo bat du:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Ezin da %s paketea lokalizatu"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Pakete Izenak Guztira : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Pakete Izenak Guztira : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Pakete normalak:"
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Pakete birtual puruak:"
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Bakanako pakete birtualak: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Nahastutako pakete birtualak: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Falta direnak: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Bertsio Ezberdinak Guztira: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Azalpen Ezberdinak Guztira: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Dependentziak Guztira: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Guztira Bertsio/fitxategi erlazioak: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Fitx/Azalpen erlazioak guztira: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Guztira Saltzaile Mapatzea: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Guztira bateratutako kateak: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Guztira bertsio dependentzia lekua: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Guztira galdutako tokia:"
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Guztira erregistratutako lekua: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "%s pakete fitxategia ez dago sinkronizatuta."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Zehazki eredu bat eman behar duzu."
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Ez da paketerik aurkitu"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Ezin da %s paketea lokalizatu"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Pakete Fitxategiak:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Katxea ez dago sinkronizatuta, ezin zaio erreferentziarik (x-ref) egin "
 "pakete fitxategi bati"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pin duten Paketeak:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(ez da aurkitu)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalatuta: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Hautagaia: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(bat ere ez)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Paketearen pin-a:"
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Bertsio taula:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s %s-rentzat %s %s-ean konpilatua\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -314,12 +312,12 @@
 "  -c=? Irakurri konfigurazio fitxategi hau\n"
 "  -o=? Ezarri konfigurazio aukera arbitrario bat. Adib.: -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "%s : ezin da idatzi"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Ezin da debconf bertsioa eskuratu. Debconf instalatuta dago?"
 
@@ -653,79 +651,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Huts egin du %s izenaren ordez %s ipintzean"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Adierazpen erregularren konpilazio errorea - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Ondorengo paketeetan bete gabeko mendekotasunak daude:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "baina %s instalatuta dago"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "baina %s instalatzeko dago"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "baina ez da instalagarria"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "baina pakete birtuala da"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "baina ez dago instalatuta"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "baina ez da instalatuko"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " edo"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Ondorengo pakete BERRIAK instalatuko dira:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Ondorengo paketeak KENDUKO dira:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Ondorengo paketeak mantendu egin dira:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Ondorengo paketeak bertsio-berrituko dira:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Ondorengo paketeak AURREKO BERTSIORA itzuliko dira:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Ondorengo pakete atxikiak aldatu egingo dira:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (arrazoia: %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -733,142 +731,142 @@
 "KONTUZ: Ondorengo funtsezko paketeak kendu egingo dira\n"
 "EZ ezazu horrelakorik egin, ez badakizu ondo zertan ari zaren!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu bertsio berritua(k), %lu berriki instalatuta, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu berrinstalatuta, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu aurreko bertsiora itzulita, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu kentzeko, eta %lu bertsio-berritu gabe.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu ez erabat instalatuta edo kenduta.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Mendekotasunak zuzentzen..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " : huts egin du."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Ezin dira mendekotasunak zuzendu"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Ezin da bertsio berritzeko multzoa minimizatu"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Eginda"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Beharbada 'apt-get -f install' exekutatu nahiko duzu zuzentzeko."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Bete gabeko mendekotasunak. Probatu -f erabiliz."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "KONTUZ: Hurrengo paketeak ezin dira egiaztatu!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Egiaztapen abisua gainidazten.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Paketeak egiaztapen gabe instalatu [b/E]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Zenbait pakete ezin dira egiaztatu"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Arazoak daude, eta -y erabili da --force-yes gabe"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Barne errorea, InstallPackages apurturiko paketeez deitu da!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Paketeak ezabatu beharra dute baina Ezabatzea ezgaiturik dago."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Barne errorea, ez da ordenatzeaz amaitu"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Ezin izan da Iturburu zerrenda irakurri."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Hau bitxia.. Tamainak ez dira berdina, idatzi apt@packages.debian.org-ra "
 "berri emanez (ingelesez)"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Artxiboetako %sB/%sB eskuratu behar dira.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Artxiboetako %sB eskuratu behar dira.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Ekintza honen ondoren, %sB gehiago erabiliko dira diskoan.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Ekintza honen ondoren, %sB libratuko dira diskoan.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Ezin da %s(e)n duzun leku librea atzeman."
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Ez daukazu nahikoa leku libre %s(e)n."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "'Trivial Only' zehaztu da, baina hau ez da eragiketa tribial bat."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Bai, egin esandakoa!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -879,28 +877,28 @@
 "Jarraitzeko, idatzi '%s' esaldia\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Abortatu."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Aurrera jarraitu nahi al duzu [B/e]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Ezin da lortu %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Fitxategi batzuk ezin izan dira deskargatu"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Deskarga amaituta eta deskarga soileko moduan"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -908,19 +906,19 @@
 "Ezin izan dira artxibo batzuk lortu; beharbada apt-get update exekutatu, edo "
 "--fix-missing aukerarekin saiatu?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing eta euskarri aldaketa ez dira onartzen oraingoz"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Falta diren paketeak ezin dira zuzendu."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Abortatu instalazioa."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -930,49 +928,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Oharra, %s hautatzen %s(r)en ordez\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "%s saltatzen. Instalatuta dago, eta ez dago bertsio-berritzerik.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "%s saltatzen. Instalatuta dago, eta ez dago bertsio-berritzerik.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "%s paketea ez dago instalatuta, eta, beraz, ez da kenduko\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "%s pakete birtual bat da, honek hornitua:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Instalatuta]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Hautagaien bertsioak"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Zehazki bat hautatu behar duzu instalatzeko."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -983,65 +981,65 @@
 "egiten dio. Beharbada paketea faltako da, edo zaharkituta egongo da, edo \n"
 "beste iturburu batean bakarrik egongo da erabilgarri\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Baina ondorengo paketeek ordezten dute:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "%s paketeak ez du instalatzeko hautagairik"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "%s berriro instalatzea ez da posible; ezin da deskargatu.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s bertsiorik berriena da jada.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "'%2$s'(r)en '%1$s' banaketa ez da aurkitu"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "'%2$s'(r)en '%1$s' bertsioa ez da aurkitu"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Hautatutako bertsioa: %s (%s) -- %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Ezin da atzitu %s iturburu paketeen zerrenda"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Eguneratzeko komandoak ez du argumenturik hartzen"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Suposatu ez dugun zerbait ezabatuko da, ezin da AutoRemover abiarazi"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1055,7 +1053,7 @@
 "Ondorengo pakete automatikoki instalatuak izan ziren eta ez dira luzaroago "
 "behar."
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1067,11 +1065,11 @@
 "Ondorengo pakete automatikoki instalatuak izan ziren eta ez dira luzaroago "
 "behar."
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "'apt-get autoremove' erabili ezabatzeko."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1089,43 +1087,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Informazio honek arazoa konpontzen lagun dezake:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Barne Errorea, AutoRemover-ek zerbait apurtu du"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Barne Errorea, AllUpgade-k zerbait apurtu du"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Ezin izan da %s zeregina aurkitu"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Ezin izan da %s paketea aurkitu"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Oharra: %s hautatzen '%s' adierazpen erregularrarentzat\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s eskuz instalatua bezala ezarri.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Beharbada 'apt-get -f install' exekutatu nahiko duzu hauek zuzentzeko:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1133,7 +1126,7 @@
 "Bete gabeko mendekotasunak. Probatu 'apt-get -f install' paketerik gabe (edo "
 "zehaztu konponbide bat)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1145,126 +1138,141 @@
 "beharrezko pakete batzuk ez ziren sortuko oraindik, edo \n"
 "Sarrerakoetan (Incoming) egoten jarraituko dute."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Hautsitako paketeak"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Ondorengo pakete gehigarriak instalatuko dira:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Iradokitako paketeak:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Gomendatutako paketeak:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s eskuz instalatua bezala ezarri.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Berriketak kalkulatzen... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Huts egin du"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Eginda"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Barne Errorea, arazo konpontzaileak zerbait apurtu du"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Ezin da deskarga direktorioa blokeatu"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Gutxienez pakete bat zehaztu behar duzu iturburua lortzeko"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Ezin da iturburu paketerik aurkitu %s(r)entzat"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Dagoeneko deskargaturiko '%s' fitxategia saltatzen\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Ez daukazu nahikoa leku libre %s(e)n."
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Iturburu artxiboetako %sB/%sB eskuratu behar dira.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Iturburu artxiboetako %sB eskuratu behar dira.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Eskuratu %s iturburua\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Huts egin du zenbat artxibo lortzean."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 "%s(e)n dagoeneko deskonprimitutako iturburua deskonprimitzea saltatzen\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Deskonprimitzeko '%s' komandoak huts egin du.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Egiaztatu 'dpkg-dev' paketea instalaturik dagoen.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Eraikitzeko '%s' komandoak huts egin du.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Prozesu umeak huts egin du"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Gutxienez pakete bat zehaztu behar duzu eraikitze mendekotasunak egiaztatzeko"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Ezin izan da %s(r)en eraikitze mendekotasunen informazioa eskuratu"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s: ez du eraikitze mendekotasunik.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1272,7 +1280,7 @@
 msgstr ""
 "%2$s(r)en %1$s mendekotasuna ezin da bete, %3$s paketea ezin delako aurkitu"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1281,32 +1289,32 @@
 "%2$s(r)en %1$s mendekotasuna ezin da bete, ez baitago bertsio-eskakizunak "
 "betetzen dituen %3$s paketearen bertsio erabilgarririk"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Huts egin du %2$s(r)en %1$s mendekotasuna betetzean: instalatutako %3$s "
 "paketea berriegia da"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Huts egin du %2$s(r)en %1$s mendekotasuna betetzean: %3$s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "%s(r)en eraikitze mendekotasunak ezin izan dira bete."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Huts egin du eraikitze mendekotasunak prozesatzean"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Onartutako Moduluak:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1642,8 +1650,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Ezin da %s irakurri"
@@ -1672,10 +1681,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "info eta temp direktorioek fitxategi sistema berean egon behar dute"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Pakete Zerrenda irakurtzen"
 
@@ -1895,171 +1903,171 @@
 msgid "Write error"
 msgstr "Idazketa errorea"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Ezin izan da socket-a sortu"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 "Ezin izan da datu-socketa konektatu; konexioak denbora muga gainditu du"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Ezin izan da socket pasibora konektatu."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo-k ezin izan du socket entzule bat eskuratu"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Ezin izan da socket bat lotu"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Ezin izan da socket-ean entzun"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Ezin izan da socket-aren izena zehaztu"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Ezin da PORT komandoa bidali"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Helbide familia ezezagunaa: %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRTek huts egin du, eta zerbitzariak hau esan du: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Datu-socket konexioak denbora muga gainditu du"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Ezin da konexioa onartu"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Arazoa fitxategiaren hash egitean"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Ezin da fitxategia lortu; zerbitzariak hau esan du: '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Datu-socketak denbora muga gainditu du"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Datu transferentziak huts egin du, eta zerbitzariak hau esan du: '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Kontsulta"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Ezin da deitu "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Konektatzen -> %s.(%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Ezin izan da socket-ik sortu honentzat: %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Ezin izan da konexioa hasi -> %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr ""
 "Ezin izan da konektatu -> %s:%s (%s). Konexioak denbora muga gainditu du"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Ezin izan da konektatu -> %s:%s (%s)"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Konektatzen -> %s..."
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Ezin izan da '%s' ebatzi"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Aldi baterako akatsa '%s' ebaztean"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Zerbait arraroa pasatu da '%s:%s' (%i) ebaztean"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Ezin da konektatu -> %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Abortatu instalazioa."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "Barne errorea: Sinadura zuzena, baina ezin da egiaztapen marka zehaztu"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Beintza sinadura baliogabe bat aurkitu da."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "Ezin da %s abiarazi sinadura egiaztatzeko (gpgv instalaturik al dago?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Errore ezezaguna gpgv exekutatzean"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Ondorengo sinadurak baliogabeak dira:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2138,19 +2146,19 @@
 msgid "Error reading from server"
 msgstr "Errorea zerbitzaritik irakurtzean"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Huts fitxategia mozterakoan"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Goiburu data gaizki dago"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Konexioak huts egin du"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Barne errorea"
 
@@ -2218,7 +2226,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "%s hautapena ez da aurkitu"
@@ -2342,6 +2350,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Ezin da %s(e)ra aldatu"
@@ -2528,7 +2537,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Ezin izan da %s aldiroko EgoeraFitrxategia idatzi"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2663,7 +2672,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Ezin dira arazoak konpondu; hautsitako paketeak atxiki dituzu."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2713,12 +2722,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Mesedez sa ''%s' izeneko diska '%s' gailuan eta enter sakatu"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "'%s' pakete sistema ez da onartzen"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Ezin da pakete sistemaren mota egokirik zehaztu"
 
@@ -2731,25 +2740,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "'Iturburu' URI batzuk jarri behar dituzu sources.list-en"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Pakete zerrenda edo egoera fitxategia ezin dira analizatu edo ireki."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Beharbada 'apt-get update' exekutatu nahiko duzu arazoak konpontzeko"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Erregistro baliogabea hobespenen fitxategian, pakete goibururik ez"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Ez da ulertu %s orratz-mota (pin)"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Ez da lehentasunik zehaztu orratzarentzat (pin) (edo zero da)"
 
@@ -2838,32 +2847,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Ezin da atzitu %s iturburu paketeen zerrenda"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Fitxategiaren erreferentziak biltzen"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "S/I errorea iturburu katxea gordetzean"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "huts egin du izen-aldaketak, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum ez dator bat"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Egiaztapena ez dator bat"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Ez dago gako publiko erabilgarririk hurrengo gako ID hauentzat:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2872,7 +2906,7 @@
 "Ezin izan dut %s paketeko fitxategi bat lokalizatu. Beharbada eskuz konpondu "
 "beharko duzu paketea. (arkitektura falta delako)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2881,7 +2915,7 @@
 "Ezin izan dut %s paketeko fitxategi bat lokalizatu. Beharbada eskuz konpondu "
 "beharko duzu paketea."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2889,25 +2923,35 @@
 "Paketearen indize fitxategiak hondatuta daude. 'Filename:' eremurik ez %s "
 "paketearentzat."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Tamaina ez dator bat"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Ezin da %s pakete fitxategia analizatu (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Oharra, %s hautatzen %s(r)en ordez\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Lerro baliogabea desbideratze fitxategian: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Ezin da %s pakete fitxategia analizatu (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3002,154 +3046,237 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Diskoarentzako jatorri sarrerak:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i erregistro grabaturik.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i erregistro eta %i galdutako fitxategi grabaturik.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i erregistro eta %i okerreko fitxategi grabaturik\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "%i erregistro, %i galdutako fitxategi eta %i okerreko fitxategi grabaturik\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "%s konfigurazio fitxategia irekitzen"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Egiaztapena ez dator bat"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Oharra: %s hautatzen '%s' adierazpen erregularrarentzat\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Hautatutako bertsioa: %s (%s) -- %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "%s Instalatzen"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s konfiguratzen"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s kentzen"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s guztiz ezabatu da"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Inbstalazio-ondorengo %s abiarazlea exekutatzen"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "'%s' direktorioa falta da"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "%s fitxategia ezin izan da ireki"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s prestatzen"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "%s irekitzen"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "%s konfiguratzeko prestatzen"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s Instalatuta"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "%s kentzeko prestatzen"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s kendurik"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "%s guztiz ezabatzeko prestatzen"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s guztiz ezabatu da"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Ezin da erregistroa idatzi, openpty() -ek huts egin du (/dev/pts ez dago "
 "muntaturik?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Ezin da zerrenda direktorioa blokeatu"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3164,7 +3291,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Konexioa behar baino lehenago itxi da"
 

=== modified file 'po/fi.po'
--- po/fi.po	2010-05-25 16:01:42 +0000
+++ po/fi.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.5.26\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-12-11 14:52+0200\n"
 "Last-Translator: Tapio Lehtonen <tale@debian.org>\n"
 "Language-Team: Finnish <debian-l10n-finnish@lists.debian.org>\n"
@@ -17,147 +17,145 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms:  nplurals=2; plural=(n != 1);\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Paketin %s versiossa %s on tyydyttämätön riippuvuus:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Pakettia %s ei löydy"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Pakettien kokonaismäärä : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Pakettien kokonaismäärä : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Tavallisia paketteja: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Aitoja näennäispaketteja: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Yksinkertaisia näennäispaketteja: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Sekanäennäispaketteja: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Puuttuu: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Eri versioita yhteensä: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Eri kuvauksia yhteensä: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Riippuvuuksia yhteensä: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Versio/tdsto suhteita yht: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Kuvaus/tdsto suhteita yht: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Tarjoamiskuvauksia yhteensä: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Erilaisia merkkijonoja yhteensä: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Versioriippuvuustila yhteensä: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Löysää tilaa yhteensä: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Käytetty tila yhteensä: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Pakettitiedosto %s ei ole ajan tasalla."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "On annettava täsmälleen yksi lauseke"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Yhtään pakettia ei löytynyt"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Pakettia %s ei löydy"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Pakettitiedostot:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Varasto ei ole ajan tasalla, pakettitiedostoa ei löydy kansiosta"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Paketit joissa tunniste:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(ei löydy)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Asennettu: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Ehdokas: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ei mitään)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Paketin tunnistenumero: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Versiotaulukko:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s laitealustalle %s käännöksen päiväys %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -311,12 +309,12 @@
 "  -c=? Lue tämä asetustiedosto\n"
 "  -o=? Aseta mikä asetusvalitsin tahansa, esim. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Tiedostoon %s kirjoittaminen ei onnistu"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Ohjelman debconf versiota ei saa selvitettyä. Onko debconf asennettu?"
 
@@ -654,79 +652,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Nimen muuttaminen %s -> %s ei onnistunut"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "K"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Käännösvirhe lausekkeessa - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Näillä paketeilla on tyydyttämättömiä riippuvuuksia:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "mutta %s on asennettu"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "mutta %s on merkitty asennettavaksi"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "mutta ei ole asennuskelpoinen"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "mutta on näennäispaketti"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "mutta ei ole asennettu"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "mutta ei ole merkitty asennettavaksi"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " tai"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Seuraavat UUDET paketit asennetaan:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Seuraavat paketit POISTETAAN:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Nämä paketit on jätetty odottamaan:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Nämä paketit päivitetään:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Nämä paketit VARHENNETAAN:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Seuraavat pysytetyt paketit muutetaan:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (syynä %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -734,142 +732,142 @@
 "VAROITUS: Seuraavat välttämättömät paketit poistetaan.\n"
 "Näin EI PITÄISI tehdä jos ei aivan tarkkaan tiedä mitä tekee!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu päivitetty, %lu uutta asennusta, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu uudelleen asennettua, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu varhennettua, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu poistettavaa ja %lu päivittämätöntä.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu ei asennettu kokonaan tai poistettiin.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Korjataan riippuvuuksia..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " ei onnistunut."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Riippuvuuksien korjaus ei onnistu"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Päivitysjoukon minimointi ei onnistu"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Valmis"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Halunnet suorittaa \"apt-get -f install\" korjaamaan nämä."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Tyydyttämättömiä riippuvuuksia. Koita käyttää -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "VAROITUS: Seuraavian pakettien alkuperää ei voi varmistaa!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Varoitus varmistamisesta on ohitettu.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Asennetaanko nämä paketit ilman todennusta [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Joidenkin pakettien alkuperästä ei voitu varmistua"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Oli pulmia ja -y käytettiin ilman valitsinta --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Sisäinen virhe, InstallPackages kutsuttiin rikkinäisille paketeille!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Paketteja pitäisi poistaa mutta Remove ei ole käytössä."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Tapahtui sisäinen virhe, järjestäminen keskeytyi"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Lähteiden luetteloa ei pystynyt lukemaan."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "No jo on... Koot eivät täsmää, sähköpostita email apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Noudettavaa arkistoa %st/%st.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Noudettavaa arkistoa %st.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Toiminnon jälkeen käytetään %s t lisää levytilaa.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Toiminnon jälkeen vapautuu %s t levytilaa.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Kansion %s vapaan tilan määrä ei selvinnyt"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Kansiossa %s ei ole riittävästi vapaata tilaa."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "On määritetty Trivial Only mutta tämä ei ole itsestäänselvä toimenpide."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Kyllä, tee kuten käsketään!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -880,28 +878,28 @@
 "Jatka kirjoittamalla \"%s\"\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Keskeytä."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Haluatko jatkaa [K/e]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Tiedoston %s nouto ei onnistunut  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Joidenkin tiedostojen nouto ei onnistunut"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Nouto on valmis ja määrätty vain nouto"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -909,19 +907,19 @@
 "Joidenkin arkistojen nouto ei onnistunut, ehkä \"apt-get update\" auttaa tai "
 "kokeile --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing ja taltion vaihto ei ole nyt tuettu"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Puuttuvia paketteja ei voi korjata."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Asennus keskeytetään."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -931,49 +929,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Huomautus, valitaan %s eikä %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Ohitetaan %s, se on jo asennettu eikä ole komennettu päivitystä.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Ohitetaan %s, se on jo asennettu eikä ole komennettu päivitystä.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Pakettia %s ei ole asennettu, niinpä sitä ei poisteta\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Paketti %s on näennäispaketti, jonka kattaa:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Asennettu]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Mahdolliset versiot"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Yksi pitää valita asennettavaksi."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -984,66 +982,66 @@
 "Tämä voi tarkoittaa paketin puuttuvan, olevan vanhentunut tai\n"
 "saatavilla vain jostain muusta lähteestä\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Seuraavat paketit kuitenkin korvaavat sen:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Paketilla %s ei ole asennettavaa valintaa"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Paketin %s uudelleenasennus ei ole mahdollista, sitä ei voi noutaa.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s on jo uusin versio.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Julkaisua \"%s\" paketille \"%s\" ei löytynyt"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Versiota \"%s\" paketille \"%s\" ei löytynyt"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Valittiin versio %s (%s) paketille %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "stat ei toiminut lähdepakettiluettelolle %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Komento update ei käytä parametreja"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "On tarkoitus olla poistamatta mitään, joten AutoRemover:ia ei voi käynnistää"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1057,7 +1055,7 @@
 "Seuraavat paketit asennettiin automaattisesti, eivätkä ne ole enää "
 "vaadittuja:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1069,11 +1067,11 @@
 "Seuraavat paketit asennettiin automaattisesti, eivätkä ne ole enää "
 "vaadittuja:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Poista ne komennolla \"apt-get autoremove\"."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1091,43 +1089,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Seuraavista tiedoista voi olla hyötyä selvitettäessä tilannetta:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Sisäinen virhe, AutoRemover rikkoi jotain"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Sisäinen virhe, AllUpgrade rikkoi jotain"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Tehtävää %s ei löytynyt"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Pakettia %s ei löytynyt"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Huomautus, valitaan %s lausekkeella \"%s\"\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s on merkitty käyttäjän toimesta asennetuksi.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Saatat haluta suorittaa \"apt-get -f install\" korjaamaan nämä:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1135,7 +1128,7 @@
 "Kaikkia riippuvuuksia ei ole tyydytetty. Kokeile \"apt-get -f install\" "
 "ilmanpaketteja (tai ratkaise itse)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1146,125 +1139,140 @@
 "jos käytetään epävakaata jakelua, joitain vaadittuja paketteja ei ole\n"
 "vielä luotu tai siirretty Incoming-kansiosta."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Rikkinäiset paketit"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Seuraavat ylimääräiset paketit on merkitty asennettaviksi:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Ehdotetut paketit:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Suositellut paketit:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s on merkitty käyttäjän toimesta asennetuksi.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Käsitellään päivitystä ... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Ei onnistunut"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Valmis"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Sisäinen virhe, resolver rikkoi jotain"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Noutokansiota ei saatu lukittua"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "On annettava ainakin yksi paketti jonka lähdekoodi noudetaan"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Paketin %s lähdekoodipakettia ei löytynyt"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Ohitetaan jo noudettu tiedosto \"%s\"\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Kansiossa %s ei ole riittävästi vapaata tilaa"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "On noudettava %st/%st lähdekoodiarkistoja.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "On noudettava %st lähdekoodiarkistoja.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Nouda lähdekoodi %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Joidenkin arkistojen noutaminen ei onnistunut."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Ohitetaan purku jo puretun lähdekoodin %s kohdalla\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Purkukomento \"%s\" ei onnistunut.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Tarkista onko paketti \"dpkg-dev\" asennettu.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Paketointikomento \"%s\" ei onnistunut.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Lapsiprosessi kaatui"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "On annettava ainakin yksi paketti jonka paketointiriippuvuudet tarkistetaan"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Paketille %s ei ole saatavilla riippuvuustietoja"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "Paketille %s ei ole määritetty paketointiriippuvuuksia.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1272,7 +1280,7 @@
 msgstr ""
 "riippuvuutta %s paketille %s ei voi tyydyttää koska pakettia %s ei löydy"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1281,32 +1289,32 @@
 "%s riippuvuutta paketille %s ei voi tyydyttää koska mikään paketin %s versio "
 "ei vastaa versioriippuvuuksia"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Riippuvutta %s paketille %s ei voi tyydyttää: Asennettu paketti %s on liian "
 "uusi"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Riippuvuutta %s paketille %s ei voi tyydyttää: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Paketointiriippuvuuksia paketille %s ei voi tyydyttää."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Paketointiriippuvuuksien käsittely ei onnistunut"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Tuetut moduulit:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1642,8 +1650,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Tiedostoa %s ei voi lukea"
@@ -1672,10 +1681,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Kansioiden info ja temp pitää olla samassa tiedostojärjestelmässä"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Luetaan pakettiluetteloita"
 
@@ -1893,171 +1901,171 @@
 msgid "Write error"
 msgstr "Virhe kirjoitettaessa"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Pistoketta ei voitu luoda"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Pistoketta ei voitu kytkeä, yhteys aikakatkaistiin"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Passiivista pistoketta ei voitu kytkeä."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo ei saanut kuuntelupistoketta"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Pistoketta ei voitu nimetä"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Pistoketta ei voitu kuunnella"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Pistokkeen nimeä ei saatu selville"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Komennon PORT lähetys ei onnistu"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Tuntematon osoiteperhe %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT ei onnistunut, palvelin ilmoitti: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Pistokkeen kytkeminen aikakatkaistiin"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Yhteyttä ei voitu hyväksyä"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Pulmia tiedoston hajautuksessa"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Tiedostoa ei saatu noudettua, palvelin ilmoitti \"%s\""
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Pistoke aikakatkaistiin"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Tiedonsiirto ei onnistunut, palvelin ilmoitti \"%s\""
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Kysely"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Käynnistys ei onnistu"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Avataan yhteys %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Pistokeen luonti ei onnistu %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Yhteyden %s avaus ei onnistu: %s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Yhteyttä %s ei voitu muodostaa: %s (%s), yhteys aikakatkaistiin"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Yhteyttä %s ei voitu muodostaa: %s (%s)"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Avataan yhteys %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nimeä \"%s\" ei voitu selvittää"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Tilapäinen häiriö selvitettäessä \"%s\""
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Jotain kenkkua tapahtui selvitettäessä \"%s: %s\" (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Ei ole mahdollista muodostaa yhteyttä %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Asennus keskeytetään."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Sisäinen virhe: Allekirjoitus kelpaa, mutta avaimen sormenjälki tuntematon?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "LÖytyi ainakin yksi kelvoton allekirjoitus."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Ei käynnistynyt \"%s\" allekirjoitusta tarkistamaan (onko gpgv asennettu?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Tapahtui tuntematon virhe suoritettaessa gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Seuraavat allekirjoitukset eivät olleet kelvollisia:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2136,19 +2144,19 @@
 msgid "Error reading from server"
 msgstr "Tapahtui virhe luettaessa palvelimelta"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Tiedoston typistäminen ei onnistunut"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Virheellinen otsikkotieto"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Yhteys ei toiminut"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Sisäinen virhe"
 
@@ -2214,7 +2222,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Valintaa %s ei löydy"
@@ -2337,6 +2345,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Kansioon %s vaihto ei onnistu"
@@ -2520,7 +2529,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Tilapäisen tilatiedoston %s kirjoittaminen ei onnistunut"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2653,7 +2662,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Pulmia ei voi korjata, rikkinäisiä paketteja on pysytetty."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2703,12 +2712,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Pistä levy nimeltään: \"%s\" asemaan \"%s\" ja paina Enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Paketointijärjestelmä \"%s\" ei ole tuettu"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Sopivaa paketointijärjestelmän tyyppiä ei saa selvitettyä"
 
@@ -2721,26 +2730,26 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Tiedostossa sources.list on oltava rivejä joissa \"lähde\"-URI"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Pakettiluettelonn tai tilatiedoston avaaminen tai jäsennys epäonnistui."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Voit haluta suorittaa apt-get update näiden pulmien korjaamiseksi"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Asetustiedostossa on virheellinen tietue, Package-otsikko puuttuu"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Tunnistetyyppi %s on tuntematon"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Tärkeysjärjestystä ei määritetty tunnisteelle (tai se on nolla)"
 
@@ -2830,32 +2839,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "stat ei toiminut lähdepakettiluettelolle %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Kootaan tiedostojen tarjoamistietoja"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Syöttö/Tulostus -virhe tallennettaessa pakettivarastoa"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "nimen vaihto ei onnistunut, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum ei täsmää"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash Sum täsmää"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Julkisia avaimia ei ole saatavilla, avainten ID:t ovat:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2864,7 +2898,7 @@
 "En löytänyt pakettia %s vastaavaa tiedostoa. Voit ehkä joutua korjaamaan "
 "tämän paketin itse (puuttuvan arkkitehtuurin vuoksi)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2873,7 +2907,7 @@
 "Pakettia %s vastaavaa tiedostoa ei löytynyt. Voit ehkä joutua korjaamaan "
 "tämän paketin itse."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2881,25 +2915,35 @@
 "Pakettihakemistotiedostot ovat turmeltuneet. Paketille %s ei ole Filename-"
 "kenttää."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Koko ei täsmää"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Pakettitiedostoa %s (1) ei voi jäsentää"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Huomautus, valitaan %s eikä %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Virheellinen rivi korvautustiedostossa: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Pakettitiedostoa %s (1) ei voi jäsentää"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2994,155 +3038,238 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Tämän levyn lähdekoodipakettien luettelon tietueita ovat:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Kirjoitettiin %i tietuetta.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Kirjoitettiin %i tietuetta joissa oli %i puuttuvaa tiedostoa.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Kirjoitettiin %i tietuetta joissa oli %i paritonta tiedostoa\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Kirjoitettiin %i tietuetta joissa oli %i puuttuvaa ja %i paritonta "
 "tiedostoa\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Avataan asetustiedosto %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash Sum täsmää"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Huomautus, valitaan %s lausekkeella \"%s\"\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Valittiin versio %s (%s) paketille %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Asennetaan %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Tehdään asetukset: %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Poistetaan %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s poistettiin kokonaan"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Suoritetaan jälkiasennusliipaisin %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Kansio \"%s\" puuttuu."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Tiedostoa %s ei voitu avata"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Valmistellaan %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Puretaan %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Valmistaudutaan tekemään asetukset: %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s asennettu"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Valmistaudutaan poistamaan %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s poistettu"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Valmistaudutaan poistamaan %s kokonaan"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s poistettiin kokonaan"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Lokiin ei voi kirjoittaa, openpty() epäonnistui (onko /dev/pts "
 "liittämättä?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Luettelokansiota ei voitu lukita"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3157,7 +3284,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Yhteys katkesi ennenaikaisesti"
 

=== modified file 'po/fr.po'
--- po/fr.po	2010-05-25 16:01:42 +0000
+++ po/fr.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: fr\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2010-02-27 07:25+0100\n"
 "Last-Translator: Christian Perrier <bubulle@debian.org>\n"
 "Language-Team: fr <debian-l10n-french@lists.debian.org>\n"
@@ -18,147 +18,145 @@
 "X-Generator: Lokalize 1.0\n"
 "Plural-Forms: Plural-Forms: nplurals=2; plural=n>1;\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Le paquet %s de version %s contient une dépendance absente :\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Impossible de trouver le paquet %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Nombre total de paquets : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Nombre total de paquets : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Paquets ordinaires : "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Paquets entièrement virtuels : "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Paquets virtuels simples : "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Paquets virtuels mixtes : "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Manquants : "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Nombre de versions distinctes : "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Nombre de descriptions distinctes : "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Nombre de dépendances : "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Nombre de relations version/fichier : "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Nombre de relations description/fichier : "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Nombre de relations « Provides » : "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Nombre de motifs rationnels : "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Espace occupé par les versions des dépendances : "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Espace disque gaspillé : "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Total de l'espace attribué : "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Fichier %s désynchronisé."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Vous devez fournir exactement un motif"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Aucun paquet n'a été trouvé"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Impossible de trouver le paquet %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Fichiers du paquet :"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Le cache est désynchronisé, impossible de référencer un fichier"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Paquets étiquetés :"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(non trouvé)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Installé : "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidat : "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(aucun)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Étiquette de paquet : "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr " Table de version :"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s pour %s compilé sur %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -319,12 +317,12 @@
 "   -c=? Lit ce fichier de configuration\n"
 "   -o=? Spécifie une option de configuration, p. ex. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Impossible d'écrire sur %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr ""
 "Impossible d'obtenir la version de debconf. Est-ce que debconf est installé ?"
@@ -662,79 +660,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Impossible de changer le nom %s en %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "O"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Erreur de compilation de l'expression rationnelle - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Les paquets suivants contiennent des dépendances non satisfaites :"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "mais %s est installé"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "mais %s devra être installé"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "mais il n'est pas installable"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "mais c'est un paquet virtuel"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "mais il n'est pas installé"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "mais ne sera pas installé"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " ou"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Les NOUVEAUX paquets suivants seront installés :"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Les paquets suivants seront ENLEVÉS :"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Les paquets suivants ont été conservés :"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Les paquets suivants seront mis à jour :"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Les paquets suivants seront mis à une VERSION INFÉRIEURE :"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Les paquets retenus suivants seront changés :"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (en raison de %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -743,136 +741,136 @@
 "Vous NE devez PAS faire ceci, à moins de savoir exactement ce\n"
 "que vous êtes en train de faire."
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu mis à jour, %lu nouvellement installés, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu réinstallés, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu remis à une version inférieure, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu à enlever et %lu non mis à jour.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu partiellement installés ou enlevés.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Correction des dépendances..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " a échoué."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Impossible de corriger les dépendances"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Impossible de minimiser le nombre des paquets mis à jour"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Fait"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Vous pouvez lancer « apt-get -f install » pour corriger ces problèmes."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dépendances manquantes. Essayez d'utiliser l'option -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ATTENTION : les paquets suivants n'ont pas été authentifiés."
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Avertissement d'authentification ignoré.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Faut-il installer ces paquets sans vérification (o/N) ? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Certains paquets n'ont pas pu être authentifiés"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Il y a des problèmes et -y a été employé sans --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Erreur interne, « InstallPackages » appelé avec des paquets cassés."
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr ""
 "Les paquets doivent être enlevés mais la désinstallation est désactivée."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Erreur interne. Le tri a été interrompu."
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "La liste des sources ne peut être lue."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Étrangement, les tailles ne correspondent pas. Veuillez le signaler par "
 "courriel à apt@packages.debian.org."
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Il est nécessaire de prendre %so/%so dans les archives.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Il est nécessaire de prendre %so dans les archives.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "Après cette opération, %so d'espace disque supplémentaires seront utilisés.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Après cette opération, %so d'espace disque seront libérés.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Impossible de déterminer l'espace disponible sur %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Pas assez d'espace disponible sur %s"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "L'option --trivial-only a été indiquée mais il ne s'agit pas d'une opération "
@@ -880,11 +878,11 @@
 
 # The space before the exclamation mark must not be a non-breaking space; this
 # sentence is supposed to be typed by a user who cannot see the difference.
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Oui, faites ce que je vous dis !"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -895,28 +893,28 @@
 "Pour continuer, tapez la phrase « %s »\n"
 " ?]"
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Annulation."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Souhaitez-vous continuer [O/n] ? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Impossible de récupérer %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Certains fichiers n'ont pu être téléchargés."
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Téléchargement achevé et dans le mode téléchargement uniquement"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -924,20 +922,20 @@
 "Impossible de récupérer quelques archives, peut-être devrez-vous lancer apt-"
 "get update ou essayer avec --fix-missing ?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr ""
 "l'option --fix-missing et l'échange de support ne sont pas encore reconnus."
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Impossible de corriger le fait que les paquets manquent."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Annulation de l'installation."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -947,49 +945,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Note, sélection de %s au lieu de %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Passe %s, il est déjà installé et la mise à jour n'est pas prévue.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Passe %s, il est déjà installé et la mise à jour n'est pas prévue.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Le paquet %s n'est pas installé, et ne peut donc être supprimé\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Le paquet %s est un paquet virtuel fourni par :\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Installé]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versions possibles"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Vous devez explicitement sélectionner un paquet à installer."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -1001,69 +999,69 @@
 "devenu obsolète\n"
 "ou qu'il n'est disponible que sur une autre source\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Cependant les paquets suivants le remplacent :"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Aucun paquet ne correspond au paquet %s"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 "La réinstallation de %s est impossible, il ne peut pas être téléchargé.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s est déjà la plus récente version disponible.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "La version  « %s » de « %s » est introuvable"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "La version « %s » de « %s » n'a pu être trouvée"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Version choisie %s (%s) pour %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 "La distribution cible « %s » indisponible pour le paquet « %s » est ignorée"
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Choix de « %s » comme paquet source à la place de « %s »\n"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr "La version « %s » indisponible du paquet « %s » est ignorée"
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "La commande de mise à jour ne prend pas d'argument"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Aucune suppression n'est sensée se produire : impossible de lancer "
 "« Autoremover »"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1077,7 +1075,7 @@
 "Les paquets suivants ont été installés automatiquement et ne sont plus "
 "nécessaires :"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1087,11 +1085,11 @@
 msgstr[1] ""
 "%lu paquets ont été installés automatiquement et ne sont plus nécessaires.\n"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Veuillez utiliser « apt-get autoremove » pour les supprimer."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1110,44 +1108,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "L'information suivante devrait vous aider à résoudre la situation : "
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr ""
 "Erreur interne, l'outil de suppression automatique a cassé quelque chose."
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Erreur interne, AllUpgrade a cassé le boulot !"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Impossible de trouver la tâche %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Impossible de trouver le paquet %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Note, sélectionne %s pour l'expression rationnelle « %s »\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s passé en « installé manuellement ».\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Vous pouvez lancer « apt-get -f install » pour corriger ces problèmes :"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1155,7 +1148,7 @@
 "Dépendances non satisfaites. Essayez « apt-get -f install » sans paquet\n"
 "(ou indiquez une solution)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1167,128 +1160,143 @@
 "la distribution unstable, que certains paquets n'ont pas encore\n"
 "été créés ou ne sont pas sortis d'Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Paquets défectueux"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Les paquets supplémentaires suivants seront installés : "
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Paquets suggérés :"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Paquets recommandés :"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s passé en « installé manuellement ».\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Calcul de la mise à jour... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Échec"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Fait"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 "Erreur interne, la tentative de résolution du problème a cassé certaines "
 "parties"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Impossible de verrouiller le répertoire de téléchargement"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Vous devez spécifier au moins un paquet source"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Impossible de trouver une source de paquet pour %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Saut du téléchargement du fichier « %s », déjà téléchargé\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Pas assez d'espace disponible sur %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Nécessité de prendre %so/%so dans les sources.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Nécessité de prendre %so dans les sources.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Récupération des sources %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Échec lors de la récupération de quelques archives."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Saut du décompactage des paquets sources déjà décompactés dans %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "La commande de décompactage « %s » a échoué.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Veuillez vérifier si le paquet dpkg-dev est installé.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "La commande de construction « %s » a échoué.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Échec du processus fils"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Il faut spécifier au moins un paquet pour vérifier les dépendances de "
 "construction"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Impossible d'obtenir les dépendances de construction pour %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s n'a pas de dépendance de construction.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1297,7 +1305,7 @@
 "La dépendance %s vis-à-vis de %s ne peut être satisfaite car le paquet %s ne "
 "peut être trouvé"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1306,33 +1314,33 @@
 "La dépendance %s vis-à-vis de %s ne peut être satisfaite car aucune version "
 "du paquet %s ne peut satisfaire à la version requise"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Impossible de satisfaire la dépendance %s pour %s : le paquet installé %s "
 "est trop récent"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Impossible de satisfaire les dépendances %s pour %s : %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr ""
 "Les dépendances de compilation pour %s ne peuvent pas être satisfaites."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Impossible d'activer les dépendances de construction"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Modules reconnus :"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1677,8 +1685,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Impossible de lire %s"
@@ -1709,10 +1718,9 @@
 "Les répertoires info et temp doivent se trouver sur le même système de "
 "fichiers"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Lecture des listes de paquets"
 
@@ -1933,176 +1941,176 @@
 msgid "Write error"
 msgstr "Erreur d'écriture"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Impossible de créer un connecteur"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 "Impossible de se connecter sur le port de données, délai de connexion dépassé"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Impossible de se connecter au port en mode passif."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "gettaddrinfo n'a pu obtenir un port d'écoute"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Impossible de se connecter à un port"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Impossible d'écouter sur le port"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Impossible de déterminer le nom du port"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Impossible d'envoyer la commande PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Famille d'adresses %u inconnue (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT a échoué, le serveur a répondu : %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Délai de connexion au port de données dépassé"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Impossible d'accepter une connexion"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problème de hachage du fichier"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Impossible de récupérer le fichier, le serveur a répondu « %s »"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Pas de réponse du port données dans les délais"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Le transfert de données a échoué, le serveur a répondu « %s »"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Requête"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Impossible d'invoquer "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Connexion à %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP : %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Impossible de créer de connexion pour %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Impossible d'initialiser la connexion à %s: %s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Connexion à %s: %s (%s) impossible, délai de connexion dépassé"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Connexion à %s: %s (%s) impossible."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Connexion à %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Ne parvient pas à résoudre « %s »"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Erreur temporaire de résolution de « %s »"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr ""
 "Quelque chose d'imprévisible est survenu lors de la détermination de « %s:%"
 "s » (%i - %s)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Impossible de se connecter à %s:%s :"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, c-format
 msgid "No keyring installed in %s."
 msgstr "Pas de porte-clés installé dans %s."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Erreur interne : signature correcte, mais il est impossible de déterminer "
 "l'empreinte de la clé."
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Au moins une signature non valable a été rencontrée."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Impossible d'exécuter « %s » pour contrôler la signature\n"
 "(veuillez vérifier si gpgv est installé)."
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Erreur inconnue à l'exécution de gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Les signatures suivantes ne sont pas valables :\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2181,19 +2189,19 @@
 msgid "Error reading from server"
 msgstr "Erreur de lecture du serveur"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Échec de la troncature du fichier"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Mauvais en-tête de donnée"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Échec de la connexion"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Erreur interne"
 
@@ -2262,7 +2270,7 @@
 msgid "%lis"
 msgstr "%lis"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "La sélection %s n'a pu être trouvée"
@@ -2389,6 +2397,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Impossible d'accéder à %s"
@@ -2572,7 +2581,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Erreur d'écriture du fichier d'état temporaire %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2722,7 +2731,7 @@
 "Impossible de corriger les problèmes, des paquets défectueux sont en mode "
 "« garder en l'état »."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2774,12 +2783,12 @@
 "Veuillez insérer le disque « %s » dans le lecteur « %s » et appuyez sur la "
 "touche Entrée."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Le système de paquet « %s » n'est pas supporté"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Impossible de déterminer un type du système de paquets adéquat"
 
@@ -2793,29 +2802,29 @@
 msgstr ""
 "Vous devez insérer quelques adresses « sources » dans votre sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Les listes de paquets ou le fichier « status » ne peuvent être analysés ou "
 "lus."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Vous pouvez lancer « apt-get update » pour corriger ces problèmes."
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "Enregistrement non valable dans le fichier de préférences %s, aucune entrée "
 "« Package »."
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Étiquette %s inconnue"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Aucune priorité (ou zéro) n'a été spécifiée pour l'étiquette"
 
@@ -2914,34 +2923,59 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Impossible de localiser la liste des paquets sources %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Assemblage des fichiers listés dans les champs Provides"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr ""
 "Erreur d'entrée/sortie lors de la sauvegarde du fichier de cache des sources"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "impossible de changer le nom, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Somme de contrôle MD5 incohérente"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Somme de contrôle de hachage incohérente"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Aucune clé publique n'est disponible pour la/les clé(s) suivante(s) :\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2950,7 +2984,7 @@
 "Impossible de localiser un fichier du paquet %s. Cela signifie que vous "
 "devrez corriger ce paquet vous-même (absence d'architecture)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2959,7 +2993,7 @@
 "Impossible de localiser un fichier du paquet %s. Cela signifie que vous "
 "devrez corriger ce paquet vous-même."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2967,25 +3001,35 @@
 "Les fichiers d'index des paquets sont corrompus. Aucun champ « Filename: » "
 "pour le paquet %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Taille incohérente"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Impossible d'analyser le fichier Release %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "Pas de sections dans le fichier Release %s"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "Pas d'entrée de hachage dans le fichier Release %s"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Pas d'entrée de hachage dans le fichier Release %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Pas d'entrée de hachage dans le fichier Release %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3082,134 +3126,203 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Les entrées de listes de sources pour ce disque sont :\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i enregistrements écrits.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i enregistrements écrits avec %i fichiers manquants.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i enregistrements écrits avec %i fichiers qui ne correspondent pas\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "%i enregistrements écrits avec %i fichiers manquants et %i qui ne "
 "correspondent pas\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Fichier %s inexistant ignoré"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr "Impossible de trouver l'enregistrement d'authentification pour %s"
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Somme de contrôle de hachage incohérente pour %s"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Note, sélectionne %s pour l'expression rationnelle « %s »\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Version choisie %s (%s) pour %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Installation de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Configuration de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Suppression de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, c-format
 msgid "Completely removing %s"
 msgstr "Suppression complète de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Exécution des actions différées (« trigger ») de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Répertoire %s inexistant"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Impossible d'ouvrir le fichier %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Préparation de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Décompression de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Préparation de la configuration de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s installé"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Préparation de la suppression de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s supprimé"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Préparation de la suppression complète de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s complètement supprimé"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Impossible d'écrire le journal, échec d'openpty()\n"
 "(/dev/pts est-il monté ?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr "Exécution de dpkg"
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
@@ -3218,25 +3331,39 @@
 "Impossible de verrouiller le répertoire d'administration (%s). Il est "
 "possible qu'un autre processus l'utilise."
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr ""
 "Impossible de verrouiller le répertoire d'administration (%s). Avez-vous les "
 "privilèges du superutilisateur ?"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, fuzzy, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 "dpkg a été interrompu. Il est nécessaire d'utiliser « dpkg --configure -a » "
 "pour corriger le problème."
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "Non verrouillé"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3255,7 +3382,7 @@
 "Impossible de modifier %s avec mmap (sans échec particulier de mmap) : le "
 "correctif semble être corrompu."
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Connexion fermée prématurément"
 

=== modified file 'po/gl.po'
--- po/gl.po	2010-05-25 16:01:42 +0000
+++ po/gl.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: apt_po_gl\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-12-17 22:44+0100\n"
 "Last-Translator: mvillarino <mvillarino@users.sourceforge.net>\n"
 "Language-Team: galician <proxecto@trasno.net>\n"
@@ -18,149 +18,147 @@
 "X-Generator: KBabel 1.11.4\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "O paquete %s versión %s ten unha dependencia incumprida:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Non se puido atopar o paquete %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Número total de nomes de paquetes : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Número total de nomes de paquetes : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Paquetes normais: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Paquetes virtuais puros: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Paquetes virtuais simples: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Paquetes virtuais mixtos: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Non atopados: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Número total de versións distintas: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Número total de descricións distintas: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Número total de dependencias: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Número total de relacións versión/ficheiro: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Número total de relacións descrición/ficheiro: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Número total de mapas de Provides: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Número total de cadeas: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Espazo total de versións de dependencias: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Espazo de reserva total: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Espazo total contabilizado: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "O ficheiro de paquete %s está sen sincronizar."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Debe fornecer exactamente un patrón"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Non se atopou ningún paquete"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Non se puido atopar o paquete %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Ficheiros de paquetes:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "A caché está sen sincronizar, non se pode facer referencia a un ficheiro de "
 "paquetes"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Paquetes inmobilizados:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(non se atopou)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalado: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidato: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ningún)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Inmobilizado: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Táboa de versións:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s para %s compilado o %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -319,12 +317,12 @@
 "  -o=? Establece unha opción de configuración, por exemplo: -o dir::cache=/"
 "tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Non se puido escribir en %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Non se puido obter a versión de debconf. ¿Debconf está instalado?"
 
@@ -665,79 +663,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Non se puido cambiar o nome de %s a %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "S"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Erro na compilación da expresión regular - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Os seguintes paquetes teñen dependencias sen cumprir:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "pero %s está instalado"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "pero hase instalar %s"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "pero non é instalable"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "pero é un paquete virtual"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "pero non está instalado"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "pero non se ha instalar"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " ou"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Os seguintes paquetes NOVOS hanse instalar:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Os seguintes paquetes hanse ELIMINAR:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Os seguintes paquetes consérvanse:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Os seguintes paquetes hanse actualizar:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Os seguintes paquetes hanse DESACTUALIZAR:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Os seguintes paquetes retidos hanse modificar:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (debido a %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -745,141 +743,141 @@
 "AVISO: Hanse eliminar os seguintes paquetes esenciais.\n"
 "¡Isto NON se debe facer a menos que saiba exactamente o que está a facer!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu actualizados, %lu instalados, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstalados, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu desactualizados, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu hanse eliminar e %lu sen actualizar.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu non instalados ou eliminados de todo.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "A corrixir as dependencias..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " fallou."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Non se puido corrixir as dependencias."
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Non se puido minimizar o xogo de actualizacións"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Rematado"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Pode querer executar \"apt-get -f install\" para corrixilos."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dependencias incumpridas. Probe a empregar -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "AVISO: ¡Non se poden autenticar os seguintes paquetes!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Ignórase o aviso de autenticación.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "¿Instalar estes paquetes sen verificación [s/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Non se puido autenticar algúns paquetes"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Houbo problemas e empregouse -y sen --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Erro interno, chamouse a InstallPackages con paquetes rotos."
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Hai que eliminar paquetes pero a eliminación está desactivada."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Erro interno, a ordeación non rematou"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Non se puido ler a lista de orixes."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Que raro... Os tamaños non coinciden, envíe email a apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Hai que recibir %sB/%sB de arquivos.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Hai que recibir %sB de arquivos.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Despois desta operación hanse ocupar %sB de disco adicionais.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Despois desta operación hanse liberar %sB de disco.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Non se puido determinar o espazo libre en %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Non hai espazo libre de abondo en %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Especificouse \"Só Triviais\" pero esta non é unha operación trivial."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "¡Si, fai o que digo!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -890,28 +888,28 @@
 "Para continuar escriba a frase \"%s\"\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Abortar."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "¿Quere continuar [S/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Non se puido obter %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Non se puido descargar algúns ficheiros"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Completouse a descarga no modo de só descargas"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -919,21 +917,21 @@
 "Non se puido obter algúns arquivos; probe con apt-get update ou --fix-"
 "missing."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr ""
 "O emprego conxunto de --fix-missing e intercambio de discos non está "
 "soportado"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Non se puido corrixir os paquetes non dispoñibles."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "A abortar a instalación."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -943,49 +941,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Nota, escóllese %s no canto de %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Omítese %s, xa está instalado e non se especificou a actualización.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Omítese %s, xa está instalado e non se especificou a actualización.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "O paquete %s non está instalado, así que non se eliminou\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "O paquete %s é un paquete virtual fornecido por:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Instalado]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versións candidatas"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Debería escoller un para instalar."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -996,67 +994,67 @@
 "Isto pode significar que o paquete falla, está obsoleto ou só está\n"
 "dispoñible noutra fonte.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Nembargantes, os seguintes paquetes substitúeno:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "O paquete %s non ten un candidato para a instalación"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "A reinstalación de %s non é posible, non se pode descargar.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s xa é a versión máis recente.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Non se atopou a versión \"%s\" de \"%s\""
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Non se atopou a versión \"%s\" de \"%s\""
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Escolleuse a versión %s (%s) de %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Non se atopou a lista de paquetes fonte %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "A orde \"update\" non toma argumentos"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Non se supón que se deban eliminar cousas; non se pode iniciar o "
 "autoeliminador"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1068,7 +1066,7 @@
 msgstr[1] ""
 "Os seguintes paquetes instaláronse automaticamente e xa non son necesarios:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1078,11 +1076,11 @@
 msgstr[1] ""
 "Os seguintes paquetes instaláronse automaticamente e xa non son necesarios:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Empregue \"apt-get autoremove\" para eliminalos."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1100,43 +1098,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "A seguinte información pode axudar a resolver a situación:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Erro interno, o autoeliminador rompeu cousas"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Erro interno, AllUpgrade rompeu cousas"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Non se puido atopar a tarefa %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Non se puido atopar o paquete %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Nota, escóllese %s para a expresión regular \"%s\"\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s cambiouse a instalado manualmente.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Pode querer executar \"apt-get -f install\" corrixir isto:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1144,7 +1137,7 @@
 "Dependencias incumpridas. Probe \"apt-get -f install\" sen paquetes (ou "
 "especifique unha solución)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1155,127 +1148,142 @@
 "unha situación imposible ou, se emprega a distribución inestable, que\n"
 "algúns paquetes solicitados aínda non se crearon ou moveron de Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Paquetes rotos"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Hanse instalar os seguintes paquetes extra:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Paquetes suxiridos:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Paquetes recomendados:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s cambiouse a instalado manualmente.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "A calcular a actualización... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Fallou"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Rematado"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Erro interno, o resolvedor interno rompeu cousas"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Non se puido bloquear o directorio de descargas"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "Ten que especificar alomenos un paquete para lle descargar o código fonte"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Non se puido atopar un paquete fonte para %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Omítese o ficheiro xa descargado \"%s\"\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Non hai espazo libre de abondo en %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Hai que recibir %sB/%sB de arquivos de fonte.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Hai que recibir %sB de arquivos de fonte.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Obter fonte %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Non se puido recibir algúns arquivos."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Omítese o desempaquetamento do código fonte xa desempaquetado en %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Fallou a orde de desempaquetamento \"%s\".\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Comprobe que o paquete \"dpkg-dev\" estea instalado.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Fallou a codificación de %s.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "O proceso fillo fallou"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Ten que especificar alomenos un paquete para lle comprobar as dependencias "
 "de compilación"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Non se puido obter a información de dependencias de compilación de %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s non ten dependencias de compilación.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1284,7 +1292,7 @@
 "A dependencia \"%s\" de %s non se pode satisfacer porque non se pode atopar "
 "o paquete %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1293,32 +1301,32 @@
 "A dependencia \"%s\" de %s non se pode satisfacer porque ningunha versión "
 "dispoñible do paquete %s satisfai os requirimentos de versión"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Non se puido satisfacer a dependencia \"%s\" de %s: O paquete instalado %s é "
 "novo de máis"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Non se puido satisfacer a dependencia \"%s\" de %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Non se puideron satisfacer as dependencias de compilación de %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Non se puido procesar as dependencias de compilación"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Módulos soportados:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1657,8 +1665,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Non se pode ler %s"
@@ -1688,10 +1697,9 @@
 msgstr ""
 "Os directorios info e temp teñen que estar no mesmo sistema de ficheiros"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "A ler as listas de paquetes"
 
@@ -1907,174 +1915,174 @@
 msgid "Write error"
 msgstr "Erro de escritura"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Non se puido crear un socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 "Non se puido conectar o socket de datos, o tempo esgotouse para a conexión"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Non se puido conectar o socket pasivo."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo non puido obter un socket para escoitar"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Non se puido ligar un socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Non se puido escoitar no socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Non se puido determinar o nome do socket"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Non se puido enviar a orde PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Familia de enderezos %u (AF_*) descoñecida"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "A orde EPRT fallou, o servidor dixo: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "A conexión do socket de datos esgotou o tempo"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Non se pode aceptar a conexión"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problema ao calcular o hash do ficheiro"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Non se pode obter o ficheiro, o servidor dixo \"%s\""
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "O socket de datos esgotou o tempo"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "A transferencia de datos fallou, o servidor dixo \"%s\""
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Petición"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Non se puido chamar a "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "A conectar a %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Non se puido crear un socket para %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Non se pode iniciar a conexión a %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Non se puido conectar a %s:%s (%s), a conexión esgotou o tempo"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Non se puido conectar a %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "A conectar a %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Non se puido resolver \"%s\""
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Fallo temporal ao resolver \"%s\""
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Algo estraño ocorreu ao resolver \"%s:%s\" (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Non se pode conectar a %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "A abortar a instalación."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Erro interno: Sinatura correcta, pero non se puido determinar a pegada "
 "dixital da chave"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Atopouse alomenos unha sinatura non válida."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Non se puido executar \"%s\" para verificar a sinatura (¿está gpgv "
 "instalado?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Erro descoñecido ao executar gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "As seguintes sinaturas non eran válidas:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2153,19 +2161,19 @@
 msgid "Error reading from server"
 msgstr "Erro ao ler do servidor"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Non se puido truncar o ficheiro"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Datos da cabeceira incorrectos"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "A conexión fallou"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Erro interno"
 
@@ -2231,7 +2239,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Non se atopou a selección %s"
@@ -2355,6 +2363,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Non se pode cambiar a %s"
@@ -2538,7 +2547,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Non se puido gravar o ficheiro de estado temporal %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2672,7 +2681,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Non se poden resolver os problemas, ten retidos paquetes rotos."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2722,12 +2731,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Introduza o disco etiquetado: \"%s\" na unidade \"%s\" e prema Intro."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "O sistema de empaquetamento \"%s\" non está soportado"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Non se puido determinar un tipo de sistema de empaquetamento axeitado"
 
@@ -2740,28 +2749,28 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Debe introducir algúns URIs fonte no seu ficheiro sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Non se puido analizar ou abrir as listas de paquetes ou ficheiro de estado."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Pode querer executar apt-get update para corrixir estes problemas"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "Rexistro non válido no ficheiro de preferencias, non hai unha cabeceira "
 "Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Non se entendeu o tipo de inmobilización %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr ""
 "Non se indicou unha prioridade (ou indicouse cero) para a inmobilización"
@@ -2851,33 +2860,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Non se atopou a lista de paquetes fonte %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "A recoller as provisións de ficheiros"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Erro de E/S ao gravar a caché de fontes"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "fallou o cambio de nome, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Os MD5Sum non coinciden"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Os \"hashes\" non coinciden"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Non hai unha clave pública dispoñible para os seguintes IDs de clave:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2886,7 +2920,7 @@
 "Non se puido atopar un ficheiro para o paquete %s. Isto pode significar que "
 "ten que arranxar este paquete a man. (Falla a arquitectura)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2895,7 +2929,7 @@
 "Non se puido atopar un ficheiro para o paquete %s. Isto pode significar que "
 "ten que arranxar este paquete a man."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2903,25 +2937,35 @@
 "Os ficheiros de índices de paquetes están corrompidos. Non hai un campo "
 "Filename: para o paquete %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Os tamaños non coinciden"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Non se pode analizar o ficheiro de paquetes %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Nota, escóllese %s no canto de %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Liña non válida no ficheiro de desvíos: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Non se pode analizar o ficheiro de paquetes %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3016,155 +3060,238 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "As entradas da lista de fontes deste disco son:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Graváronse %i rexistros.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Graváronse %i rexistros con %i ficheiros que fallan.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Graváronse %i rexistros con %i ficheiros que non coinciden\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Graváronse %i rexistros con %i ficheiros que fallan e %i ficheiros que non "
 "coinciden\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "A abrir o ficheiro de configuración %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Os \"hashes\" non coinciden"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Nota, escóllese %s para a expresión regular \"%s\"\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Escolleuse a versión %s (%s) de %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "A instalar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "A configurar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "A eliminar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Eliminouse %s completamente"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "A executar o disparador de post-instalación %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "O directorio \"%s\" falla"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Non se puido abrir o ficheiro %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "A preparar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "A desempaquetar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "A se preparar para configurar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Instalouse %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "A se preparar para a eliminación de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Eliminouse %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "A se preparar para eliminar %s completamente"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Eliminouse %s completamente"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Non se puido escribir no rexistro, a chamada a openpty() fallou (¿/dev/pts "
 "non estaba montado?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Non se puido bloquear o directorio de listas"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3179,7 +3306,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "A conexión pechouse prematuramente"
 

=== modified file 'po/hu.po'
--- po/hu.po	2010-05-25 16:01:42 +0000
+++ po/hu.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: hu\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-05-11 14:49+0100\n"
 "Last-Translator: SZERVÁC Attila <sas@321.hu>\n"
 "Language-Team: Hungarian <debian-l10n-hungarian>\n"
@@ -19,148 +19,146 @@
 "X-Poedit-Language: Hungarian\n"
 "X-Poedit-Country: HUNGARY\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "%s csomag %s verziójának teljesítetlen függősége van:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Az alábbi csomag nem található: %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Csomagnevek összesen : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Csomagnevek összesen : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normális csomagok: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Teljesen virtuális csomagok: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Egyedi virtuális csomagok: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Vegyes virtuális csomagok: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Hiányzik: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Különböző verziók összesen: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Összes külső leírás: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Függőségek összesen: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Verzió/Fájl kapcsolatok összesen: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Összes Leírás/Fájl kapcsolat: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "\"Előkészít\" kapcsolatok összesen: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Minták összesen: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Függőségi-verzió terület összesen: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Slack terület összesen: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Terület összesen: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "%s csomag fájl szinkronon kívül."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Pontosan egy mintát kell megadnod"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Nem találtam csomagokat"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Az alábbi csomag nem található: %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Csomagfájlok:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "A gyorsítótár nincs szinkronban, nem lehet kereszthivatkozni a csomag fájlra"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Rögzített csomagok:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(nem találtam)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Telepítve: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Jelölt: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(nincs)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Csomag Tű: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Verziótáblázat:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s erre: %s ekkor fordult: %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -315,12 +313,12 @@
 "  -c=? Ezt a konfigurációs fájlt olvassa be\n"
 "  -o=? Beállít egy tetszőleges konfigurációs opciót, pl -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Nem lehet írni ebbe: %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Nem lehet megállapítani a debconf verziót. A debconf telepítve van?"
 
@@ -657,79 +655,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Nem sikerült átnevezni %s-t erre: %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "I"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Regex fordítási hiba - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Az alábbi csomagoknak teljesítetlen függőségei vannak:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "de %s van telepítve"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "de csak %s telepíthető"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "de az nem telepíthető"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "de az egy virtuális csomag"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "de az nincs telepítve"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "de az nincs telepítésre megjelölve"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " vagy"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Az alábbi ÚJ csomagok lesznek telepítve:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Az alábbi csomagok el lesznek TÁVOLÍTVA:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Az alábbi csomagok vissza lesznek tartva:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Az alábbi csomagok frissítve lesznek:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Az alábbi csomagok ÖREGBÍTÉSRE kerülnek:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Az alábbi visszafogott csomagokat cserélem:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (%s miatt) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -737,140 +735,140 @@
 "FIGYELEM: Az alábbi alapvető csomagok lesznek eltávolítva\n"
 "NE tedd ezt, míg nem tudod pontosan, mit csinálsz!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu frissített, %lu újonnan telepített, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu újratelepítendő, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu kerül öregbítésre, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu eltávolítandó és %lu nem frissített.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu nincs teljesen telepítve/eltávolítva.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Függőségek javítása..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " sikertelen."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Nem lehet javítani a függőségeket"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Nem lehet minimalizálni a frissítendő csomagok mennyiségét"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Kész"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Ezek kijavításához próbáld futtatni az 'apt-get -f install'-t ."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Teljesítetlen függőségek. Próbáld a -f használatával."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "FIGYELEM: Az alábbi csomagok nem hitelesíthetők!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "A hitelesítési figyelmeztetést átléptem.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Valóban telepíted e csomagokat ellenőrzés nélkül (i/N)? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Néhány csomag nem hitelesíthető"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Problémák vannak és a -y -t használtad --force-yes nélkül"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Belső hiba, az InstallPackages törött csomagokkal lett meghívva!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Csomagokat kellene eltávolítani, de az Eltávolítás nem engedélyezett."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Belső hiba, a rendezés nem zárult"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "A források listája olvashatatlan."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "Ez durva... A méretek nem egyeznek, írj ide:apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Letöltendő az archívumokból: %sB/%sB\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Letöltés az archívumokból: %sB\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "E művelet után további %sB lemez-területetet használok fel.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "E művelet után %sB lemez-terület szabadul fel.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Nem határozható meg a szabad hely itt: %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Nincs elég szabad hely itt:  %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "A 'Trivial Only' meg van adva, de ez nem egy triviális művelet."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Igen, tedd amit mondok!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -881,28 +879,28 @@
 "A folytatáshoz írd be ezt: '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Megszakítva."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Folytatni akarod [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Sikertelen letöltés: %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Néhány fájlt nem sikerült letölteni"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "A letöltés befejeződött a 'csak letöltés' módban"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -910,19 +908,19 @@
 "Nem lehet letölteni néhány archívumot.\n"
 " Próbáld ki az apt-get update -et vagy a --fix-missing -et."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing és média csere jelenleg nem támogatott"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Nem lehet javítani a hiányzó csomagokat."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Telepítés megszakítása."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -931,49 +929,49 @@
 "all files have been overwritten by other packages:"
 msgstr[0] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Megjegyzés: %s kiválasztása %s helyett\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "%s kihagyása, ez már telepítve van és a frissítés nincs beállítva.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "%s kihagyása, ez már telepítve van és a frissítés nincs beállítva.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "A megadott %s csomag nincs telepítve, így hát nem is töröltem\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "%s egy virtuális csomag, melyet az alábbi csomagok adnak:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Telepítve]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Lehetséges verziók"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Egyet név szerint ki kell jelölnöd a telepítésre."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -983,65 +981,65 @@
 "%s csomag nem elérhető, de egy másik hivatkozik rá\n"
 ".A kért csomag tehát: hiányzik, elavult vagy csak más forrásból érhető el\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "De az alábbi csomagok felváltják:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "%s csomagnak nincs e telepítéshez kijelölhető változata"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "%s újratelepítése nem lehetséges, mert nem lehet letölteni.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s már a legújabb verzió.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "'%s' kiadás ehhez: '%s' nem található"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "'%s' verzió ehhez: '%s' nem található"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "%s (%s) a kiválasztott verzió ehhez: %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Nem lehet a(z) %s forrás csomaglistáját elérni"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Az update parancsnak nincsenek argumentumai"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Nincs törölnivaló, az AutoRemover nem indítható"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1050,18 +1048,18 @@
 "required:"
 msgstr[0] "Az alábbi csomagok automatikusan települtek, de már nem kellenek:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
 "%lu packages were automatically installed and are no longer required.\n"
 msgstr[0] "Az alábbi csomagok automatikusan települtek, de már nem kellenek:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Töröld az 'apt-get autoremove' paranccsal!"
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1079,43 +1077,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Az alábbi információ segíthet megoldani a helyzetet:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Belső hiba, az AutoRemover sérült"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Belső hiba, AllUpgrade megsértett valamit"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Hiányzó %s feladat"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Az alábbi csomag nem található: %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Megjegyzés: %s kiválasztása %s reguláris kifejezéshez\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s kézi telepítésre állított.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Próbáld futtatni az 'apt-get -f install'-t az alábbiak javításához:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1123,7 +1116,7 @@
 "Teljesítetlen függőségek. Próbáld az 'apt-get -f install'-t csomagok nélkül "
 "(vagy telepítsd a függőségeket is!)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1135,127 +1128,142 @@
 "használod, akkor néhány igényelt csomag még nem készült el vagy ki\n"
 "lett mozdítva az Incoming-ból."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Törött csomagok"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Az alábbi extra csomagok kerülnek telepítésre:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Javasolt csomagok:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Ajánlott csomagok:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s kézi telepítésre állított.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Frissítés kiszámítása... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Sikertelen"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Kész"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Belső hiba, hibafeloldó gond"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Nem tudom zárolni a letöltési könyvtárat"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "Legalább egy csomagot meg kell adnod, aminek a forrását le kell tölteni"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Nem található forráscsomag ehhez: %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "A már letöltött '%s' fájl kihagyása\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Nincs elég szabad hely itt: %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "%sB/%sB forrás-archívumot kell letölteni.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "%sB forrás-archívumot kell letölteni.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Forrás letöltése: %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Nem sikerült néhány archívumot letölteni."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Egy már kibontott forrás kibontásának kihagyása itt: %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "'%s' kibontási parancs nem sikerült.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Ellenőrizd, hogy a 'dpkg-dev' csomag telepítve van-e.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "'%s' elkészítési parancs nem sikerült.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Hiba a gyermekfolyamatnál"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Legalább egy csomagot adj meg, aminek a fordítási függőségeit ellenőrizni "
 "kell"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Nem lehet %s fordítási-függőség információját beszerezni"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "Nincs fordítási függősége a következőnek: %s.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1264,7 +1272,7 @@
 "%s függősége ennek: %s, ez nem elégíthető ki, mert a(z) %s csomag nem "
 "található"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1273,32 +1281,32 @@
 "%s függősége ennek: %s, ez nem elégíthető ki, mert a(z) %s csomagnak nincs a "
 "verzió-követelményt kielégítő elérhető verziója."
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "%s függőséget %s csomaghoz nem lehet kielégíteni: %s telepített csomag túl "
 "friss."
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "%s függőséget %s csomaghoz nem lehet kielégíteni: %s "
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "%s építési függőségei nem elégíthetőek ki."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Nem sikerült az építési függőségeket feldolgozni"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Támogatott modulok:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1632,8 +1640,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "%s nem olvasható"
@@ -1662,10 +1671,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Az info és temp könyvtáraknak egy fájlrendszeren kell lenniük"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Csomaglisták olvasása"
 
@@ -1881,169 +1889,169 @@
 msgid "Write error"
 msgstr "Írási hiba"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Nem lehet létrehozni a socket-et"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Nem lehet kapcsolódni az adat sockethez, a kapcsolat túllépte az időt"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Nem lehet kapcsolódni a passzív sockethez."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "A getaddrinfo nem talált figyelő socketet"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Nem lehet összekapcsolódni a sockettel"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Nem lehet figyelni a socketen"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Nem lehet megállapítani a socket nevét"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Nem lehet PORT parancsot küldeni"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Ismeretlen %u címcsalád (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Hibás EPRT, a kiszolgáló üzenete: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Az adat sockethez kapcsolódás túllépte az időt"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Nem lehet elfogadni a kapcsolatot"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Probléma a fájl hash értékének meghatározásakor"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Nem lehet letölteni a fájlt, a kiszolgáló üzenete: '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Az adat socket túllépte az időt"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Adatátvitel sikertelen, a kiszolgáló üzenete: '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Lekérdezés"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Nem lehet meghívni "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Csatlakozás: %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "socket létrehozása sikertelen ehhez: %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Kapcsolat létrehozása sikertelen ehhez: %s: %s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Időtúllépés miatt nem lehet kapcsolódni a következőhöz: %s: %s (%s)"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Nem tudtam kapcsolódni ehhez: %s: %s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Kapcsolódás: %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nem lehet feloldani a következőt: '%s' "
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Átmeneti hiba '%s' feloldása közben"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Valami rossz történt '%s: %s' feloldásakor (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Sikertelen kapcsolódás ide: %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Telepítés megszakítása."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "Belső hiba: Jó aláírás, de meghatározhatatlan kulcs ujjlenyomat?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "1 vagy több érvénytelen aláírást találtam."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "'%s' nem futtatható az aláírás ellenőrzéséhez (a gpgv telepítve van?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Ismeretlen gpgv futtatási hiba"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Az alábbi aláírások érvénytelenek voltak:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2121,20 +2129,20 @@
 msgid "Error reading from server"
 msgstr "Hiba a kiszolgálóról olvasáskor"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "%s fájl írása sikertelen"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Rossz fejlécadat"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Sikertelen kapcsolódás"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Belső hiba"
 
@@ -2201,7 +2209,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "%s kiválasztás nem található"
@@ -2325,6 +2333,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Nem sikerült ide váltani: %s"
@@ -2508,7 +2517,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "%s átmeneti állapot-fájl írása sikertelen"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2643,7 +2652,7 @@
 msgstr ""
 "A problémák nem javíthatók, sérült visszafogott csomagok vannak a rendszeren."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2693,12 +2702,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Tedd be a(z) %s címkéjű lemezt a(z) %s meghajtóba és üss entert"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "A(z) '%s' csomagrendszer nem támogatott"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "A megfelelő csomagrendszer típus nem határozható meg"
 
@@ -2711,26 +2720,26 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Néhány 'source' URI-t be kell tenned a sources.list fájlba"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "A csomaglista vagy az állapot fájl nem dolgozható fel vagy nem olvasható."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Próbáld futtatni az apt-get update -et, hogy javítsd e hibákat"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Hibás rekord a tulajdonság fájlban, nincs csomagfejléc"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "A(z) %s tűtípus nem értelmezhető"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Nincs prioritás (vagy nulla) megadva a tűhöz"
 
@@ -2825,32 +2834,57 @@
 msgstr "Nem lehet a(z) %s forrás csomaglistáját elérni"
 
 # FIXME
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "\"Előkészít\" kapcsolatok összegyűjtése"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IO hiba a forrás-gyorsítótár mentésekor"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "sikertelen átnevezés, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Az MD5Sum nem megfelelő"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "A Hash Sum nem megfelelő"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Nincs elérhető nyilvános kulcs az alábbi kulcs azonosítókhoz:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2859,7 +2893,7 @@
 "Nem találtam egy fájlt a(z) %s csomaghoz. Ez azt jelentheti, hogy kézzel "
 "kell kijavítani a csomagot. (hiányzó arch. miatt)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2868,32 +2902,42 @@
 "Nem találtam egy fájlt a(z) %s csomaghoz. Ez azt jelentheti, hogy kézzel "
 "kell kijavítani a csomagot."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "A csomagindex-fájlok megsérültek. Nincs Filename: mező a(z) %s csomaghoz."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "A méret nem megfelelő"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Nem lehet a(z) %s csomagfájlt feldolgozni (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Megjegyzés: %s kiválasztása %s helyett\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Érvénytelen sor az eltérítő fájlban: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Nem lehet a(z) %s csomagfájlt feldolgozni (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2988,151 +3032,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "E lemezhez tartozó forráslista-bejegyzések a következők:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i rekord kiírva.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i rekord kiírva, %i hiányzó fájllal.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i rekord kiírva %i hibásan párosított fájllal\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "%i rekord kiírva %i hiányzó és %i hibásan párosított fájllal\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "%s konfigurációs fájl megnyitása"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "A Hash Sum nem megfelelő"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Megjegyzés: %s kiválasztása %s reguláris kifejezéshez\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "%s (%s) a kiválasztott verzió ehhez: %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "Telepített %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s konfigurálása"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s eltávolítása"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s teljesen eltávolítva"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Hiányzik ez a könyvtár: %s"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Nem lehet megnyitni %s fájlt"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s előkészítése"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "%s kicsomagolása"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "%s konfigurálásának előkészítése"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Telepített %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "%s eltávolításának előkészítése"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Eltávolított %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "%s teljes eltávolítása előkészítése"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s teljesen eltávolítva"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "Naplózási hiba, sikertelen openpty() (a /dev/pts nincs csatolva?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Nem tudom a listakönyvtárat zárolni"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3147,7 +3274,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "A kapcsolat idő előtt lezárult"
 

=== modified file 'po/it.po'
--- po/it.po	2010-05-25 16:01:42 +0000
+++ po/it.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2010-05-15 20:33+0200\n"
 "Last-Translator: Milo Casagrande <milo@ubuntu.com>\n"
 "Language-Team: Italian <tp@lists.linux.it>\n"
@@ -16,148 +16,146 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Il pacchetto %s versione %s ha una dipendenza non soddisfatta:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Impossibile trovare il pacchetto %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Totale nomi dei pacchetti: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Totale nomi dei pacchetti: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Pacchetti normali: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Pacchetti virtuali puri: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Pacchetti virtuali singoli: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Pacchetti virtuali misti: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Mancante: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Totale versioni distinte: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Totale descrizioni distinte: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Totale dipendenze: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Totale relazioni ver/file: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Totale relazioni Desc/File: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Totale corrispondenze fornite: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Totale stringhe globalizzate: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Totale spazio di dipendenza di versione: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Totale spazio inutilizzato: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Totale spazio occupato: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Il file dei pacchetti %s non è sincronizzato."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "È necessario specificare un solo modello"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Nessun pacchetto trovato"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Impossibile trovare il pacchetto %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "File dei pacchetti:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "La cache non è sincronizzata, impossibile referenziare un file di pacchetti"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pacchetti con gancio:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(non trovato)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Installato: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidato: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(nessuno)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Gancio del pacchetto: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabella versione:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s per %s compilato il %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -314,12 +312,12 @@
 "  -c=? Legge come configurazione il file specificato\n"
 "  -o=? Imposta un'opzione di configurazione, come -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Impossibile scrivere in %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Impossibile trovare la versione di debconf. È installato?"
 
@@ -657,79 +655,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Rinomina di %s in %s non riuscita"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "S"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Errore di compilazione dell'espressione regolare - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "I seguenti pacchetti hanno dipendenze non soddisfatte:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "ma %s è installato"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "ma %s sta per essere installato"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ma non è installabile"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ma è un pacchetto virtuale"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ma non è installato"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "ma non sta per essere installato"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " oppure"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "I seguenti pacchetti NUOVI saranno installati:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "I seguenti pacchetti saranno RIMOSSI:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "I seguenti pacchetti sono stati mantenuti alla versione attuale:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "I seguenti pacchetti saranno aggiornati:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "I seguenti pacchetti saranno RETROCESSI:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "I seguenti pacchetti bloccati saranno cambiati:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (a causa di %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -738,148 +736,148 @@
 "Questo non dovrebbe essere fatto a meno che non si sappia esattamente cosa "
 "si sta facendo."
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu aggiornati, %lu installati, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstallati, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu retrocessi, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu da rimuovere e %lu non aggiornati.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu non completamente installati o rimossi.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Correzione delle dipendenze..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " non riuscita."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Impossibile correggere le dipendenze"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Impossibile minimizzare l'insieme da aggiornare"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Fatto"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 #, fuzzy
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 "È utile eseguire \"apt-get -f install\" per correggere questi problemi."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dipendenze non trovate. Riprovare usando -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ATTENZIONE: i seguenti pacchetti non possono essere autenticati."
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Avviso di autenticazione disabilitato.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Installare questi pacchetti senza verificarli [s/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Alcuni pacchetti non possono essere autenticati"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Si sono verificati dei problemi ed è stata usata -y senza --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 "Errore interno, InstallPackages è stato chiamato con un pacchetto "
 "danneggiato."
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr ""
 "I pacchetti devono essere rimossi, ma l'azione di rimozione è disabilitata."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Errore interno, l'ordinamento non è stato terminato"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Impossibile leggere l'elenco dei sorgenti."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Le dimensioni non corrispondono. Inviare un'email a: apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "È necessario scaricare %sB/%sB di archivi.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "È necessario scaricare %sB di archivi.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Dopo quest'operazione, verranno occupati %sB di spazio su disco.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Dopo quest'operazione, verranno liberati %sB di spazio su disco.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Impossibile determinare lo spazio libero su %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Spazio libero in %s insufficiente."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "È stata specificata la modalità \"Trivial Only\", ma questa non è "
 "un'operazione banale."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Sì, esegui come da richiesta."
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -890,28 +888,28 @@
 "Per continuare scrivere la frase \"%s\"\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Interrotto."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Continuare [S/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Impossibile recuperare %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Scaricamento di alcuni file non riuscito"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Scaricamento completato e in modalità solo scaricamento"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -919,19 +917,19 @@
 "Impossibile recuperare alcuni pacchetti. Potrebbe essere utile eseguire "
 "\"apt-get update\" o provare l'opzione \"--fix-missing\"."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing su supporti estraibili non è ancora supportato"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Impossibile correggere i pacchetti mancanti."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Interruzione dell'installazione."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -941,51 +939,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Nota, viene selezionato %s al posto di %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Viene saltato %s poiché è già installato e l'aggiornamento non è impostato.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Viene saltato %s poiché è già installato e l'aggiornamento non è impostato.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Il pacchetto %s non è installato e quindi non è stato rimosso\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Il pacchetto %s è un pacchetto virtuale fornito da:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Installato]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versioni candidate"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "È necessario sceglierne uno da installare."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -996,68 +994,68 @@
 "pacchetto. Questo può significare che il pacchetto è mancante, è obsoleto\n"
 "oppure è disponibile solo all'interno di un'altra sorgente\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Tuttavia questi pacchetti lo sostituiscono:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Il pacchetto %s non ha candidati da installare"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "La reinstallazione di %s non è possibile, non può essere scaricato.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s è già alla versione più recente.\n"
 
 # (ndt) dovrebbe essere inteso il file Release
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Release \"%s\" per \"%s\" non trovato."
 
 # (ndt) dovrebbe essere inteso il Version
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Version \"%s\" per \"%s\" non trovato"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Versione %s (%s) selezionata per %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr "Ignorato il rilascio non disponibile \"%s\" del pacchetto \"%s\""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Scelto \"%s\" come pacchetto sorgente al posto di \"%s\"\n"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr "Ignorata la versione \"%s\" non disponibile del pacchetto \"%s\""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Il comando update non accetta argomenti"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Non si è autorizzati a rimuovere nulla, impossibile avviare AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1071,7 +1069,7 @@
 "I seguenti pacchetti sono stati installati automaticamente e non sono più "
 "richiesti:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1083,11 +1081,11 @@
 "%lu pacchetti sono stati installati automaticamente e non sono più "
 "richiesti.\n"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Usare \"apt-get autoremove\" per rimuoverli."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1105,45 +1103,40 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Le seguenti informazioni possono aiutare a risolvere la situazione: "
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Errore interno, AutoRemover ha rovinato qualche cosa"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Errore interno, AllUpgrade ha rovinato qualche cosa"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Impossibile trovare il task %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Impossibile trovare il pacchetto %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Nota, si sta selezionando %s per l'espressione regolare \"%s\"\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "È stato impostato %s per l'installazione manuale.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 #, fuzzy
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 "È utile eseguire \"apt-get -f install\" per correggere questi problemi:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1151,7 +1144,7 @@
 "Dipendenze non soddisfatte. Provare \"apt-get -f install\" senza pacchetti "
 "(o specificare una soluzione)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1163,127 +1156,142 @@
 "usando una distribuzione in sviluppo, che alcuni pacchetti richiesti\n"
 "non sono ancora stati creati o sono stati rimossi da Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Pacchetto danneggiato"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "I seguenti pacchetti saranno inoltre installati:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Pacchetti suggeriti:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Pacchetti raccomandati:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "È stato impostato %s per l'installazione manuale.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Calcolo dell'aggiornamento... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Non riuscito"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Eseguito"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Errore interno, \"problem resolver\" ha rovinato qualcosa"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Impossibile bloccare la directory di scaricamento"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "È necessario specificare almeno un pacchetto di cui recuperare il sorgente"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Impossibile trovare un pacchetto sorgente per %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Il pacchetto \"%s\" già scaricato viene saltato\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Lo spazio libero in %s è insufficiente"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "È necessario recuperare %sB/%sB di sorgenti.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "È necessario recuperare %sB di sorgenti\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Recupero sorgente %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Recupero di alcuni archivi non riuscito."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Estrazione del pacchetto sorgente già estratto in %s saltata\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Comando di estrazione \"%s\" non riuscito.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Verificare che il pacchetto \"dpkg-dev\" sia installato.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Comando \"%s\" di generazione non riuscito.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Creazione processo figlio non riuscita"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "È necessario specificare almeno un pacchetto di cui controllare le "
 "dipendenze di generazione"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Impossibile ottenere informazioni di dipendenza di generazione per %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s non ha dipendenze di generazione.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1292,7 +1300,7 @@
 "%s dipendenze per %s non possono essere soddisfatte perché il pacchetto %s "
 "non può essere trovato"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1301,32 +1309,32 @@
 "%s dipendenze per %s non possono essere soddisfatte perché nessuna versione "
 "del pacchetto %s può soddisfare le richieste di versione"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "La dipendenza %s per %s non è stata soddisfatta: il pacchetto installato %s "
 "è troppo nuovo"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "La dipendenza %s per %s non è stata soddisfatta: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Le dipendenze di generazione per %s non sono state soddisfatte."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Elaborazione delle dipendenze di generazione non riuscita"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Moduli supportati:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1673,8 +1681,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Impossibile leggere %s"
@@ -1703,10 +1712,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Le directory temp e info devono essere sullo stesso file system"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Lettura elenco dei pacchetti"
 
@@ -1924,174 +1932,174 @@
 msgid "Write error"
 msgstr "Errore di scrittura"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Impossibile creare un socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Impossibile connettersi al socket dati, connessione terminata"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Impossibile connettere socket passivo."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "Impossibile ottenere un socket in ascolto con getaddrinfo()"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Impossibile eseguire bind() su un socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Impossibile eseguire listen() su un socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Impossibile determinare il nome del socket"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Impossibile inviare il comando PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Famiglia di indirizzamento %u (AF_*) sconosciuta"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT non riuscito, il server riporta: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Connessione al socket dati terminata"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Impossibile accettare connessioni"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Si è verificato un problema nel creare l'hash del file"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Impossibile recuperare il file, il server riporta: \"%s\""
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Socket dati terminato"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Trasferimento dati non riuscito, il server riporta: \"%s\""
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Interrogazione"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Impossibile invocare "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Connessione a %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Impossibile creare un socket per %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Impossibile iniziare la connessione a %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Impossibile connettersi a %s:%s (%s), connessione terminata"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Impossibile connettersi a %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Connessione a %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Impossibile risolvere \"%s\""
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Risoluzione di \"%s\" temporaneamente non riuscita"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr ""
 "Si è verificato qualcosa di anormale nella risoluzione di \"%s:%s\" (%i - %s)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Impossibile connettersi a %s:%s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, c-format
 msgid "No keyring installed in %s."
 msgstr "Nessun portachiavi installato in %s."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Errore interno: firma corretta, ma non è possibile determinare l'impronta "
 "della chiave."
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "È stata trovata almeno una firma non valida."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Impossibile eseguire \"%s\" per verificare la firma (forse gpgv non è "
 "installato)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Errore sconosciuto durante l'esecuzione di gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Le seguenti firme non erano valide:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2170,19 +2178,19 @@
 msgid "Error reading from server"
 msgstr "Errore nel leggere dal server"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Troncamento del file non riuscito"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Header dati non corretto"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Connessione non riuscita"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Errore interno"
 
@@ -2250,7 +2258,7 @@
 msgid "%lis"
 msgstr "%lis"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Selezione %s non trovata"
@@ -2379,6 +2387,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Impossibile passare a %s"
@@ -2563,7 +2572,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Scrittura del file temporaneo di stato %s non riuscita"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2706,7 +2715,7 @@
 msgstr ""
 "Impossibile correggere i problemi, ci sono pacchetti danneggiati bloccati."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2756,12 +2765,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Inserire il disco chiamato \"%s\" nell'unità \"%s\" e premere Invio."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Il sistema di pacchetti \"%s\" non è supportato"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Impossibile determinare un tipo di sistema appropriato di pacchetti"
 
@@ -2775,29 +2784,29 @@
 msgstr ""
 "È necessario inserire alcuni URI di tipo \"source\" nel file sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "L'elenco dei pacchetti o il file di stato non può essere letto o aperto."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "È consigliato eseguire \"apt-get update\" per correggere questi problemi"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "Campo non valido nel file delle preferenze %s, manca l'intestazione \"Package"
 "\""
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Impossibile comprendere il tipo di gancio %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Priorità per il gancio non specificata (o zero)"
 
@@ -2891,33 +2900,58 @@
 msgstr "Impossibile eseguire stat sull'elenco dei pacchetti sorgente %s"
 
 # (ndt) non mi convince per niente, ma vediamo cosa salta fuori
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Il file fornisce"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Errore di I/O nel salvare la cache sorgente"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "rename() non riuscita: %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5sum non corrispondente"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Somma hash non corrispondente"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Non è disponibile alcuna chiave pubblica per i seguenti ID di chiavi:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2926,7 +2960,7 @@
 "Impossibile trovare un file per il pacchetto %s. Potrebbe essere necessario "
 "sistemare manualmente questo pacchetto (a causa dell'architettura mancante)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2935,7 +2969,7 @@
 "Impossibile trovare un file per il pacchetto %s. Potrebbe essere necessario "
 "sistemare manualmente questo pacchetto."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2943,25 +2977,35 @@
 "L'indice dei file è danneggiato. Manca il campo \"Filename:\" per il "
 "pacchetto %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Le dimensioni non corrispondono"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Impossibile analizzare il file Release %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "Nessuna sezione nel file Release %s"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "Nessuna voce Hash nel file Release %s"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Nessuna voce Hash nel file Release %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Nessuna voce Hash nel file Release %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3058,133 +3102,202 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Le voci dell'elenco sorgenti per questo disco sono:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Scritti %i record.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Scritti %i record con %i file mancanti.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Scritti %i record con %i file senza corrispondenze\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Scritti %i record con %i file mancanti e %i file senza corrispondenze\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Saltato il file inesistente %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr "Impossibile trovare il record di autenticazione per %s"
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash non corrispondente per %s"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Nota, si sta selezionando %s per l'espressione regolare \"%s\"\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Versione %s (%s) selezionata per %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Installazione di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Configurazione di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Rimozione di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, c-format
 msgid "Completely removing %s"
 msgstr "Rimozione completa di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Esecuzione comando di post installazione %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Directory \"%s\" mancante"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Impossibile aprire il file %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Preparazione di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Estrazione di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Preparazione alla configurazione di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Pacchetto %s installato"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Preparazione alla rimozione di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Pacchetto %s rimosso"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Preparazione alla rimozione completa di %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Pacchetto %s rimosso completamente"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Impossibile scrivere il registro, openpty() non riuscita (forse /dev/pts non "
 "è montato)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr "Esecuzione di dpkg"
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
@@ -3193,25 +3306,39 @@
 "Impossibile acquisire il blocco sulla directory di amministrazione (%s). Un "
 "altro processo potrebbe tenerla occupata."
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr ""
 "Impossibile acquisire il blocco sulla directory di amministrazione (%s). È "
 "necessario essere root."
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, fuzzy, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 "dpkg è stato interrotto. È necessario eseguire \"dpkg --configure -a\" per "
 "correggere il problema. "
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "Non bloccato"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3230,7 +3357,7 @@
 "Impossibile applicare la patch a %s con mmap (nessun errore da parte di "
 "mmap). La patch sembra essere danneggiata."
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Connessione chiusa prematuramente"
 

=== modified file 'po/ja.po'
--- po/ja.po	2010-05-25 16:01:42 +0000
+++ po/ja.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-13 09:26+0900\n"
 "Last-Translator: Kenshi Muto <kmuto@debian.org>\n"
 "Language-Team: Debian Japanese List <debian-japanese@lists.debian.org>\n"
@@ -16,147 +16,145 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8 bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "パッケージ %s のバージョン %s には解決不可能な依存関係があります:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "パッケージ %s が見つかりません"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "パッケージ名総数: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "パッケージ名総数: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  通常パッケージ: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  純粋仮想パッケージ: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  単一仮想パッケージ: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  複合仮想パッケージ: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  欠落: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "個別バージョン総数: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "個別説明総数: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "依存関係総数: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "バージョン/ファイル関係総数: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "説明/ファイル関係総数: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "提供マッピング総数: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Glob 文字列の総数: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "総依存関係・バージョン容量: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "総空き容量: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "総占有容量: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Package ファイル %s が同期していません。"
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "パターンはちょうど 1 つだけ指定してください"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "パッケージが見つかりません"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "パッケージ %s が見つかりません"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "パッケージファイル:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "キャッシュが同期しておらず、パッケージファイルを相互参照できません"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pin パッケージ:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(見つかりません)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  インストールされているバージョン: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  候補: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(なし)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  パッケージ Pin: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  バージョンテーブル:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s for %s コンパイル日時: %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -312,12 +310,12 @@
 "  -c=? 指定した設定ファイルを読み込む\n"
 "  -o=? 指定した設定オプションを適用する (例: -o dir::cache=/tmp)\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "%s に書き込めません"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr ""
 "debconf のバージョンを取得できません。debconf はインストールされていますか?"
@@ -654,79 +652,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "%s を %s に名前変更できませんでした"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "正規表現の展開エラー - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "以下のパッケージには満たせない依存関係があります:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "しかし、%s はインストールされています"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "しかし、%s はインストールされようとしています"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "しかし、インストールすることができません"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "しかし、これは仮想パッケージです"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "しかし、インストールされていません"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "しかし、インストールされようとしていません"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " または"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "以下のパッケージが新たにインストールされます:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "以下のパッケージは「削除」されます:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "以下のパッケージは保留されます:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "以下のパッケージはアップグレードされます:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "以下のパッケージは「ダウングレード」されます:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "以下の変更禁止パッケージは変更されます:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (%s のため) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -734,143 +732,143 @@
 "警告: 以下の不可欠パッケージが削除されます。\n"
 "何をしようとしているか本当にわかっていない場合は、実行してはいけません!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "アップグレード: %lu 個、新規インストール: %lu 個、"
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "再インストール: %lu 個、"
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "ダウングレード: %lu 個、"
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "削除: %lu 個、保留: %lu 個。\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu 個のパッケージが完全にインストールまたは削除されていません。\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "依存関係を解決しています ..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " 失敗しました。"
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "依存関係を訂正できません"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "アップグレードセットを最小化できません"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " 完了"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 "これらを直すためには 'apt-get -f install' を実行する必要があるかもしれませ"
 "ん。"
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "未解決の依存関係があります。-f オプションを試してください。"
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "警告: 以下のパッケージは認証されていません!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "認証の警告は上書きされました。\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "検証なしにこれらのパッケージをインストールしますか [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "いくつかのパッケージを認証できませんでした"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "問題が発生し、-y オプションが --force-yes なしで使用されました"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "内部エラー、InstallPackages が壊れたパッケージで呼び出されました!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "パッケージを削除しなければなりませんが、削除が無効になっています。"
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "内部エラー、調整が終わっていません"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "ソースのリストを読むことができません。"
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "おっと、サイズがマッチしません。apt@packages.debian.org にメールしてください"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "%2$sB 中 %1$sB のアーカイブを取得する必要があります。\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "%sB のアーカイブを取得する必要があります。\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "この操作後に追加で %sB のディスク容量が消費されます。\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "この操作後に %sB のディスク容量が解放されます。\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "%s の空き領域を測定できません"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "%s に充分な空きスペースがありません。"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Trivial Only が指定されましたが、これは簡単な操作ではありません。"
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Yes, do as I say!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -881,28 +879,28 @@
 "続行するには、'%s' というフレーズをタイプしてください。\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "中断しました。"
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "続行しますか [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "%s の取得に失敗しました  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "いくつかのファイルの取得に失敗しました"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "ダウンロードオンリーモードでパッケージのダウンロードが完了しました"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -910,19 +908,19 @@
 "いくつかのアーカイブが取得できません。apt-get update を実行するか --fix-"
 "missing オプションを付けて試してみてください。"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing とメディア交換は現在同時にはサポートされていません"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "足りないパッケージを直すことができません。"
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "インストールを中断します。"
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -932,53 +930,53 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "注意、%2$s の代わりに %1$s を選択します\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "すでにインストールされておりアップグレードも設定されていないため、%s をスキッ"
 "プします。\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "すでにインストールされておりアップグレードも設定されていないため、%s をスキッ"
 "プします。\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "パッケージ %s はインストールされていないため、削除はできません\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "%s は以下のパッケージで提供されている仮想パッケージです:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [インストール済み]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "候補バージョン"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "インストールするパッケージを明示的に選択する必要があります。"
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -989,66 +987,66 @@
 "おそらく、そのパッケージが見つからないか、もう古くなっているか、\n"
 "あるいは別のソースからのみしか利用できないという状況が考えられます\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "しかし、以下のパッケージで置き換えられています:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "パッケージ %s にはインストール候補がありません"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "ダウンロードできないため、%s の再インストールは不可能です。\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s はすでに最新バージョンです。\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "'%2$s' のリリース '%1$s' が見つかりませんでした"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "'%2$s' のバージョン '%1$s' が見つかりませんでした"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "%3$s にはバージョン %1$s (%2$s) を選択しました\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "ソースパッケージリスト %s の状態を取得できません"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "update コマンドは引数をとりません"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "一連のものを削除するようになっていないので、AutoRemover を開始できません"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1060,7 +1058,7 @@
 msgstr[1] ""
 "以下のパッケージが自動でインストールされましたが、もう必要とされていません:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1070,11 +1068,11 @@
 msgstr[1] ""
 "以下のパッケージが自動でインストールされましたが、もう必要とされていません:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "これらを削除するには 'apt-get autoremove' を利用してください。"
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1092,45 +1090,40 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "以下の情報がこの問題を解決するために役立つかもしれません:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "内部エラー、AutoRemover が何かを破壊しました"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "内部エラー、AllUpgrade が何かを破壊しました"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "タスク %s が見つかりません"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "パッケージ %s が見つかりません"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "注意: 正規表現 '%2$s' に対して %1$s を選択しました\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s は手動でインストールしたと設定されました。\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 "以下の問題を解決するために 'apt-get -f install' を実行する必要があるかもしれ"
 "ません:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1138,7 +1131,7 @@
 "未解決の依存関係です。'apt-get -f install' を実行してみてください (または解法"
 "を明示してください)。"
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1150,127 +1143,142 @@
 "であれば) 必要なパッケージがまだ作成されていなかったり Incoming から移\n"
 "動されていないことが考えられます。"
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "壊れたパッケージ"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "以下の特別パッケージがインストールされます:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "提案パッケージ:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "推奨パッケージ:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s は手動でインストールしたと設定されました。\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "アップグレードパッケージを検出しています ... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "失敗"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "完了"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "内部エラー、問題リゾルバが何かを破壊しました"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "ダウンロードディレクトリをロックできません"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "ソースを取得するには少なくともひとつのパッケージ名を指定する必要があります"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "%s のソースパッケージが見つかりません"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "すでにダウンロードされたファイル '%s' をスキップします\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "%s に充分な空きスペースがありません"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "%2$sB 中 %1$sB のソースアーカイブを取得する必要があります。\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "%sB のソースアーカイブを取得する必要があります。\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "ソース %s を取得\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "いくつかのアーカイブの取得に失敗しました。"
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "すでに %s に展開されたソースがあるため、展開をスキップします\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "展開コマンド '%s' が失敗しました。\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr ""
 "'dpkg-dev' パッケージがインストールされていることを確認してください。\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "ビルドコマンド '%s' が失敗しました。\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "子プロセスが失敗しました"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "ビルド依存関係をチェックするパッケージを少なくとも 1 つ指定する必要があります"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "%s のビルド依存情報を取得できません"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s にはビルド依存情報が指定されていません。\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1279,7 +1287,7 @@
 "パッケージ %3$s が見つからないため、%2$s に対する %1$s の依存関係を満たすこと"
 "ができません"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1288,32 +1296,32 @@
 "入手可能な %3$s はいずれもバージョンについての要求を満たせないため、%2$s に対"
 "する %1$s の依存関係を満たすことができません"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "%2$s の依存関係 %1$s を満たすことができません: インストールされた %3$s パッ"
 "ケージは新しすぎます"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "%2$s の依存関係 %1$s を満たすことができません: %3$s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "%s のビルド依存関係を満たすことができませんでした。"
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "ビルド依存関係の処理に失敗しました"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "サポートされているモジュール:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1652,8 +1660,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "%s を読み込むことができません"
@@ -1682,10 +1691,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "info と temp ディレクトリは同じファイルシステム上になければなりません"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "パッケージリストを読み込んでいます"
 
@@ -1903,171 +1911,171 @@
 msgid "Write error"
 msgstr "書き込みエラー"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "ソケットを作成できません"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "データソケットへ接続できませんでした。接続がタイムアウトしました"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "パッシブソケットに接続できません。"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo はリスニングポートを取得することができませんでした"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "ソケットをバインドできませんでした"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "ソケットをリスンできませんでした"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "ソケットの名前を特定できませんでした"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "PORT コマンドを送信できません"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "未知のアドレスファミリ %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT に失敗しました。サーバ応答: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "データソケット接続タイムアウト"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "接続を accept できません"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "ファイルのハッシュでの問題"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "ファイルを取得できません。サーバ応答 '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "データソケットタイムアウト"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "データ転送に失敗しました。サーバ応答 '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "問い合わせ"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "呼び出せません"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "%s (%s) へ接続しています"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "%s (f=%u t=%u p=%u) に対するソケットを作成できません"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "%s:%s (%s) への接続を開始できません。"
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "%s:%s (%s) へ接続できませんでした。接続がタイムアウトしました"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "%s:%s (%s) へ接続できませんでした。"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "%s へ接続しています"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "'%s' を解決できませんでした"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "'%s' が一時的に解決できません"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "'%s:%s' (%i) の解決中に問題が起こりました"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "%s %s へ接続できません:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "インストールを中断します。"
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "内部エラー: 正しい署名ですが、鍵指紋を確定できません?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "少なくとも 1 つの不正な署名が発見されました。"
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "署名を検証するための '%s' の実行ができませんでした (gpgv はインストールされて"
 "いますか?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "gpgv の実行中に未知のエラーが発生"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "以下の署名が無効です:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2144,19 +2152,19 @@
 msgid "Error reading from server"
 msgstr "サーバからの読み込みに失敗しました"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "ファイルの切り詰めに失敗しました"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "不正なヘッダです"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "接続失敗"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "内部エラー"
 
@@ -2222,7 +2230,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "選択された %s が見つかりません"
@@ -2345,6 +2353,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "%s へ変更することができません"
@@ -2528,7 +2537,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "一時状態ファイル %s の書き込みに失敗しました"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2663,7 +2672,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "問題を解決することができません。壊れた変更禁止パッケージがあります。"
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2715,12 +2724,12 @@
 "'%s' とラベルの付いたディスクをドライブ '%s' に入れて enter を押してくださ"
 "い。"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "パッケージングシステム '%s' はサポートされていません"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "適切なパッケージシステムタイプを特定できません"
 
@@ -2733,31 +2742,31 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "sources.list に 'ソース' URI を指定する必要があります"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "パッケージリストまたはステータスファイルを解釈またはオープンすることができま"
 "せん。"
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "これらの問題を解決するためには apt-get update を実行する必要があるかもしれま"
 "せん"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "不正なレコードが preferences ファイルに存在します。パッケージヘッダがありませ"
 "ん"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "pin タイプ %s が理解できませんでした"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "pin で優先度 (または 0) が指定されていません"
 
@@ -2846,32 +2855,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "ソースパッケージリスト %s の状態を取得できません"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "ファイル提供情報を収集しています"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "ソースキャッシュの保存中に IO エラーが発生しました"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "名前の変更に失敗しました。%s (%s -> %s)"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum が適合しません"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "ハッシュサムが適合しません"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "以下の鍵 ID に対して利用可能な公開鍵がありません:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2880,7 +2914,7 @@
 "パッケージ %s のファイルの位置を特定できません。おそらくこのパッケージを手動"
 "で修正する必要があります (存在しないアーキテクチャのため)。"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2889,7 +2923,7 @@
 "パッケージ %s のファイルの位置を特定できません。おそらくこのパッケージを手動"
 "で修正する必要があります。"
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2897,25 +2931,35 @@
 "パッケージインデックスファイルが壊れています。パッケージ %s に Filename: "
 "フィールドがありません。"
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "サイズが適合しません"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "パッケージファイル %s を解釈することができません (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "注意、%2$s の代わりに %1$s を選択します\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "diversion ファイルに不正な行があります: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "パッケージファイル %s を解釈することができません (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3010,155 +3054,238 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "このディスクのソースリストのエントリ:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i レコードを書き込みました。\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i レコードを書き込みました。%i 個のファイルが存在しません。\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i レコードを書き込みました。%i 個の適合しないファイルがあります。\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "%i レコードを書き込みました。%i 個のファイルが見つからず、%i 個の適合しない"
 "ファイルがあります。\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "設定ファイル %s をオープンできませんでした"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "ハッシュサムが適合しません"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "注意: 正規表現 '%2$s' に対して %1$s を選択しました\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "%3$s にはバージョン %1$s (%2$s) を選択しました\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "%s をインストールしています"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s を設定しています"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s を削除しています"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s を完全に削除しました"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "インストール後トリガ %s を実行しています"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "ディレクトリ '%s' が見つかりません"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "ファイル %s をオープンできませんでした"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s を準備しています"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "%s を展開しています"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "%s の設定を準備しています"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s をインストールしました"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "%s の削除を準備しています"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s を削除しました"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "%s を完全に削除する準備をしています"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s を完全に削除しました"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "ログに書き込めません。openpty() に失敗しました (/dev/pts がマウントされていな"
 "い?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "list ディレクトリをロックできません"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3173,7 +3300,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "途中で接続がクローズされました"
 

=== modified file 'po/km.po'
--- po/km.po	2010-05-25 16:01:42 +0000
+++ po/km.po	2010-06-10 14:02:22 +0000
@@ -10,7 +10,7 @@
 msgstr ""
 "Project-Id-Version: apt_po_km\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2006-10-10 09:48+0700\n"
 "Last-Translator: Khoem Sokhem <khoemsokhem@khmeros.info>\n"
 "Language-Team: Khmer <support@khmeros.info>\n"
@@ -19,149 +19,147 @@
 "Content-Transfer-Encoding: 8bit\n"
 "X-Generator: KBabel 1.11.2\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "កញ្ចប់ %s កំណែ %s មាន​ភាព​អាស្រ័យ​មិន​ត្រូវ​គ្នា ៖\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "មិន​អាច​កំណត់​ទីតាំង​កញ្ចប់ %s បានឡើយ"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "ឈ្មោះ​កញ្ចប់​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "ឈ្មោះ​កញ្ចប់​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  កញ្ចប់​ធម្មតា ៖ "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  កញ្ចប់​និម្មិត​សុទ្ធ ៖ "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  កញ្ចប់​និម្មិត​តែ​មួយ ៖ "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  កញ្ចប់​និម្មិត​លាយ ៖ "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  បាត់បង់ ៖ "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "កំណែ​ផ្សេងៗ​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "កំណែ​ផ្សេងៗ​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "ភាព​អាស្រ័យ​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "ទំនាក់ទំនង កំណែ/ឯកសារ​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "ទំនាក់ទំនង កំណែ/ឯកសារ​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "ការផ្គូរផ្គង​ការផ្ដល់​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "ខ្សែ​អក្សរ​សរុប​ ៖ "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "ទំហំ​កំណែ​ភាព​អាស្រ័យ​សរុប ៖ "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "ទំហំ slack សរុប ៖"
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "ទំហំ​សរុប​ដែល​ទុក​សម្រាប់ ៖ "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "ឯកសារ​កញ្ចប់ %s នៅ​ខាងក្រៅ​ការ​ធ្វើសមកាលកម្ម ។"
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "អ្នក​ត្រូវ​តែ​ផ្ដល់​លំនាំ​មួយ​ដែល​ពិត​ប្រាកដ"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "រក​កញ្ចប់​មិន​ឃើញ"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "មិន​អាច​កំណត់​ទីតាំង​កញ្ចប់ %s បានឡើយ"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "ឯកសារ​កញ្ចប់ ៖"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "ឃ្លាំង​សម្ងាត់​ឋិតនៅ​ក្រៅ​ការ​ធ្វើ​សមកាល​កម្ម ដែលមិន​អាច x-ref ឯកសារ​កញ្ចប់​បាន​ទេ"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "កញ្ចប់​ដែល​បាន​ខ្ទាស់ ៖"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(រក​មិន​ឃើញ)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  បាន​ដំឡើង ៖ "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  សាកល្បង ៖ "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(គ្មាន)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  ខ្ទាស់​កញ្ចប់ ៖ "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  តារាង​កំណែ ៖"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s សម្រាប់ %s %s បាន​ចងក្រងនៅលើ​%s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -316,12 +314,12 @@
 "  -c=? អាន​ឯកសារ​ការ​កំណត់​រចនាស្ព័ន្ធ​នេះ\n"
 "  -o=? កំណត់​ជម្រើស​ការ​កំណត់​រចនា​សម្ព័ន្ធ​តាម​ចិត្ត ឧ. eg -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "មិន​អាច​សរសេរ​ទៅ %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "មិន​អាច​ទទួល​យក​កំណែ​ debconf  ។ តើ​ debconf បានដំឡើង​ឬ ?"
 
@@ -657,79 +655,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "បរាជ័យ​ក្នុង​ការ​ប្តូរ​ឈ្មោះ %s ទៅ %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Regex កំហុស​ការចងក្រង​ - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "កញ្ចប់​ខាងក្រោម​មាន​ភាពអាស្រ័យ​ដែល​ខុស​គ្នា ៖"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "ប៉ុន្តែ​ %s ត្រូវ​បាន​ដំឡើង​"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "ប៉ុន្តែ​ %s នឹង​ត្រូវ​បាន​ដំឡើ​ង"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ប៉ុន្តែ​​វា​មិន​អាច​ដំឡើង​បាន​ទេ​"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ប៉ុន្តែ​​វា​ជា​កញ្ចប់​និម្មិត​"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ប៉ុន្តែ​វា​មិន​បាន​ដំឡើង​ទេ​"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "ប៉ុន្តែ វា​នឹង​មិន​ត្រូវ​បាន​ដំឡើង​ទេ"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " ឬ"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "កញ្ចប់​ថ្មី​ខាងក្រោម​នឹង​ត្រូវ​បាន​ដំឡើង​ ៖"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "កញ្ចប់​ខាងក្រោម​នឹងត្រូវ​បាន​យកចេញ ៖"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "​កញ្ចប់​ខាង​ក្រោម​ត្រូវ​បាន​យក​ត្រឡប់​មក​វិញ ៖"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "កញ្ចប់​ខាងក្រោម​នឹង​​ត្រូវ​បាន​​ធ្វើ​ឲ្យប្រសើ​ឡើង ៖"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "កញ្ចប់​ខាងក្រោម​នឹង​​ត្រូវ​បាន​បន្ទាប ៖"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "កញ្ចប់​រង់ចាំ​ខាងក្រោម​នឹង​ត្រូវ​​បានផ្លាស់​​ប្តូរ​ ៖"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (ដោយ​សារតែ​ %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -737,140 +735,140 @@
 "ព្រមាន​ ៖ កញ្ចប់ដែល​ចាំបាច់​ខាងក្រោម​នឹង​ត្រូវ​បាន​យកចេញ ។\n"
 "ការយកចេញ​នេះ​មិន​ត្រូវ​បានធ្វើ​ទេ​លុះត្រា​តែ​អ្នកដឹង​ថា​​អ្នក​កំពុង​ធ្វើ​អ្វីឲ្យប្រាកដ !"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu ត្រូវ​បាន​ធ្វើ​ឲ្យ​ប្រសើរ %lu ត្រូវ​បានដំឡើង​ថ្មី "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu ត្រូវ​បាន​ដំឡើង​ឡើង​វិញ "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu ​ត្រូវបានបន្ទាប់ "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu ដែលត្រូវ​យក​ចេញ​ ហើយ​ %lu មិន​​បាន​ធ្វើ​ឲ្យ​ប្រសើរឡើយ ។\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu មិន​បាន​ដំឡើង​ ឬ យក​ចេញបានគ្រប់ជ្រុងជ្រោយ​ឡើយ​ ។\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "កំពុង​កែ​ភាពអាស្រ័យ​..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " បាន​បរាជ័យ ។"
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "មិន​អាច​កែ​ភាព​អាស្រ័យ​បានឡើយ​"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "មិនអាច​បង្រួម​ការ​កំណត់​ភាព​ប្រសើរ​​បាន​ឡើយ​"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " ធ្វើ​រួច"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "អ្នក​ប្រហែល​ជា​ចង់រត់ 'apt-get -f install' ដើម្បី​កែ​វា​​ទាំងនេះ​ហើយ ។"
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "ភាព​អាស្រ័យ​ដែល​ខុស​គ្នា ។ ព្យាយាម​ការ​ប្រើ -f ។"
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ព្រមាន​ ៖ មិនអាច​ធ្វើការផ្ទៀងផ្ទាត់ភាពត្រឹមត្រូវកញ្ចប់ខាងក្រោមបានឡើយ !"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "បានបដិសេធ​ការព្រមាន​ការផ្ទៀងផ្ទាត់ភាព​ត្រឹមត្រូវ ។\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "ដំឡើង​កញ្ចប់​ទាំងនេះ ​ដោយគ្មានការពិនិត្យ​បញ្ជាក់ [y/N] ? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "មិនអាច​ផ្ទៀងផ្ទាត់ភាពត្រឹមត្រូវកញ្ចប់​មួយចំនួន​បានឡើយ​"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "មាន​បញ្ហា​ ហើយ -y ត្រូវ​បាន​ប្រើ​ដោយគ្មាន​​ --force​-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "កំហុស​ខាងក្នុង កញ្ចប់​ដំឡើង​ត្រូវ​បាន​ហៅ​​ជាមួយ​កញ្ចប់​ដែល​ខូច !"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "កញ្ចប់ ​ត្រូវការឲ្យ​យក​ចេញ​​ ប៉ុន្តែមិនអនុញ្ញាត​ឲ្យយកចេញឡើយ ។"
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "កំហុស​ខាងក្នុង​ ការ​រៀប​តាម​លំដាប់​មិន​បាន​បញ្ចប់ឡើយ"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "មិន​អាច​អាន​បញ្ជី​ប្រភព​បាន​ឡើយ​ ។"
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "យី អី​ក៏​ចម្លែង​ម្លេះ.. ទំហំ​មិន​ដូច​គ្នា​ឡើយ ។ សូម​ផ្ញើ​អ៊ីមែល​ទៅ apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "ត្រូវការ​​យក​ %sB/%sB នៃ​ប័ណ្ណសារ ។​\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "ត្រូវ​ការយក​ %sB នៃ​ប័ណ្ណសារ ។\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "បន្ទាប់​ពី​ពន្លា​ %sB នៃ​ការ​បន្ថែម​​ទំហំ​ថាស​ត្រូវ​បាន​ប្រើ ។\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "បន្ទាប់​ពី​ពន្លា​ %sB ទំហំ​ថាសនឹង​​ទំនេរ ។ \n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "មិន​អាច​កំណត់​ទំហំ​ទំនេរ​ក្នុង​ %s បានឡើយ"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "អ្នក​គ្មាន​ទំហំ​​ទំនេរ​គ្រប់គ្រាន់​ក្នុង​​ %s ឡើយ ។"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "បានបញ្ជាក់​តែប្រតិបត្តិការដែលមិនសំខាន់ប៉ុណ្ណោះ ប៉ុន្តែ​នេះមិនមែនជាប្រតិបត្តិការមិនសំខាន់នោះទេ ។"
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "បាទ/ចាស ធ្វើ​ដូច​ដែល​ខ្ញុំ​និយាយ !"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -881,28 +879,28 @@
 "ដើម្បី​បន្ត ​​វាយ​ក្នុង​ឃ្លា​ '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "បោះបង់ ។"
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "តើ​អ្នក​ចង់​បន្តឬ​ [បាទ ចាស/ទេ​] ? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "បរាជ័យ​ក្នុង​ការ​ទៅ​ប្រមូល​យក​ %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "ឯកសារ​មួយ​ចំនួន​បាន​បរាជ័យ​ក្នុង​ការ​ទាញ​យក​"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "បានបញ្ចប់ការទាញ​យក​ ហើយ​តែ​ក្នុង​របៀប​​ទាញ​យក​ប៉ុណ្ណោះ"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -910,19 +908,19 @@
 "អនុញ្ញាត​ឲ្យ​ទៅ​ប្រមូល​យក​ប័ណ្ណសារ​មួយ​ចំនួន​ ប្រហែល​ជា​រត់​ភាព​ទាន់​សម័យ apt-get ឬ ព្យាយាមប្រើ​ជាមួយ --"
 "fix- ដែលបាត់ឬ់ ?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix- ដែលបាត់​ និង ​ស្វប​មេឌៀ​ដែល​មិនបាន​​គាំទ្រនៅពេល​បច្ចុប្បន្ន​"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "មិន​អាច​កែ​កញ្ចប់​ដែលបាត់បង់​បានឡើយ ។"
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "កំពុង​បោះបង់​ការ​ដំឡើង​ ។"
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -932,49 +930,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "ចំណាំ កំពុង​ជ្រើស​ %s ជំនួស​ %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "កំពុង​រំលង​ %s វា​បាន​ដំឡើង​រួចរាល់​ ហើយ​ភាព​ធ្វើឲ្យ​ប្រសើរ​​មិន​ទាន់​កំណត់​​ ។\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "កំពុង​រំលង​ %s វា​បាន​ដំឡើង​រួចរាល់​ ហើយ​ភាព​ធ្វើឲ្យ​ប្រសើរ​​មិន​ទាន់​កំណត់​​ ។\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "មិនទាន់បានដំឡើង​កញ្ចប់​ %s ទេ​ ដូច្នេះ មិន​បាន​យកចេញឡើយ \n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "កញ្ចប់​ %s ជា​កញ្ចប់​និម្មិត​ដែល​បាន​ផ្តល់​ដោយ​ ៖\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [បានដំឡើង​]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "កំណែ​សាកល្បង​"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "អ្នក​គួរតែ​ជ្រើស​យក​មួយ​​ឲ្យ​ច្បាស់​ដើម្បី​ដំឡើង​ ។"
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -985,65 +983,65 @@
 "វា​មានន័យ​ថា​បាត់កញ្ចប់ ​គេ​លែង​ប្រើ ឬ\n"
 "អាច​រក​បាន​ពី​ប្រភព​ផ្សេង​ទៀត\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "ទោះ​យ៉ាងណា​ក៏ដោយ កញ្ចប់​ខាងក្រោម​ជំនួស​វា ៖"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "កញ្ចប់​ %s មិនមាន​ការដំឡើងសាកល្បងឡើយ"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "មិនអាចធ្វើការដំឡើង %s ឡើងវិញបានទេ វា​មិនអាចត្រូវបាន​ទាញយកបានឡើយ ។\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s ជាកំណែ​ដែលថ្មីបំផុតរួចទៅហើយ ។\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "រក​មិន​ឃើញ​ការ​ចេញ​ផ្សាយ​ '%s' សម្រាប់​ '%s' ឡើយ"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "រក​មិន​ឃើញ​កំណែ​ '%s' សម្រាប់ '%s'"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "បានជ្រើស​កំណែ​ %s (%s) សម្រាប់ %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "មិនអាចថ្លែង បញ្ជី​កញ្ចប់​ប្រភពចប់​ បានឡើយ %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "ពាក្យ​បញ្ជា​ដែលធ្វើ​ឲ្យ​ទាន់​សម័យ​គ្មាន​អាគុយម៉ង់​ទេ"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1053,7 +1051,7 @@
 msgstr[0] "កញ្ចប់​ថ្មី​ខាងក្រោម​នឹង​ត្រូវ​បាន​ដំឡើង​ ៖"
 msgstr[1] "កញ្ចប់​ថ្មី​ខាងក្រោម​នឹង​ត្រូវ​បាន​ដំឡើង​ ៖"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1061,11 +1059,11 @@
 msgstr[0] "កញ្ចប់​ថ្មី​ខាងក្រោម​នឹង​ត្រូវ​បាន​ដំឡើង​ ៖"
 msgstr[1] "កញ្ចប់​ថ្មី​ខាងក្រោម​នឹង​ត្រូវ​បាន​ដំឡើង​ ៖"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1081,51 +1079,46 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "ព័ត៌មាន​ដូចតទៅនេះ អាចជួយ​ដោះស្រាយ​ស្ថានភាព​បាន ៖"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "កំហុស​ខាងក្នុង អ្នក​ដោះស្រាយ​បញ្ហា​បានធ្វើឲ្យខូច​ឧបករណ៍"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "កំហុស​ខាងក្នុង ការធ្វើឲ្យប្រសើរ​ទាំងអស់បានធ្វើឲ្យ​ឧបករណ៍​ខូច"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "មិន​អាច​រក​កញ្ចប់ %s បានទេ"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "មិន​អាច​រក​កញ្ចប់ %s បានទេ"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "ចំណាំ កំពុង​ជ្រើស​ %s សម្រាប់ regex '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "ប៉ុន្តែ​ %s នឹង​ត្រូវ​បាន​ដំឡើ​ង"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "អ្នក​ប្រហែល​ជា​ចង់​រត់ 'apt-get -f install' ដើម្បី​កែ​ពួក​វា​ទាំង​នេះ ៖"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
 msgstr ""
 "ភាពអស្រ័យ​ដែល​ខុស​គ្នា ។ ព្យាយាម​ 'apt-get -f install' ដោយ​គ្មាន​កញ្ចប់ (ឬ បញ្ជាក់​ដំណោះស្រាយ) ។"
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1137,131 +1130,146 @@
 "ដែលបាន​ទាមទារនឹងមិនទាន់បានបង្កើត​ឡើយ​\n"
 " ឬ ​បានយក​ចេញ​ពីការមកដល់ ។"
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "កញ្ចប់​ដែល​បាន​ខូច​"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "កញ្ចប់​បន្ថែម​ដូចតទៅនេះ នឹងត្រូវបាន​ដំឡើង ៖"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "កញ្ចប់​ដែល​បាន​ផ្ដល់​យោបល់ ៖"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "កញ្ចប់​ដែល​បាន​ផ្ដល់​អនុសាសន៍ ៖"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "ប៉ុន្តែ​ %s នឹង​ត្រូវ​បាន​ដំឡើ​ង"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "កំពុង​គណនា​ការ​ធ្វើ​ឲ្យ​ប្រសើរ... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "បាន​បរាជ័យ"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "ធ្វើរួច​"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "កំហុស​ខាងក្នុង អ្នក​ដោះស្រាយ​បញ្ហា​បានធ្វើឲ្យខូច​ឧបករណ៍"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "មិន​អាច​ចាក់​សោ​ថត​ទាញ​យក​បាន​ឡើយ"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "យ៉ាងហោចណាស់​ត្រូវ​​បញ្ជាក់​​កញ្ចប់​មួយ ​ដើម្បី​ទៅ​​ប្រមូល​យក​ប្រភព​សម្រាប់"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "មិន​អាច​រក​កញ្ចប់ប្រភព​​សម្រាប់ %s បានឡើយ"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "កំពុង​រំលង​ឯកសារ​ដែល​បាន​ទាញយក​រួច​ '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "អ្នក​ពុំ​មាន​ទំហំ​ទំនេរ​គ្រប់គ្រាន់​ទេ​នៅក្នុង​ %s ឡើយ"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "ត្រូវការ​យក​ %sB/%sB នៃ​ប័ណ្ណសារ​ប្រភព ។\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "ត្រូវការ​យក​ %sB នៃ​ប័ណ្ណសារ​ប្រភព​ ។\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "ទៅប្រមូល​ប្រភព​ %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "បរាជ័យ​ក្នុងការទៅប្រមូលយក​ប័ណ្ណសារ​មួយចំនួន ។"
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "កំពុង​រំលង​ការស្រាយ​នៃប្រភព​ដែលបានស្រាយរួច​នៅក្នុង %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "ពាក្យ​បញ្ជា​ស្រាយ '%s' បាន​បរាជ័យ​ ។\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "ពិនិត្យ​ប្រសិន​បើកញ្ចប់ 'dpkg-dev' មិន​ទាន់​បាន​ដំឡើង​ ។\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "សាងសង​ពាក្យ​បញ្ជា​ '%s' បានបរាជ័យ​ ។\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "ដំណើរ​ការ​កូន​បាន​បរាជ័យ​"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "ត្រូវតែ​បញ្ជាក់​យ៉ាងហោចណាស់​មួយកញ្ចប់ដើម្បីពិនិត្យ builddeps សម្រាប់"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "មិន​អាច​សាងសង់​​ព័ត៌មាន​ភាពអស្រ័យ​សម្រាប់ %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s មិនមានភាពអាស្រ័យ​ស្ថាបនាឡើយ​ ។\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "%s ភាពអស្រ័យ​សម្រាប់​ %s មិន​អាច​ធ្វើ​ឲ្យ​ពេញចិត្ត​ ព្រោះ​រក​​ %s កញ្ចប់​មិន​ឃើញ​ "
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1270,30 +1278,30 @@
 "ភាពអាស្រ័យ %s សម្រាប់ %s មិនអាច​តម្រូវចិត្តបានទេ ព្រោះ មិនមាន​កំណែ​នៃកញ្ចប់ %s ដែលអាច​តម្រូវចិត្ត​"
 "តម្រូវការ​កំណែបានឡើយ"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr "បរាជ័យ​ក្នុងការ​តម្រូវចិត្តភាពអាស្រ័យ %s សម្រាប់ %s ៖ កញ្ចប់ %s ដែលបានដំឡើង គឺថ្មីពេក"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "បរាជ័យ​ក្នុងការ​តម្រូវចិត្តភាពអាស្រ័យ %s សម្រាប់ %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "ភាពអាស្រ័យ​ដែល​បង្កើត​ %s មិន​អាច​បំពេញ​សេចក្ដី​ត្រូវការ​បាន​ទេ ។"
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "បាន​បរាជ័យ​ក្នុង​ការ​ដំណើរ​​ការ​បង្កើត​ភាព​អាស្រ័យ"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "ម៉ូឌុល​ដែល​គាំទ្រ ៖ "
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1625,8 +1633,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "មិន​អាច​អាន​ %s បានឡើយ"
@@ -1655,10 +1664,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "ថតព័ត៌មាន​ និង ពុម្ព ត្រូវការនៅលើ​ប្រព័ន្ធឯកសារ​ដូចគ្នា​"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "កំពុង​អាន​បញ្ជី​កញ្ចប់"
 
@@ -1872,169 +1880,169 @@
 msgid "Write error"
 msgstr "ការសរសេរ​មានកំហុស"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "មិន​អាច​បង្កើត​រន្ធបានឡើយ"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "មិន​អាច​តភ្ជាប់​​រន្ធទិន្នន័យ​បានឡើយ អស់​ពេល​ក្នុងការតភ្ជាប់​"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "មិនអាចតភ្ជាប់​​រន្ធអកម្ម​​បានឡើយ ។"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo មិន​អាច​​ទទួល​យក​រន្ធ​សម្រាប់​ស្តាប់​​បានឡើយ"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "មិន​អាច​ចងរន្ធ​បានបានឡើយ​"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "មិនអាច​ស្ដាប់នៅលើរន្ធ​បានឡើយ"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "មិន​អាច​កំណត់​ឈ្មោះរបស់​រន្ធ​បានឡើយ"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "មិនអាច​ផ្ញើពាក្យ​បញ្ជា​ PORT បានឡើយ"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "មិន​ស្គាល់​អាសយដ្ឋាន​គ្រួសារ​ %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT បរាជ័យ​ ម៉ាស៊ីន​បម្រើ​បាន​និយាយ ៖ %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "ការតភ្ជាប់​រន្ធ​​ទិន្នន័បានអស់ពេល​"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "មិនអាច​ទទួលយក​ការតភ្ជាប់​បានឡើយ"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "បញ្ហា​ធ្វើឲ្យខូច​ឯកសារ"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "មិន​អាច​ទៅ​ប្រមូល​យក​ឯកសារ​បានឡើយ ម៉ាស៊ីន​បម្រើ​បាន​និយាយ​ '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "រន្ធ​ទិន្នន័យ​បាន​អស់​ពេល​"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "បរាជ័យក្នុងការ​ផ្ទេរ​ទិន្នន័យ ម៉ាស៊ីន​បម្រើ​បាន​និយាយ​ '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "សំណួរ​"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "មិន​អាច​ហៅ​ "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "កំពុង​តភ្ជាប់​ទៅ​កាន់​ %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP ៖ %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "មិន​អាច​បង្កើត​រន្ធ​សម្រាប់ %s (f=%u t=%u p=%u) បានឡើយ"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "មិនអាច​ចាប់ផ្ដើម​ការតភ្ជាប់​​ទៅ​កាន់​ %s:%s (%s) បានឡើយ ។"
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "មិន​អាច​តភ្ជាប់​ទៅ​កាន់​ %s:%s (%s) បានឡើយ ការ​តភ្ជាប់​បានអស់​ពេល​"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "មិន​អាច​តភ្ជាប់​ទៅកាន់​ %s:%s (%s) បានឡើយ ។"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "កំពុង​តភ្ជាប់​ទៅកាន់ %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "មិន​អាច​ដោះស្រាយ​ '%s' បានឡើយ"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "ការ​ដោះស្រាយ​ភាព​បរាជ័យ​​បណ្តោះអាសន្ន '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "ការ​ដោះស្រាយ​អ្វី​អាក្រក់ដែល​បាន​កើត​ឡើង​ '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "មិន​អាច​តភ្ជាប់​ទៅកាន់​​ %s %s ៖"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "កំពុង​បោះបង់​ការ​ដំឡើង​ ។"
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "កំហុស​ខាងក្នុង​ ៖ ហត្ថលេខា​​ល្អ ប៉ុន្តែ ​មិន​អាច​កំណត់​កូនសោ​ស្នាម​ម្រាមដៃ ?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "​បានជួប​ប្រទះ​​​​ហត្ថលេខា​យ៉ាងហោចណាស់មួយ ដែ​លត្រឹមត្រូវ​ ។"
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "មិន​អាច​ប្រតិបត្តិ '%s' ដើម្បី​ផ្ទៀងផ្ទាត់​ហត្ថលេខា (តើ gpgv ត្រូវ​បាន​ដំឡើង​ឬនៅ ?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "មិនស្គាល់កំហុស ក្នុងការប្រតិបត្តិ gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "ហត្ថលេខា​ខាង​ក្រោម​មិន​ត្រឹមត្រូវ ៖\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2111,20 +2119,20 @@
 msgid "Error reading from server"
 msgstr "កំហុស​ក្នុងការអាន​ពី​ម៉ាស៊ីន​បម្រើ"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "បរាជ័យ​ក្នុងការ​សរសេរ​ឯកសារ %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "ទិន្នន័យ​បឋមកថា​ខូច"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "ការតភ្ជាប់​បាន​បរាជ័យ​"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "កំហុស​ខាង​ក្នុង​"
 
@@ -2190,7 +2198,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "ជម្រើស​ %s រក​មិន​ឃើញ​ឡើយ"
@@ -2313,6 +2321,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "មិនអាច​ប្ដូរទៅ %s បានឡើយ"
@@ -2497,7 +2506,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "បរាជ័យ​ក្នុងការ​សរសេរ​ឯកសារ %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2630,7 +2639,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "មិន​អាច​កែ​បញ្ហាបានទេេ អ្កបានទុក​កញ្ចប់​ដែល​ខូច ។។"
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2679,12 +2688,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "សូម​បញ្ចូល​ស្លាក​ឌីស​ ៖ '%s' ក្នុង​ដ្រាយ​ '%s' ហើយ​សង្កត់​ចូល ។"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "មិន​គាំទ្រ​ប្រព័ន្ធ​កញ្ចប់'%s' ឡើយ"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "មិនអាច​កំណត់​ប្រភេទ​ប្រព័ន្ធ​កញ្ចប់​ដែល​សមរម្យ​បានឡើយ"
 
@@ -2697,25 +2706,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "អ្នកត្រូវតែដាក់ 'ប្រភព' URIs មួយចំនួន​នៅក្នុង sources.list របស់អ្នក"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "បញ្ជី​កញ្ចប់​ ឬ ឯកសារ​ស្ថានភាព​មិន​អាចត្រូវបាន​​ញែក ​​ឬ ត្រូវបាន​បើកបានឡើយ​​ ។"
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "អ្នកប្រហែលជា​ចង់ភាពទាន់សម័យ apt-get ដើម្បី​កែ​បញ្ហា​ទាំងនេះ"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "កំណត់ត្រា​មិនត្រឹមត្រូវ​នៅក្នុង​ឯកសារចំណង់ចំណូលចិត្ត មិនមាន​បឋមកថា​កញ្ចប់ទេ"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "មិន​បាន​យល់​ពី​ប្រភេទ​ម្ជុល %s ឡើយ"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "គ្មាន​អទិភាព (ឬ សូន្យ​) បានបញ្ជាក់​សម្រាប់​ម្ជុល​ទេ"
 
@@ -2805,33 +2814,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "មិនអាចថ្លែង បញ្ជី​កញ្ចប់​ប្រភពចប់​ បានឡើយ %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "ការផ្ដល់​ឯកសារ​ប្រមូលផ្ដុំ"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IO កំហុសក្នុងការររក្សាទុក​ឃ្លាំង​សម្ងាត់​ប្រភព​"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "ប្តូរ​ឈ្មោះ​បានបរាជ័យ​, %s (%s -> %s) ។"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum មិន​ផ្គួផ្គង​"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "MD5Sum មិន​ផ្គួផ្គង​"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "គ្មាន​កូនសោ​សាធារណៈ​អាច​រក​បាន​ក្នុងកូនសោ IDs ខាងក្រោម​នេះទេ ៖\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2840,7 +2874,7 @@
 "ខ្ញុំ​មិន​អាច​រកទីតាំង​ឯកសារ​សម្រាប់​កញ្ចប់ %s បាន​ទេ ។ ​មាន​ន័យ​ថា​អ្នក​ត្រូវការ​ជួសជុល​កញ្ចប់​នេះ​ដោយ​ដៃ ។ "
 "(ដោយសារ​​បាត់​ស្ថាបត្យកម្ម)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2848,31 +2882,41 @@
 msgstr ""
 "ខ្ញុំ​មិន​អាច​រកទីតាំង​ឯកសារ​សម្រាប់​កញ្ចប់ %s បានទេ ។ ​មាន​ន័យ​ថា​អ្នក​ត្រូវការ​ជួសជុល​កញ្ចប់​នេះ​ដោយ​ដៃ ។"
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "កញ្ចប់​ឯកសារ​លិបិក្រម​ត្រូវ​បាន​ខូច ។ គ្មាន​ឈ្មោះ​ឯកសារ ៖ វាល​សម្រាប់​កញ្ចប់នេះ​ទេ​ %s ។"
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "ទំហំ​មិនបាន​ផ្គួផ្គង​"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "មិនអាច​ញែក​ឯកសារកញ្ចប់ %s (1) បានឡើយ"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "ចំណាំ កំពុង​ជ្រើស​ %s ជំនួស​ %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "បន្ទាត់​ដែលមិនត្រឹមត្រូវ​នៅក្នុង​ឯកសារ​បង្វែរ ៖ %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "មិនអាច​ញែក​ឯកសារកញ្ចប់ %s (1) បានឡើយ"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2966,151 +3010,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "ធាតុបញ្ចូល​បញ្ជីប្រភព​សម្រាប់​ឌីស​នេះគឺ ៖\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "បានសរសេរ %i កំណត់ត្រា ។\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "បានសរសេរ %i កំណត់ត្រា​ជាមួយ​ %i ឯកសារ​ដែល​បាត់បង់ ។\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "បានសរសេរ​ %i កំណត់ត្រា​ជាមួយួយ​ %i ឯកសារ​ដែល​មិន​បាន​ផ្គួផ្គង​\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "បានសរសេរ %i កំណត់ត្រា​ជាមួយ​ %i ឯកសារ​ដែល​បាត់បង់​ និង​ %i ឯកសារ​ដែល​មិន​បាន​ផ្គួផ្គង​ ​\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "កំពុង​បើ​ឯកសារ​កំណត់រចនាសម្ព័ន្ធ​ %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "MD5Sum មិន​ផ្គួផ្គង​"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "ចំណាំ កំពុង​ជ្រើស​ %s សម្រាប់ regex '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "បានជ្រើស​កំណែ​ %s (%s) សម្រាប់ %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "បាន​ដំឡើង %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "កំពុង​កំណត់​រចនា​សម្ព័ន្ធ %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "កំពុង​យក %s ចេញ"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "បាន​យក %s ចេញ​ទាំង​ស្រុង"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "រាយបញ្ជី​ថត​ %spartial គឺ​បាត់បង់​ ។"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "មិន​អាច​បើក​ឯកសារ​ %s បានឡើយ"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "កំពុងរៀបចំ​ %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "កំពុង​ស្រាយ %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "កំពុងរៀបចំ​កំណត់រចនាសម្ព័ន្ធ %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "បាន​ដំឡើង %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "កំពុងរៀបចំដើម្បី​ការយក​ចេញ​នៃ %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "បាន​យក %s ចេញ"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "កំពុង​រៀបចំ​យក %s ចេញ​ទាំង​ស្រុង"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "បាន​យក %s ចេញ​ទាំង​ស្រុង"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "មិន​អាច​ចាក់​សោ​ថត​បញ្ជីបានឡើយ"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3125,7 +3252,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "បាន​បិទ​ការ​តភ្ជាប់​មុន​ពេល"
 

=== modified file 'po/ko.po'
--- po/ko.po	2010-05-25 16:01:42 +0000
+++ po/ko.po	2010-06-10 14:02:22 +0000
@@ -5,7 +5,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-13 07:14+0900\n"
 "Last-Translator: Changwoo Ryu <cwryu@debian.org>\n"
 "Language-Team: Korean <debian-l10n-korean@lists.debian.org>\n"
@@ -13,147 +13,145 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "%s 패키지의 %s 버전의 의존성이 맞지 않습니다:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "%s 패키지를 찾을 수 없습니다"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "전체 패키지 이름 : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "전체 패키지 이름 : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  일반 패키지: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  순수 가상 패키지: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  단일 가상 패키지: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  혼합 가상 패키지: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  빠짐: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "개별 버전 전체: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "개별 설명 전체: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "전체 의존성: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "전체 버전/파일 관계: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "전체 설명/파일 관계: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "전체 제공 매핑: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "전체 패턴 문자열: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "전체 의존성 버전 용량: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "전체 빈 용량: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "차지하는 전체 용량: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "패키지 파일 %s 파일이 동기화되지 않았습니다."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "정확히 한 개의 패턴을 넘겨야 합니다"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "패키지가 없습니다"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "%s 패키지를 찾을 수 없습니다"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "패키지 파일:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "캐시가 동기화되지 않았습니다. 패키지 파일을 상호 참조할 수 없습니다"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "핀 패키지:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(없음)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  설치: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  후보: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(없음)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  패키지 핀: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  버전 테이블:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s(%s), 컴파일 시각 %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -308,12 +306,12 @@
 "  -c=? 설정 파일을 읽습니다\n"
 "  -o=? 임의의 옵션을 설정합니다. 예를 들어 -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "%s에 쓸 수 없습니다"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "debconf 버전을 알 수 없습니다. debconf가 설치되었습니까?"
 
@@ -651,79 +649,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "%s 파일의 이름을 %s(으)로 바꾸는 데 실패했습니다"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "정규식 컴파일 오류 - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "다음 패키지의 의존성이 맞지 않습니다:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "하지만 %s 패키지를 설치했습니다"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "하지만 %s 패키지를 설치할 것입니다"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "하지만 설치할 수 없습니다"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "하지만 가상 패키지입니다"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "하지만 설치하지 않았습니다"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "하지만 %s 패키지를 설치하지 않을 것입니다"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " 혹은"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "다음 새 패키지를 설치할 것입니다:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "다음 패키지를 지울 것입니다:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "다음 패키지를 과거 버전으로 유지합니다:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "다음 패키지를 업그레이드할 것입니다:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "다음 패키지를 다운그레이드할 것입니다:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "고정되었던 다음 패키지를 바꿀 것입니다:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (%s때문에) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -731,146 +729,146 @@
 "경고: 꼭 필요한 다음 패키지를 지우게 됩니다.\n"
 "무슨 일을 하고 있는 지 정확히 알지 못한다면 지우지 마십시오!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu개 업그레이드, %lu개 새로 설치, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu개 다시 설치, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu개 업그레이드, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu개 지우기 및 %lu개 업그레이드 안 함.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu개를 완전히 설치하지 못했거나 지움.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "의존성을 바로잡는 중입니다..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " 실패."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "의존성을 바로잡을 수 없습니다"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "업그레이드 집합을 최소화할 수 없습니다"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " 완료"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 "이 상황을 바로잡으려면 'apt-get -f install'을 실행해야 할 수도 있습니다."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "의존성이 맞지 않습니다. -f 옵션을 사용해 보십시오."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "경고: 다음 패키지를 인증할 수 없습니다!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "인증 경고를 무시합니다.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "확인하지 않고 패키지를 설치하시겠습니까 [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "인증할 수 없는 패키지가 있습니다"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "문제가 발생했고 -y 옵션이 --force-yes 옵션 없이 사용되었습니다"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "내부 오류. 망가진 패키지에서 InstallPackages를 호출했습니다!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "패키지를 지워야 하지만 지우기가 금지되어 있습니다."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "내부 오류. 순서변경작업이 끝나지 않았습니다"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "소스 목록을 읽을 수 없습니다."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "이상하게도 크기가 서로 다릅니다. apt@packages.debian.org로 이메일을 보내주십"
 "시오."
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "%s바이트/%s바이트 아카이브를 받아야 합니다.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "%s바이트 아카이브를 받아야 합니다.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "이 작업 후 %s바이트의 디스크 공간을 더 사용하게 됩니다.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "이 작업 후 %s바이트의 디스크 공간이 비워집니다.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "%s의 여유 공간의 크기를 파악할 수 없습니다"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "%s 안에 충분한 여유 공간이 없습니다."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "사소한 작업만 가능하도록(Trivial Only) 지정되었지만 이 작업은 사소한 작업이 "
 "아닙니다."
 
 # 입력을 받아야 한다.  한글 입력을 못 할 수 있으므로 원문 그대로 사용.
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Yes, do as I say!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -881,28 +879,28 @@
 "계속하시려면 다음 문구를 입력하십시오: '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "중단."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "계속 하시겠습니까 [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "%s 파일을 받는 데 실패했습니다  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "일부 파일을 받는 데 실패했습니다"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "다운로드를 마쳤고 다운로드 전용 모드입니다"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -910,19 +908,19 @@
 "아카이브를 받을 수 없습니다. 아마도 apt-get update를 실행해야 하거나 --fix-"
 "missing 옵션을 줘서 실행해야 할 것입니다."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing 옵션과 동시에 미디어 바꾸기는 현재 지원하지 않습니다"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "빠진 패키지를 바로잡을 수 없습니다."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "설치를 중단합니다."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -932,51 +930,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "주의, %2$s 대신에 %1$s 패키지를 선택합니다\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "%s 패키지를 건너 뜁니다. 이미 설치되어 있고 업그레이드를 하지 않습니다.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "%s 패키지를 건너 뜁니다. 이미 설치되어 있고 업그레이드를 하지 않습니다.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "%s 패키지를 설치하지 않았으므로, 지우지 않습니다\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "%s 패키지는 다음 패키지가 제공하는 가상 패키지입니다:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [설치함]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "후보 버전"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "설치할 패키지를 하나 분명히 지정해야 합니다."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -987,65 +985,65 @@
 "해당 패키지가 누락되었거나 지워졌다는 뜻입니다. 아니면 또 다른 곳에서\n"
 "패키지를 받아와야 하는 경우일 수도 있습니다.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "하지만 다음 패키지가 대체합니다:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "%s 패키지는 설치할 수 있는 후보가 없습니다"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "%s 패키지를 다시 설치하는 건 불가능합니다. 다운로드할 수 없습니다.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s 패키지는 이미 최신 버전입니다.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "%2$s 패키지의 '%1$s' 릴리즈를 찾을 수 없습니다"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "%2$s 패키지의 '%1$s' 버전을 찾을 수 없습니다"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "%3$s 패키지의 %1$s (%2$s) 버전을 선택합니다\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "소스 패키지 목록 %s의 정보를 읽을 수 없습니다"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "update 명령은 인수를 받지 않습니다"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "삭제를 할 수 없으므로 AutoRemover를 실행하지 못합니다"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1057,7 +1055,7 @@
 msgstr[1] ""
 "다음 새 패키지가 전에 자동으로 설치되었지만 더 이상 필요하지 않습니다:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1067,11 +1065,11 @@
 msgstr[1] ""
 "다음 새 패키지가 전에 자동으로 설치되었지만 더 이상 필요하지 않습니다:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "이들을 지우기 위해서는 'apt-get autoremove'를 사용하십시오."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1089,44 +1087,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "이 상황을 해결하는 데 다음 정보가 도움이 될 수도 있습니다:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "내부 오류, 문제 해결 프로그램이 무언가를 망가뜨렸습니다"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "내부 오류, AllUpgrade 프로그램이 무언가를 망가뜨렸습니다"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "%s 작업를 찾을 수 없습니다"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "%s 패키지를 찾을 수 없습니다"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "주의, 정규식 '%2$s'에 대하여 %1$s을(를) 선택합니다\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s 패키지 수동설치로 지정합니다.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "다음을 바로잡으려면 'apt-get -f install'을 실행해 보십시오:"
 
 # FIXME: specify a solution?  무슨 솔루션?
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1134,7 +1127,7 @@
 "의존성이 맞지 않습니다. 패키지 없이 'apt-get -f install'을 시도해 보십시오 "
 "(아니면 해결 방법을 지정하십시오)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1145,124 +1138,139 @@
 "불안정 배포판을 사용해서 일부 필요한 패키지를 아직 만들지 않았거나,\n"
 "아직 Incoming에서 나오지 않은 경우일 수도 있습니다."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "망가진 패키지"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "다음 패키지를 더 설치할 것입니다:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "제안하는 패키지:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "추천하는 패키지:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s 패키지 수동설치로 지정합니다.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "업그레이드를 계산하는 중입니다... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "실패"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "완료"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "내부 오류, 문제 해결 프로그램이 무언가를 망가뜨렸습니다"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "다운로드 디렉토리를 잠글 수 없습니다"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "해당되는 소스 패키지를 가져올 패키지를 최소한 하나 지정해야 합니다"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "%s의 소스 패키지를 찾을 수 없습니다"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "이미 다운로드 받은 파일 '%s'은(는) 다시 받지 않고 건너 뜁니다.\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "%s에 충분한 공간이 없습니다"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "소스 아카이브를 %s바이트/%s바이트 받아야 합니다.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "소스 아카이브를 %s바이트 받아야 합니다.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "%s 소스를 가져옵니다\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "일부 아카이브를 가져오는 데 실패했습니다."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "%s에 이미 풀려 있는 소스의 압축을 풀지 않고 건너 뜁니다.\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "압축 풀기 명령 '%s' 실패.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "'dpkg-dev' 패키지가 설치되었는지를 확인하십시오.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "빌드 명령 '%s' 실패.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "하위 프로세스가 실패했습니다"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "해당되는 빌드 의존성을 검사할 패키지를 최소한 하나 지정해야 합니다"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "%s의 빌드 의존성 정보를 가져올 수 없습니다"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s 패키지에 빌드 의존성이 없습니다.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1271,7 +1279,7 @@
 "%2$s에 대한 %1$s 의존성을 만족시킬 수 없습니다. %3$s 패키지를 찾을 수 없습니"
 "다"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1280,32 +1288,32 @@
 "%2$s에 대한 %1$s 의존성을 만족시킬 수 없습니다. %3$s 패키지의 사용 가능한 버"
 "전 중에서는 이 버전 요구사항을 만족시킬 수 없습니다"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "%2$s에 대한 %1$s 의존성을 만족시키는 데 실패했습니다: 설치한 %3$s 패키지가 너"
 "무 최근 버전입니다"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "%2$s에 대한 %1$s 의존성을 만족시키는 데 실패했습니다: %3$s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "%s의 빌드 의존성을 만족시키지 못했습니다."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "빌드 의존성을 처리하는 데 실패했습니다"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "지원하는 모듈:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1640,8 +1648,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "%s을(를) 읽을 수 없습니다"
@@ -1670,10 +1679,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "정보 디렉토리와 임시 디렉토리는 같은 파일 시스템에 있어야 합니다"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "패키지 목록을 읽는 중입니다"
 
@@ -1888,171 +1896,171 @@
 msgid "Write error"
 msgstr "쓰기 오류"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "소켓을 만들 수 없습니다"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "데이터 소켓을 연결할 수 없습니다. 연결 시간이 초과되었습니다"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "수동(passive) 소켓을 연결할 수 없습니다."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo에서 소켓에 listen할 수 없습니다"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "소켓을 bind할 수 없습니다"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "소켓에 listen할 수 없습니다"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "소켓의 이름을 알아낼 수 없습니다"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "PORT 명령을 보낼 수 없습니다"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "주소 %u의 종류(AF_*)를 알 수 없습니다"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT 실패, 서버에서는: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "데이터 소켓 연결 시간 초과"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "연결을 받을 수 없습니다"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "파일 해싱에 문제가 있습니다"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "파일을 가져올 수 없습니다. 서버 왈, '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "데이터 소켓에 제한 시간이 초과했습니다"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "데이터 전송 실패, 서버에서는: %s"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "질의"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "다음을 실행할 수 없습니다: "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "%s(%s)에 연결하는 중입니다"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "%s에 대한 소켓을 만들 수 없습니다 (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "%s:%s에 연결을 초기화할 수 없습니다 (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "%s:%s에 연결할 수 없습니다 (%s). 연결 제한 시간이 초과했습니다"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "%s:%s에 연결할 수 없습니다 (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "%s에 연결하는 중입니다"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "'%s'의 주소를 알아낼 수 없습니다"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "'%s'의 주소를 알아내는 데 임시로 실패했습니다"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "'%s:%s'의 주소를 알아내는 데 무언가 이상한 일이 발생했습니다 (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "%s %s에 연결할 수 없습니다:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "설치를 중단합니다."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "내부 오류: 서명은 올바르지만 키 지문을 확인할 수 없습니다!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "최소한 하나 이상의 서명이 잘못되었습니다."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "서명을 확인하는 '%s' 프로그램을 실행할 수 없습니다. (gnuv 프로그램을 설치했습"
 "니까?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "gpgv 실행 도중 알 수 없는 오류 발생"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "다음 서명이 올바르지 않습니다:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2129,19 +2137,19 @@
 msgid "Error reading from server"
 msgstr "서버에서 읽는 데 오류가 발생했습니다"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "파일을 자르는 데 실패했습니다"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "헤더 데이터가 잘못되었습니다"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "연결이 실패했습니다"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "내부 오류"
 
@@ -2207,7 +2215,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "선택한 %s이(가) 없습니다"
@@ -2330,6 +2338,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "%s 디렉토리로 이동할 수 없습니다"
@@ -2513,7 +2522,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "임시 상태파일 %s 쓰는 데 실패했습니다"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2647,7 +2656,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "문제를 바로잡을 수 없습니다. 망가진 고정 패키지가 있습니다."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2698,12 +2707,12 @@
 msgstr ""
 "'%2$s' 드라이브에 '%1$s'(으)로 표기된 디스크를 넣고 Enter를 누르십시오."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "'%s' 패키지 시스템을 지원하지 않습니다"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "올바른 패키지 시스템 타입을 알아낼 수 없습니다"
 
@@ -2716,25 +2725,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "sources.list에 '소스' URI를 써 넣어야 합니다"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "패키지 목록이나 상태 파일을 파싱할 수 없거나 열 수 없습니다."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "apt-get update를 실행하면 이 문제를 바로잡을 수도 있습니다."
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "기본 설정 파일에 잘못된 데이터가 있습니다. 패키지 헤더가 없습니다"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "핀 타입 %s이(가) 무엇인지 이해할 수 없습니다"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "핀에 우선순위(혹은 0)를 지정하지 않았습니다"
 
@@ -2823,32 +2832,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "소스 패키지 목록 %s의 정보를 읽을 수 없습니다"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "파일에서 제공하는 것을 모으는 중입니다"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "소스 캐시를 저장하는 데 입출력 오류가 발생했습니다"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "이름 바꾸기가 실패했습니다. %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum이 맞지 않습니다"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "해쉬 합계가 서로 다릅니다"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "다음 키 ID의 공개키가 없습니다:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2857,7 +2891,7 @@
 "%s 패키지의 파일을 찾을 수 없습니다. 수동으로 이 패키지를 고쳐야 할 수도 있습"
 "니다. (아키텍쳐가 빠졌기 때문입니다)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2866,32 +2900,42 @@
 "%s 패키지의 파일을 찾을 수 없습니다. 수동으로 이 패키지를 고쳐야 할 수도 있습"
 "니다."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "패키지 인덱스 파일이 손상되었습니다. %s 패키지에 Filename: 필드가 없습니다."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "크기가 맞지 않습니다"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "패키지 파일 %s 파일을 파싱할 수 없습니다 (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "주의, %2$s 대신에 %1$s 패키지를 선택합니다\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "전환 파일에 잘못된 줄이 있습니다: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "패키지 파일 %s 파일을 파싱할 수 없습니다 (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2984,152 +3028,235 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "이 디스크의 소스 리스트 항목은 다음과 같습니다:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "레코드 %i개를 썼습니다.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "레코드 %i개를 파일 %i개가 빠진 상태로 썼습니다.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "레코드 %i개를 파일 %i개가 맞지 않은 상태로 썼습니다\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "레코드 %i개를 파일 %i개가 빠지고 %i개가 맞지 않은 상태로 썼습니다\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "설정 파일 %s 파일을 여는 중입니다"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "해쉬 합계가 서로 다릅니다"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "주의, 정규식 '%2$s'에 대하여 %1$s을(를) 선택합니다\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "%3$s 패키지의 %1$s (%2$s) 버전을 선택합니다\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "%s 설치하는 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s 설정 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s 패키지를 지우는 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s 패키지를 완전히 지웠습니다"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "설치 후 트리거 %s 실행하는 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "디렉토리 '%s' 없습니다."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "%s 파일을 열 수 없습니다"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s 준비 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "%s 푸는 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "%s 패키지를 설정할 준비하는 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s 설치"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "%s 패키지를 지울 준비하는 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s 지움"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "%s 패키지를 완전히 지울 준비를 하는 중입니다"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s 패키지를 완전히 지웠습니다"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "로그에 쓰는데 실패. openpty() 실패(/dev/pts가 마운트되어있지 않습니까?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "목록 디렉토리를 잠글 수 없습니다"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3144,7 +3271,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "연결이 너무 빨리 끊어졌습니다"
 

=== modified file 'po/ku.po'
--- po/ku.po	2010-05-25 16:01:42 +0000
+++ po/ku.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: apt-ku\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-05-08 12:48+0200\n"
 "Last-Translator: Erdal Ronahi <erdal dot ronahi at gmail dot com>\n"
 "Language-Team: ku <ubuntu-l10n-kur@lists.ubuntu.com>\n"
@@ -18,149 +18,147 @@
 "X-Generator: KAider 0.1\n"
 "Plural-Forms: nplurals=2; plural= n != 1;\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr ""
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Pakêt nehate dîtin %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Navên paketan bi giştî :"
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Navên paketan bi giştî :"
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Pakêtên normal:"
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Pakêtên farazî yên safî:"
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Pakêta tenê ya farazî:"
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Pakêtên hevbeş yên farazî:"
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Winda: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Guhertoyên vekirî yên giştî:"
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "Guhertoyên vekirî yên giştî:"
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Bindestên giştî:"
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "Guhertoyên vekirî yên giştî:"
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Cihê giştî yê sist:"
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Cihê giştî yê veqetandî: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Pakêta dosya %s li derveyî demê ye."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Pêwist e tu mînakekê bidî"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Pakêt nayên dîtin"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Pakêt nehate dîtin %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Pelgehên Pakêt:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(nehate dîtin)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Sazkirî: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Berendam: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ne tiştek)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Destika pakêtê:"
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabloya guhertoyan:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s ji bo %s %s komkirî di %s %s de\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 msgid ""
 "Usage: apt-cache [options] command\n"
 "       apt-cache [options] add file1 [file2 ...]\n"
@@ -269,12 +267,12 @@
 "  -o=? Set an arbitrary configuration option, eg -o dir::cache=/tmp\n"
 msgstr ""
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Nivîsandin ji bo %s ne pêkane"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Guhertoya debconf nehate stendin. debconf sazkirî ye?"
 
@@ -568,218 +566,218 @@
 msgid "Failed to rename %s to %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "E"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr ""
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "lê %s sazkirî ye"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "lê %s dê were sazkirin"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "lê sazkirina wê ne gengaz e"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "lê paketeke farazî ye"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "lê ne sazkirî ye"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "lê dê neyê sazkirin"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " û"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Ev pakêtên NÛ dê werine sazkirin:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Ev pakêt dê werine RAKIRIN:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr ""
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Ev paket dê werine bilindkirin:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr ""
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr ""
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (ji ber %s)"
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
 msgstr ""
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu hatine bilindkirin, %lu nû hatine sazkirin."
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu ji nû ve sazkirî,"
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu hatine nizmkirin."
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu werin rakirin û %lu neyên bilindkirin. \n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Bindestî tên serrastkirin..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " neserketî."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Nikare bindestiyan rast kirin"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr ""
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Temam"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr ""
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr ""
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr ""
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr ""
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr ""
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr ""
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr ""
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr ""
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Anîna %sB/%sB ji arşîvan pêwist e.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Anîna %sB ji arşîvan pêwist e.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Nikarî cihê vala li %s tesbît bike"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Cihê vala li %s têre nake."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Erê, wusa bike!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -787,46 +785,46 @@
 " ?] "
 msgstr ""
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Betal."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Dixwazî bidomînî [E/n]?"
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Anîna %s %s biserneket\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Daxistina çend pelan biserneket"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr ""
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
 msgstr ""
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr ""
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr ""
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Sazkirin tê betalkirin."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -836,49 +834,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Sazkirî]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Guhartoyên berendam"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr ""
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -886,65 +884,65 @@
 "is only available from another source\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr ""
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr ""
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s jixwe guhertoya nûtirîn e.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr ""
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr ""
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr ""
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr ""
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -954,7 +952,7 @@
 msgstr[0] "Ev pakêtên NÛ dê werine sazkirin:"
 msgstr[1] "Ev pakêtên NÛ dê werine sazkirin:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -962,11 +960,11 @@
 msgstr[0] "Ev pakêtên NÛ dê werine sazkirin:"
 msgstr[1] "Ev pakêtên NÛ dê werine sazkirin:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -982,49 +980,44 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr ""
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Peywira %s nehate dîtin"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Nikarî pakêta %s bibîne"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr ""
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "lê %s dê were sazkirin"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
 msgstr ""
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1032,161 +1025,176 @@
 "or been moved out of Incoming."
 msgstr ""
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Paketên şikestî"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr ""
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Paketên tên pêşniyaz kirin:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Paketên tên tawsiyê kirin:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "lê %s dê were sazkirin"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Bilindkirin tê hesibandin..."
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Serneket"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Temam"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Pelrêça daxistinê nayê quflekirin"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Cihê vala li %s têre nake"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Çavkanîna %s bîne\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Anîna çend arşîvan biserneket."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr ""
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr ""
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
 "package %s can satisfy version requirements"
 msgstr ""
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr ""
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr ""
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr ""
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 msgid ""
 "Usage: apt-get [options] command\n"
 "       apt-get [options] install|remove pkg1 [pkg2 ...]\n"
@@ -1467,8 +1475,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Nikare %s bixwîne"
@@ -1497,10 +1506,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr ""
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Lîsteya pakêtan tê xwendin"
 
@@ -1710,171 +1718,170 @@
 msgid "Write error"
 msgstr "Çewtiya nivîsînê"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr ""
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr ""
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr ""
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr ""
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr ""
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr ""
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr ""
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr ""
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr ""
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr ""
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr ""
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr ""
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, fuzzy, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Danegira %s nehate vekirin: %s"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr ""
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr ""
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Lêpirsîn"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 #, fuzzy
 msgid "Unable to invoke "
 msgstr "%s venebû"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Girêdan bi %s (%s) re pêk tê"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr ""
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr ""
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr ""
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr ""
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Bi %s re tê girêdan"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nikarî '%s' çareser bike"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr ""
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr ""
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Nikare bi %s re girêdan pêk bîne %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Sazkirin tê betalkirin."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr ""
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Di xebitandina gpgv de çewtiya nenas"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 #, fuzzy
 msgid "The following signatures were invalid:\n"
 msgstr "Ev pakêtên NÛ dê werine sazkirin:"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -1952,20 +1959,20 @@
 msgid "Error reading from server"
 msgstr ""
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Nivîsîna pelê %s biserneket"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr ""
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Girêdan pêk nehatiye"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Çewtiya hundirîn"
 
@@ -2031,7 +2038,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Hilbijartina %s nehatiye dîtin"
@@ -2154,6 +2161,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Nikarî derbasa %s bike"
@@ -2337,7 +2345,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "%s ji hev nehate veçirandin"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2465,7 +2473,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr ""
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2513,12 +2521,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Dîsketê siwar bike û piştre bişkoja derbaskirinê bitikîne"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr ""
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr ""
 
@@ -2531,25 +2539,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr ""
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr ""
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr ""
 
@@ -2638,70 +2646,105 @@
 msgid "Couldn't stat source package list %s"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "nav guherandin biserneket, %s (%s -> %s)"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum li hev nayên"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash Sum li hev nayên"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
 "to manually fix this package. (due to missing arch)"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
 "manually fix this package."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Mezinahî li hev nayên"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Pakêt nehate dîtin %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr ""
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr ""
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Pakêt nehate dîtin %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2792,151 +2835,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i tomar hatin nivîsîn.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash Sum li hev nayên"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:194
+#, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "%s hatine sazkirin"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s tê mîhengkirin"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s tê rakirin"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s bi tevahî hatine rakirin"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Peldanka '%s' kêm e"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Nikarî pelê %s veke"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s tê amadekirin"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "%s tê derxistin"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Mîhengkirina %s tê amadekirin"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s hatine sazkirin"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Rakirina %s tê amadekirin"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s hatine rakirin"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Bi tevahî rakirina %s tê amadekirin"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s bi tevahî hatine rakirin"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Pelrêça daxistinê nayê quflekirin"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -2951,7 +3077,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Girêdan zû hatiye girtin"
 

=== modified file 'po/lt.po'
--- po/lt.po	2010-05-25 16:01:42 +0000
+++ po/lt.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-08-02 01:47-0400\n"
 "Last-Translator: Gintautas Miliauskas <gintas@akl.lt>\n"
 "Language-Team: Lithuanian <komp_lt@konferencijos.lt>\n"
@@ -17,149 +17,146 @@
 "Content-Transfer-Encoding: 8bit\n"
 "X-Launchpad-Export-Date: 2008-08-02 05:04+0000\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Paketas %s versijos numeriu %s turi netenkinamą priklausomybę:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Nepavyko rasti paketo %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 #, fuzzy
 msgid "Total package names: "
 msgstr "Visi paketų pavadinimai: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Visi paketų pavadinimai: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normalūs paketai: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Virtualūs paketai: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Pavieniai virtualūs paketai: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Mišrūs virtualūs paketai: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Trūksta: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Viso skirtingų versijų: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "Viso skirtingų aprašymų: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Viso priklausomybių: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Viso versijų/failų santykių yra: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Viso aprašymų/failų santykių yra: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr ""
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr ""
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+msgid "You must give at least one search pattern"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Paketų nerasta"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Nepavyko rasti paketo %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Paketų failai:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Surišti paketai:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(nerasta)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Įdiegta: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidatas: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(nėra)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Paketo susiejimai: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Versijų lentelė:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr ""
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 msgid ""
 "Usage: apt-cache [options] command\n"
 "       apt-cache [options] add file1 [file2 ...]\n"
@@ -278,12 +275,12 @@
 "  -c=? Nuskaityti šį konfigūracijų failą\n"
 "  -o=? Nustatyti savarankiškas nuostatas, pvz.: -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Nepavyko įrašyti į %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Nepavyko sužinoti debconf versijos. Ar įdiegtas debconf?"
 
@@ -624,79 +621,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Nepavyko pervadinti %s į %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "T"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr ""
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Šie paketai turi neįdiegtų priklausomybių:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "bet %s yra įdiegtas"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "bet %s bus įdiegtas"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "tačiau jis negali būti įdiegtas"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "bet tai yra virtualus paketas"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "bet jis nėra įdiegtas"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "bet jis nebus įdiegtas"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " arba"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Bus įdiegti šie NAUJI paketai:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Bus PAŠALINTI šie paketai:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Šių paketų atnaujinimas sulaikomas:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Bus atnaujinti šie paketai:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Bus PAKEISTI SENESNIAIS šie paketai:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Bus pakeisti šie sulaikyti paketai:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (dėl %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -704,141 +701,141 @@
 "Įspėjimas: Šie būtini paketai bus pašalinti.\n"
 "Tai NETURĖTŲ būti daroma, kol tiksliai nežinote ką darote!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu atnaujinti, %lu naujai įdiegti, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu įdiegti iš naujo, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu pasendinti, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu bus pašalinta ir %lu neatnaujinta.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu nepilnai įdiegti ar pašalinti.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Taisomos priklausomybės..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " nepavyko."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Nepavyko patenkinti priklausomybių"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 #, fuzzy
 msgid "Unable to minimize the upgrade set"
 msgstr "Nepavyko minimizuoti atnaujinimo rinkinio"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Įvykdyta"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Įvykdykite „apt-get -f install“, jei norite ištaisyti šias klaidas."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Nepatenkintos priklausomybės. Bandykit naudoti -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "DĖMESIO: Šie paketai negali būti autentifikuoti!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Įdiegti šiuos paketus be patvirtinimo [t/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Nepavyko autentikuoti kai kurių paketų"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Atsirado problemų ir -y buvo panaudotas be --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Reikia pašalinti paketus, tačiau šalinimas išjungtas."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr ""
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Nepavyko perskaityti šaltinių sąrašo."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "Keista.. Dydis neatitinka, Parašykite laišką apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Reikia parsiųsti %sB/%sB archyvų.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Reikia parsiųsti %sB archyvų.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Po šios operacijos bus naudojama %sB papildomos disko vietos.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Po šios operacijos bus atlaisvinta %sB disko vietos.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Nepavyko nustatyti %s laisvos vietos"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "%s nėra pakankamai laisvos vietos."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Taip, daryk kaip liepiu!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -849,28 +846,28 @@
 "Jei norite tęsti, įveskite frazę „%s“\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Nutraukti."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Ar norite tęsti [T/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Nepavyko parsiųsti %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Nepavyko parsiųsti kai kurių failų"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Pavyko parsiųsti tik parsiuntimo režime"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -878,19 +875,19 @@
 "Nepavyko parsiųsti kai kurių archyvų, pabandykite paleisti „apt-get update“ "
 "arba pabandykite su parametru --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing bei laikmenų apkeitimas nepalaikomas"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Nepavyko pataisyti dingusių paketų."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Diegimas nutraukiamas."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -900,51 +897,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Pastaba: pažymimas %s vietoje %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Praleidžiamas %s, nes jis jau yra įdiegtas ir atnaujinimas nėra nurodytas.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Praleidžiamas %s, nes jis jau yra įdiegtas ir atnaujinimas nėra nurodytas.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Paketas %s nėra įdiegtas, todėl nebuvo pašalintas\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Paketas %s yra virtualus, pateiktas:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Įdiegtas]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Galimos versijos"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Reikia pažymėti įdiegimui bent vieną."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -955,65 +952,65 @@
 "Tai gali reikšti, kad paketas dingęs, nebenaudojamas \n"
 "arba prieinamas tik iš kitų šaltinių.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Tačiau šie paketai jį pakeičia:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Paketas %s neturi diegimo kandidatų"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Pakartotinas %s įdiegimas neįmanomas, jo nepavyksta parsiųsti.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s ir taip jau yra naujausias.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Nebuvo rastas „%s“ leidimas paketui „%s“"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Nebuvo rasta „%s“ versija paketui „%s“"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Pažymėta versija %s (%s) paketui %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr ""
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Atnaujinimo komandai argumentų nereikia"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1023,7 +1020,7 @@
 msgstr[0] "Šie paketai buvo automatiškai įdiegti ir daugiau nebėra reikalingi:"
 msgstr[1] "Šie paketai buvo automatiškai įdiegti ir daugiau nebėra reikalingi:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1031,11 +1028,11 @@
 msgstr[0] "Šie paketai buvo automatiškai įdiegti ir daugiau nebėra reikalingi:"
 msgstr[1] "Šie paketai buvo automatiškai įdiegti ir daugiau nebėra reikalingi:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Norėdami juos pašalinti, paleiskite „apt-get autoremove“"
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1051,43 +1048,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Ši informacija gali padėti išspręsti šią situaciją:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr ""
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Nepavyko rasti užduoties %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Nepavyko rasti paketo %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Pastaba, žymima %s regex atitikimų formoje '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s nustatytas kaip įdiegtas rankiniu būdu\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Jūs galite norėti paleisti 'apt-get -f install\" klaidų taisymui:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1095,7 +1087,7 @@
 "Nepatenkintos priklausomybės. Pabandykite įvykdyti 'apt-get -f install' be "
 "nurodytų paketų (arba nurodykite išeitį)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1107,124 +1099,139 @@
 "leidimą, kuomet kai kurie paketai dar nebuvo sukurti arba buvo\n"
 "pašalinti iš \"Incoming\" aplanko."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Sugadinti paketai"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Bus įdiegti šie papildomi paketai:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Siūlomi paketai:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Rekomenduojami paketai:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s nustatytas kaip įdiegtas rankiniu būdu\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Skaičiuojami atnaujinimai... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Nepavyko"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Įvykdyta"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Vidinė klaida, problemos sprendimas kažką sugadino"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Nepavyko užrakinti parsiuntimų aplanko"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Būtina nurodyti bent vieną paketą, kad parsiųsti jo išeities tekstą"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Nepavyko surasti išeities teksto paketo, skirto %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Praleidžiama jau parsiųsta byla „%s“\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Neturite pakankamai laisvos vietos %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Reikia parsiųsti %sB/%sB išeities archyvų.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Reikia parsiųsti %sB išeities archyvų.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Parsiunčiamas archyvas %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Nepavyko gauti kai kurių arhcyvų."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Jau išpakuotas archyvas %s praleidžiama\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Nepavyko įvykdyti išpakavimo komandos „%s“\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Patikrinkite, ar įdiegtas „dpkg-dev“ paketas.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Nepavyko įvykdyti paketo kompiliavimo komandos „%s“\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Klaida procese-palikuonyje"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "Būtina nurodyti bent vieną paketą, kuriam norite įvykdyti builddeps"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Nepavyko gauti kūrimo-priklausomybių informacijos paketui %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1232,7 +1239,7 @@
 msgstr ""
 "%s priklausomybė %s paketui negali būti patenkinama, nes paketas %s nerastas"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1241,32 +1248,32 @@
 "%s priklausomybė %s paketui negali būti patenkinama, nes nėra tinkamos "
 "versijos %s paketo"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Nepavyko patenkinti %s priklausomybės %s paketui: Įdiegtas paketas %s yra "
 "per naujas"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Nepavyko patenkinti %s priklausomybės %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr ""
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr ""
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Palaikomi moduliai:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 msgid ""
 "Usage: apt-get [options] command\n"
 "       apt-get [options] install|remove pkg1 [pkg2 ...]\n"
@@ -1564,8 +1571,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Nepavyko perskaityti %s"
@@ -1594,10 +1602,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr ""
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Skaitomi paketų sąrašai"
 
@@ -1806,169 +1813,168 @@
 msgid "Write error"
 msgstr "Rašymo klaida"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr ""
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr ""
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr ""
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr ""
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr ""
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr ""
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr ""
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr ""
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr ""
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr ""
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr ""
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr ""
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Nepavyko atsiųsti failo, serveris atsakė „%s“"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr ""
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr ""
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Užklausti"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr ""
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Jungiamasi prie %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr ""
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr ""
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Nepavyko prisijungti prie %s:%s (%s), prisijungimas per ilgai užtruko"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Nepavyko prisijungti prie %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Jungiamasi prie %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nepavyko surasti vardo „%s“"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Laikinas sutrikimas ieškant vardo „%s“"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr ""
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Nepavyko prisijungti prie %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Diegimas nutraukiamas."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr ""
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Nežinoma klaida kviečiant gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Šie parašai buvo nevalidūs:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2045,20 +2051,20 @@
 msgid "Error reading from server"
 msgstr ""
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Nepavyko patikrinti %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr ""
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Prisijungti nepavyko"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Vidinė klaida"
 
@@ -2124,7 +2130,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr ""
@@ -2247,6 +2253,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Nepavyko pakeisti į %s"
@@ -2430,7 +2437,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr ""
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2558,7 +2565,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr ""
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2608,12 +2615,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Įdėkite diską „%s“ į įrenginį „%s“ ir paspauskite Enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr ""
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr ""
 
@@ -2626,27 +2633,27 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr ""
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Nepavyko perskaityti arba atverti paketų sąrašo arba būklės failo."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Greičiausiai norėsite paleisti „apt-get update“, kad šios problemos būtų "
 "ištaisytos"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr ""
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr ""
 
@@ -2735,70 +2742,105 @@
 msgid "Couldn't stat source package list %s"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr ""
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5 sumos neatitikimas"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Maišos sumos nesutapimas"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr "GPG klaida: %s: %s"
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
 "to manually fix this package. (due to missing arch)"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
 "manually fix this package."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Neatitinka dydžiai"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Nepavyko atverti DB failo %s: %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Pastaba: pažymimas %s vietoje %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Pastaba: pažymimas %s vietoje %s\n"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Nepavyko atverti DB failo %s: %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2889,151 +2931,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Praleidžiama jau parsiųsta byla „%s“\n"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Maišos sumos nesutapimas"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Pastaba, žymima %s regex atitikimų formoje '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Pažymėta versija %s (%s) paketui %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "Įdiegta %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Konfigūruojamas %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Šalinamas %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Visiškai pašalintas %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Trūksta aplanko „%s“"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Nepavyko atverti failo %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Ruošiamas %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Išpakuojamas %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Ruošiamasi konfigūruoti %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Įdiegta %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Ruošiamasi %s pašalinimui"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Pašalintas %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Ruošiamasi visiškai pašalinti %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Visiškai pašalintas %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Nepavyko užrakinti sąrašo aplanko"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3048,7 +3173,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr ""
 
@@ -3079,9 +3204,6 @@
 #~ msgid "Line %d too long (max %u)"
 #~ msgstr "Eilutė %d per ilga (leidžiama %u simbolių)"
 
-#~ msgid "GPG error: %s: %s"
-#~ msgstr "GPG klaida: %s: %s"
-
 #~ msgid "Apt Authentication issue"
 #~ msgstr "Apt autentikacijos problema"
 

=== modified file 'po/mr.po'
--- po/mr.po	2010-05-25 16:01:42 +0000
+++ po/mr.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-20 23:27+0530\n"
 "Last-Translator: Sampada <sampadanakhare@gmail.com>\n"
 "Language-Team: Marathi, janabhaaratii, C-DAC, Mumbai, India "
@@ -15,147 +15,145 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "पॅकेज %s आवृती %s मध्ये एक अनोळखी डीईपी:आहे\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "पॅकेज %s शोधण्यास असमर्थ आहे"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "पॅकेजची सर्व नांवे: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "पॅकेजची सर्व नांवे: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr " सामान्य पॅकेजेस्: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr " शुध्द आभासी पॅकेजेस्:"
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr " एकमेव आभासी पॅकेजेस्:"
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "मिश्रित आभासी पॅकेजेस्:"
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr " हरवलेले/गहाळ: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "एकूण स्पष्ट आवृत्या: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "एकूण स्पष्ट विवरणे: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "एकूण निर्भरता:"
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "एकूण व्हीईआर/संचिका परस्पर संबंध:"
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "एकूण विव/संचिका परस्पर संबंध:"
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "एकूण मॅपींगस् तरतूद: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "एकूण एकत्रित अक्षरसंच:"
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "एकूण परावलंबित आवृत्ती अवकाश:"
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "एकूण दुर्लक्षित अवकाश:"
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "हिशेबात घेतलेली एकूण अवकाश(जागा):"
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "पॅकेज संचिका %s सिंक्रोनाइज नाहीत"
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "तुम्हाला फक्त एकच नमुना द्यावा लागेल"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "पॅकेजेस सापडले नाहीत"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "पॅकेज %s शोधण्यास असमर्थ आहे"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "पॅकेज संचिका:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "दृतिका सिंक नाही,पॅकेज संचिका क्ष-संदर्भ करता येत नाही"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "एकत्रित पॅकेजेस:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(मिळाले नाही)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "अधिष्ठापित केले:"
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "उमेदवार:"
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(कोणताच नाही)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "पॅकेज (पिन):"
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "आवृत्ती कोष्टक:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s हे %s करिता %s %s वर संग्रहित\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -310,12 +308,12 @@
 "  -c=?  ही संरचना संचिका वाचा \n"
 " -o=?  एखादा अहेतुक संरचना पर्याय निर्धारित करा जसे-  -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "%s मध्ये लिहिण्यास असमर्थ "
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "debconf आवृत्ती मिळू शकत नाही,debconf अधिष्ठापित झाली काय?"
 
@@ -651,79 +649,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "%s ला पुनर्नामांकन %s करण्यास असमर्थ "
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "होय"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "रिजेक्स कंपायलेशन त्रुटी -%s "
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "खालील पॅकेजेस मध्ये नमिळणाऱ्या निर्भरता/ डिपेन्डन्सीज आहेत:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "पण %s संस्थापित झाले"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "पण %s संस्थापित करायचे आहे"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "पण ते संस्थापित करण्याजोगे नाही"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "पण ते आभासी पॅकेज आहे"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "पण ते संस्थापित केले नाही"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "पण ते संस्थापित होणार नाही"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr "किंवा"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "खालील नविन पॅकेजेस संस्थापित होतील:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "खालील नविन पॅकेजेस कायमची काढून टाकली जातील:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "खालील पॅकेजेस परत ठेवली गेली:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "खालील पॅकेजेस पुढिल आवृत्तीकृत होतील:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "खालील पॅकेजेस पुढच्या आवृत्तीकृत होणार नाहीत:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "पुढिल ठेवलेली पॅकेजेस बदलतील:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (च्या मुळे %s)"
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -731,140 +729,140 @@
 "धोक्याची सूचना:खालील जरूरीची पॅकेजेस कायमची काढून टाकली जातील।\n"
 "तुम्हाला तुम्ही काय करत आहात हे कळेपर्यंत असं करता येणार नाही!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu पुढे आवृत्तीकृत केले, %lu नव्याने संस्थापित केले,"
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu पुनर्संस्थापित केले,"
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu मागील आवृत्तीकृत केले,"
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu कायमचे काढून टाकण्यासाठी आणि %lu पुढच्या आवृत्तीकृत झालेली नाही.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu संपूर्ण संस्थापित किंवा कायमची काढून टाकलेली नाही.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "डिपेन्डन्सीज बरोबर/दुरूस्त करत आहे..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr "अयशस्वी/चूकीचे झाले."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "डिपेन्डन्सीज बरोबर करण्यास असमर्थ आहे "
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "आवृत्तीकृत संच कमीतकमी करण्यास असमर्थ"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr "झाले"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "हे बरोबर करण्यासाठी तुम्हाला `apt-get -f संस्थापना' प्रोग्राम चालू करावा लागेल."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "अनमेट डिपेंडन्सीज.-f.वापरून प्रयत्न करा "
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "धोक्याची सूचना:खालील पॅकेजेस् प्रमाणित करु शकत नाही! "
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "प्रमाणीकरणाची धोक्याची सूचना दुर्लक्षित करा.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "पडताळून पाहिल्याशिवाय ही पॅकेजेस संस्थापित करायची का [हो/नाही]?"
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "काही पॅकेजेसचे प्रमाणिकरण होऊ शकत नाही"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "काही अडचणी आहेत आणि --force-yes शिवाय -y वापरला गेला"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "अंतर्गत त्रुटी, तुटलेल्या पॅकेजेस बरोबर  संस्थापित पॅकेजला आवाहन केले गेले/बोलावले गेले!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "पॅकेजेस कायमची काढायची आहेत पण रिमूव्ह अकार्यक्षम केले आहे"
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "अंतर्गत त्रुटी,क्रम अजून संपला नाही"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "उगमांच्या याद्या वाचता येणार नाहीत."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "किती विचित्र...आकार जुळत नाहीत, ईमेल apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "अर्काईव्हजच्या %sB/%sB घेण्याची गरज आहे\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "अर्काईव्हज%sB घेण्याची गरज आहे.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "या क्रियेनंतर, %sB एवढी अधिक डिस्क जागा वापरली जाईल.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "या क्रियेनंतर, %sB डिस्क जागा मोकळी होईल.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "%s मध्ये रिकामी जागा सांगू शकत नाही"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "%s मध्ये तुमच्याकडे पुरेशी जागा नाही."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "क्षुल्लक फक्त निर्देशित केले आहे पण हे क्षुल्लक कृति/ऑपरेशन नाही."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "हो, मी म्ह्टल्याप्रमाणे करा!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -875,28 +873,28 @@
 "पुढे '%s' उक्ती मध्ये लिहिणार \n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "व्यत्यय/बंद करा."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "तुम्हाला पुढे जायचे आहे [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "%s  %s आणणे असफल\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "काही संचिका डाऊनलोड करण्यास असमर्थ"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "डाऊनलोड संपूर्ण आणि डाऊनलोड मध्ये फक्त पद्धती"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -904,20 +902,20 @@
 "काही आर्काइव्हज आणण्यास असमर्थ, कदाचित apt-get रन करुन अद्ययावत करा किंवा --fix- "
 "बरोबर प्रयत्न कराहरवलेले/गहाळ?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr ""
 "--fix- सापडत नाही आणि माध्यम/मिडिया अदलाबदल हे सध्या तांत्रिक मदत देऊ शकत नाही"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "न सापडणारी पॅकेजेस नीट करण्यास असमर्थ."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "संस्थापन खंडित करत आहे."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -927,49 +925,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "लक्षात घ्या,%s ऐवजी %s ची निवड करत आहे \n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "%s सोडून देत आहे, ते आधिच संस्थापित केले आहे आणि पुढिल आवृत्ती निश्चित केलेली नाही.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "%s सोडून देत आहे, ते आधिच संस्थापित केले आहे आणि पुढिल आवृत्ती निश्चित केलेली नाही.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "%s पॅकेज संस्थापित केलेले नाही,म्हणून काढले नाही\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "%s हे आभासी पॅकेज ह्यांच्याकडून तरतूद केले आहे,:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr "[संस्थापित केले]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "कंॅडिडेट आवृत्त्या"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "तुम्ही संस्थापित करण्यासाठी एक निश्चित स्पष्टपणे निवडले पाहिजे."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -980,65 +978,65 @@
 "याचा अर्थ असाही आहे की पॅकेज सापडत नाही,ते कालबाह्य किंवा \n"
 " म्हणजे ते दुसऱ्या उगमातून उपलब्ध\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "तथापि खालील पॅकेजेस मध्ये बदल झाला:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "%s पॅकेजला संस्थापित कॅन्डिडेट नाही"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "%s चे पुनर्संस्थापन शक्य नाही, हे डाऊनलोड करता येत नाही.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s ही आधीच नविन आवृत्ती आहे.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "'%s' साठी '%s' आवृत्ती सापडली नाही"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "'%s' साठी '%s' आवृत्ती सापडली नाही"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "%s साठी %s (%s) निवडलेली आवृत्ती.\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "%s उगम पॅकेज यादी सुरू करता येत नाही"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "सुधारित आवृत्तीचा विधान आर्ग्युमेंटस घेऊ    शकत नाही."
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "आपण या गोष्टी काढून टाकता नये, ऑटोरिमूव्हर सुरू करता येत नाही"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1048,7 +1046,7 @@
 msgstr[0] "खालील नवीन पॅकेजेस स्वयंचलितपणे संस्थापित झाली होती व आता आवश्यक नाहीत:"
 msgstr[1] "खालील नवीन पॅकेजेस स्वयंचलितपणे संस्थापित झाली होती व आता आवश्यक नाहीत:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1056,11 +1054,11 @@
 msgstr[0] "खालील नवीन पॅकेजेस स्वयंचलितपणे संस्थापित झाली होती व आता आवश्यक नाहीत:"
 msgstr[1] "खालील नवीन पॅकेजेस स्वयंचलितपणे संस्थापित झाली होती व आता आवश्यक नाहीत:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "ती काढून टाकण्यासाठी 'apt-get autoremove' वापरा."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1078,45 +1076,40 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "खालील माहिती परिस्थिती निवळण्यासाठी मदत ठरू शकेल:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "अंतर्गत त्रुटी, AutoRemoverने स्टफला तोडले"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "अंतर्गत त्रुटी,ऑलअपग्रेडने स्टफला तोडले"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "%s कार्य सापडू शकले नाही"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "%s पॅकेज सापडू शकले नाही"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "सूचना, '%s' रिजेक्स साठी %s ची निवड करत आहे\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s  स्वहस्ते संस्थापित करायचे आहे.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 "तुम्हाला कदाचित 'apt-get -f install'(एपीटी-गेट -एफ संस्थापन') प्रोग्राम चालू करावा "
 "लागेल'यात बदल करण्यासाठी:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1124,7 +1117,7 @@
 "अनमेट डिपेंडन्सीज.एपीटी-गेट -एफ संस्थापन ('apt-get -f install') पॅकेजशिवाय प्रयत्न करा "
 "(किंवा पर्याय सांगा)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1136,131 +1129,146 @@
 "विभागणी असणारी पण हवी असणारी, तयार केली नसलेली पॅकेजेस वापरत असाल \n"
 "किंवा ती येणाऱ्यांपैकी बाहेर हलविली असतील."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "तुटलेली पॅकेजेस"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "खालील अतिरिक्त पॅकेजेस संस्थापित होतील:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "सुचवलेली पॅकेजेस:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "शिफारस केलेली पॅकेजेस:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s  स्वहस्ते संस्थापित करायचे आहे.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "पुढिल आवृत्तीची गणती करीत आहे..."
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "असमर्थ"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "झाले"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "अंतर्गत त्रुटी, अडचण निवारकाने स्टफला तोडले"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "डाऊनलोड डिरेक्टरी कुलूपबंद करण्यास असमर्थ"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "उगम शोधण्यासाठी किमान एक पॅकेज देणे/सांगणे गरजेचे आहे"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "%s उगम पॅकेज शोधणे शक्य नाही/शोधण्यास असमर्थ आहे"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "आधीच डाऊनलोड केलेली '%s' फाईल सोडून द्या\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "%s मध्ये पुरेशी जागा नाही"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "उगम अर्काईव्हज चा %sB/%sB घेण्याची गरज आहे.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "उगम अर्काईव्हजचा %sB घेण्याची गरज आहे.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "%s उगम घ्या\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "काही अर्काईव्हज आणण्यास असमर्थ."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "%s मध्ये आधीच उघडलेल्या उगमातील उघडलेल्याला सोडून द्या किंवा वगळा\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "'%s' आज्ञा सुट्या करण्यास असमर्थ.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "'dpkg-dev' पॅकेज संस्थापित केले आहे का ते पडताळून पहा.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "बांधणी करणाऱ्या आज्ञा '%s' अयशस्वी.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "चाईल्ड प्रक्रिया अयशस्वी"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "बिल्डेपस् कशासाठी ते पडताळण्यासाठी किमान एक पॅकेज सांगणे गरजेचे आहे"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "%s साठी बांधणी डिपेंडन्सी माहिती मिळवण्यास असमर्थ"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s ला बांधणी डिपेंडन्स नाहीत.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "%s पॅकेज न सापडल्याने %s साठी %s डिपेंडन्सी पूर्ण होऊ शकत नाही"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1269,30 +1277,30 @@
 "आवृतीची मागणी पूर्ण करण्यासाठी %s पॅकेजची आवृत्ती उपलब्ध नाही,त्यामुळे %s साठी %s "
 "डिपेंडन्सी पूर्ण होऊ शकत नाही"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr "%s अवलंबित्व %s साठी पूर्ण होण्यास असमर्थ: संस्थापित पॅकेज %s खूपच नवीन आहे"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "%s साठी %s डिपेंडन्सी पूर्ण होण्यास असमर्थ: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "%s साठी बांधणी-डिपेंडन्सीज पूर्ण होऊ शकत नाही."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "बांधणी-डिपेंडन्सीज क्रिया पूर्ण करण्यास असमर्थ "
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "प्रोग्राम गटाला तांत्रिक मदत दिली:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1628,8 +1636,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "%s वाचण्यास असमर्थ"
@@ -1658,10 +1667,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "info आणि temp संचिका सारख्याच फाईलप्रणालीत असणे आवश्यक आहे"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "पॅकेज याद्या वाचत आहोत"
 
@@ -1876,170 +1884,170 @@
 msgid "Write error"
 msgstr "लिहिण्यात त्रुटी"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "सॉकेट तयार करू शकत नाही"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "डेटा सॉकेट जोडू शकत नाही,जोडणी वेळेअभावी बंद केली"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "पॅसिव्ह सॉकेट जोडता येत नाही"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "गेटऍड्रेसइनफो लिसनिंग सॉकेट घेण्यास असमर्थ होते"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "सॉकेट चिकटवता येत नाही"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "सॉकेट वर ऐकता येत नाही"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "सॉकेटचे नाव सांगता येत नाही"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "पोर्ट आज्ञा पाठवता येत नाही/पोर्ट आज्ञा  पाठविण्यास असमर्थ"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "माहित नसलेला पत्ता फॅमिली %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "ई.पी.आर.टी. चुकले,सर्व्हरने %s सांगितले"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "डेटा सॉकेट जोडणी वेळेअभावी तुटली"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "जोडणी स्विकारण्यास असमर्थ"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "फाईल हॅश करण्यात त्रुटी"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "सर्व्हरने %s सांगितले, फाईल मिळवण्यास असमर्थ"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "डेटा सॉकेट वेळेअभावी तुटले"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "सर्व्हरने %s सांगितले, डेटा स्थानांतरण चुकले"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "प्रश्न"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "जारी करण्यास करण्यास असमर्थ"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "%s (%s) ला जोडत आहे"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[आयपी:%s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "%s (f=%u t=%u p=%u) साठी सॉकेट तयार करू शकत नाही"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "%s:%s (%s). साठी जोडणी इनिशिएट/पुढाकारीत करू शकत नाही"
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "%s:%s (%s) ला जोडू शकत नाही,जोडणी वेळेअभावी तुटली"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "%s:%s (%s) ला जोडू शकत नाही"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "%s ला जोडत आहे"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "%s रिझॉल्व्ह होऊ शकत नाही "
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "'%s' रिझॉल्व्ह करताना तात्पुरती त्रुटी"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "%s:%s' (%i) रिझॉल्व्ह होत असताना काहीतरी वाईट घडले"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "%s %s ला जोडण्यास असमर्थ:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "संस्थापन खंडित करत आहे."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "अंतर्गत त्रुटी: चांगली सही, पण की ठसे सांगू शकत नाही?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "किमान एक अवैध सही सापडली."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "सहीची खात्री करण्यासाठी '%s' कार्यान्वित करू शकत नाही (gpgv संस्थापित केले आहे का?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "gpgv कार्यान्वित होत असताना अपरिचित त्रुटी"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "खालील सह्या अवैध आहेत:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2116,19 +2124,19 @@
 msgid "Error reading from server"
 msgstr "सर्व्हर मधून वाचण्यात चूक"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "फाईल छोटी करणे असफल"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "चुकीचा शीर्षक डाटा"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "जोडणी अयशस्वी"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "अंतर्गत त्रुटी"
 
@@ -2194,7 +2202,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "%s निवडक भाग सापडत नाही"
@@ -2317,6 +2325,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "%s मध्ये बदलण्यास असमर्थ"
@@ -2500,7 +2509,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "%s तात्पुरत्या StateFile मध्ये लिहिणे असफल"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2634,7 +2643,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "अडचणी दूर करण्यास असमर्थ, तुम्ही तुटलेले पॅकेज घेतलेले आहे."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2684,12 +2693,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "कृपया '%s' लेबल असलेली डिस्क '%s' या ड्राइव्हमध्ये ठेवा आणि एन्टर कळ दाबा."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "'%s' पॅकेजींग प्रणाली सहाय्यकारी नाही"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "योग्य असा पॅकेजिंग प्रणाली प्रकार निश्चित करण्यास असमर्थ "
 
@@ -2702,25 +2711,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "तुम्ही तुमच्या उगमस्थान यादीत URI घाला"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "पॅकेजच्या याद्या किंवा संचिकेची स्थिती स्पष्ट होऊ शकत नाही किंवा ती उघडू शकत नाही."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "तुम्ही ह्या समस्यांचे निवारण करण्यासाठी  apt-get update प्रोग्राम चालू करु शकता"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "पसंतीच्या संचिकेत अवैध माहितीसंच, पॅकेजला शीर्षक नाही "
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "%s पिनचा प्रकार समजलेला नाही"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "पिन करिता प्राधान्य/अग्रक्रम (किंवा शून्य)निर्देशीत केलेला नाही"
 
@@ -2814,32 +2823,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "%s उगम पॅकेज यादी सुरू करता येत नाही"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "तरतूद/पुरवलेल्या संचिका संग्रहित करीत आहे"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IO त्रुटी उगम निवडक संचयस्थानात संग्रहित होत आहे"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "पुनर्नामांकन अयशस्वी, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "एमडी५ बेरीज/MD5Sum जुळत नाही"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "हॅश बेरीज जुळत नाही"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "पुढील कळ ओळखचिन्हांसाठी सार्वजनिक कळ उपलब्ध नाही:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2848,7 +2882,7 @@
 "मी %s पॅकेजकरीता संचिका शोधण्यास  समर्थ नव्हतो. याचा अर्थ असाकी तुम्हाला हे पॅकेज स्वहस्ते "
 "स्थिर/निश्चित करण्याची गरज आहे(हरवलेल्या आर्चमुळे) "
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2857,7 +2891,7 @@
 "मी %s पॅकेजकरीता संचिका शोधण्यास  समर्थ नव्हतो. याचा अर्थ असाकी तुम्हालाहे पॅकेज स्वहस्ते "
 "स्थिर/निश्चित करण्याची गरज आहे."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2865,25 +2899,35 @@
 "पॅकेज यादीची/सुचीची संचिका दूषित/खराब झालेली आहे. संचिका नाव नाही: पॅकेजकरीता क्षेत्र/"
 "ठिकाण %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "आकार जुळतनाही"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "%s (1) पॅकेज फाईल पार्स करण्यात असमर्थ"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "लक्षात घ्या,%s ऐवजी %s ची निवड करत आहे \n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "%s डायव्हर्जन फाईलमध्ये अवैध ओळ आहे:"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "%s (1) पॅकेज फाईल पार्स करण्यात असमर्थ"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2978,151 +3022,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "ह्या डिस्क/चकती करिता स्त्रोत सूचीच्या प्रवेशिका आहेत: \n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i माहितीसंच लिहिले.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i गहाळ संचिकाबरोबर %i माहिती संच  लिहिले.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i विजोड संचिकांबरोबर %i माहिती संच लिहिले\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "%i गहाळ संचिकाबरोबर आणि %i विजोड संचिकाबरोबर %i माहिती संच लिहिले\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "%s संरचना फाईल उघडत आहे"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "हॅश बेरीज जुळत नाही"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "सूचना, '%s' रिजेक्स साठी %s ची निवड करत आहे\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "%s साठी %s (%s) निवडलेली आवृत्ती.\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "%s संस्थापित होत आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s संरचित होत आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s काढून टाकत आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s संपूर्ण काढून टाकले"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "संस्थापना-पश्चात ट्रिगर %s चालवत आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "'%s' संचयिका गहाळ आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "%s फाईल उघडता येत नाही"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s तयार करित आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "%s सुटे/मोकळे करीत आहे "
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "%s संरचने साठी तयार करत आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s संस्थापित झाले"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "%s ला काढून टाकण्यासाठी तयारी करत आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s काढून टाकले"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "%s संपूर्ण काढून टाकण्याची तयारी करत आहे"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s संपूर्ण काढून टाकले"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "सत्रनोंद लिहिता येत नाही, openpty() असफल (/dev/pts आरोहित नाही?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "संचयिका यादीला कुलुप लावण्यात असमर्थ"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3137,7 +3264,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "जोडणी अकाली बंद झाली"
 

=== modified file 'po/nb.po'
--- po/nb.po	2010-05-25 16:01:42 +0000
+++ po/nb.po	2010-06-10 14:02:22 +0000
@@ -13,7 +13,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-02-01 18:26+0100\n"
 "Last-Translator: Hans Fredrik Nordhaug <hans@nordhaug.priv.no>\n"
 "Language-Team: Norwegian Bokmal <i18n-nb@lister.ping.ui.no>\n"
@@ -22,148 +22,146 @@
 "Content-Transfer-Encoding: 8bit\n"
 "X-Generator: KBabel 1.9.1\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Pakken %s versjon %s har et uinnfridd avhengighetsforhold:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Klarer ikke  finne pakken %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Plassmengde pakkenavn: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Plassmengde pakkenavn: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Vanlige pakker: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Rent virtuelle pakker: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Enkle virtuelle pakker: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Sammensatte virtuelle pakker: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Mangler: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Antall unike versjoner: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Antall unike beskrivelser: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Antall avhengighetsforhold: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Antall forhold versjon/fil: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Antall forhold beskrivelse/fil: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Antall tilbudte tilknyttinger: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Antall utvidede strenger: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Total plass for avhengighetsforhold/versjoner: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Plass brukt av slark: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Samlet mengde redegjort plass: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Pakkefila %s er ikke oppdatert."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Du m oppgi nyaktig ett mnster"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Fant ingen pakker"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Klarer ikke  finne pakken %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Pakkefiler:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Mellomlageret er ikke oppdatert, kan ikke kryssreferere til en pakkefil"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Lste pakker:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(ikke funnet)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Installert: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidat: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ingen)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Pakke lst til: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Versjonstabell:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s for %s kompilert p %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -320,12 +318,12 @@
 "  -c=? Les denne innstillingsfila.\n"
 "  -o=? Sett en vilkrlig innstilling, f.eks. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Kan ikke skrive til %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Kan ikke fastsl debconf-versjonen. Er debconf installert?"
 
@@ -661,79 +659,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Klarte ikke  endre navnet p %s til %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "J"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Kompileringsfeil i regulrt uttrykk - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Flgende pakker har uinnfridde avhengighetsforhold:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "men %s er installert"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "men %s skal installeres"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "men lar seg ikke installere"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "men er en virtuell pakke"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "men er ikke installert"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "men skal ikke installeres"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " eller"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Flgende NYE pakker vil bli installert:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Flgende pakker vil bli FJERNET:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Flgende pakker er holdt tilbake:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Flgende pakker vil bli oppgradert:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Flgende pakker vil bli NEDGRADERT:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Flgende pakker vil bli endret:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (pga. %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -741,143 +739,143 @@
 "ADVARSEL: Flgende essensielle pakker vil bli fjernet.\n"
 "Dette br IKKE gjres, med mindre du vet nyaktig hva du gjr!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu oppgraderte, %lu nylig installerte, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu installert p nytt, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu nedgraderte, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu  fjerne og %lu ikke oppgradert.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu pakker ikke fullt installert eller fjernet.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Retter p avhengighetsforhold ..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " mislyktes."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Klarer ikke  rette p avhengighetsforholdene"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Klarer ikke  minimere oppgraderingsettet"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Utfrt"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Du vil kanskje kjre apt-get -f install for  rette p dette."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Uinnfridde avhengighetsforhold - Prv -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ADVARSEL: Flgende pakker ble ikke autentisert!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Autentiseringsadvarsel overstyrt.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Installer disse pakkene uten verifikasjon [j/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Noen pakker ble ikke autentisert"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Det oppsto problemer og -y ble brukt uten --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Intern feil, InstallPackages ble kalt med delagte pakker!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Pakker trenges  fjernes, men funksjonen er sltt av."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Intern feil, sortering fullfrte ikke"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Kan ikke lese kildlista."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "S rart ... Strrelsene stemmer ikke overens, send en e-post til "
 "apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "M hente %sB/%sB med arkiver.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "M hente %sB med arkiver.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Etter denne operasjonen vil %sB ekstra diskplass bli brukt.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Etter denne operasjonen vil %sB diskplass bli ledig.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Klarte ikke bestemme ledig plass i %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Dessverre, ikke nok ledig plass i %s"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "Bare trivielle endringer ble angitt, men dette er ikke en triviell endring."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ja, gjr som jeg sier!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -888,28 +886,28 @@
 "For  fortsette skriv inn teksten %s\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Avbryter."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Vil du fortsette [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Klarte ikke  skaffe %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Noen av filene kunne ikke lastes ned"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Nedlasting fullfrt med innstillinga bare nedlasting"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -917,19 +915,19 @@
 "Klarte ikke  hente alle arkivene. Du kan prve med apt-get update eller --"
 "fix-missing."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing og bytte av media stttes n ikke"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Klarer ikke  rette p manglende pakker."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Avbryter istallasjonen."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -939,51 +937,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Merk, velger %s istedenfor %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Omgr %s - den er allerede installert eller ikke satt til oppgradering.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Omgr %s - den er allerede installert eller ikke satt til oppgradering.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Pakken %s er ikke installert, og derfor heller ikke fjernet\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Pakken %s er en virtuell pakke, som oppfylt av:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Installert]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versjons-kandidater"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Du m velge en pakke som skal installeres."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -994,65 +992,65 @@
 "Dette kan bety at pakken mangler, er utgtt, eller bare finnes \n"
 "tilgjengelig fra en annen kilde.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Flgende pakker erstatter den imidlertid:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Pakken %s har ingen installasjonskandidat"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Det er ikke mulig  installere %s p nytt - den kan ikke nedlastes.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s er allerede nyeste versjon.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Utgave %s av %s ble ikke funnet"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Versjon %s av %s ble ikke funnet"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Utvalgt versjon %s (%s) for %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Kunne ikke finne informasjon om %s - lista over kildekodepakker"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Oppdaterings-kommandoen tar ingen argumenter"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Vi skal ikke slette ting, kan ikke starte auto-fjerner (AutoRemover)"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1064,7 +1062,7 @@
 msgstr[1] ""
 "Flgende pakker ble automatisk installert og er ikke lenger pkrevet:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1074,11 +1072,11 @@
 msgstr[1] ""
 "Flgende pakker ble automatisk installert og er ikke lenger pkrevet:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Bruk apt-get autoremove for  fjerne dem."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1096,43 +1094,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Flgende informasjon kan vre til hjelp med  lse problemet:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Intern feil, autofjerneren (AutoRemover) dela noe"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Intern feil - AllUpgrade dela noe"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Klarte ikke  finne oppgave %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Klarte ikke  finne pakken %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Merk, velger %s istedenfor det regulre uttrykket %s\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s satt til manuell installasjon.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Du vil kanskje utfre apt-get -f install for  rette p disse:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1140,7 +1133,7 @@
 "Uinnfridde avhengighetsforhold. Prv apt-get -f install uten pakker (eller "
 "angi en lsning)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1152,131 +1145,146 @@
 "at visse kjernepakker enn ikke er laget eller flyttet ut av Incoming for\n"
 "distribusjonen."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "delagte pakker"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Flgende ekstra pakker vil bli installert."
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Foresltte pakker:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Anbefalte pakker"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s satt til manuell installasjon.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Beregner oppgradering... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Mislyktes"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Utfrt"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Intern feil, problemlser dela noe"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Klarer ikke  lse nedlastingsmappa"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Du m angi minst en pakke du vil ha kildekoden til"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Klarer ikke  finne en kildekodepakke for %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Hopper over allerede nedlastet fil %s\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Du har ikke nok ledig plass i %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Trenger  skaffe %sB av %sB fra kildekodearkivet.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Trenger  skaffe %sB fra kildekodearkivet.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Skaffer kildekode %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Klarte ikke  skaffe alle arkivene."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Omgr utpakking av allerede utpakket kilde i %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Utpakkingskommandoen %s mislyktes.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Sjekk om pakken dpkg-dev er installert.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Byggekommandoen %s mislyktes.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Barneprosessen mislyktes"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "Du m angi minst en pakke du vil sjekke builddeps for"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Klarer ikke  skaffe informasjon om bygge-avhengighetene for %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s har ingen avhengigheter.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "Kravet %s for %s kan ikke oppfylles fordi pakken %s ikke finnes"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1285,32 +1293,32 @@
 "Kravet %s for %s kan ikke oppfylles fordi det ikke finnes noen tilgjengelige "
 "versjoner av pakken %s som oppfyller versjonskravene"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Klarte ikke  tilfredsstille %s avhengighet for %s: den installerte pakken %"
 "s er for ny"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Klarte ikke  tilfredsstille %s avhengighet for %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Klarte ikke  tilfredstille bygg-avhengighetene for %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Klarte ikke  behandle forutsetningene for bygging"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Stttede moduler:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1647,8 +1655,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Klarer ikke  lese %s"
@@ -1678,10 +1687,9 @@
 msgstr ""
 "Infokatalogen og den midlertidige katalogen m vre p det samme filsystemet"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Leser pakkelister"
 
@@ -1901,170 +1909,170 @@
 msgid "Write error"
 msgstr "Skrivefeil"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Klarte ikke  opprette en sokkel"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Klarte ikke  kople til datasokkelen, tidsavbrudd p forbindelsen"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Klarte ikke  koble til en passiv sokkel."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo klarte ikke  opprette en lyttesokkel"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Klarte ikke  binde til sokkel"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Klarte ikke  lytte til sokkel"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Klarte ikke  avgjre sokkelnavnet"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Klarte ikke  sende PORT-kommandoen"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Ukjent adressefamilie %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT mislykkes, tjeneren sa: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Tidsavbrudd p tilkoblingen til datasokkelen"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Klarte ikke  godta tilkoblingen"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problem ved oppretting av nkkel for fil"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Klarte ikke  hente fila, tjeneren sa %s"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Tidsavbrudd p datasokkelen"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Dataoverfringen mislykkes, tjeneren sa %s"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Sprring"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Klarte ikke  starte"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Kobler til %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Klarte ikke  opprette en sokkel for %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Klarte ikke  starte forbindelsen til %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Klarte ikke  koble til %s:%s (%s), tidsavbrudd p forbindelsen"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Klarte ikke  koble til %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Kobler til %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Klarte ikke  sl opp %s"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Midlertidig feil ved oppslag av %s"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Noe galt skjedde ved oppslag av %s:%s (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Klarte ikke  koble til %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Avbryter istallasjonen."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "Intern feil: God signatur, men kunne bestemme nkkelfingeravtrykk?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Minst en ugyldig signatur ble funnet."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Klarte ikke kjre %s for  verifisere signaturen (er gpgv installert?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Ukjent feil ved kjring av gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "De flgende signaturene var ugyldige:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2143,19 +2151,19 @@
 msgid "Error reading from server"
 msgstr "Feil ved lesing fra tjeneren"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Klarte ikke forkorte fila %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "delagte hodedata"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Forbindelsen mislykkes"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Intern feil"
 
@@ -2223,7 +2231,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Fant ikke utvalget %s"
@@ -2346,6 +2354,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Klarer ikke  endre %s"
@@ -2529,7 +2538,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Klarte ikke  skrive midlertidig StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2663,7 +2672,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Klarer ikke  rette problemene, noen delagte pakker er holdt tilbake."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2713,12 +2722,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Sett inn disken merket %s i lagringsenheten %s og trykk Enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Pakkesystemet %s stttes ikke"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Klarer ikke bestemme en passende pakkesystemtype"
 
@@ -2732,26 +2741,26 @@
 msgstr ""
 "Beklager, du m legge inn noen kilder (nettadresser) i din sources.list."
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Pakkelista eller tilstandsfila kunne ikke fortolkes eller pnes."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Det kan hende du vil kjre apt-get update for  rette p disse problemene"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Ugyldig oppslag i foretrekksfila, manglende pakkehode"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Forsto ikke spikring av typen %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Ingen prioritet (eller null) spesifisert for pin"
 
@@ -2840,33 +2849,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Kunne ikke finne informasjon om %s - lista over kildekodepakker"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Samler inn filtilbud"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IO-feil ved lagring av kildekode-lager"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "klarte ikke  endre navnet, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Feil MD5sum"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hashsummen stemmer ikke"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Det er ingen offentlig nkkel tilgjengelig for de flgende nkkel-ID-ene:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2875,7 +2909,7 @@
 "Klarte ikke  finne en fil for pakken %s. Det kan bety at du m ordne pakken "
 "selv (fordi arkitekturen mangler)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2884,31 +2918,41 @@
 "Klarte ikke  finne en fil for pakken %s. Det kan bety at du m ordne denne "
 "pakken selv."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "Oversiktsfilene er delagte. Feltet Filename: mangler for pakken %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Feil strrelse"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Klarer ikke  fortolke pakkefila %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Merk, velger %s istedenfor %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Ugyldig linje i avledningsfila: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Klarer ikke  fortolke pakkefila %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3003,151 +3047,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Kildelisteoppfringer for denne CD-en er:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Skrev %i poster.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Skrev %i poster med %i manglende filer.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Skrev %i poster med %i feile filer.\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Skrev %i poster med %i manglende filer og %i feile filer.\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "pner oppsettsfila %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hashsummen stemmer ikke"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Merk, velger %s istedenfor det regulre uttrykket %s\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Utvalgt versjon %s (%s) for %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Installerer %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Setter opp %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Fjerner %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Fjernet %s fullstendig"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Kjrer etter-installasjonsutlser %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Mappa %s mangler"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Kunne ikke pne fila %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Forbereder %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Pakker ut %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Forbereder oppsett av %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Installerte %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Forbereder fjerning av %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Fjernet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Forbereder  fullstendig slette %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Fjernet %s fullstendig"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "Klarte ikke skrive logg, openpty() feilet (/dev/pts ikke montert?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Kan ikke lse listemappa"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3162,7 +3289,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Forbindelsen ble uventet stengt"
 

=== modified file 'po/ne.po'
--- po/ne.po	2010-05-25 16:01:42 +0000
+++ po/ne.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: apt_po\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2006-06-12 14:35+0545\n"
 "Last-Translator: Shiva Pokharel <pokharelshiva@hotmail.com>\n"
 "Language-Team: Nepali <info@mpp.org.np>\n"
@@ -16,149 +16,147 @@
 "Plural-Forms: nplurals=2;plural=(n!=1)\n"
 "X-Generator: KBabel 1.10.2\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "प्याकेज %s संस्करण %s संग एउटा नभेटिएको dep छ:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "प्याकेज %s तोक्न असक्षम भयो"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "कूल प्याकेज नामहरू :"
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "कूल प्याकेज नामहरू :"
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  सामान्य प्याकेजहरू:"
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "शुद्ध अवास्तविक प्याकेजहरू:"
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  एकल अवास्तविक प्याकेजहरू:"
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  मिश्रित अवास्तविक प्याकेजहरू:"
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  हराइरहेको:"
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "कूल भिन्न संस्करणहरू:"
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "कूल भिन्न संस्करणहरू:"
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "कूल निर्भरताहरू:"
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "जम्मा ver/file सम्बन्धहरू: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "जम्मा ver/file सम्बन्धहरू: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "कूल उपलब्ध मानचित्रणहरू:"
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "कूल विश्वव्यापी स्ट्रिङ्गहरू:"
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "कूल निर्भरता संस्करण खाली ठाऊँ:"
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "कूल शिथिल खाली ठाऊँ:"
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "को लागि कूल खाली ठाऊँ लेखांकन:"
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "प्याकेज फाइल %s sync भन्दा बाहिर छ ।"
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "तपाईँले एउटा वास्तविक बान्की दिनुपर्छ"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "कुनै प्याकेजहरू फेला परेन"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "प्याकेज %s तोक्न असक्षम भयो"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "प्याकेज फाइलहरू:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "क्यास sync  भन्दा बाहिर छ, प्याकेज फाइल x-ref गर्न सक्दैन"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "पिन गरिएका प्याकेजहरू:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(फेला परेन)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  स्थापना भयो:"
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  उमेद्वार:"
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(कुनै पनि होइन)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "प्याकेज पिन:"
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  संस्करण तालिका:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s को लागि %s %s, %s %s मा कम्पाएल गरिएको छ\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -314,12 +312,12 @@
 "  -c=? यो कनफिगरेसन फाइल पढ्नुहोस्\n"
 "  -o=? एउटा स्वेच्छाचारी कनफिगरेसन विकल्प सेट गर्नुहोस्, जस्तै -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr " %s मा लेख्न असक्षम"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr " debconf संस्करण प्राप्त गर्न सकिएन । के debconf स्थापना भयो ? "
 
@@ -654,79 +652,79 @@
 msgid "Failed to rename %s to %s"
 msgstr " %s मा  %s  पुन:नामकरण असफल भयो"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "संकलन त्रुटि रिजेक्स गर्नुहोस् - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "निम्न प्याकेजहरुले निर्भरताहरू भेटेनन्:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "तर %s स्थापना भयो"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "तर %s स्थापना हुनुपर्यो"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "तर यो स्थापनायोग्य छैन"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "तर यो अवास्तविक प्याकेज होइन"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "तर यो स्थापना भएन"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "तर यो स्थापना हुन गइरहेको छैन"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr "वा"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "निम्न नयाँ प्याकेजहरू स्थापना हुनेछन्:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "निम्न प्याकेजहरू हटाइनेछन्:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "निम्न प्याकेजहरू पछाडि राखिनेछन्:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "निम्न प्याकेजहरू स्तर वृद्धि हुनेछन्:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "निम्न प्याकेजहरू स्तरकम गरिनेछन्:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "निम्न भइरहेको प्याकेजहरू परिवर्तन हुनेछैन:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (%s कारणले) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -734,140 +732,140 @@
 "चेतावनी: निम्न आवश्यक प्याकेजहरू हटाइनेछन् ।\n"
 "तपाईँ के गरिरहेको यकिन नभएसम्म यो काम गरिने छैन!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu स्तर वृद्धि गरियो, %lu नयाँ स्थापना भयो, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu पुन: स्थापना गरियो, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu स्तर कम गरियो, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu हटाउन र %lu स्तर वृद्धि गरिएन ।\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu पूर्णरुपले स्थापना भएन र हटाइएन ।\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "निर्भरताहरू सुधार गरिदैछ..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr "असफल भयो ।"
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "निर्भरताहरू सुधार गर्न असक्षम भयो"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "स्तर वृद्धि सेटलाई न्यूनतम गर्न असक्षम भयो"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr "काम भयो"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "यी सुधार गर्न तपाईँले 'apt-get -f install' चलाउन पर्छ ।"
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "नभेटिएका निर्भरताहरू । -f प्रयोग गरेर प्रयास गर्नुहोस् ।"
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "चेतावनी: निम्न प्याकलेजहरू प्रणाणीकरण हुन सक्दैन! "
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "प्रमाणिकरण चेतावनी अधिलेखन भयो ।\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "यी प्याकेजहरू रूजू बिना स्थापना गर्नुहुन्छ [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "केही प्याकेजहरू प्रमाणीकरण हुन सक्दैन"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "त्यहाँ समस्याहरू छन् र हुन्छलाई जोड नगरिकन -y को प्रयोग भयो"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "आन्तरिक त्रुटि, स्थापना प्याकेजहरुलाई भाँचिएको प्याकेज भनिन्थ्यो!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "प्याकेजहरू हट्न चाहदैछन् तर हटाई अक्षम भइरहेछ ।"
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "आन्तरिक त्रुटि, आदेश समाप्त भएको छैन"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "स्रोतहरुको सूचि पढ्न सकिएन ।"
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "कस्तो नमिलेको.. साइजहरू मेल खाएन, apt@packages.debian.org इमेल गर्नुहोस्"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "संग्रहहरुको %sB/%sB प्राप्त गर्न आवश्यक ।\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "संग्रहहरुको %sB प्राप्त गर्न आवश्यक ।\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "अनप्याक गरिसके पछि थप डिस्क खाली ठाउँको %sB प्रयोग हुनेछ ।\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "%sB अनप्याक गरिसके पछि डिस्क खाली ठाउँ खाली हुनेछ ।\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr " %s मा खाली ठाऊँ निर्धारण गर्न सकिएन"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "तपाईँ संग %s मा पर्याप्त खाली ठाऊँ छैन ।"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "त्रिभियल मात्र निर्दिष्ट गरिएको छ तर यो त्रिभियल सञ्चालन होइन ।"
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "हो,मैले भने जस्तै गर्नुहोस्!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -878,28 +876,28 @@
 "निरन्तरता दिन '%s' वाक्यांशमा टाइप गर्नुहोस् \n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "परित्याग गर्नुहोस् ।"
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "के तपाईँ निरन्तरता दिन चाहनुहुन्छ [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "%s  %s तान्न असफल भयो\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "केही फाइलहरू डाउनलोड गर्न असफल भयो"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "डाउनलोड समाप्त भयो र डाउनलोडमा मोड मात्रै छ"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -907,19 +905,19 @@
 "केही संग्रहहरू तान्न असक्षम भयो,apt-get अद्यावधिक चलिरहेछ वा हराइरहेको --fix-संगै प्रयास "
 "गर्नुहुन्छ ?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "हराइरहेको --fix-र स्वाप भइरहेको मेडिया हाल समर्थित भइरहेको छैन"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "हराइरहेको प्याकेजहरू सुधार्न असक्षम भयो ।"
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "स्थापना परित्याग गरिदैछ ।"
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -929,49 +927,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "द्रष्टब्य, %s को सट्टा  %s चयन भइरहेछ\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "%s फड्किदैछ, यो पहिल्यै स्थापना भयो र स्तरवृद्धि सेट भएको छैन ।\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "%s फड्किदैछ, यो पहिल्यै स्थापना भयो र स्तरवृद्धि सेट भएको छैन ।\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "प्याकेज %s स्थापना भएन, त्यसैले हटेन\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "प्याकेज %s ...द्वारा उपलब्ध गराइएको अवास्तविक प्याकेज हो:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [स्थापना भयो]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "उमेद्वार संस्करणहरू"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "तपाईँले स्थापना गर्न स्पष्ट रुपमा एउटा चयन गर्नुहोस् ।"
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -982,65 +980,65 @@
 "यसको मतलब प्याकेज हराइरहेको प्याकेज, बेकायम भयो\n"
 " अर्को स्रोतबाट मात्र उपलब्ध हुन्छ\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "जे भए पनि निम्न प्याकेजहरूले यसलाई बदल्छ:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "प्याकेज %s संग कुनै स्थापना उमेद्वार छैन"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr " %s को पुन: स्थापना सम्भव छैन, यो डाउनलोड हुन सक्दैन ।\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s पहिल्यै नयाँ संस्करण हो ।\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr " '%s' को लागि '%s' निष्काशन फेला पार्न सकिएन"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr " '%s' को लागि '%s' संस्करण फेला पार्न सकिएन"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "%s को लागि चयन भएको संस्करण %s (%s)\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "स्रोत प्याकेज सूची %s स्थिर गर्न सकिएन "
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "अद्यावधिक आदेशले कुनै तर्कहरू लिदैन"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1050,7 +1048,7 @@
 msgstr[0] "निम्न नयाँ प्याकेजहरू स्थापना हुनेछन्:"
 msgstr[1] "निम्न नयाँ प्याकेजहरू स्थापना हुनेछन्:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1058,11 +1056,11 @@
 msgstr[0] "निम्न नयाँ प्याकेजहरू स्थापना हुनेछन्:"
 msgstr[1] "निम्न नयाँ प्याकेजहरू स्थापना हुनेछन्:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1078,44 +1076,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "निम्न सूचनाले अवस्थालाई हल गर्न मद्दत गर्नेछ: "
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "आन्तरिक त्रुटि,समस्या हलकर्ताले उत्तम गुण भाँच्यो "
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "आन्तरिक त्रुटि,सबै स्तरवृद्धिले उत्तम गुण नष्ट गर्दछ"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "प्याकेज फेला पार्न सकिएन  %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "प्याकेज फेला पार्न सकिएन  %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "द्रष्टब्य, रिजेक्स '%s' को लागि %s चयन गरिदैछ\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "तर %s स्थापना हुनुपर्यो"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "तपाईँ यसलाई सुधार गर्न 'apt-get -f install' चलाउन चाहनुहुन्छ:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1123,7 +1116,7 @@
 "नभेटिएका निर्भरताहरू । प्याकेजहरू बिना 'apt-get -f install' प्रयास गर्नुहोस् ( वा "
 "समाधान निर्दिष्ट गर्नुहोस्) ।"
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1136,131 +1129,146 @@
 " वितरण अहिले सम्म सिर्जना\n"
 " भएको छैन वा आवगमन विनानै सर्यो ।"
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "भाँचिएका प्याकेजहरू"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "निम्न अतिरिक्त प्याकेजहरू स्थापना हुनेछन्:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "सुझाव दिएका प्याकेजहरू:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "सिफारिस गरिएका प्याकेजहरू:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "तर %s स्थापना हुनुपर्यो"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "स्तर वृद्धि गणना गरिदैछ..."
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "असफल भयो"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "काम भयो"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "आन्तरिक त्रुटि,समस्या हलकर्ताले उत्तम गुण भाँच्यो "
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "डाउनलोड डाइरेक्ट्री ताल्चा मार्न असक्षम"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "को लागि स्रोत तान्न कम्तिमा एउटा प्याकेज निर्दिष्ट गर्नुपर्छ"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "%s को लागि स्रोत प्याकेज फेला पार्न असफल भयो"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "पहिल्यै डाउनलोड भएका फाइलहरु फड्काइदैछ '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "तपाईँ संग %s मा पर्याप्त खाली ठाऊँ छैन"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "स्रोत संग्रहहरुको %sB/%sB प्राप्त गर्न आवश्यक छ ।\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "स्रोत संग्रहहरुको %sB प्राप्त गर्न आवश्यक छ ।\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "स्रोत फड्काउनुहोस् %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "केही संग्रह फड्काउन असफल भयो ।"
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr " %s मा पहिल्यै अनप्याक गरिएका स्रोतको अनप्याक फड्काइदैछ\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "अनप्याक आदेश '%s' असफल भयो ।\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "जाँच्नुहोस् यदि 'dpkg-dev' प्याकेज स्थापना भयो ।\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "निर्माण आदेश '%s' असफल भयो ।\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "शाखा प्रक्रिया असफल भयो"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "को लागि builddeps जाँच्न कम्तिमा एउटा प्याकेज निर्दष्ट गर्नुपर्छ"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "%s को लागि निर्माण-निर्भरता सूचना प्राप्त गर्न असक्षम भयो"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s कुनै निर्माणमा आधारित हुदैन ।\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "%s को लागि %s निर्भरता सन्तुष्ट हुन सकेन किनभने प्याकेज %s फेला पार्न सकिएन"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1269,30 +1277,30 @@
 "%sको लागि %s निर्भरता सन्तुष्ट हुन सकेन किन भने प्याकेज %s को कुनै उपलब्ध संस्करणले संस्करण "
 "आवश्यकताहरुलाई सन्तुष्ट पार्न सकेन "
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr "%s को लागि %s निर्भरता सन्तुष्ट पार्न असफल भयो: स्थापित प्याकेज %s अति नयाँ छ"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "%s को लागि %s निर्भरता सन्तुष्ट गर्न असफल: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "%s को लागि निर्माण निर्भरताहरू सन्तुष्ट गर्न सकिएन । "
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "निर्माण निर्भरताहरू प्रक्रिया गर्न असफल"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "समर्थित मोड्युलहरू:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1626,8 +1634,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "%s पढ्न असफल भयो"
@@ -1656,10 +1665,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "सूचना र टेम्प डाइरेक्ट्रीहरू एउटै फाइल प्रणालीमा हुनपर्छ"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "प्याकेज सूचिहरू पढिदैछ"
 
@@ -1874,169 +1882,169 @@
 msgid "Write error"
 msgstr "त्रुटि लेख्नुहोस्"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "एउटा सकेट सिर्जना गर्न सकेन"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "डेटा सकेट जडान गर्न सकिएन, जडान समय सकियो"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "निस्क्रिय सकेट जडान गर्न सकिएन"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo सुन्ने सकेट प्राप्त गर्न असक्षम भयो"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "सकेट बाँध्न सकिएन"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "सकेटमा सुन्न सकिएन"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "सकेट नाम निर्धारण गर्न सकिएन"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "पोर्ट आदेश पठाउन असक्षम भयो"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "अज्ञात ठेगाना परिवार %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT असफल भयो, सर्भरले भन्यो: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "डेटा सकेटको जडान समय सकियो"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "जडान स्वीकार गर्न असक्षम भयो"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "समस्या द्रुतान्वेषण फाइल"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "फाइल तान्न असक्षम भयो, सर्भरले भन्यो '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "डेटा सकेट समय सकियो"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "डेटा स्थान्तरण असफल भयो, सर्भरले भन्यो '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "क्वेरी"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "आह्वान गर्न असक्षम भयो"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "%s (%s) मा जडान गरिदैछ"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "%s (f=%u t=%u p=%u) को लागि सकेट सिर्जना गर्न सकिएन"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr " %s:%s (%s) मा जडान सुरुवात गर्न सकेन"
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "%s:%s (%s) मा जडान गर्न सकिएन, जडान समय सकियो"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr " %s:%s (%s) मा जडान गर्न सकिएन ।"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "%s मा जडान गरिदैछ"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "'%s' हल गर्न सकिएन"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "'%s' हल गर्दा अस्थायी असफल"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr " '%s:%s' (%i) हल गर्दा केही दुष्ट घट्यो"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "%s %s मा जडान गर्न असफल भयो:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "स्थापना परित्याग गरिदैछ ।"
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "आन्तरिक त्रुटि: असल हस्ताक्षर, तर कुञ्जी औठाछाप निर्धारण गर्न सकिएन?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "कम्तिमा एउटा अवैध हस्ताक्षर विरोध भयो ।"
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "हस्ताक्षर रूजू गर्न '%s' कार्यन्वयन गर्न सकिएन (के gpgv स्थापना भयो?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "gpgv कार्यन्वयन गर्दा अज्ञात त्रुटि"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "निम्न हस्ताक्षरहरू अवैध छन्:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2113,20 +2121,20 @@
 msgid "Error reading from server"
 msgstr "सर्भरबाट त्रुटि पढिदैछ"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "फाइल %s लेख्न असफल भयो"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "खराब हेडर डेटा"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "जडान असफल भयो"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "आन्तरिक त्रुटि"
 
@@ -2192,7 +2200,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "चयन %s फेला पार्न सकिएन"
@@ -2315,6 +2323,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "%s मा परिवर्तन गर्न असक्षम"
@@ -2499,7 +2508,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "फाइल %s लेख्न असफल भयो"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2632,7 +2641,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "समस्याहरू सुधार्न असक्षम भयो, तपाईँले प्याकेजहरु भाँच्नुभयो ।"
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2682,12 +2691,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "कृपया डिस्क लेबुल: '%s' ड्राइभ '%s'मा घुसउनुहोस् र इन्टर थिच्नुहोस् । "
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "प्याकिङ्ग प्रणाली '%s' समर्थित छैन"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "उपयुक्त प्याकिङ्ग प्रणाली प्रकार निर्धारन गर्न असक्षम भयो"
 
@@ -2700,25 +2709,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "तपाईँको स्रोत सूचिमा केही 'source' URIs राख्नुहोस्"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "प्याकेज सूचीहरू वा वस्तुस्थिति फाइल पद वर्णन गर्न वा खोल्न सकिएन ।"
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "यो समस्याहरू सुधार्न तपाईँ apt-get अद्यावधिक चलाउन चाहनुहुन्छ"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "प्राथमिकता फाइलमा अवैध रेकर्ड, कुनै प्याकेज हेडर छैन"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "पिन टाइप %s बुझ्न सकिएन "
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "पिनको लागि कुनै प्राथमिकता (वा शून्य) निर्दिष्ट छैन"
 
@@ -2808,33 +2817,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "स्रोत प्याकेज सूची %s स्थिर गर्न सकिएन "
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "फाइल उपलब्धताहरू संकलन गरिदैछ"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "स्रोत क्यास बचत गर्दा IO त्रुटि"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "पुन:नामकरण असफल गरियो, %s (%s -> %s) ।"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum मेल भएन"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "MD5Sum मेल भएन"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "निम्न कुञ्जी IDs को लागि कुनै सार्वजनिक कुञ्जी उपलब्ध छैन:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2843,7 +2877,7 @@
 "%s प्याकेजको लागि मैले फाइल स्थित गर्न सकिन । यसको मतलब तपाईँले म्यानुल्ली यो प्याकेज "
 "निश्चित गर्नुहोस् । (arch हराएरहेको कारणले) "
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2852,31 +2886,41 @@
 "%s प्याकेजको लागि मैले फाइल स्थित गर्न सकिन । यसको मतलब तपाईँले म्यानुल्ली यो प्याकेज "
 "निश्चित गर्नुहोस् ।"
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "प्याकेज अनुक्रमणिका फाइलहरू दूषित भए । प्याकेज %s को लागि कुनै फाइलनाम: फाँट छैन ।"
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "साइज मेल खाएन"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "प्याकेज फाइल पद वर्णन गर्न असक्षम %s (१)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "द्रष्टब्य, %s को सट्टा  %s चयन भइरहेछ\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "घुमाउरो फाइलमा अवैध लाइन:%s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "प्याकेज फाइल पद वर्णन गर्न असक्षम %s (१)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2970,151 +3014,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "यो डिस्कको लागि स्रोत सूचि प्रविष्टिहरू:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i रेकर्डहरू लेखियो ।\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "हराइरहेको फाइल %i हरू संगै %i रेकर्डहरू लेख्नुहोस् ।\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "मेल नखाएका फाइल %i हरू संगै %i रेकर्डहरू लेख्नुहोस् ।\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "हराइरहेको फाइल %i हरू र मेल नखाएका फाइल %i हरू संगै %i रेकर्डहरू लेख्नुहोस् ।\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "कनफिगरेसन फाइल खोलिदैछ %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "MD5Sum मेल भएन"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "द्रष्टब्य, रिजेक्स '%s' को लागि %s चयन गरिदैछ\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "%s को लागि चयन भएको संस्करण %s (%s)\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr " %s स्थापना भयो"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr " %s कनफिगर गरिदैछ"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr " %s हटाइदैछ"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr " %s पूर्ण रुपले हट्यो"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "आंशिक सूचिहरुको डाइरेक्ट्री %s हराइरहेछ ।"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "फाइल %s खोल्न सकिएन"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr " %s तयार गरिदैछ"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr " %s अनप्याक गरिदैछ"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr " %s कनफिगर गर्न तयार गरिदैछ"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr " %s स्थापना भयो"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr " %s हटाउन तयार गरिदैछ"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr " %s हट्यो"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr " %s पूर्ण रुपले हटाउन तयार गरिदैछ"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr " %s पूर्ण रुपले हट्यो"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "सूचि डाइरेक्ट्री ताल्चा मार्न असफल"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3129,7 +3256,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "जडान असमायिक बन्द भयो"
 

=== modified file 'po/nl.po'
--- po/nl.po	2010-05-25 16:01:42 +0000
+++ po/nl.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: nl\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2010-03-16 06:52+0100\n"
 "Last-Translator: Frans Pop <elendil@planet.nl>\n"
 "Language-Team: Dutch <debian-l10n-dutch@lists.debian.org>\n"
@@ -19,147 +19,145 @@
 "X-Poedit-Language: Dutch\n"
 "X-Generator: KBabel 1.11.4\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Pakket %s versie %s heeft een niet-voldane vereiste:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Kan pakket %s niet vinden"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Totaal aantal pakketnamen: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Totaal aantal pakketnamen: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normale pakketten: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr " Zuiver virtuele pakketten: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Losstaande virtuele pakketten: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Gemengde virtuele pakketten: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Ontbrekend: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Totaal aantal verschillende versies: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Totaal aantal verschillende beschrijvingen: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Totaal aantal vereisten: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Totaal aantal versie/bestand-relaties: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Totaal aantal Beschrijving/bestand-relaties: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Totaal aantal 'Voorziet'-toewijzingen "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Totaal aantal geglobde strings: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Totale hoeveelheid vereisten-versieruimte: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Totale onbenutte ruimte: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Totale hoeveelheid verantwoorde ruimte: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Pakketbestand %s is niet meer gesynchroniseerd."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "U dient precies één patroon op te geven"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Geen pakketten gevonden"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Kan pakket %s niet vinden"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Pakketbestanden:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Cache loopt niet synchroon, kan pakketbestand niet 'x-ref'-en"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Vastgepinde pakketten:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(niet gevonden)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Geïnstalleerd: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidaat: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(geen)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Pakketpin: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Versietabel:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s voor %s gecompileerd op %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -317,12 +315,12 @@
 "  -c=? Lees dit configuratiebestand.\n"
 "  -o=? Stel een willekeurige optie in, b.v. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Kan niet naar %s schrijven"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Kan versie van debconf niet bepalen. Is debconf geïnstalleerd?"
 
@@ -660,79 +658,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Hernoemen van %s naar %s is mislukt"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "J"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Regex-compilatiefout - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "De volgende pakketten hebben niet-voldane vereisten:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "maar %s is geïnstalleerd"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "maar %s zal geïnstalleerd worden"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "maar het is niet installeerbaar"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "maar het is een virtueel pakket"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "maar het is niet geïnstalleerd"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "maar het zal niet geïnstalleerd worden"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " of"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "De volgende NIEUWE pakketten zullen geïnstalleerd worden:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "De volgende pakketten zullen VERWIJDERD worden:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "De volgende pakketten zijn achtergehouden:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "De volgende pakketten zullen opgewaardeerd worden:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "De volgende pakketten zullen GEDEGRADEERD worden:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "De volgende vastgehouden pakketten zullen gewijzigd worden:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (vanwege %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -740,143 +738,143 @@
 "WAARSCHUWING: De volgende essentiële pakketten zullen verwijderd worden.\n"
 "Dit dient NIET gedaan te worden tenzij u precies weet wat u doet!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu pakketten opgewaardeerd, %lu pakketten nieuw geïnstalleerd, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu opnieuw geïnstalleerd, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu gedegradeerd, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu te verwijderen en %lu niet opgewaardeerd.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu pakketten niet volledig geïnstalleerd of verwijderd.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Vereisten worden gecorrigeerd..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " mislukt."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Kan vereisten niet corrigeren"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Kon de verzameling op te waarderen pakketten niet minimaliseren"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Klaar"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "U kunt 'apt-get -f install' uitvoeren om dit op te lossen."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Er zijn vereisten waaraan niet voldaan is. Probeer -f te gebruiken."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr ""
 "WAARSCHUWING: De volgende pakketten kunnen niet geauthentificeerd worden:"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Authentificatiewaarschuwing is genegeerd.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Wilt u deze pakketten installeren zonder verificatie [j/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Sommige pakketten konden niet geauthentificeerd worden"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Er zijn problemen en -y was gebruikt zonder --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Interne fout, InstallPackages is aangeroepen met defecte pakketten!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Pakketten moeten verwijderd worden maar verwijderen is uitgeschakeld."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Interne fout, rangschikken is niet voltooid"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "De lijst van bronnen kon niet gelezen worden."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Merkwaardig... De groottes kwamen niet overeen, gelieve apt@packages.debian."
 "org te mailen"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Er moeten %sB/%sB aan archieven opgehaald worden.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Er moeten %sB aan archieven opgehaald worden.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Door deze operatie zal er %sB extra schijfruimte gebruikt worden.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Door deze operatie zal er %sB schijfruimte vrijkomen.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Kon de hoeveelheid vrije schijfruimte op %s niet bepalen"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "U heeft onvoldoende vrije schijfruimte op %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "'Trivial Only' is opgegeven, dit is echter geen triviale bewerking."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ja, doe wat ik zeg!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -887,28 +885,28 @@
 "Als u wilt doorgaan, dient u de zin '%s' in te typen.\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Afbreken."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Wilt u doorgaan [J/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Ophalen van %s is mislukt  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Ophalen van sommige bestanden is mislukt"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Ophalen klaar en alleen-ophalen-modus staat aan"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -916,19 +914,19 @@
 "Kon sommige archieven niet ophalen, misschien kunt u 'apt-get update' of --"
 "fix-missing proberen?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing en medium wisselen wordt op dit moment niet ondersteund"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Geen oplossing voor de missende pakketten gevonden."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Installatie wordt afgebroken."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -938,53 +936,53 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Let op, %s wordt geselecteerd in plaats van %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "%s wordt overgeslagen, het is al geïnstalleerd en opwaardering is niet "
 "gevraagd.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "%s wordt overgeslagen, het is al geïnstalleerd en opwaardering is niet "
 "gevraagd.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Pakket %s is niet geïnstalleerd, en wordt dus niet verwijderd\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Pakket %s is een virtueel pakket voorzien door:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Geïnstalleerd]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Kandidaat-versies"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "U dient er één expliciet te selecteren voor installatie."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -995,66 +993,66 @@
 "een ander pakket. Mogelijk betekent dit dat het pakket ontbreekt,\n"
 "verouderd is, of enkel beschikbaar is van een andere bron\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Echter, de volgende pakketten vervangen dit:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Pakket %s heeft geen installeerbare kandidaat"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 "Herinstallatie van %s is niet mogelijk daar het niet opgehaald kan worden.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s is reeds de nieuwste versie.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Release '%s' voor '%s' is niet gevonden"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Versie '%s' voor '%s' is niet gevonden"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Versie %s (%s) geselecteerd voor %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr "Negeer niet beschikbare doelrelease '%s' van pakket '%s'"
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "'%s' wordt genomen als bronpakket in plaats van '%s'\n"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr "Negeer niet beschikbare versie '%s' van pakket '%s'"
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "De opdracht 'update' aanvaard geen argumenten"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "We mogen geen dingen verwijderen, kan AutoRemover niet starten"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1068,7 +1066,7 @@
 "De volgende pakketten zijn automatisch geïnstalleerd en zijn niet langer "
 "nodig:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1078,11 +1076,11 @@
 msgstr[1] ""
 "%lu pakketten zijn automatisch geïnstalleerd en zijn niet langer nodig.\n"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "U kunt deze verwijderen via 'apt-get autoremove'."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1100,45 +1098,40 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "De volgende informatie helpt u mogelijk verder:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Interne fout, AutoRemover heeft dingen stukgemaakt"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Interne fout, AllUpgrade heeft dingen stukgemaakt"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Kon taak %s niet vinden"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Kon pakket %s niet vinden"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Let op, %s wordt geselecteerd omwille van de regex '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s is ingesteld voor handmatige installatie.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 "U wilt waarschijnlijk 'apt-get -f install' uitvoeren om volgende op te "
 "lossen:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1146,7 +1139,7 @@
 "Er zijn niet-voldane vereisten. U kunt best 'apt-get -f install' uitvoeren "
 "zonder pakketten op te geven, (of u kunt zelf een oplossing specificeren)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1157,128 +1150,143 @@
 "een onmogelijke situatie gevraagd hebt of dat u de 'unstable'-distributie \n"
 "gebruikt en sommige benodigde pakketten nog vastzitten in 'incoming'."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Niet-werkende pakketten:"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "De volgende extra pakketten zullen geïnstalleerd worden:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Voorgestelde pakketten:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Aanbevolen pakketten:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s is ingesteld voor handmatige installatie.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Opwaardering wordt doorgerekend... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Mislukt"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Klaar"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Interne fout, probleemoplosser heeft dingen stukgemaakt"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Kon de ophaalmap niet vergrendelen"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "U dient minstens 1 pakket op te geven waarvan de broncode opgehaald moet "
 "worden"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Kan geen bronpakket vinden voor %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Reeds opgehaald bestand '%s' wordt overgeslagen\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "U heeft niet voldoende vrije schijfruimte op %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Moet %sB/%sB aan bronarchieven ophalen.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Moet %sB aan bronarchieven ophalen.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Ophalen bron %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Ophalen van sommige archieven is mislukt."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Het uitpakken van de reeds uitgepakte bron in %s wordt overgeslagen\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Uitpakopdracht '%s' is mislukt.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Gelieve na te gaan of het 'dpkg-dev'-pakket geïnstalleerd is.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Bouwopdracht '%s' is mislukt.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Dochterproces is mislukt"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "U dient tenminste één pakket op te geven om de bouwvereisten van te "
 "controleren"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Kan de informatie over de bouwvereisten voor %s niet ophalen"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s heeft geen bouwvereisten.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1287,7 +1295,7 @@
 "De vereiste %s van pakket %s kan niet voldaan worden omdat pakket %s "
 "onvindbaar is"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1296,32 +1304,32 @@
 "De vereiste %s van pakket %s kan niet voldaan worden omdat er geen "
 "beschikbare versies zijn van pakket %s die aan de versievereisten voldoen"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Voldoen van Vereiste %s van pakket %s is mislukt: geïnstalleerde versie %s "
 "is te nieuw"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Voldoen van de vereiste %s van pakket %s is mislukt: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Bouwvereisten voor %s konden niet voldaan worden."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Verwerken van de bouwvereisten is mislukt"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Ondersteunde modules:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1666,8 +1674,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Kan %s niet lezen"
@@ -1697,10 +1706,9 @@
 msgstr ""
 "De 'info'- en de 'temp'-mappen dienen op hetzelfde bestandsysteem te staan"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Pakketlijsten worden ingelezen"
 
@@ -1918,173 +1926,173 @@
 msgid "Write error"
 msgstr "Schrijffout"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Kon geen socket aanmaken"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Kon de datasocket niet verbinden, de verbinding verliep"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Kon de passieve socket niet verbinden."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo kon geen luistersocket verkrijgen"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Kon geen socket binden"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Kon niet op de socket niet luisteren"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Kon de socketnaam niet bepalen"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Kan PORT-commando niet verzenden"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Onbekende adresfamilie %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT is mislukt; bericht van server: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Datasocket verbinding is verlopen"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Kan de verbinding niet aanvaarden"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Probleem bij het hashen van het bestand"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Kan bestand niet ophalen; bericht van server: %s"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Datasocket verliep"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Data transfer is mislukt, server zei: %s"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Zoekopdracht"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Aanroepen mislukt van "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Er wordt verbinding gemaakt met %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Kon de socket voor %s (f=%u t=%u p=%u) niet aanmaken"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Kan de verbinding met %s:%s (%s) niet aangaan."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Kon niet verbinden met %s:%s (%s), de verbinding verliep"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Kon niet verbinden met %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Er wordt verbinding gemaakt met %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Kon '%s' niet vinden"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Tijdelijke fout bij het opzoeken van '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Er gebeurde iets raars bij het oplossen van '%s:%s' (%i - %s)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Kan geen verbinding maken met %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, c-format
 msgid "No keyring installed in %s."
 msgstr "Geen sleutelring geïnstalleerd in %s."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Interne fout: ondertekening is goed maar kon de vingerafdruk van de sleutel\n"
 "niet bepalen?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Er is tenminste één ongeldige ondertekening gevonden."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Kon '%s' niet uitvoeren om ondertekening te verifiëren (is gpgv "
 "geïnstalleerd?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Onbekende fout bij het uitvoeren van gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "De volgende ondertekeningen waren ongeldig:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2166,19 +2174,19 @@
 msgid "Error reading from server"
 msgstr "Fout bij het lezen van de server"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Afkorten van bestand is mislukt"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Foute koptekstdata"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Verbinding mislukt"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Interne fout"
 
@@ -2246,7 +2254,7 @@
 msgid "%lis"
 msgstr "%lis"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Selectie %s niet gevonden"
@@ -2375,6 +2383,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Kan %s niet veranderen"
@@ -2561,7 +2570,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Wegschrijven van tijdelijke StateFile %s is mislukt"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2701,7 +2710,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Kan problemen niet verhelpen, u houdt defecte pakketten vast."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2753,12 +2762,12 @@
 "Gelieve de schijf met label '%s' in het station '%s' te plaatsen en op "
 "'enter' te drukken."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Pakketbeheersysteem '%s' wordt niet ondersteund"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Kan geen geschikt pakketsysteemtype bepalen"
 
@@ -2773,29 +2782,29 @@
 "Uw bronnenlijst (/etc/apt/sources.list) dient tenminste één bron-URI te "
 "bevatten"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "De pakketlijsten of het statusbestand konden of niet ontleed, of niet "
 "geopend worden."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "U kunt misschien 'apt-get update' uitvoeren om deze problemen te verhelpen"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "Ongeldige record in het voorkeurenbestand %s, 'Package' koptekst ontbreekt"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Pintype %s wordt niet begrepen"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Er is geen prioriteit (of nul) opgegeven voor deze pin"
 
@@ -2888,33 +2897,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Kon de status van de bronpakketlijst %s niet opvragen"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Voorziene bestanden worden verzameld"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Invoer/Uitvoer-fout tijdens wegschrijven bronpakket-cache"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "herbenoeming is mislukt, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5-som komt niet overeen"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash-som komt niet overeen"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Er zijn geen publieke sleutels beschikbaar voor de volgende sleutel-IDs:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2923,7 +2957,7 @@
 "Er kon geen bestand gevonden worden voor pakket %s. Dit kan betekenen dat u "
 "dit pakket handmatig moet repareren (wegens missende architectuur)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2932,7 +2966,7 @@
 "Er kon geen bestand gevonden worden voor pakket %s. Dit kan betekenen dat u "
 "dit pakket handmatig moet repareren."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2940,25 +2974,35 @@
 "De pakketindex-bestanden zijn beschadigd. Er is geen 'Filename:'-veld voor "
 "pakket %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Grootte komt niet overeen"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Kon Release-bestand %s niet ontleden"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "Geen secties in Release-bestand %s"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "Geen Hash-vermelding in Release-bestand %s"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Geen Hash-vermelding in Release-bestand %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Geen Hash-vermelding in Release-bestand %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3055,134 +3099,203 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Bronlijst-ingangen voor de schijf zijn:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "%i records weggeschreven.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "%i records weggeschreven met %i missende bestanden.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "%i records weggeschreven met %i niet overeenkomende bestanden\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "%i records weggeschreven met %i missende bestanden en %i niet overeenkomende "
 "bestanden\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Niet-bestaand bestand %s wordt overgeslagen"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr "Kan geen authenticatierecord vinden voor: %s"
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash-som komt niet overeen voor: %s"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Let op, %s wordt geselecteerd omwille van de regex '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Versie %s (%s) geselecteerd voor %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "%s wordt geïnstalleerd"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "%s wordt geconfigureerd"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "%s wordt verwijderd"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, c-format
 msgid "Completely removing %s"
 msgstr "%s wordt volledig verwijderd"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Post-installatie-trigger %s wordt uitgevoerd"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Map '%s' ontbreekt"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Kon het bestand %s niet openen"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "%s wordt voorbereid"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "%s wordt uitgepakt"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Configuratie van %s wordt voorbereid"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s is geïnstalleerd"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Verwijdering van %s wordt voorbereid"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s is verwijderd"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Volledige verwijdering van %s wordt voorbereid"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s is volledig verwijderd"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Kon logbestand niet wegschrijven, openpty() is mislukt (/dev/pts niet "
 "aangekoppeld?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr "dpkg wordt uitgevoerd"
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
@@ -3191,23 +3304,37 @@
 "Kan de beheersmap (%s) niet vergrendelen. Is deze in gebruik door een ander "
 "proces?"
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Kan de beheersmap (%s) niet vergrendelen. Heeft u beheerdersrechten?"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, fuzzy, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 "dpkg werd onderbroken; voer handmatig 'dpkg --configure -a' uit om het "
 "probleem te verhelpen. "
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "Niet vergrendeld"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3226,7 +3353,7 @@
 "Kon %s niet patchen met mmap (maar zonder mmap-specifieke fout) - de patch "
 "lijkt beschadigd te zijn."
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Verbinding werd voortijdig afgebroken"
 

=== modified file 'po/nn.po'
--- po/nn.po	2010-05-25 16:01:42 +0000
+++ po/nn.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: apt_nn\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2005-02-14 23:30+0100\n"
 "Last-Translator: Havard Korsvoll <korsvoll@skulelinux.no>\n"
 "Language-Team: Norwegian nynorsk <i18n-nn@lister.ping.uio.no>\n"
@@ -18,149 +18,147 @@
 "Content-Transfer-Encoding: 8bit\n"
 "X-Generator: KBabel 1.9.1\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Pakken %s versjon %s har eit krav som ikkje er oppfylt:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Finn ikkje pakken %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Tal p pakkenamn: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Tal p pakkenamn: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Vanlege pakkar: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Reine virtuelle pakkar: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Enkle virtuelle pakkar: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Samansette virtuelle pakkar: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Manglar: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Tal p einskildversjonar: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "Tal p einskildversjonar: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Tal p krav: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Tal p ver./fil-forhold: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "Tal p ver./fil-forhold: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Tal p tilbyr-forhold: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Tal p strengar med jokerteikn: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Storleik p kravs- og versjonsrom: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Slingringsmon: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Brukt plass i alt: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Pakkefila %s er ute av takt."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Du m oppgi nyaktig eitt mnster"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Fann ingen pakkar"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Finn ikkje pakken %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Pakkefiler:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Mellomlageret er ute av takt, kan ikkje x-referera ei pakkefil"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Spikra pakkar:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(ikkje funne)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Installert: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidat: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ingen)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Pakke spikra til: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Versjonstabell:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s for %s %s kompilert p %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -318,12 +316,12 @@
 "  -c=? Les denne innstillingsfila.\n"
 "  -o=? Set ei vilkrleg innstilling, t.d. -o dir::cache=/tmp.\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Klarte ikkje skriva til %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Finn ikkje debconf-versjonen. Er debconf installert?"
 
@@ -655,79 +653,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Klarte ikkje endra namnet p %s til %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "J"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Regex-kompileringsfeil - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Flgjande pakkar har krav som ikkje er oppfylte:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "men %s er installert"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "men %s skal installerast"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "men lt seg ikkje installera"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "men er ein virtuell pakke"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "men er ikkje installert"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "men skal ikkje installerast"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " eller"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Dei flgjande NYE pakkane vil verta installerte:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Dei flgjande pakkane vil verta FJERNA:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Dei flgjande pakkane er haldne tilbake:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Dei flgjande pakkane vil verta oppgraderte:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Dei flgjande pakkane vil verta NEDGRADERTE:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Dei flgjande pakkane som er haldne tilbake vil verta endra:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (fordi %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 #, fuzzy
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
@@ -736,142 +734,142 @@
 "TVARING: Dei flgjande ndvendige pakkane vil verta fjerna.\n"
 "Dette br IKKJE gjerast utan at du er fullstendig klar over kva du gjer!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu oppgraderte, %lu nyleg installerte, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu installerte p nytt, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu nedgraderte, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu skal fjernast og %lu skal ikkje oppgraderast.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu ikkje fullstendig installerte eller fjerna.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Rettar p krav ..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " mislukkast."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Klarte ikkje retta p krav"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Klarte ikkje minimera oppgraderingsmengda"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Ferdig"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Du vil kanskje prva  retta p desse ved  kyra apt-get -f install."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Nokre krav er ikkje oppfylte. Prv med -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "TVARING: Klarer ikkje autentisere desse pakkane."
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Installer desse pakkane utan verifikasjon [j/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Nokre pakkar kunne ikkje bli autentisert"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Det oppstod problem, og -y vart brukt utan --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Nokre pakkar m fjernast, men fjerning er sltt av."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 #, fuzzy
 msgid "Internal error, Ordering didn't finish"
 msgstr "Intern feil ved tilleggjing av avleiing"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Kjeldelista kan ikkje lesast."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "M henta %sB/%sB med arkiv.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "M henta %sB med arkiv.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Etter utpakking vil %sB meir diskplass verta brukt.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Etter utpakking vil %sB meir diskplass verta frigjort.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, fuzzy, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Du har ikkje nok ledig plass i %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Du har ikkje nok ledig plass i %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "Trivial Only var spesifisert, men dette er ikkje noka triviell handling."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ja, gjer som eg seier!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, fuzzy, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -882,28 +880,28 @@
 "For  halda fram, m du skriva nyaktig %s.\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Avbryt."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Vil du halda fram [J/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Klarte ikkje henta %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Klarte ikkje henta nokre av filene"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Nedlastinga er ferdig i nedlastingsmodus"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -911,19 +909,19 @@
 "Klarte ikkje henta nokre av arkiva. Du kan prva med apt-get update eller --"
 "fix-missing."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing og byte av medium er ikkje sttta for tida"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Klarte ikkje retta opp manglande pakkar."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Avbryt installasjon."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -933,53 +931,53 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Merk, vel %s i staden for %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Hoppar over %s, for den er installert fr fr og ikkje sett til "
 "oppgradering.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Hoppar over %s, for den er installert fr fr og ikkje sett til "
 "oppgradering.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Pakken %s er ikkje installert, og vert difor ikkje fjerna\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Pakken %s er ein virtuell pakke, tilbydd av:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Installert]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Kandidatversjonar"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Du m velja ein som skal installerast."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -990,65 +988,65 @@
 "av ein annan pakke. Dette tyder at pakket manglar, er gjort overfldig\n"
 "eller er berre tilgjengeleg fr ei anna kjelde\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Dei flgjande pakkane kan brukast i staden:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Det finst ingen installasjonskandidat for pakken %s"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "%s kan ikkje installerast p nytt, for pakken kan ikkje lastast ned.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "Den nyaste versjonen av %s er installert fr fr.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Fann ikkje utgva %s av %s"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Fann ikkje versjonen %s av %s"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Vald versjon %s (%s) for %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Klarte ikkje f status p kjeldepakkelista %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Oppdateringskommandoen tek ingen argument"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1058,7 +1056,7 @@
 msgstr[0] "Dei flgjande NYE pakkane vil verta installerte:"
 msgstr[1] "Dei flgjande NYE pakkane vil verta installerte:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1066,11 +1064,11 @@
 msgstr[0] "Dei flgjande NYE pakkane vil verta installerte:"
 msgstr[1] "Dei flgjande NYE pakkane vil verta installerte:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1086,44 +1084,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Flgjande informasjon kan hjelpa med  lysa situasjonen:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Intern feil. AllUpgrade ydelagde noko"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Intern feil. AllUpgrade ydelagde noko"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "Fann ikkje pakken %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Fann ikkje pakken %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Merk, vel %s i staden for regex %s\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "men %s skal installerast"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Du vil kanskje prva  retta p desse ved  kyra apt-get -f install."
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1131,7 +1124,7 @@
 "Nokre krav er ikkje oppfylte. Du kan prva apt-get -f install (eller velja "
 "ei lysing)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1143,132 +1136,147 @@
 "distribusjonen, kan det g henda at nokre av pakkane som trengst ikkje\n"
 "er laga enno eller at dei framleis ligg i Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "ydelagde pakkar"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Dei flgjande tilleggspakkane vil verta installerte:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Fresltte pakkar:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Tilrdde pakkar"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "men %s skal installerast"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Reknar ut oppgradering ... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Mislukkast"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Ferdig"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 #, fuzzy
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Intern feil. AllUpgrade ydelagde noko"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Klarte ikkje lsa nedlastingskatalogen"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Du m velja minst in pakke som kjeldekoden skal hentast for"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Finn ingen kjeldepakke for %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, fuzzy, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Hoppar over utpakking av kjeldekode som er utpakka fr fr i %s\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Du har ikkje nok ledig plass i %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "M henta %sB/%sB med kjeldekodearkiv.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "M henta %sB med kjeldekodearkiv.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Hent kjeldekode %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Klarte ikkje henta nokre av arkiva."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Hoppar over utpakking av kjeldekode som er utpakka fr fr i %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Utpakkingskommandoen %s mislukkast.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Byggjekommandoen %s mislukkast.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Barneprosessen mislukkast"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "Du m velja minst ein pakke som byggjekrava skal sjekkast for"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Klarte ikkje henta byggjekrav for %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s har ingen byggjekrav.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "Kravet %s for %s kan ikkje oppfyllast fordi pakken %s ikkje finst"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1277,31 +1285,31 @@
 "Kravet %s for %s kan ikkje oppfyllast fordi det ikkje finst nokon "
 "tilgjengelege versjonar av pakken %s som oppfyller versjonskrava"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Klarte ikkje oppfylla kravet %s for %s: Den installerte pakken %s er for ny"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Klarte ikkje oppfylla kravet %s for %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Byggjekrav for %s kunne ikkje tilfredstillast."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Klarte ikkje behandla byggjekrava"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Sttta modular:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1634,8 +1642,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Klarte ikkje lesa %s"
@@ -1665,10 +1674,9 @@
 msgstr ""
 "Infokatalogen og den mellombelse katalogen m vera p det same filsystemet"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Les pakkelister"
 
@@ -1887,170 +1895,169 @@
 msgid "Write error"
 msgstr "Skrivefeil"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Klarte ikkje oppretta sokkel"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Klarte ikkje kopla til datasokkel, tidsavbrot p sambandet"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Klarte ikkje kopla til passiv sokkel."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo klarte ikkje oppretta ein lyttesokkel"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Klarte ikkje binda til sokkel"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Klarte ikkje lytta til sokkel"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Klarte ikkje avgjera sokkelnamnet"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Klarte ikkje senda PORT-kommandoen"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Ukjend adressefamilie %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT mislukkast, tenaren sa: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Tidsavbrot p tilkopling til datasokkel"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Klarte ikkje godta tilkoplinga"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problem ved oppretting av nkkel for fil"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Klarte ikkje henta fila, tenaren sa %s"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Tidsavbrot p datasokkelen"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Dataoverfringa mislukkast, tenaren sa %s"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Sprjing"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Klarte ikkje starta "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Koplar til %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Klarte ikkje oppretta sokkel for %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Klarte ikkje initiera sambandet til %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Klarte ikkje kopla til %s:%s (%s), tidsavbrot p sambandet"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Klarte ikkje kopla til %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Koplar til %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Klarte ikkje sl opp %s"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Mellombels feil ved oppslag av %s"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Det hende noko dumt ved oppslag av %s:%s (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Klarte ikkje kopla til %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Avbryt installasjon."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr ""
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr ""
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 #, fuzzy
 msgid "The following signatures were invalid:\n"
 msgstr "Dei flgjande tilleggspakkane vil verta installerte:"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2127,20 +2134,20 @@
 msgid "Error reading from server"
 msgstr "Feil ved lesing fr tenaren"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Klarte ikkje skriva fila %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "ydelagde hovuddata"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Sambandet mislukkast"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Intern feil"
 
@@ -2206,7 +2213,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Fann ikkje utvalet %s"
@@ -2329,6 +2336,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Klarte ikkje byta til %s"
@@ -2513,7 +2521,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Klarte ikkje skriva fila %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2648,7 +2656,7 @@
 msgstr ""
 "Klarte ikkje retta opp problema. Nokre ydelagde pakkar er haldne tilbake."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2701,12 +2709,12 @@
 " %s\n"
 "i stasjonen %s og trykk Enter.\n"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Pakkesystemet %s er ikkje sttta"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Klarte ikkje avgjera ein eigna pakkesystemtype"
 
@@ -2719,26 +2727,26 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Du m leggja nokre kjelde-URI-ar i fila sources.list."
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Klarte ikkje tolka eller opna pakkelista eller tilstandsfila."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Du vil kanskje prva  retta p desse problema ved  kyra apt-get update."
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Ugyldig oppslag i innstillingsfila, manglar pakkehovud"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Skjnar ikkje spikringstypen %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Ingen prioritet (eller null) oppgitt for spiker"
 
@@ -2828,33 +2836,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Klarte ikkje f status p kjeldepakkelista %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Samlar inn filtilbod"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IU-feil ved lagring av kjeldelager"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "endring av namn mislukkast, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Feil MD5-sum"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "Feil MD5-sum"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2863,7 +2896,7 @@
 "Fann ikkje fila for pakken %s. Det kan henda du m fiksa denne pakken sjlv "
 "(fordi arkitekturen manglar)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2871,32 +2904,42 @@
 msgstr ""
 "Fann ikkje fila for pakken %s. Det kan henda du m fiksa denne pakken sjlv."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "Pakkeindeksfilene er ydelagde. Feltet Filename: manglar for pakken %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Feil storleik"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Klarte ikkje tolka pakkefila %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Merk, vel %s i staden for %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Ugyldig linje i avleiingsfila: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Klarte ikkje tolka pakkefila %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2990,151 +3033,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Kjeldelisteoppfringar for denne disken er:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Skreiv %i postar.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Skreiv %i postar med %i manglande filer.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Skreiv %i postar med %i filer som ikkje passa\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Skreiv %i postar med %i manglande filer og %i filer som ikkje passa\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Opnar oppsettsfila %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Feil MD5-sum"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Merk, vel %s i staden for regex %s\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Vald versjon %s (%s) for %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "  Installert: "
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, fuzzy, c-format
 msgid "Configuring %s"
 msgstr "Koplar til %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, fuzzy, c-format
 msgid "Removing %s"
 msgstr "Opnar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Klarte ikkje fjerna %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "Listekatalogen %spartial manglar."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Klarte ikkje opna fila %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, fuzzy, c-format
 msgid "Preparing %s"
 msgstr "Opnar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, fuzzy, c-format
 msgid "Unpacking %s"
 msgstr "Opnar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, fuzzy, c-format
 msgid "Preparing to configure %s"
 msgstr "Opnar oppsettsfila %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, fuzzy, c-format
 msgid "Installed %s"
 msgstr "  Installert: "
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, fuzzy, c-format
 msgid "Removed %s"
 msgstr "Tilrdingar"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, fuzzy, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Opnar oppsettsfila %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, fuzzy, c-format
 msgid "Completely removed %s"
 msgstr "Klarte ikkje fjerna %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Klarte ikkje lsa listekatalogen"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3149,7 +3275,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Sambandet vart uventa stengd"
 

=== modified file 'po/pl.po'
--- po/pl.po	2010-05-25 16:01:42 +0000
+++ po/pl.po	2010-06-10 14:02:22 +0000
@@ -10,7 +10,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.23.1\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-09-27 03:42+0100\n"
 "Last-Translator: Wiktor Wandachowicz <siryes@gmail.com>\n"
 "Language-Team: Polish <debian-l10n-polish@lists.debian.org>\n"
@@ -18,149 +18,147 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Pakiet %s w wersji %s ma niespełnione zależności:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Nie udało się odnaleźć pakietu %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Liczba nazw pakietów: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Liczba nazw pakietów: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Zwykłych pakietów: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Czysto wirtualnych pakietów: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Pojedynczych pakietów wirtualnych: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Mieszanych pakietów wirtualnych: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Brakujących: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "W sumie różnych wersji: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "W sumie różnych opisów: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "W sumie zależności: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "W sumie zależności wersja/plik: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "W sumie zależności opis/plik: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "W sumie mapowań zapewnień: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "W sumie dopasowanych napisów: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Sumaryczny rozmiar obszaru zależności od wersji: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Sumaryczny rozmiar niewykorzystanego miejsca: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Całkowity rozmiar: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Plik pakietu %s jest przestarzały."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Należy podać dokładnie jeden wzorzec"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Nie znaleziono żadnych pakietów"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Nie udało się odnaleźć pakietu %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Plików pakietów:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Magazyn podręczny jest przestarzały, nie można odwołać się (x-ref) do pliku "
 "pakietu."
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Przypięte pakiety:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(nieznaleziony)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Zainstalowana: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandydująca: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(brak)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Sposób przypięcia: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabela wersji:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s dla %s skompilowany %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -317,12 +315,12 @@
 "  -c=? Czyta wskazany plik konfiguracyjny.\n"
 "  -o=? Ustawia dowolną opcję konfiguracji, np. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Nie udało się pisać do %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Nie udało się pobrać wersji debconf. Czy debconf jest zainstalowany?"
 
@@ -660,79 +658,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Nie udało się zmienić nazwy %s na %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "T"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Błąd kompilacji wyrażenia regularnego - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Następujące pakiety mają niespełnione zależności:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "ale %s jest zainstalowany"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "ale %s ma zostać zainstalowany"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ale nie da się go zainstalować"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ale jest pakietem wirtualnym"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ale nie jest zainstalowany"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "ale nie zostanie zainstalowany"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " lub"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Zostaną zainstalowane następujące NOWE pakiety:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Następujące pakiety zostaną USUNIĘTE:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Następujące pakiety zostały zatrzymane:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Następujące pakiety zostaną zaktualizowane:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Zostaną zainstalowane STARE wersje następujących pakietów:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Zostaną zmienione następujące zatrzymane pakiety:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (z powodu %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -740,142 +738,142 @@
 "UWAGA: Zostaną usunięte następujące istotne pakiety.\n"
 "Nie powinno się tego robić, chyba że dokładnie wiesz co robisz!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu aktualizowanych, %lu nowo instalowanych, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu przeinstalowywanych, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu cofniętych wersji, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu usuwanych i %lu nieaktualizowanych.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu nie w pełni zainstalowanych lub usuniętych.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Naprawianie zależności..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " nie udało się."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Nie udało się naprawić zależności"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Nie udało się zminimalizować zbioru aktualizacji"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Gotowe"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Należy uruchomić \"apt-get -f install\", aby je naprawić."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Niespełnione zależności. Proszę spróbować użyć -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "UWAGA: Następujące pakiety nie mogą zostać zweryfikowane!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Ostrzeżenie uwierzytelniania zignorowano.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Zainstalować te pakiety bez weryfikacji [t/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Niektóre pakiety nie mogły zostać zweryfikowane"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Były problemy, a użyto -y bez --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Błąd wewnętrzny, InstallPackages użyto z uszkodzonymi pakietami!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Pakiety powinny zostać usunięte, ale Remove jest wyłączone."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Błąd wewnętrzny, sortowanie niezakończone"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Nie udało się odczytać list źródeł."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Dziwne. Rozmiary się nie zgadzają, proszę to zgłosić pod apt@packages.debian."
 "org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Konieczne pobranie %sB/%sB archiwów.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Konieczne pobranie %sB archiwów.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Po tej operacji zostanie dodatkowo użyte %sB miejsca na dysku.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Po tej operacji zostanie zwolnione %sB miejsca na dysku.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Nie udało się ustalić ilości wolnego miejsca w %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Niestety w %s nie ma wystarczającej ilości wolnego miejsca."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Nakazano wykonywać tylko trywialne operacje, a to nie jest trywialne."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Tak, rób jak mówię!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -886,28 +884,28 @@
 "Aby kontynuować wpisz zdanie \"%s\"\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Przerwane."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Kontynuować [T/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Nie udało się pobrać %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Nie udało się pobrać niektórych plików"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Ukończono pobieranie w trybie samego pobierania"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -915,19 +913,19 @@
 "Nie udało się pobrać niektórych archiwów, proszę spróbować uruchomić apt-get "
 "update lub użyć opcji --fix-missing"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing i zamiana nośników nie są obecnie obsługiwane"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Nie udało się poprawić brakujących pakietów."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Przerywanie instalacji"
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -937,51 +935,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Uwaga, wybieranie %s zamiast %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Pomijanie %s, jest już zainstalowane, a nie została wybrana aktualizacja.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Pomijanie %s, jest już zainstalowane, a nie została wybrana aktualizacja.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Pakiet %s nie jest zainstalowany, więc nie zostanie usunięty.\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Pakiet %s jest pakietem wirtualnym zapewnianym przez:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Zainstalowany]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Kandydujące wersje"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Należy jednoznacznie wybrać jeden z nich do instalacji."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -992,66 +990,66 @@
 "Zazwyczaj oznacza to, że pakietu brakuje, został zastąpiony przez inny\n"
 "pakiet lub nie jest dostępny przy pomocy obecnie ustawionych źródeł.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Jednak następujące pakiety go zastępują:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Pakiet %s nie ma kandydata do instalacji"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 "Ponowna instalacja pakietu %s nie jest możliwa, nie może on zostać pobrany.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s jest już w najnowszej wersji.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Wydanie \"%s\" dla \"%s\" nie zostało znalezione"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Wersja \"%s\" dla \"%s\" nie została znaleziona"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Wybrano wersję %s (%s) dla %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Nie udało się wykonać operacji stat na liście pakietów źródłowych %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Polecenie update nie wymaga żadnych argumentów"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Nic nie powinno być usuwane, AutoRemover nie zostanie uruchomiony"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1065,7 +1063,7 @@
 "Następujące pakiety zostały zainstalowane automatycznie i nie są już więcej "
 "wymagane:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1077,11 +1075,11 @@
 "%lu pakiety(ów) zostały zainstalowane automatycznie i nie są już więcej "
 "wymagane.\n"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Aby je usunąć należy użyć \"apt-get autoremove\"."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1099,43 +1097,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Następujące informacje mogą pomóc rozwiązać sytuację:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Błąd wewnętrzny, AutoRemover wszystko popsuł"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Błąd wewnętrzny, AllUpgrade wszystko popsuło"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Nie udało się odnaleźć zadania %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Nie udało się odnaleźć pakietu %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Uwaga, wybieranie %s za wyrażenie \"%s\"\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s zaznaczony jako zainstalowany ręcznie.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Należy uruchomić \"apt-get -f install\", aby je naprawić:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1143,7 +1136,7 @@
 "Niespełnione zależności. Proszę spróbować \"apt-get -f install\" bez "
 "pakietów (lub podać rozwiązanie)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1155,128 +1148,143 @@
 "w której niektóre pakiety nie zostały jeszcze utworzone lub przeniesione\n"
 "z katalogu Incoming (\"Przychodzące\")."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Pakiety są uszkodzone"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Zostaną zainstalowane następujące dodatkowe pakiety:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Sugerowane pakiety:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Polecane pakiety:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s zaznaczony jako zainstalowany ręcznie.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Obliczanie aktualizacji..."
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Nie udało się"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Gotowe"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Błąd wewnętrzny, rozwiązywanie problemów wszystko popsuło"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Nie udało się zablokować katalogu pobierania"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "Należy podać przynajmniej jeden pakiet, dla którego mają zostać pobrane "
 "źródła"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Nie udało się odnaleźć źródła dla pakietu %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Pomijanie już pobranego pliku \"%s\"\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "W %s nie ma wystarczającej ilości wolnego miejsca"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Konieczne pobranie %sB/%sB archiwów źródeł.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Konieczne pobranie %sB archiwów źródeł.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Pobierz źródło %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Nie udało się pobrać niektórych archiwów."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Pomijanie rozpakowania już rozpakowanego źródła w %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Polecenie rozpakowania \"%s\" zawiodło.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Proszę sprawdzić czy pakiet \"dpkg-dev\" jest zainstalowany.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Polecenie budowania \"%s\" zawiodło.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Proces potomny zawiódł"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Należy podać przynajmniej jeden pakiet, dla którego mają zostać sprawdzone "
 "zależności dla budowania"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Nie udało się pobrać informacji o zależnościach dla budowania %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s nie ma zależności dla budowania.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1285,7 +1293,7 @@
 "Zależność %s od %s nie może zostać spełniona, ponieważ nie znaleziono "
 "pakietu %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1294,32 +1302,32 @@
 "Zależność %s od %s nie może zostać spełniona, ponieważ żadna z dostępnych "
 "wersji pakietu %s nie ma odpowiedniej wersji"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Nie udało się spełnić zależności %s od %s: Zainstalowany pakiet %s jest zbyt "
 "nowy"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Nie udało się spełnić zależności %s od %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Nie udało się spełnić zależności dla budowania %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Nie udało się przetworzyć zależności dla budowania"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Obsługiwane moduły:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1661,8 +1669,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Nie można czytać %s"
@@ -1691,10 +1700,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Pliki info i katalog tymczasowy muszą być na tym samym systemie plików"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Czytanie list pakietów"
 
@@ -1914,173 +1922,173 @@
 msgid "Write error"
 msgstr "Błąd zapisu"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Nie udało się utworzyć gniazda"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Nie udało się połączyć gniazda danych, przekroczenie czasu połączenia"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Nie udało się połączyć pasywnego gniazda."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo nie było w stanie uzyskać nasłuchującego gniazda"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Nie udało się przyłączyć gniazda"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Nie udało się nasłuchiwać na gnieździe"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Nie udało się określić nazwy gniazda"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Nie można wysłać polecenia PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Nieznana rodzina adresów %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Polecenie EPRT nie powiodło się, odpowiedź serwera: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Przekroczony czas połączenia gniazda danych"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Nie udało się przyjąć połączenia"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Nie udało się obliczyć skrótu pliku"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Nie można pobrać pliku, odpowiedź serwera: %s"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Przekroczony czas oczekiwania na dane"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Nie udało się przesłać danych, odpowiedź serwera: %s"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Info"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Nie można wywołać "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Podłączanie do %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Nie udało się utworzyć gniazda dla %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Nie udało się zainicjalizować połączenia z %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Nie udało się połączyć z %s:%s (%s), przekroczenie czasu połączenia"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Nie udało się połączyć z %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Łączenie z %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nie udało się przetłumaczyć nazwy \"%s\""
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Tymczasowy błąd przy tłumaczeniu \"%s\""
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Coś niewłaściwego stało się przy tłumaczeniu \"%s:%s\" (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Nie udało się połączyć z %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Przerywanie instalacji"
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Błąd wewnętrzny: Prawidłowy podpis, ale nie nie udało się ustalić odcisku "
 "klucza?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Napotkano przynajmniej jeden nieprawidłowy podpis."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Nie udało się uruchomić \"%s\" by zweryfikować podpis (czy gpgv jest "
 "zainstalowane?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Nieznany błąd podczas uruchamiania gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Następujące podpisy były błędne:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2159,19 +2167,19 @@
 msgid "Error reading from server"
 msgstr "Błąd czytania z serwera"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Nie udało się uciąć zawartości pliku %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Błędne dane nagłówka"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Połączenie nie udało się"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Błąd wewnętrzny"
 
@@ -2239,7 +2247,7 @@
 msgid "%lis"
 msgstr "%lis"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Nie odnaleziono wyboru %s"
@@ -2364,6 +2372,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Nie udało się przejść do %s"
@@ -2547,7 +2556,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Nie udało się zapisać tymczasowego pliku stanu %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2682,7 +2691,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Nie udało się naprawić problemów, zatrzymano uszkodzone pakiety."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2732,12 +2741,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Proszę włożyć do napędu \"%s\" dysk o nazwie: \"%s\" i nacisnąć enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "System pakietów \"%s\" nie jest obsługiwany"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Nie udało się określić odpowiedniego typu systemu pakietów"
 
@@ -2750,25 +2759,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Należy dopisać jakieś URI pakietów źródłowych do pliku sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Nie udało się otworzyć lub zanalizować zawartości list pakietów."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Należy uruchomić apt-get update aby naprawić te problemy."
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Nieprawidłowe informacje w pliku ustawień %s, brak nagłówka Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Nierozpoznany typ przypinania %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Brak (lub zerowy) priorytet przypięcia"
 
@@ -2860,32 +2869,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Nie udało się wykonać operacji stat na liście pakietów źródłowych %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Zbieranie zapewnień plików"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Błąd wejścia/wyjścia przy zapisywaniu podręcznego magazynu źródeł"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "nie udało się zmienić nazwy, %s (%s -> %s)"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Błędna suma MD5"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Błędna suma kontrolna"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Dla następujących identyfikatorów kluczy brakuje klucza publicznego:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2894,7 +2928,7 @@
 "Nie udało się odnaleźć pliku dla pakietu %s. Może to oznaczać, że trzeba "
 "będzie ręcznie naprawić ten pakiet (z powodu brakującej architektury)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2903,32 +2937,42 @@
 "Nie udało się odnaleźć pliku dla pakietu %s. Może to oznaczać, że trzeba "
 "będzie ręcznie naprawić ten pakiet."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "Pliki indeksu pakietów są uszkodzone. Brak pola Filename: dla pakietu %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Błędny rozmiar"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Nie udało się zanalizować pliku Release %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "Brak sekcji w pliku Release %s"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "Brak wpisu Hash w pliku Release %s"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Brak wpisu Hash w pliku Release %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Brak wpisu Hash w pliku Release %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3025,132 +3069,201 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Źródła dla tej płyty to:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Zapisano %i rekordów.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Zapisano %i rekordów z %i brakującymi plikami.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Zapisano %i rekordów z %i niepasującymi plikami\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Zapisano %i rekordów z %i brakującymi plikami i %i niepasującymi\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Otwieranie pliku konfiguracyjnego %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Błędna suma kontrolna"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Uwaga, wybieranie %s za wyrażenie \"%s\"\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Wybrano wersję %s (%s) dla %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Instalowanie %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Konfigurowanie %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Usuwanie %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Całkowicie usunięto %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Uruchamianie wyzwalacza post-installation %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Brakuje katalogu \"%s\""
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Nie udało się otworzyć pliku %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Przygotowanie %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Rozpakowywanie %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Przygotowanie do konfiguracji %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Zainstalowany %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Przygotowanie do usunięcia %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Usunięto %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Przygotowanie do całkowitego usunięcia %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Całkowicie usunięto %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Nie można zapisać dziennika, openpty() nie powiodło się (/dev/pts nie "
 "zamontowane?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr "Uruchamianie dpkg"
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
@@ -3159,24 +3272,38 @@
 "Nie udało się zablokować katalogu administracyjnego (%s), czy inny proces go "
 "używa?"
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr ""
 "Nie udało się zablokować katalogu administracyjnego (%s), czy jesteś rootem?"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, fuzzy, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 "dpkg został przerwany, należy ręcznie uruchomić \"dpkg --configure -a\" aby "
 "naprawić problem."
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "Nie zablokowany"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3191,7 +3318,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Połączenie zostało zamknięte przedwcześnie"
 

=== modified file 'po/pt.po'
--- po/pt.po	2010-05-25 16:01:42 +0000
+++ po/pt.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-09-09 20:54+0100\n"
 "Last-Translator: Miguel Figueiredo <elmig@debianpt.org>\n"
 "Language-Team: Portuguese <traduz@debianpt.org>\n"
@@ -15,148 +15,146 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "O pacote %s versão %s tem uma dependência não satisfeita:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Não foi possível encontrar o pacote %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Total de nomes de pacotes: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Total de nomes de pacotes: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Pacotes normais: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Pacotes puramente virtuais: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Pacotes virtuais únicos: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Pacotes virtuais misturados: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Faltam: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Total de versões distintas: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Total de descrições distintas: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Total de dependências: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Total de relações ver/ficheiro: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Total de relações Desc/Ficheiro: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Total de Mapeamentos 'Provides': "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Total de strings globbed: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Espaço total de dependência de versão: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Espaço total desperdiçado: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Espaço total contabilizado: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "O ficheiro do pacote %s está dessincronizado."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
-msgstr "Você deve dar exactamente um pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
+msgstr "Você deve passar exatamente um padrão"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Não foi encontrado nenhum pacote"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Não foi possível encontrar o pacote %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Ficheiros de Pacotes :"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "A cache está dessincronizada, não pode x-referenciar um ficheiro de pacote"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pacotes Marcados: "
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(não encontrado)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalado: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidato: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(nenhum)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Marcação do Pacote: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabela de Versão:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s para %s compilado em %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -315,12 +313,12 @@
 "  -o=? Definir uma opção arbitrária de configuração, p.e.: -o dir::cache=/"
 "tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Não conseguiu escrever para %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Não pode obter a versão do debconf. O debconf está instalado?"
 
@@ -656,79 +654,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Falhou renomear %s para %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "S"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Erro de compilação de regex - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Os pacotes a seguir têm dependências não satisfeitas:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "mas %s está instalado"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "mas %s está para ser instalado"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "mas não é instalável"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "mas é um pacote virtual"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "mas não está instalado"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "mas não vai ser instalado"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " ou"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Serão instalados os seguintes NOVOS pacotes:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Serão REMOVIDOS os seguintes pacotes:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Serão mantidos em suas versões actuais os seguintes pacotes:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Serão actualizados os seguintes pacotes:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Será feito o DOWNGRADE aos seguintes pacotes:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Os seguintes pacotes mantidos serão mudados:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (devido a %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -736,142 +734,142 @@
 "AVISO: Os seguintes pacotes essenciais serão removidos.\n"
 "Isso NÃO deverá ser feito a menos que saiba exactamente o que está a fazer!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu pacotes actualizados, %lu pacotes novos instalados, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstalados, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu a que foi feito o downgrade, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu a remover e %lu não actualizados.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu pacotes não totalmente instalados ou removidos.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "A corrigir dependências..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " falhou."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Não foi possível corrigir dependências"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Não foi possível minimizar o conjunto de actualizações"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Feito"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Você pode querer executar 'apt-get -f install' para corrigir isso."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dependências não satisfeitas. Tente utilizar -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "AVISO: Os seguintes pacotes não podem ser autenticados!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Aviso de autenticação ultrapassado.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Instalar estes pacotes sem verificação [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Alguns pacotes não puderam ser autenticados"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Há problemas e foi utilizado -y sem --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Erro Interno, InstallPackages foi chamado com pacotes estragados!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Pacotes precisam de ser removidos mas Remove está desabilitado."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Erro Interno, Ordering não terminou"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "A lista de fontes não pôde ser lida."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Estranho.. Os tamanhos não coincidiram, escreva para apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "É necessário obter %sB/%sB de arquivos.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "É necessário obter %sB de arquivos.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "Após esta operação, serão utilizados %sB adicionais de espaço em disco.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Após esta operação, será libertado %sB de espaço em disco.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Não foi possível determinar o espaço livre em %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Você não possui espaço livre suficiente em %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Trivial Only especificado mas isto não é uma operação trivial."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Sim, faça como eu digo!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -882,28 +880,28 @@
 "Para continuar escreva a frase '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Abortado."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Deseja continuar [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Falhou obter %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Falhou o download de alguns ficheiros"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Download completo e em modo de fazer apenas o download"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -911,19 +909,19 @@
 "Não foi possível obter alguns arquivos, tente talvez correr apt-get update "
 "ou tente com --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing e troca de mídia não são suportados actualmente"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Não foi possível corrigir os pacotes em falta."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "A abortar a instalação."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -933,49 +931,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Note, a seleccionar %s em vez de %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Saltando %s, já está instalado e a actualização não está definida.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Saltando %s, já está instalado e a actualização não está definida.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "O pacote %s não está instalado, por isso não será removido\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "O pacote %s é um pacote virtual disponibilizado por:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Instalado]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versões candidatas"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Você deve seleccionar explicitamente um para instalar."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -986,67 +984,67 @@
 "Isso pode significar que o pacote falta, ou ficou obsoleto, ou\n"
 "está disponível somente a partir de outra fonte\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "No entanto, os seguintes pacotes substituem-no:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "O pacote %s não tem candidato para instalação"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr ""
 "A reinstalação de %s não é possível, o download do mesmo não pode ser "
 "feito.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s já está na versão mais recente.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Não foi encontrado o Release '%s' para '%s'"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Não foi encontrada a versão '%s' para '%s'"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Versão seleccionada %s (%s) para %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Não foi possível executar stat à lista de pacotes de código fonte %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "O comando update não leva argumentos"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Não é suposto nós apagarmos coisas, não pode iniciar o AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1060,7 +1058,7 @@
 "Os seguintes pacotes foram instalados automaticamente e já não são "
 "necessários:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1072,11 +1070,11 @@
 "Os seguintes pacotes foram instalados automaticamente e já não são "
 "necessários:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Utilize 'apt-get autoremove' para os remover."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1094,43 +1092,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "A seguinte informação pode ajudar a resolver a situação:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Erro Interno, o AutoRemover estragou coisas"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Erro Interno, AllUpgrade estragou algo"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Não foi possível encontrar a tarefa %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Impossível encontrar o pacote %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Note, a seleccionar %s para a expressão regular '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s está definido para ser instalado manualmente.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Você deve querer executar 'apt-get -f install' para corrigir estes:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1138,7 +1131,7 @@
 "Dependências não satisfeitas. Tente 'apt-get -f install' sem nenhum pacote "
 "(ou especifique uma solução)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1150,128 +1143,143 @@
 "distribuição unstable em que alguns pacotes pedidos ainda não foram \n"
 "criados ou foram movidos do Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Pacotes estragados"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Os seguintes pacotes extra serão instalados:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Pacotes sugeridos:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Pacotes recomendados:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s está definido para ser instalado manualmente.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "A calcular a actualização... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Falhou"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Pronto"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Erro Interno, o solucionador de problemas estragou coisas"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Impossível criar acesso exclusivo ao directório de downloads"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Tem de especificar pelo menos um pacote para obter o código fonte de"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Não foi possível encontrar um pacote de código fonte para %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "A saltar o ficheiro '%s', já tinha sido feito download'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Você não possui espaço livre suficiente em %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "É necessário obter %sB/%sB de arquivos de código fonte.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "É necessário obter %sB de arquivos de código fonte.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Obter código fonte %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Falhou obter alguns arquivos."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 "A saltar a descompactação do pacote de código fonte já descompactado em %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "O comando de descompactação '%s' falhou.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Verifique se o pacote 'dpkg-dev' está instalado.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "O comando de compilação '%s' falhou.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "O processo filho falhou"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Deve especificar pelo menos um pacote para verificar as dependências de "
 "compilação"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr ""
 "Não foi possível obter informações de dependências de compilação para %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s não tem dependências de compilação.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1280,7 +1288,7 @@
 "a dependência de %s para %s não pôde ser satisfeita porque o pacote %s não "
 "pôde ser encontrado"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1289,32 +1297,32 @@
 "a dependência de %s para %s não pode ser satisfeita porque nenhuma versão "
 "disponível do pacote %s pode satisfazer os requisitos de versão"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Falha ao satisfazer a dependência %s para %s: O pacote instalado %s é "
 "demasiado novo"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Falha ao satisfazer a dependência %s para %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Não foi possível satisfazer as dependências de compilação para %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Falhou processar as dependências de compilação"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Módulos Suportados:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1656,8 +1664,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Não foi possível ler %s"
@@ -1687,10 +1696,9 @@
 msgstr ""
 "Os directórios info e temp precisam estar no mesmo sistema de ficheiros"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "A ler as listas de pacotes"
 
@@ -1906,173 +1914,173 @@
 msgid "Write error"
 msgstr "Erro de escrita"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Não foi possível criar um socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Não foi possível ligar socket de dados, a ligação expirou"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Não foi possível ligar socket passivo."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo não foi capaz de obter um socket de escuta"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Não foi possível fazer o bind a um socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Não foi possível executar listen no socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Não foi possível determinar o nome do socket"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Não foi possível enviar o comando PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Família de endereços %u desconhecida (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT falhou, o servidor respondeu: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Ligação de socket de dados expirou"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Impossível aceitar ligação"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problema ao calcular o hash do ficheiro"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Não foi possível obter o ficheiro, o servidor respondeu '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Expirou o tempo do socket de dados"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "A transferência de dados falhou, o servidor respondeu '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Pesquisa"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Não foi possível invocar "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "A Ligar a %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Não foi possível criar um socket para %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Não posso iniciar a ligação para %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Não foi possível ligar a %s:%s (%s), a conexão expirou"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Não foi possível ligar em %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "A ligar a %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Não foi possível resolver '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Falha temporária a resolver '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Algo estranho aconteceu ao resolver '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Não foi possível ligar a %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "A abortar a instalação."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Erro interno: Assinatura válida, mas não foi possível determinar a impressão "
 "digital da chave?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Pelo menos uma assinatura inválida foi encontrada."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Não foi possível executar '%s' para verificar a assinatura (o gpgv está "
 "instalado?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Erro desconhecido ao executar gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "As seguintes assinaturas eram inválidas:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2151,19 +2159,19 @@
 msgid "Error reading from server"
 msgstr "Erro ao ler do servidor"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Falhou truncar o ficheiro"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Dados de cabeçalho errados"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "A ligação falhou"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Erro interno"
 
@@ -2229,7 +2237,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "A selecção %s não foi encontrada"
@@ -2354,6 +2362,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Impossível mudar para %s"
@@ -2540,7 +2549,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Falha escrever ficheiro temporário StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2678,7 +2687,7 @@
 "Não foi possível corrigir problemas, você tem pacotes mantidos (hold) "
 "estragados."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2729,12 +2738,12 @@
 msgstr ""
 "Por favor insira o disco denominado: '%s' no leitor '%s' e pressione enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Sistema de empacotamento '%s' não é suportado"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr ""
 "Não foi possível determinar um tipo de sistema de empacotamento adequado"
@@ -2748,27 +2757,27 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Você deve colocar alguns URIs 'source' no seu sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "As listas de pacotes ou o ficheiro de status não pôde ser analisado ou "
 "aberto."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Você terá que executar apt-get update para corrigir estes problemas"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Registro inválido no ficheiro de preferências, sem cabeçalho Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Não foi possível entender o tipo de marca (pin) %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Nenhuma prioridade (ou zero) especificada para marcação (pin)"
 
@@ -2863,34 +2872,59 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Não foi possível executar stat à lista de pacotes de código fonte %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "A obter File Provides"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Erro de I/O ao gravar a cache de código fonte"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "falhou renomear, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum não coincide"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Código de verificação hash não coincide"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Não existe qualquer chave pública disponível para as seguintes IDs de "
 "chave:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2900,7 +2934,7 @@
 "significar que você precisa corrigir manualmente este pacote. (devido a "
 "arquitectura em falta)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2909,7 +2943,7 @@
 "Não foi possível localizar arquivo para o pacote %s. Isto pode significar "
 "que você precisa consertar manualmente este pacote."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2917,25 +2951,35 @@
 "Os arquivos de índice de pacotes estão corrompidos. Nenhum campo Filename: "
 "para o pacote %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Tamanho incorrecto"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Não foi possível fazer parse ao ficheiro do pacote %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Note, a seleccionar %s em vez de %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Linha inválida no ficheiro de desvio: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Não foi possível fazer parse ao ficheiro do pacote %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3030,155 +3074,238 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "As entradas de listas de Source para este Disco são:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Escreveu %i registos.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Escreveu %i registos com %i ficheiros em falta.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Escreveu %i registos com %i ficheiros não coincidentes\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Escreveu %i registos com %i ficheiros em falta e %i ficheiros não "
 "coincidentes\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "A abrir o ficheiro de configuração %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Código de verificação hash não coincide"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Note, a seleccionar %s para a expressão regular '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Versão seleccionada %s (%s) para %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "A instalar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "A configurar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "A remover %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Remoção completa de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "A correr o 'trigger' de pós-instalação %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Falta o directório '%s'"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Não foi possível abrir ficheiro o %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "A preparar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "A desempacotar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "A preparar para configurar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s instalado"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "A preparar a remoção de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s removido"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "A preparar para remover completamente %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Remoção completa de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Não é possível escrever o registo (log), openpty() falhou (/dev/pts não está "
 "montado?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Impossível criar acesso exclusivo ao directório de listas"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3193,10 +3320,13 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Ligação encerrada prematuramente"
 
+#~ msgid "You must give exactly one pattern"
+#~ msgstr "Você deve dar exactamente um pattern"
+
 #~ msgid "E: Argument list from Acquire::gpgv::Options too long. Exiting."
 #~ msgstr ""
 #~ "E: A lista de argumentos de Acquire::gpgv::Options é demasiado longa. A "
@@ -3332,9 +3462,6 @@
 #~ msgid "Replaced file "
 #~ msgstr "Substitui"
 
-#~ msgid "You must give at least one file name"
-#~ msgstr "Você deve passar exatamente um padrão"
-
 #~ msgid "Regex compilation error"
 #~ msgstr "Erro de compilação de regex - %s"
 

=== modified file 'po/pt_BR.po'
--- po/pt_BR.po	2010-05-25 16:01:42 +0000
+++ po/pt_BR.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-17 02:33-0200\n"
 "Last-Translator: Felipe Augusto van de Wiel (faw) <faw@debian.org>\n"
 "Language-Team: Brazilian Portuguese <debian-l10n-portuguese@lists.debian."
@@ -16,149 +16,147 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "O pacote %s versão %s tem uma dependência desencontrada:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Impossível encontrar o pacote %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Total de Nomes de Pacotes: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Total de Nomes de Pacotes: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Pacotes normais: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Pacotes puramente virtuais: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Pacotes virtuais únicos: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Pacotes virtuais misturados: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Faltando: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Total de versões distintas: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Total de descrições distintas: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Total de dependências: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Total de relações ver/arquivo: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Total de relações Desc/Arquivo: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Total de mapeamentos \"Provides\": "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Total de strings \"globbed\": "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Total de espaço de dependência de versão: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Total de espaço frouxo: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Total de espaço contabilizado para: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "O arquivo de pacote %s está fora de sincronia."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Você deve passar exatamente um padrão"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Nenhum pacote encontrado"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Impossível encontrar o pacote %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Arquivos de pacote:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "O cache está fora de sincronia, não foi possível fazer a referência cruzada "
 "de um arquivo de pacote"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pacotes alfinetados (\"pinned\"):"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(não encontrado)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalado: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidato: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(nenhum)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Pacote alfinetado (\"pin\"): "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabela de versão:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s para %s compilado em %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -319,12 +317,12 @@
 "  -o=? Define uma opção de configuração arbitrária, e.g.: -o dir::cache=/"
 "tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Impossível escrever para %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Não foi possível obter a versão do debconf. O debconf está instalado?"
 
@@ -661,79 +659,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Falhou ao renomear %s para %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "S"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Erro de compilação de regex - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Os pacotes a seguir têm dependências desencontradas:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "mas %s está instalado"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "mas %s está para ser instalado"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "mas não é instalável"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "mas é um pacote virtual"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "mas não está instalado"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "mas não será instalado"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " ou"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Os NOVOS pacotes a seguir serão instalados:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Os pacotes a seguir serão REMOVIDOS:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Os pacotes a seguir serão mantidos em suas versões atuais:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Os pacotes a seguir serão atualizados:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Os pacotes a seguir serão REVERTIDOS:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Os seguintes pacotes mantidos serão mudados:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (por causa de %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -742,143 +740,143 @@
 "Isso NÃO deveria ser feito a menos que você saiba exatamente o que você está "
 "fazendo!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu pacotes atualizados, %lu pacotes novos instalados, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstalados, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu revertidos, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu a serem removidos e %lu não atualizados.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu pacotes não totalmente instalados ou removidos.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Corrigindo dependências..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " falhou."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Impossível corrigir dependências"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Impossível minimizar o conjunto de atualizações"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Pronto"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Você pode querer executar 'apt-get -f install' para corrigí-los."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dependências desencontradas. Tente usar -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "AVISO: Os pacotes a seguir não podem ser autenticados!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Aviso de autenticação sobreposto.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Instalar estes pacotes sem verificação [s/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Alguns pacotes não puderam ser autenticados"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Há problemas e -y foi usado sem --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Erro interno, InstallPackages foi chamado com pacotes quebrados!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Pacotes precisam ser removidos mas a remoção está desabilitada."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Erro interno, Ordenação não finalizou"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "A lista de fontes não pode ser lida."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Que estranho.. Os tamanhos não batem, mande e-mail para apt@packages.debian."
 "org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "É preciso baixar %sB/%sB de arquivos.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "É preciso baixar %sB de arquivos.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "Depois desta operação, %sB adicionais de espaço em disco serão usados.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Depois desta operação, %sB de espaço em disco serão liberados.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Não foi possível determinar o espaço livre em %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Você não possui espaço suficiente em %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "\"Trivial Only\" especificado mas esta não é uma operação trivial."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Sim, faça o que eu digo!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -889,28 +887,28 @@
 "Para continuar digite a frase '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Abortar."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Você quer continuar [S/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Falhou ao buscar %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Alguns arquivos falharam ao baixar"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Baixar completo e no modo somente baixar (\"download only\")"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -918,19 +916,19 @@
 "Impossível buscar alguns arquivos, talvez executar apt-get update ou tentar "
 "com --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing e troca de mídia não são suportados atualmente"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Impossível corrigir pacotes faltantes."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Abortando instalação."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -940,49 +938,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Nota, selecionando %s ao invés de %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Pulando %s, já está instalado e a atualização não está configurada.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Pulando %s, já está instalado e a atualização não está configurada.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "O pacote %s não está instalado, então não será removido\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "O pacote %s é um pacote virtual fornecido por:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Instalado]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versões candidatas"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Você deveria selecionar explicitamente um para instalar."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -993,65 +991,65 @@
 "Isto pode significar que o pacote está faltando, ficou obsoleto ou\n"
 "está disponível somente a partir de outra fonte\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "No entanto, os pacotes a seguir o substituem:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "O pacote %s não tem candidato para instalação"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "A reinstalação de %s não é possível, não pode ser baixado.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s já é a versão mais nova.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Release '%s' para '%s' não foi encontrada"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Versão '%s' para '%s' não foi encontrada"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Versão selecionada %s (%s) para %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Não foi possível executar \"stat\" na lista de pacotes fonte %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "O comando update não leva argumentos"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Nós não deveríamos apagar coisas, impossível iniciar AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1065,7 +1063,7 @@
 "Os seguintes pacotes foram automaticamente instalados e não são mais "
 "requeridos:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1077,11 +1075,11 @@
 "Os seguintes pacotes foram automaticamente instalados e não são mais "
 "requeridos:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Use 'apt-get autoremove' para removê-los."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1099,43 +1097,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "A informação a seguir pode ajudar a resolver a situação:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Erro Interno, o AutoRemover quebrou coisas"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Erro interno, AllUpgrade quebrou coisas"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Impossível achar tarefa %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Impossível achar pacote %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Nota, selecionando %s para expressão regular '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s configurado para instalar manualmente.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Você deve querer executar 'apt-get -f install' para corrigí-los:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1143,7 +1136,7 @@
 "Dependências desencontradas. Tente 'apt-get -f install' sem nenhum pacote "
 "(ou especifique uma solução)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1155,126 +1148,141 @@
 "distribuição instável, que alguns pacotes requeridos não foram\n"
 "criados ainda ou foram retirados da \"Incoming\"."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Pacotes quebrados"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Os pacotes extra a seguir serão instalados:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Pacotes sugeridos:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Pacotes recomendados:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s configurado para instalar manualmente.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Calculando atualização... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Falhou"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Pronto"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Erro interno, o solucionador de problemas quebrou coisas"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Impossível criar trava no diretório de download"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Deve-se especificar pelo menos um pacote para que se busque o fonte"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Impossível encontrar um pacote fonte para %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Pulando arquivo já baixado '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Você não possui espaço livre suficiente em %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Preciso obter %sB/%sB de arquivos fonte.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Preciso obter %sB de arquivos fonte.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Obter fonte %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Falhou ao buscar alguns arquivos."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Pulando o desempacotamento de fontes já desempacotados em %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Comando de desempacotamento '%s' falhou.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Confira se o pacote 'dpkg-dev' está instalado.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Comando de construção '%s' falhou.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Processo filho falhou"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Deve-se especificar pelo menos um pacote para que se cheque as dependências "
 "de construção"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Impossível conseguir informações de dependência de construção para %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s não tem dependências de construção.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1283,7 +1291,7 @@
 "a dependência de %s por %s não pode ser satisfeita porque o pacote %s não "
 "pode ser encontrado"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1292,32 +1300,32 @@
 "a dependência de %s por %s não pode ser satisfeita porque nenhuma versão "
 "disponível do pacote %s pode satisfazer os requerimentos de versão"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Falhou ao satisfazer a dependência de %s por %s: Pacote instalado %s é muito "
 "novo"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Falhou ao satisfazer a dependência de %s por %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Não foi possível satisfazer as dependências de compilação para %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Falhou ao processar as dependências de construção"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Módulos para os quais há suporte:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1659,8 +1667,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Impossível ler %s"
@@ -1689,10 +1698,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Os diretórios info e temp precisam estar no mesmo sistema de arquivos"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Lendo listas de pacotes"
 
@@ -1909,173 +1917,173 @@
 msgid "Write error"
 msgstr "Erro de escrita"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Não foi possível criar um socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Não foi possível conectar um socket de dados, conexão expirou"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Não foi possível conectar um socket passivo."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo não foi capaz de obter um socket de escuta"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Não foi possível fazer \"bind\" de um socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Não foi possível ouvir no socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Não foi possível determinar o nome do socket"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Impossível enviar o comando PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Família de endereços %u desconhecida (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT falhou, servidor disse: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Conexão do socket de dados expirou"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Impossível aceitar conexão"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problema criando o hash do arquivo"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Impossível obter arquivo, servidor disse '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Socket de dados expirou"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Transferência de dados falhou, servidor disse '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Pesquisa"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Impossível invocar "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Conectando em %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Não foi possível criar um socket para %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Não foi possível iniciar a conexão para %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Não foi possível conectar em %s:%s (%s), conexão expirou"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Não foi possível conectar em %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Conectando a %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Não foi possível resolver '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Falha temporária resolvendo '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Algo estranho aconteceu resolvendo '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Impossível conectar em %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Abortando instalação."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Erro interno: Assinatura boa, mas não foi possível determinar a impressão "
 "digital da chave?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Ao menos uma assinatura inválida foi encontrada."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Não foi possível executar '%s' para verificar a assinatura (o gpgv está "
 "instalado?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Erro desconhecido executando gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "As seguintes assinaturas eram inválidas:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2154,19 +2162,19 @@
 msgid "Error reading from server"
 msgstr "Erro lendo do servidor"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Falhou ao truncar arquivo"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Dados de cabeçalho ruins"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Conexão falhou"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Erro interno"
 
@@ -2232,7 +2240,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Seleção %s não encontrada"
@@ -2358,6 +2366,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Impossível mudar para %s"
@@ -2541,7 +2550,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Falha ao escrever Arquivo de Estado (\"StateFile\") temporário %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2682,7 +2691,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Impossível corrigir problemas, você manteve (hold) pacotes quebrados."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2733,12 +2742,12 @@
 msgstr ""
 "Por favor, insira o disco nomeado: '%s' na unidade '%s' e pressione enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Sistema de empacotamento '%s' não é suportado"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Impossível determinar um tipo de sistema de empacotamento aplicável."
 
@@ -2751,27 +2760,27 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Você deve colocar algumas URIs 'source' em seu sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "As listas de pacotes ou os arquivos de estado não puderam ser analisados ou "
 "abertos."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Você terá que executar apt-get update para corrigir estes problemas"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Registro inválido no arquivo de preferências, sem cabeçalho Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Não foi possível entender o tipo de \"pin\" %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Nenhuma prioridade (ou zero) especificada para \"pin\""
 
@@ -2866,32 +2875,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Não foi possível executar \"stat\" na lista de pacotes fonte %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Coletando Arquivo \"Provides\""
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Erro de E/S ao gravar cache fonte"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "renomeação falhou, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum incorreto"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash Sum incorreto"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Não existem chaves públicas para os seguintes IDs de chaves:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2901,7 +2935,7 @@
 "que você precisa consertar manualmente este pacote. (devido a arquitetura "
 "não especificada)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2910,7 +2944,7 @@
 "Não foi possível localizar arquivo para o pacote %s. Isto pode significar "
 "que você precisa consertar manualmente este pacote."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2918,25 +2952,35 @@
 "Os arquivos de índice de pacotes estão corrompidos. Nenhum campo \"Filename:"
 "\" para o pacote %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Tamanho incorreto"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Impossível analisar arquivo de pacote %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Nota, selecionando %s ao invés de %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Linha inválida no arquivo de desvios: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Impossível analisar arquivo de pacote %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3031,153 +3075,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Entradas na lista de fontes para este disco são:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Gravados %i registros.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Gravados %i registros com %i arquivos faltando.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Gravados %i registros com %i arquivos que não combinam\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Gravados %i registros com %i arquivos faltando e %i arquivos que não "
 "combinam\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Abrindo arquivo de configuração %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash Sum incorreto"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Nota, selecionando %s para expressão regular '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Versão selecionada %s (%s) para %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Instalando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Configurando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Removendo %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "%s completamente removido"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Executando gatilho pós-instalação %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Diretório '%s' está faltando"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Não foi possível abrir arquivo %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Preparando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Desempacotando %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Preparando para configurar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "%s instalado"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Preparando para a remoção de %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "%s removido"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Preparando para remover completamente %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s completamente removido"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "Impossível escrever log, openpty() falhou (/dev/pts não montado?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Impossível criar trava no diretório de listas"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3192,10 +3319,13 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Conexão encerrada prematuramente"
 
+#~ msgid "You must give exactly one pattern"
+#~ msgstr "Você deve passar exatamente um padrão"
+
 #~ msgid "E: Argument list from Acquire::gpgv::Options too long. Exiting."
 #~ msgstr ""
 #~ "E: Lista de argumentos de Acquire::gpgv::Options muito extensa. Saindo."
@@ -3305,9 +3435,6 @@
 #~ msgid "Replaced file "
 #~ msgstr "Substitui"
 
-#~ msgid "You must give at least one file name"
-#~ msgstr "Você deve passar exatamente um padrão"
-
 #~ msgid "Regex compilation error"
 #~ msgstr "Erro de compilação de regex - %s"
 

=== modified file 'po/ro.po'
--- po/ro.po	2010-05-25 16:01:42 +0000
+++ po/ro.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: ro\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-15 02:21+0200\n"
 "Last-Translator: Eddy Petrișor <eddy.petrisor@gmail.com>\n"
 "Language-Team: Romanian <debian-l10n-romanian@lists.debian.org>\n"
@@ -18,148 +18,146 @@
 "Plural-Forms:  nplurals=3; plural=n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < "
 "20)) ? 1 : 2;\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Pachetul %s versiunea %s are o dependență neîndeplinită:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Nu s-a putut localiza pachetul %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Total nume pachete : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Total nume pachete : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Pachete normale: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Pachete virtuale pure: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Pachete virtuale singulare: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Pachete virtuale mixte: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Lipsă: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Total versiuni distincte: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Numărul total de descrieri distincte: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Total dependențe: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Total relații versiune/fișier: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Total relații desc/fișier: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Total cartări Furnizează: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Total șiruri înglobate: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Total spațiu versiuni ale dependențelor: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Total spațiu intern: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Total spațiu contorizat pentru: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Fișierul pachetului %s este desincronizat."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Trebuie să dați exact un șablon"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Nu s-au găsit pachete"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Nu s-a putut localiza pachetul %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Fișiere pachet: "
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Cache-ul este desincronizat, nu se poate executa x-ref pe un fișier pachet"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pachete alese special:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(negăsit)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Instalat: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Candidează: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(niciunul)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Pachet ales special: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabela de versiuni:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s pentru %s compilat la %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -315,12 +313,12 @@
 "  -c=? Citește acest fișier de configurare\n"
 "  -o=? Ajustează o opțiune de configurare arbitrară, ex. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Nu s-a putut scrie în %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Nu s-a putut citi versiunea debconf. Este instalat debconf?"
 
@@ -663,79 +661,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Eșec la redenumirea lui %s în %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Eroare de compilare expresie regulată - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Următoarele pachete au dependențe neîndeplinite:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "dar %s este instalat"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "dar %s este pe cale de a fi instalat"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "dar nu este instalabil"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "dar este un pachet virtual"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "dar nu este instalat"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "dar nu este pe cale să fie instalat"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " sau"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Următoarele pachete NOI vor fi instalate:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Următoarele pachete vor fi ȘTERSE:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Următoarele pachete au fost reținute:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Următoarele pachete vor fi ÎNNOITE:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Următoarele pachete vor fi DE-GRADATE:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Următoarele pachete ținute vor fi schimbate:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (datorită %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -743,142 +741,142 @@
 "AVERTISMENT: Următoarele pachete esențiale vor fi șterse.\n"
 "Aceasta NU ar trebui făcută decât dacă știți exact ce vreți!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu înnoite, %lu nou instalate, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinstalate, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu de-gradate, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu de șters și %lu neînnoite.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu instalate sau șterse incomplet.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Corectez dependențele..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " eșec."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Nu s-au putut corecta dependențele"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Nu s-a putut micșora mulțimea pachetelor de înnoit"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Terminat"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Ați putea să porniți 'apt-get -f install' pentru a corecta acestea."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Dependențe neîndeplinite. Încercați să folosiți -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "AVERTISMENT: Următoarele pachete nu pot fi autentificate!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Avertisment de autentificare înlocuit.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Instalați aceste pachete fără verificare [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Unele pachete n-au putut fi autentificate"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Sunt unele probleme și -y a fost folosit fără --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Eroare internă, InstallPackages a fost apelat cu pachete deteriorate!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Pachete trebuiesc șterse dar ștergerea este dezactivată."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Eroare internă, Ordering nu s-a terminat"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Lista surselor nu poate fi citită."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Ce ciudat.. Dimensiunile nu se potrivesc, scrieți la apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Este nevoie să descărcați %sB/%sB de arhive.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Este nevoie să descărcați %sB de arhive.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "După această operație vor fi folosiți din disc încă %sB.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "După această operație se vor elibera %sB din spațiul ocupat pe disc.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "N-am putut determina spațiul disponibil în %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Nu aveți suficient spațiu în %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "A fost specificat 'doar neimportant' dar nu este o operațiune neimportantă."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Da, fă cum îți spun!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -889,28 +887,28 @@
 "Pentru a continua tastați fraza '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Renunțare."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Vreți să continuați [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Eșec la aducerea lui %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Descărcarea unor fișiere a eșuat"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Descărcare completă și în modul doar descărcare"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -918,19 +916,19 @@
 "Nu s-au putut aduce unele arhive, poate ar fi o idee bună să rulați 'apt-get "
 "update' sau încercați cu --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing și schimbul de mediu nu este deocamdată suportat"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Nu pot corecta pachetele lipsă."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Abandonez instalarea."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -941,49 +939,49 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Notă, se selectează %s în locul lui %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Sar peste %s, este deja instalat și înnoirea nu este activată.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Sar peste %s, este deja instalat și înnoirea nu este activată.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Pachetul %s nu este instalat, așa încât nu este șters\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Pachetul %s este un pachet virtual furnizat de către:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Instalat]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Versiuni candidat"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Ar trebui să alegeți în mod explicit unul pentru instalare."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -994,66 +992,66 @@
 "Aceasta ar putea însemna că pachetul lipsește, s-a învechit, sau\n"
 "este disponibil numai din altă sursă\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Oricum următoarele pachete îl înlocuiesc:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Pachetul %s nu are nici un candidat la instalare"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Reinstalarea lui %s nu este posibilă, nu poate fi descărcat.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s este deja la cea mai nouă versiune.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Release '%s' pentru '%s' n-a fost găsită"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Versiunea '%s' pentru '%s' n-a fost găsită"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Versiune selectată %s (%s) pentru %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Nu pot determina starea listei surse de pachete %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Comanda de actualizare nu are argumente"
 
 # XXX: orice sugestie este bine-venită
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Nu este voie să se șteargă lucruri, nu se poate porni AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1067,7 +1065,7 @@
 msgstr[2] ""
 "Următoarele pachete au fost instalate automat și nu mai sunt necesare:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1079,11 +1077,11 @@
 msgstr[2] ""
 "Următoarele pachete au fost instalate automat și nu mai sunt necesare:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Folosiți 'apt-get autoremove' pentru a le șterge."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1102,43 +1100,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Următoarele informații ar putea să vă ajute la rezolvarea situației:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Eroare internă, AutoRemover a deteriorat diverse chestiuni"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Eroare internă, înnoire totală a defectat diverse chestiuni"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Nu s-a putut găsi sarcina %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Nu pot găsi pachetul %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Notă, selectare %s pentru expresie regulată '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s este marcat ca fiind instalat manual.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Ați putea porni 'apt-get -f install' pentru a corecta acestea:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1146,7 +1139,7 @@
 "Dependențe neîndeplinite. Încercați 'apt-get -f install' fără nici un pachet "
 "(sau oferiți o altă soluție)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1159,127 +1152,142 @@
 "pachete\n"
 "cerute n-au fost create încă sau au fost mutate din Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Pachete deteriorate"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Următoarele extra pachete vor fi instalate:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Pachete sugerate:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Pachete recomandate:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s este marcat ca fiind instalat manual.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Calculez înnoirea... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Eșec"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Terminat"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr ""
 "Eroare internă, rezolvatorul de probleme a deteriorat diverse chestiuni"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Nu s-a putut bloca directorul de descărcare"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Trebuie specificat cel puțin un pachet pentru a-i aduce sursa"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Nu s-a putut găsi o sursă pachet pentru %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Sar peste fișierul deja descărcat '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Nu aveți suficient spațiu în %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Este nevoie să descărcați %sB/%sB din arhivele surselor.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Este nevoie să descărcați %sB din arhivele surselor.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Aducere sursa %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Eșec la aducerea unor arhive."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Sar peste despachetarea sursei deja despachetate în %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Comanda de despachetare '%s' eșuată.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Verificați dacă pachetul 'dpkg-dev' este instalat.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Comanda de construire '%s' eșuată.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Procesul copil a eșuat"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Trebuie specificat cel puțin un pachet pentru a-i verifica dependențele "
 "înglobate"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Nu pot prelua informațiile despre dependențele înglobate ale lui %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s nu are dependențe înglobate.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1288,7 +1296,7 @@
 "Dependența lui %s de %s nu poate fi satisfăcută deoarece pachetul %s nu "
 "poate fi găsit"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1297,32 +1305,32 @@
 "Dependența lui %s de %s nu poate fi satisfăcută deoarece nici o versiune "
 "disponibilă a pachetului %s nu poate satisface versiunile cerute"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Eșec la satisfacerea dependenței %s pentru %s: Pachetul instalat %s este "
 "prea nou"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Eșec la satisfacerea dependenței %s pentru %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Dependențele înglobate pentru %s nu pot fi satisfăcute."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Eșec la prelucrarea dependențelor de compilare"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Module suportate:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1665,8 +1673,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Nu s-a putut citi %s"
@@ -1695,10 +1704,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Directoarele info și temp trebuie să fie în același sistem de fișiere"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Citire liste de pachete"
 
@@ -1919,175 +1927,175 @@
 msgid "Write error"
 msgstr "Eroare de scriere"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Nu s-a putut crea un socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 "Nu s-a putut realiza conectarea la socket-ul de date, timpul de conectare a "
 "expirat"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Nu s-a putut realiza conectarea la un socket pasiv"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "„getaddrinfo” n-a reușit să obțină un socket de ascultare"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Nu s-a putut realiza asocierea la un socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Nu s-a putut asculta pe socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Nu s-a putut detecta numele socket-ului"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Nu s-a putut trimite comanda PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Familie de adrese necunoscută %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "„EPRT” a eșuat, serverul a spus: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Timpul de conectare la socket-ul de date expirat"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Nu s-a putut accepta conexiune"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problemă la calcularea dispersiei pentru fișierul"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Nu s-a putut aduce fișierul, serverul a spus „%s”"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Timp expirat pentru socket-ul de date"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Transferul de date a eșuat, serverul a spus: '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Interogare"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Nu s-a putut invoca"
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Conectare la %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Nu s-a putut crea un socket pentru %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Nu s-a putut iniția conexiunea cu %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr ""
 "Nu s-a putut realiza conexiunea cu %s:%s (%s), timpul de conectare expirat"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Nu s-a putut realiza conexiunea cu %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Conectare la %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nu s-a putut rezolva „%s”"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Eșec temporar la rezolvarea lui „%s”"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "S-a întâmplat ceva „necurat” la rezolvarea lui „%s:%s” (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Nu s-a putut realiza conexiunea cu %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Abandonez instalarea."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Eroare internă: Semnătură corespunzătoare, dar nu s-a putut determina "
 "amprenta digitale a cheii?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Cel puțin o semnătură nevalidă a fost întâlnită."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Nu s-a putut executa „%s” pentru verificarea semnăturii (gpgv este instalat?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Eroare necunoscută în timp ce se execută gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Următoarele semnături nu au fost valide:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2167,19 +2175,19 @@
 msgid "Error reading from server"
 msgstr "Eroare la citirea de la server"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Eșec la trunchierea fișierului"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Antet de date necorespunzător"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Conectare eșuată"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Eroare internă"
 
@@ -2245,7 +2253,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Selecția %s nu a fost găsită"
@@ -2371,6 +2379,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Nu pot schimba la %s"
@@ -2554,7 +2563,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Eșec la scrierea fișierului temporar de stare %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2689,7 +2698,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Nu pot corecta problema, ați ținut pachete deteriorate."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2740,12 +2749,12 @@
 msgstr ""
 "Vă rog introduceți discul numit: '%s' în unitatea '%s' și apăsați Enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Sistemul de pachete '%s' nu este suportat"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Nu s-a putut determina un tip de sistem de împachetare potrivit"
 
@@ -2758,28 +2767,28 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Trebuie să puneți niște 'surse' de URI în sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Listele de pachete sau fișierul de stare n-au putut fi analizate sau "
 "deschise."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Ați putea vrea să porniți 'apt-get update' pentru a corecta aceste probleme."
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Înregistrare invalidă în fișierul de preferințe, fără antet de pachet"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Nu s-a înțeles tipul de pin %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Fără prioritate (sau zero) specificată pentru pin"
 
@@ -2874,34 +2883,59 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Nu pot determina starea listei surse de pachete %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Colectare furnizori fișier"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Eroare IO în timpul salvării sursei cache"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "redenumire eșuată, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Nepotrivire MD5Sum"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Nepotrivire la suma de căutare"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 "Nu există nici o cheie publică disponibilă pentru următoarele "
 "identificatoare de chei:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2910,7 +2944,7 @@
 "N-am putut localiza un fișier pentru pachetul %s. Aceasta ar putea însemna "
 "că aveți nevoie să reparați manual acest pachet (din pricina unui arch lipsă)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2919,7 +2953,7 @@
 "N-am putut localiza un fișier pentru pachetul %s. Aceasta ar putea însemna "
 "că aveți nevoie să depanați manual acest pachet."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2927,25 +2961,35 @@
 "Fișierele index de pachete sunt deteriorate. Fără câmpul 'nume fișier:' la "
 "pachetul %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Nepotrivire dimensiune"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Nu s-a putut analiza fișierul pachet %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Notă, se selectează %s în locul lui %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Linie necorespunzătoare în fișierul-redirectare: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Nu s-a putut analiza fișierul pachet %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3041,153 +3085,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Intrările listei surselor pentru acest disc sunt:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "S-au scris %i înregistrări.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "S-au scris %i înregistrări cu %i fișiere lipsă.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "S-au scris %i înregistrări cu %i fișiere nepotrivite\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "S-au scris %i înregistrări cu %i fișiere lipsă și %i fișiere nepotrivite\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Se deschide fișierul de configurare %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Nepotrivire la suma de căutare"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Notă, selectare %s pentru expresie regulată '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Versiune selectată %s (%s) pentru %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Se instalează %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Se configurează %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Se șterge %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Șters complet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Se rulează declanșatorul post-instalare %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Directorul „%s” lipsește."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Nu s-a putut deschide fișierul %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Se pregătește %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Se despachetează %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Se pregătește configurarea %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Instalat %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Se pregătește ștergerea lui %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Șters %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Se pregătește ștergerea completă a %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Șters complet %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Nu se poate scrie jurnalul, openpty() a eșuat (oare /dev/pts e montat?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Nu pot încuia directorul cu lista"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3202,7 +3329,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Conexiune închisă prematur"
 

=== modified file 'po/ru.po'
--- po/ru.po	2010-05-25 16:01:42 +0000
+++ po/ru.po	2010-06-10 14:02:22 +0000
@@ -13,7 +13,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.25\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2010-01-08 09:47+0300\n"
 "Last-Translator: Yuri Kozlov <yuray@komyakino.ru>\n"
 "Language-Team: Russian <debian-l10n-russian@lists.debian.org>\n"
@@ -25,147 +25,145 @@
 "10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);\n"
 "10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Пакет %s версии %s имеет неудовлетворённую зависимость:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Не удалось найти пакет %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Всего имён пакетов : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Всего имён пакетов : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Обычных пакетов: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Полностью виртуальных пакетов: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Одиночных виртуальных пакетов: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Смешанных виртуальных пакетов: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Отсутствует: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Всего уникальных версий: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Всего уникальных описаний: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Всего зависимостей: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Всего отношений Версия/Файл: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Всего отношений Описание/Файл: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Всего отношений Provides: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Всего развёрнутых строк: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Всего информации о зависимостях: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Пустого места в кэше: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Полное учтённое пространство: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Список пакетов %s рассинхронизирован."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Вы должны задать только один шаблон"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Не найдено ни одного пакета"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Не удалось найти пакет %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Списки пакетов:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Кэш рассинхронизирован, невозможно обнаружить ссылку на список пакетов"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Зафиксированные пакеты:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(не найдено)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Установлен: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Кандидат: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(отсутствует)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Фиксатор пакета: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Таблица версий:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s для %s скомпилирован %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -317,12 +315,12 @@
 "  -c=? Читать указанный файл настройки\n"
 "  -o=? Задать значение произвольной настройке, например, -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Невозможно записать в %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Невозможно определить версию debconf. Он установлен?"
 
@@ -665,80 +663,80 @@
 msgid "Failed to rename %s to %s"
 msgstr "Не удалось переименовать %s в %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "д"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Ошибка компиляции регулярного выражения - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Пакеты, имеющие неудовлетворённые зависимости:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "но %s уже установлен"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "но %s будет установлен"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "но он не может быть установлен"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "но это виртуальный пакет"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "но он не установлен"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "но он не будет установлен"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " или"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "НОВЫЕ пакеты, которые будут установлены:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Пакеты, которые будут УДАЛЕНЫ:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Пакеты, которые будут оставлены в неизменном виде:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Пакеты, которые будут обновлены:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Пакеты, будут заменены на более СТАРЫЕ версии:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr ""
 "Пакеты, которые должны были бы остаться без изменений, но будут заменены:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (вследствие %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -746,150 +744,150 @@
 "ВНИМАНИЕ: Эти существенно важные пакеты будут удалены.\n"
 "НЕ ДЕЛАЙТЕ этого, если вы НЕ представляете себе все возможные последствия!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "обновлено %lu, установлено %lu новых пакетов, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "переустановлено %lu переустановлено, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu пакетов заменены на старые версии, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "для удаления отмечено %lu пакетов, и %lu пакетов не обновлено.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "не установлено до конца или удалено %lu пакетов.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Исправление зависимостей..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " не удалось."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Невозможно скорректировать зависимости"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Невозможно минимизировать набор обновлений"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Готово"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 "Возможно, для исправления этих ошибок вы захотите воспользоваться `apt-get -"
 "f install'."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Неудовлетворённые зависимости. Попытайтесь использовать -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "ВНИМАНИЕ: Следующие пакеты невозможно аутентифицировать!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Предупреждение об аутентификации не принято в внимание.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Установить эти пакеты без проверки [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Некоторые пакеты невозможно аутентифицировать"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Существуют проблемы, а параметр -y указан без --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 "Внутренняя ошибка, InstallPackages была вызвана с неработоспособными "
 "пакетами!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Пакеты необходимо удалить, но удаление запрещено."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Внутренняя ошибка, Ordering не завершилась"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Не читается перечень источников."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "Странно.. Несовпадение размеров, напишите на apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Необходимо скачать %sB/%sB архивов.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Необходимо скачать %sБ архивов.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "После данной операции, объём занятого дискового пространства возрастёт на %"
 "sB.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr ""
 "После данной операции, объём занятого дискового пространства уменьшится на %"
 "sB.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Не удалось определить количество свободного места в %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Недостаточно свободного места в %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "Запрошено выполнение только тривиальных операций, но это не тривиальная "
 "операция."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Да, делать, как я скажу!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -900,28 +898,28 @@
 "Чтобы продолжить, введите фразу: '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Аварийное завершение."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Хотите продолжить [Д/н]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Не удалось получить %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Некоторые файлы скачать не удалось"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Указан режим \"только скачивание\", и скачивание завершено"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -929,19 +927,19 @@
 "Невозможно получить некоторые архивы, вероятно надо запустить apt-get update "
 "или попытаться повторить запуск с ключом --fix-missing"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing и смена носителя в данный момент не поддерживаются"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Невозможно исправить ситуацию с пропущенными пакетами."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Аварийное завершение установки."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -952,49 +950,49 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Заметьте, вместо %2$s выбирается %1$s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Пропускается %s - пакет уже установлен и нет команды upgrade.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Пропускается %s - пакет уже установлен и нет команды upgrade.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Пакет %s не установлен, поэтому не может быть удалён\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Пакет %s - виртуальный, его функции предоставляются пакетами:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Установлен]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Версии-кандидаты"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Вы должны явно указать, какой именно вы хотите установить."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -1005,65 +1003,65 @@
 "Это может означать, что пакет отсутствует, устарел, или доступен из "
 "источников, не упомянутых в sources.list\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Однако следующие пакеты могут его заменить:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Для пакета %s не найдены кандидаты на установку"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Переустановка %s невозможна, он не скачивается.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "Уже установлена самая новая версия %s.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Выпуск '%s' для '%s' не найден"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Версия '%s' для '%s' не найдена"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Выбрана версия %s (%s) для %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr "Игнорируется недоступный выпуск '%s' пакета '%s'"
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Используется '%s' в качестве исходного пакета вместо '%s'\n"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr "Игнорируется недоступная версия '%s' пакета '%s'"
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Команде update не нужны аргументы"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Не предполагалось удалять stuff, невозможно запустить AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1077,7 +1075,7 @@
 msgstr[2] ""
 "Следующие пакеты устанавливались автоматически и больше не требуются:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1086,11 +1084,11 @@
 msgstr[1] "%lu пакетов было установлены автоматически и больше не требуются.\n"
 msgstr[2] "%lu пакетов было установлены автоматически и больше не требуются.\n"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Для их удаления используйте 'apt-get autoremove'."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1108,45 +1106,40 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Следующая информация, возможно, поможет вам:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Внутренняя ошибка, AutoRemover всё поломал"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Внутренняя ошибка, AllUpgrade всё поломал"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Не удалось найти задачу %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Не удалось найти пакет %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Заметьте, выбирается %s из-за регулярного выражения %s\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s установлен вручную.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 "Возможно, для исправления этих ошибок вы захотите воспользоваться `apt-get -"
 "f install':"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1154,7 +1147,7 @@
 "Неудовлетворённые зависимости. Попытайтесь выполнить 'apt-get -f install', "
 "не указывая имени пакета, (или найдите другое решение)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1165,127 +1158,142 @@
 "или же используете нестабильную версию дистрибутива, где запрошенные вами\n"
 "пакеты ещё не созданы или были удалены из Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Сломанные пакеты"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Будут установлены следующие дополнительные пакеты:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Предлагаемые пакеты:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Рекомендуемые пакеты:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s установлен вручную.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Расчёт обновлений... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Неудачно"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Готово"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Внутренняя ошибка, решатель проблем всё поломал"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Невозможно заблокировать каталог, куда складываются скачиваемые файлы"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "Укажите как минимум один пакет, исходный код которого необходимо получить"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Невозможно найти пакет с исходным кодом для %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Пропускаем уже скачанный файл '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Недостаточно места в %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Необходимо получить %sб/%sб архивов исходного кода.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Необходимо получить %sб архивов исходного кода.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Получение исходного кода %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Некоторые архивы не удалось получить."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Пропускается распаковка уже распакованного исходного кода в %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Команда распаковки '%s' завершилась неудачно.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Проверьте, установлен ли пакет 'dpkg-dev'.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Команда сборки '%s' завершилась неудачно.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Порождённый процесс завершился неудачно"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Для проверки зависимостей для сборки необходимо указать как минимум один "
 "пакет"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Невозможно получить информацию о зависимостях для сборки %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s не имеет зависимостей для сборки.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1294,7 +1302,7 @@
 "Зависимость типа %s для %s не может быть удовлетворена, так как пакет %s не "
 "найден"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1303,32 +1311,32 @@
 "Зависимость типа %s для %s не может быть удовлетворена, поскольку ни одна из "
 "версий пакета %s не удовлетворяет требованиям"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Не удалось удовлетворить зависимость типа %s для пакета %s: Установленный "
 "пакет %s новее, чем надо"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Невозможно удовлетворить зависимость типа %s для пакета %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Зависимости для сборки %s не могут быть удовлетворены."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Обработка зависимостей для сборки завершилась неудачно"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Поддерживаемые модули:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1672,8 +1680,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Невозможно прочитать %s"
@@ -1702,10 +1711,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Каталоги info и temp должны находиться на одной файловой системе"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Чтение списков пакетов"
 
@@ -1924,173 +1932,173 @@
 msgid "Write error"
 msgstr "Ошибка записи"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Не удалось создать сокет"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr ""
 "Не удалось присоединиться к сокету данных, время на установление соединения "
 "истекло"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Невозможно присоединить пассивный сокет"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "Вызов getaddrinfo не смог получить сокет"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Невозможно присоединиться к сокету"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Не удалось принимать соединения на сокете"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Не удалось определить имя сокета"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Невозможно послать команду PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Неизвестное семейство адресов %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Команда EPRT не выполнена, сервер сообщил: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Время установления соединения для сокета данных истекло"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Невозможно принять соединение"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Проблема при хешировании файла"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Невозможно получить файл, сервер сообщил: '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Время ожидания соединения для сокета данных истекло"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Передача данных завершилась неудачно, сервер сообщил: '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Запрос"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Невозможно вызвать "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Соединение с %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Не удаётся создать сокет для %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Невозможно инициализировать соединение с %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Не удаётся соединиться с %s:%s (%s), connection timed out"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Не удаётся соединиться с %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Соединение с %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Не удалось найти IP адрес для %s"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Временная ошибка при попытке получить IP адрес '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Что-то странное произошло при определении '%s:%s' (%i - %s)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Невозможно соединиться с %s: %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Аварийное завершение установки."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Внутренняя ошибка: Правильная подпись, но не удалось определить отпечаток "
 "ключа?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Найдена как минимум одна неправильная подпись."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "Не удалось выполнить '%s' для проверки подписи (gpgv установлена?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Неизвестная ошибка при выполнении gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Следующие подписи неверные:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2169,19 +2177,19 @@
 msgid "Error reading from server"
 msgstr "Ошибка чтения с сервера"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Не удалось обрезать файл"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Неверный заголовок данных"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Соединение разорвано"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Внутренняя ошибка"
 
@@ -2249,7 +2257,7 @@
 msgid "%lis"
 msgstr "%liс"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Не найдено: %s"
@@ -2376,6 +2384,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Невозможно сменить текущий каталог на %s"
@@ -2565,7 +2574,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Не удалось записать временный StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2707,7 +2716,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Невозможно исправить ошибки, у вас отложены (held) битые пакеты."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2757,12 +2766,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Вставьте диск с меткой '%s' в устройство '%s' и нажмите ввод."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Менеджер пакетов '%s' не поддерживается"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Невозможно определить подходящий тип менеджера пакетов"
 
@@ -2775,25 +2784,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Вы должны заполнить sources.list, поместив туда URI источников пактов"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Списки пакетов или status-файл не могут быть открыты или прочитаны."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Вы можете запустить 'apt-get update' для исправления этих ошибок"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Неверная запись в файле параметров %s: отсутствует заголовок Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Неизвестный тип фиксации %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Для фиксации не указан приоритет (или указан нулевой)"
 
@@ -2883,32 +2892,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Не удалось получить атрибуты списка пакетов исходного кода %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Сбор информации о Provides"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Ошибка ввода/вывода при попытке сохранить кэш источников"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "переименовать не удалось, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum не совпадает"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Хеш сумма не совпадает"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Недоступен открытый ключ для следующих ID ключей:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2917,7 +2951,7 @@
 "Не удалось обнаружить файл пакета %s. Это может означать, что вам придётся "
 "вручную исправить этот пакет (возможно, пропущен arch)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2926,31 +2960,41 @@
 "Не удалось обнаружить файл пакета %s. Это может означать, что вам придётся "
 "вручную исправить этот пакет."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "Некорректный перечень пакетов. Нет поля Filename: для пакета %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Не совпадает размер"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Невозможно разобрать содержимое файла Release (%s)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "Отсутствуют разделы в файле Release (%s)"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "Отсутствуют элементы Hash в файле Release (%s)"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Отсутствуют элементы Hash в файле Release (%s)"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Отсутствуют элементы Hash в файле Release (%s)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3047,134 +3091,203 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Записи в списке источников для этого диска:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Сохранено %i записей.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Сохранено %i записей с %i отсутствующими файлами.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Сохранено %i записей с %i несовпадающими файлами\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Сохранено %i записей с %i отсутствующими файлами и с %i несовпадающими "
 "файлами\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Пропускается несуществующий файл %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr "Не удалось найти аутентификационную запись для: %s"
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Не совпадает хеш сумма для: %s"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Заметьте, выбирается %s из-за регулярного выражения %s\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Выбрана версия %s (%s) для %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Устанавливается %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Настройка %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Удаление %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, c-format
 msgid "Completely removing %s"
 msgstr "Выполняется полное удаление %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Выполняется послеустановочный триггер %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Отсутствует каталог %s"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Не удалось открыть файл %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Подготавливается %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Распаковывается %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Подготавливается для настройки %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Установлен %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Подготавливается для удаления %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Удалён %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Подготовка к полному удалению %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "%s полностью удалён"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Не удалось записать в журнал, неудачное выполнение openpty() (/dev/pts не "
 "смонтирован?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr "Запускается dpkg"
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
@@ -3183,25 +3296,39 @@
 "Не удалось выполнить блокировку управляющего каталога (%s); он уже "
 "используется другим процессом?"
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr ""
 "Не удалось выполнить блокировку управляющего каталога (%s); у вас есть права "
 "суперпользователя?"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, fuzzy, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 "Работа dpkg прервана, вы должны вручную запустить 'dpkg --configure -a' для "
 "устранения проблемы. "
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "Не заблокирован"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3220,7 +3347,7 @@
 "Не удалось наложить заплату %s с использованием mmap (но не из-за mmap) -- "
 "вероятно, повреждена заплата."
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Соединение закрыто преждевременно"
 

=== modified file 'po/sk.po'
--- po/sk.po	2010-05-25 16:01:42 +0000
+++ po/sk.po	2010-06-10 14:02:22 +0000
@@ -10,7 +10,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2010-05-11 10:22+0100\n"
 "Last-Translator: Ivan Masár <helix84@centrum.sk>\n"
 "Language-Team: Slovak <sk-i18n@lists.linux.sk>\n"
@@ -19,147 +19,145 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=((n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2);\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Balík %s verzie %s má nesplnené závislosti:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Nedá sa nájsť balík %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Celkom názvov balíkov: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Celkom názvov balíkov: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normálnych balíkov: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Čisto virtuálnych balíkov: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Jednoduchých virtuálnych balíkov: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Zmiešaných virtuálnych balíkov: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Chýbajúcich: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Celkom rôznych verzií: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Celkom rôznych popisov: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Celkom závislostí: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Celkom vzťahov ver/súbor: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Celkom vzťahov popis/súbor: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Celkom poskytnutých mapovaní: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Celkom globovaných reťazcov: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Celkom miesta závislých verzií: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Celkom jalového miesta: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Celkom priradeného miesta: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Súbor balíkov %s je neaktuálny."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Musíte zadať práve jeden vzor"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Neboli nájdené žiadne balíky"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Nedá sa nájsť balík %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Súbory balíka:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Vyrovnávacia pamäť je neaktuálna, nedá sa odvolať na súbor balíka"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pripevnené balíky:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(nenájdené)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Nainštalovaná verzia: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidát: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(žiadna)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Pripevnený balík:"
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Tabuľka verzií:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s pre %s skompilovaný %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -313,12 +311,12 @@
 "  -c=? Načíta tento konfiguračný súbor\n"
 "  -o=? Nastaví ľubovoľnú voľbu, napr. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Do %s sa nedá zapisovať"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Nedá sa určiť verzia programu debconf. Je debconf nainštalovaný?"
 
@@ -652,79 +650,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Premenovanie %s na %s zlyhalo"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Chyba pri preklade regulárneho výrazu - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Nasledovné balíky majú nesplnené závislosti:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "ale nainštalovaný je %s"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "ale inštalovať sa bude %s"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ale sa nedá nainštalovať"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ale je to virtuálny balík"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ale nie je nainštalovaný"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "ale sa nebude inštalovať"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " alebo"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Nainštalujú sa nasledovné NOVÉ balíky:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Nasledovné balíky sa ODSTRÁNIA:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Nasledovné balíky sa ponechajú v súčasnej verzii:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Nasledovné balíky sa aktualizujú:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Nasledovné balíky sa DEGRADUJÚ:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Nasledovné pridržané balíky sa zmenia:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (kvôli %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -732,143 +730,143 @@
 "UPOZORNENIE: Nasledovné dôležité balíky sa odstránia.\n"
 "Ak presne neviete, čo robíte, tak to NEROBTE!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu aktualizovaných, %lu nových nainštalovaných, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu reinštalovaných, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu degradovaných, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu na odstránenie a %lu neaktualizovaných.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu iba čiastočne nainštalovaných alebo odstránených.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Opravujú sa závislosti..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " zlyhalo."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Závislosti sa nedajú opraviť"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Sada na aktualizáciu sa nedá minimalizovať"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Hotovo"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 #, fuzzy
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Opravu môžete spustiť pomocu „apt-get -f install“."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Nesplnené závislosti. Skúste použiť -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "UPOZORNENIE: Pri nasledovných balíkoch sa nedá overiť vierohodnosť!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Upozornenie o vierohodnosti bolo potlačené.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Nainštalovať tieto nekontrolované balíky [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Nedala sa zistiť vierohodnosť niektorých balíkov"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Nastali problémy a -y bolo použité bez --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Vnútorná chyba, InstallPackages bolo volané s poškodenými balíkmi!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Je potrebné odstránenie balíka, ale funkcia Odstrániť je vypnutá."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Vnútorná chyba, Triedenie sa neukončilo"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Nedá sa načítať zoznam zdrojov."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Nezvyčajná udalosť... Veľkosti nesúhlasia, pošlite e-mail na apt@packages."
 "debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Je potrebné stiahnuť %sB/%sB archívov.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Je potrebné stiahnuť %sB archívov.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Po tejto operácii sa na disku použije ďalších %sB.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Po tejto operácii sa na disku uvoľní %sB.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Na %s sa nedá zistiť veľkosť voľného miesta"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Na %s nemáte dostatok voľného miesta."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Zadané „iba triviálne“, ale toto nie je triviálna operácia."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Áno, urob to, čo vravím!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -879,28 +877,28 @@
 "Ak chcete pokračovať, opíšte frázu „%s“\n"
 " ?]"
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Prerušené."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Chcete pokračovať [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Zlyhalo stiahnutie %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Niektoré súbory sa nedajú stiahnuť"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Sťahovanie ukončené v režime „iba stiahnuť“"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -908,19 +906,19 @@
 "Niektoré archívy sa nedajú stiahnuť. Skúste spustiť apt-get update alebo --"
 "fix-missing"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing a výmena nosiča nie sú momentálne podporované"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Chýbajúce balíky sa nedajú opraviť."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Inštalácia sa prerušuje."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -931,49 +929,49 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Poznámka: %s sa vyberá namiesto %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Preskakuje sa %s, pretože je už nainštalovaný.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Preskakuje sa %s, pretože je už nainštalovaný.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Balík %s nie je nainštalovaný, nedá sa teda odstrániť\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Balík %s je virtuálny balík poskytovaný balíkmi:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Nainštalovaný]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Kandidátske verzie"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Mali by ste explicitne vybrať jeden na inštaláciu."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -983,65 +981,65 @@
 "Balík %s nie je dostupný, ale odkazuje naň iný balík. Možno to znamená,\n"
 "že balík chýba, bol zrušený alebo je dostupný iba z iného zdroja\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Avšak nahrádzajú ho nasledovné balíky:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Balík %s nemá kandidáta na inštaláciu"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Nie je možná reinštalácia %s, pretože sa nedá stiahnuť.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s je už najnovšej verzie.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Nebolo nájdené vydanie „%s“ pre „%s“"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Nebola nájdená verzia „%s“ pre „%s“"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Zvolená verzia %s (%s) pre %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr "Ignorovať nedostupné cieľové vydanie „%s“ balíka „%s“"
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Vyberá sa „%s“ ako zdrojový balík namiesto „%s“\n"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr "Ignorovať nedostupnú verziu „%s“ balíka „%s“"
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Príkaz update neprijíma žiadne argumenty"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Nemajú sa odstraňovať veci, nespustí sa AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1055,7 +1053,7 @@
 msgstr[2] ""
 "Nasledovné balíky boli nainštalované automaticky a už viac nie sú potrebné:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1067,11 +1065,11 @@
 msgstr[2] ""
 "%lu balíkov bolo nainštalovaných automaticky a už viac nie sú potrebné.\n"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Na ich odstránenie použite „apt-get autoremove“."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1089,44 +1087,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Nasledovné informácie vám možno pomôžu vyriešiť túto situáciu:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Vnútorná chyba, AutoRemover niečo pokazil"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Vnútorná chyba, AllUpgrade pokazil veci"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Nebolo možné nájsť úlohu %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Balík %s sa nedá nájsť"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Poznámka: vyberá sa %s pre regulárny výraz „%s“\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s je nastavený na manuálnu inštaláciu.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 #, fuzzy
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Na opravu nasledovných môžete spustiť „apt-get -f install“:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1134,7 +1127,7 @@
 "Nesplnené závislosti. Skúste spustiť „apt-get -f install“ bez balíkov (alebo "
 "navrhnite riešenie)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1146,133 +1139,148 @@
 "požadované balíky ešte neboli vytvorené alebo presunuté z fronty\n"
 "Novoprichádzajúcich (Incoming) balíkov."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Poškodené balíky"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Nainštalujú sa nasledovné extra balíky:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Navrhované balíky:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Odporúčané balíky:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s je nastavený na manuálnu inštaláciu.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Prepočítava sa aktualizácia... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Chyba"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Hotovo"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Vnútorná chyba, „problem resolver“ niečo pokazil"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Adresár pre sťahovanie sa nedá zamknúť"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Musíte zadať aspoň jeden balík, pre ktorý sa stiahnu zdrojové texty"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Nedá sa nájsť zdrojový balík pre %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Preskakuje sa už stiahnutý súbor „%s“\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Na %s nemáte dostatok voľného miesta"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Je potrebné stiahnuť %sB/%sB zdrojových archívov.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Je potrebné stiahnuť %sB zdrojových archívov.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Stiahnuť zdroj %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Zlyhalo stiahnutie niektorých archívov."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Preskakuje sa rozbalenie už rozbaleného zdroja v %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Príkaz na rozbalenie „%s“ zlyhal.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Skontrolujte, či je nainštalovaný balík „dpkg-dev“.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Príkaz na zostavenie „%s“ zlyhal.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Proces potomka zlyhal"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Musíte zadať aspoň jeden balík, pre ktorý sa budú overovať závislosti na "
 "zostavenie"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Nedajú sa získať závislosti na zostavenie %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s nemá žiadne závislosti na zostavenie.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "%s závislosť pre %s sa nemôže splniť, pretože sa nedá nájsť balík %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1281,31 +1289,31 @@
 "%s závislosť pre %s sa nedá splniť, pretože sa nedá nájsť verzia balíka %s, "
 "ktorá zodpovedá požiadavke na verziu"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Zlyhalo splnenie %s závislosti pre %s: Inštalovaný balík %s je príliš nový"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Zlyhalo splnenie %s závislosti pre %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Závislosti na zostavenie %s sa nedajú splniť."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Spracovanie závislostí na zostavenie zlyhalo"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Podporované moduly:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1643,8 +1651,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Nedá sa načítať %s"
@@ -1673,10 +1682,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Adresáre info a temp musia byť na tom istom súborovom systéme"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Načítavajú sa zoznamy balíkov"
 
@@ -1892,169 +1900,169 @@
 msgid "Write error"
 msgstr "Chyba pri zápise"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Nedá sa vytvoriť socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Nedá sa pripojiť dátový socket, uplynul čas spojenia"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Nedá sa pripojiť pasívny socket."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo nezískal počúvajúci socket"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Nedá sa nadviazať socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Na sockete sa nedá počúvať"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Názov socketu sa nedá zistiť"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Príkaz PORT sa nedá odoslať"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Neznáma rodina adries %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Zlyhalo zadanie EPRT, server odpovedal: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Uplynulo spojenie dátového socketu"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Spojenie sa nedá prijať"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problém s hašovaním súboru"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Súbor sa nedá stiahnuť, server odpovedal „%s“"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Uplynula doba dátového socketu"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Prenos dát zlyhal, server odpovedal „%s“"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Dotaz"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Nedá sa vyvolať "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Pripája sa k %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Nedá sa vytvoriť socket pre %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Nedá sa nadviazať spojenie na %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Nedá sa pripojiť k %s:%s (%s), uplynul čas spojenia"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Nedá sa pripojiť k %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Pripája sa k %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Nie je možné preložiť „%s“"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Dočasné zlyhanie pri preklade „%s“"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Niečo veľmi zlé sa prihodilo pri preklade „%s:%s“ (%i - %s)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Nedá sa pripojiť k %s:%s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, c-format
 msgid "No keyring installed in %s."
 msgstr "V %s nie je nainštalovaný žiaden zväzok kľúčov."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "Vnútorná chyba: Správna signatúra, ale sa nedá zistiť odtlačok kľúča?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Bola zistená aspoň jedna nesprávna signatúra."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "Nedá sa spustiť „%s“ na kontrolu signatúry (je nainštalované gpgv?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Neznáma chyba pri spustení gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Nasledovné signatúry sú neplatné:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2133,19 +2141,19 @@
 msgid "Error reading from server"
 msgstr "Chyba pri čítaní zo servera"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Nepodarilo sa skrátiť súbor"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Zlé dátové záhlavie"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Spojenie zlyhalo"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Vnútorná chyba"
 
@@ -2213,7 +2221,7 @@
 msgid "%lis"
 msgstr "%li s"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Voľba %s nenájdená"
@@ -2338,6 +2346,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Nedá sa prejsť do %s"
@@ -2521,7 +2530,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Nie je možné zapísať dočasný StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2658,7 +2667,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Problémy sa nedajú opraviť, niektoré balíky držíte v poškodenom stave."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2708,12 +2717,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Vložte disk nazvaný „%s“ do mechaniky „%s“ a stlačte Enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Systém balíkov „%s“ nie je podporovaný"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Nedá sa určiť vhodný typ systému balíkov"
 
@@ -2726,25 +2735,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Do sources.list musíte zadať nejaký „source“ (zdrojový) URI"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Zoznamy balíkov alebo stavový súbor sa nedajú spracovať alebo otvoriť."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Na opravu týchto problémov môžete skúsiť spustiť apt-get update"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Neplatný záznam v súbore nastavení %s, chýba hlavička Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Nezrozumiteľné pridržanie typu %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Nebola zadaná žiadna (alebo nulová) priorita na pridržanie"
 
@@ -2835,32 +2844,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Nedá sa vyhodnotiť zoznam zdrojových balíkov %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Collecting File poskytuje"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "V/V chyba pri ukladaní zdrojovej vyrovnávacej pamäti"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "premenovanie zlyhalo, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Nezhoda kontrolných MD5 súčtov"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Nezhoda kontrolných haš súčtov"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Nie sú dostupné žiadne verejné kľúče ku kľúčom s nasledovnými ID:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2869,7 +2903,7 @@
 "Nedá sa nájsť súbor s balíkom %s. To by mohlo znamenať, že tento balík je "
 "potrebné opraviť manuálne (kvôli chýbajúcej architektúre)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2878,31 +2912,41 @@
 "Nedá sa nájsť súbor s balíkom %s. Asi budete musieť opraviť tento balík "
 "manuálne."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "Indexové súbory balíka sú narušené. Chýba pole Filename: pre balík %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Veľkosti sa nezhodujú"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Nedá spracovať súbor Release %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "Žiadne sekcie v Release súbore %s"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "Chýba položka Hash v súbore Release %s"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Chýba položka Hash v súbore Release %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Chýba položka Hash v súbore Release %s"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2999,155 +3043,238 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Položky zoznamu zdrojov pre tento disk sú:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Zapísaných %i záznamov.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Zapísaných %i záznamov s %i chýbajúcimi súbormi.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Zapísaných %i záznamov s %i chybnými súbormi\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Zapísaných %i záznamov s %i chýbajúcimi a %i chybnými súbormi\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Preskakuje sa neexistujúci súbor %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr "Nebolo možné nájsť autentifikačný záznam pre: %s"
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Nezhoda kontrolných haš súčtov: %s"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Poznámka: vyberá sa %s pre regulárny výraz „%s“\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Zvolená verzia %s (%s) pre %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Inštaluje sa %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Nastavuje sa %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Odstraňuje sa %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, c-format
 msgid "Completely removing %s"
 msgstr "Úplne sa odstraňuje %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Vykonáva sa spúšťač post-installation %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Adresár „%s“ chýba"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Nedá sa otvoriť súbor %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Pripravuje sa %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Rozbaľuje sa %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Pripravuje sa nastavenie %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Nainštalovaný balík %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Pripravuje sa odstránenie %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Odstránený balík %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Pripravuje sa úplné odstránenie %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Balík „%s“ je úplne odstránený"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Nedá sa zapísať záznam, volanie openpty() zlyhalo (/dev/pts nie je "
 "pripojený?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr "Spúšťa sa dpkg"
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr "Nedá sa zamknúť adresár na správu (%s), používa ho iný proces?"
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Nedá sa zamknúť adresár na správu (%s), ste root?"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, fuzzy, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 "dpkg bol prerušený, musíte ručne opraviť problém spustením „dpkg --configure "
 "-a“. "
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "Nie je zamknuté"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3166,7 +3293,7 @@
 "Nepodarilo sa záplatovať %s pomocou mmap (ale nevyskytla sa chyba týkajúca "
 "sa mmap) - zdá sa, že záplata je poškodená."
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Spojenie bolo predčasne ukončené"
 

=== modified file 'po/sl.po'
--- po/sl.po	2010-05-25 16:01:42 +0000
+++ po/sl.po	2010-06-10 14:02:22 +0000
@@ -4,7 +4,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.5.5\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2005-02-16 22:18+0100\n"
 "Last-Translator: Jure Cuhalev <gandalf@owca.info>\n"
 "Language-Team: Slovenian <sl@li.org>\n"
@@ -12,149 +12,147 @@
 "Content-Type: text/plain; charset=ISO-8859-2\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Paket %s razliica %s ima nereene odvisnosti:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Ne najdem paketa %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Vseh imen paketov:"
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Vseh imen paketov:"
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr " Navadni paketi:"
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr " isti navidezni paketi:"
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr " Posamezni navidezni paketi:"
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr " Meani navidezni paketi:"
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr " Manjka: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Vseh razliic:"
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "Vseh razliic:"
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Vseh odvisnosti:"
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Vseh povezava Raz/Dat:"
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "Vseh povezava Raz/Dat:"
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Vseh dobljenih preslikav: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Vseh razirjenih nizov: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Celotna velikost z odvisnostmi: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Celotna ohlapna velikost: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Celotna velikost, izraunana za: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Paketna datoteka %s ni usklajena."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Podati morate natanno en vzorec"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Nobena datoteka ni bila najdena"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Ne najdem paketa %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Paketne datoteke:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Predpomnilnik ni usklajen, x-ref paketne datotek ni mogo"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Pripeti paketi:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(ni najden)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Nameen: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr " Kandidat:"
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(brez)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr " Zaponka paketa:"
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr " Tabela razliic:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s za %s %s preveden na %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -312,12 +310,12 @@
 "  -c=? Prebere podano datoteko z nastavitvami\n"
 "  -o=? Nastavi poljubno nastavitveno monost, npr. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Ni mogoe pisati na %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Ni mogoe ugotoviti razliice debconfa. Je sploh nameen?"
 
@@ -650,79 +648,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Ni mogoe preimenovati %s v %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Napaka pri prevajanju regex - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Naslednji paketi imajo nereene odvisnosti:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "vendar je paket %s nameen"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "vendar bo paket %s nameen"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "vendar se ga ne da namestiti"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "vendar je navidezen paket"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "vendar ni nameen"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "vendar ne bo nameen"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " ali"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Naslednji NOVI paketi bodo nameeni:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Naslednji novi paketi bodo ODSTRANJENI:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Naslednji paketi so bili zadrani:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Naslednji paketi bodo nadgrajeni:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Naslednji paketi bodo POSTARANI:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Naslednji zadrani paketi bodo spremenjeni:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (zaradi %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 #, fuzzy
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
@@ -731,141 +729,141 @@
 "OPOZORILO: Naslednji kljuni paketi bodo odstranjeni.\n"
 "To NI priporoljivo, razen e natanno veste, kaj ponete."
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu nadgrajenih, %lu na novo nameenih, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu posodobljenih, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu postaranih, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu bo odstranjenih in %lu ne nadgrajenih.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu ne popolnoma nameenih ali odstranjenih.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Popravljanje odvisnosti ..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " spodletelo."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Ni mogoe popraviti odvisnosti"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Ni mogoe pomanjati zbirke za nadgradnjo"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Opravljeno"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "e elite popraviti napake, poskusite pognati 'apt-get -f install'."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Nereene odvisnosti. Poskusite uporabiti -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "POZORO: Naslednjih paketov ni bilo mogoe avtenticirati!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Namestim te pakete brez prevejanje [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Nisem uspel avtenticirati nekaterih paketkov"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Prilo je do teav in -y je bil uporabljen brez --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Odstraniti je potrebno pakete, a je Odstranjevanje onemogoeno."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 #, fuzzy
 msgid "Internal error, Ordering didn't finish"
 msgstr "Notranja napaka pri dodajanju odklona"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Seznama virov ni mogoe brati."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Potrebno je dobiti %sB/%sB arhivov.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Potrebno je dobiti %sB arhivov.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Po odpakiranju bo uporabljenega %sB dodatnega prostora na disku.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Po odpakiranju bo sproenega %sB prostora na disku.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, fuzzy, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Nimate dovolj prostora na %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "V %s je premalo prostora."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Izbrana je monost Samo preprosto, a to opravilo ni preprosto."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Da, naredi tako kot pravim!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, fuzzy, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -876,28 +874,28 @@
 "Za nadaljevanje vnesite frazo '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Prekini."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Ali elite nadaljevati [Y/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Ni mogoe dobiti %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Prenos nekaterih datotek ni uspel"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Prenos dokonan in uporabljen nain samo prenos"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -905,19 +903,19 @@
 "Nekaterih arhivov ni mogoe dobiti. Poskusite uporabiti apt-get update ali --"
 "fix-missing."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing in izmenjava medija trenutno nista podprta"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Ni mogoe popraviti manjkajoih paketov."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Prekinjanje namestitve."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -927,49 +925,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Opomba: izbran %s namesto %s \n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "%s preskoen, ker je e nameen in ne potrebuje nadgradnje.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "%s preskoen, ker je e nameen in ne potrebuje nadgradnje.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Paket %s ni nameen, zato ni odstranjen\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Paket %s je navidezen in ga je priskrbel:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Nameeno]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Razliice kandidatov"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Sami izberite paket, ki ga elite namestiti."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -980,65 +978,65 @@
 "To ponavadi pomeni, da paket manjka, je zastaran ali\n"
 "pa je na voljo samo iz drugega vira.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Kakorkoli, naslednji paketi ga nadomestijo:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Paket %s nima kandidata za namestitev"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Ponovna namestitev %s ni mona, ker ni moen prenos.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "Najnoveja razliica %s je e nameena.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Izdaje '%s' za '%s' ni mogoe najti"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Razliice '%s' za '%s' ni mogoe najti"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Izbrana razliica %s (%s) za %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Ni mogoe doloiti seznama izvornih paketov %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Ukaz update ne potrebuje argumentov"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1048,7 +1046,7 @@
 msgstr[0] "Naslednji NOVI paketi bodo nameeni:"
 msgstr[1] "Naslednji NOVI paketi bodo nameeni:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1056,11 +1054,11 @@
 msgstr[0] "Naslednji NOVI paketi bodo nameeni:"
 msgstr[1] "Naslednji NOVI paketi bodo nameeni:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1076,44 +1074,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Naslednji podatki vam bodo morda pomagali reiti teavo:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Notranja napaka zaradi AllUpgrade."
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Notranja napaka zaradi AllUpgrade."
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "Ni mogoe najti paketa %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Ni mogoe najti paketa %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Opomba: izbran %s namesto regex '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "vendar bo paket %s nameen"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Poskusite zagnati 'apt-get -f install', e elite popraviti:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1121,7 +1114,7 @@
 "Nereene odvisnosti. Poskusite 'apt-get -f install' brez paketov (ali "
 "podajte reitev)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1132,135 +1125,150 @@
 "nemogo poloaj, e uporabljate nestabilno izdajo pa, da nekateri zahtevani "
 "paketi e niso ustvarjeni ali preneeni iz Prihajajoe."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Pokvarjeni paketi"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Naslednji dodatni paketi bodo nameeni:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Predlagani paketi:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Priporoeni paketi:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "vendar bo paket %s nameen"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Preraunavanje nadgradnje ... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Spodletelo"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Opravljeno"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 #, fuzzy
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Notranja napaka zaradi AllUpgrade."
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Ni mogoe zakleniti imenika za prenose"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "Potrebno je navesti vsaj en paket, za katerega elite dobiti izorno kodo"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Izvornega paketa za %s ni mogoe najti"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, fuzzy, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Odpakiranje e odpakiranih izvornih paketov v %s preskoeno\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Nimate dovolj prostora na %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Potrebno je dobiti %sB/%sB izvornih arhivov.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Potrebno je dobiti %sB izvornih arhivov.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Dobi vir %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Nekaterih arhivov ni mogoe dobiti."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Odpakiranje e odpakiranih izvornih paketov v %s preskoeno\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Ukaz odpakiranja '%s' ni uspel.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr ""
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Ukaz gradnje '%s' ni uspel.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Otroki proces ni uspel"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Potrebno je navesti vsaj en paket, za katerega elite preveriti odvisnosti "
 "za gradnjo"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Ni mogoe dobiti informacij o odvisnostih za gradnjo za %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s nima odvisnosti za gradnjo.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "%s odvisnosti za %s ni mogoe zadostiti, ker ni mogoe najti paketa %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1269,31 +1277,31 @@
 "%s odvisnosti za %s ni mogoe zadostiti, ker nobena razliica paketa %s ne "
 "more zadostiti zahtevi po razliici"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Ni mogoe zadostiti %s odvisnosti za %s. Nameen paket %s je preve nov"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Ni mogoe zadostiti %s odvisnosti za %s. %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Odvisnostim za gradnjo %s ni mogoe zadostiti."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Obdelava odvisnosti za gradnjo ni uspela"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Podprti moduli:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1628,8 +1636,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Ni mogoe brati %s"
@@ -1658,10 +1667,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Podatki in zaasni imeniki morajo biti v istem datotenem sistemu"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Branje seznama paketov"
 
@@ -1877,170 +1885,169 @@
 msgid "Write error"
 msgstr "Napaka pri pisanju"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Ni mogoe ustvariti vtinice"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Ni mogoe priklopiti podatkovne vtinice. Povezava potekla."
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Ni mogoe priklopiti pasivne vtinice."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo ni mogel dobiti posluajoe vtinice"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Ni mogoe povezati vtinice"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Ni mogoe posluati na vtinici"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Ni mogoe ugotoviti imena vtinice"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Ni mogoe poslati ukaza PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Neznan naslov druine %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT ni uspel, strenik je odgovoril: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Povezava podatkovne vtinice potekla"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Ni mogoe sprejeti povezave"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Teava pri razprevanju datoteke"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Ni mogoe dobiti datoteke, strenik je odgovoril '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Podatkovna vtinica je potekla"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Prenos podatkov ni uspel, strenik je odgovoril '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Poizvedba"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Ni mogoe zagnati "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Povezovanje z %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Ni mogoe ustvariti vtinice za %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Ni mogoe zaeti povezave z %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Ni se mogoe povezati z %s:%s (%s). Povezava potekla."
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Ni se mogoe povezati z %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Povezujem se z %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Ni mogoe razreiti '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Zaasna napaka pri razreevanju '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Prilo je do napake pri razreevanju '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Ni se mogoe povezati z %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Prekinjanje namestitve."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr ""
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr ""
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 #, fuzzy
 msgid "The following signatures were invalid:\n"
 msgstr "Naslednji dodatni paketi bodo nameeni:"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2117,20 +2124,20 @@
 msgid "Error reading from server"
 msgstr "Napaka pri branju s strenika"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Napaka pri pisanju datoteke %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Napani podatki glave"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Povezava ni uspela"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Notranja napaka"
 
@@ -2196,7 +2203,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Izbira %s ni mogoe najti"
@@ -2321,6 +2328,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Ni mogoe spremeniti v %s"
@@ -2505,7 +2513,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Napaka pri pisanju datoteke %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2639,7 +2647,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Ni mogoe popraviti teav. Imate zadrane pakete."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2692,12 +2700,12 @@
 " '%s'\n"
 "v enoto '%s' in pritisnite enter\n"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Paketni sistem '%s' ni podprt"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Ni mogoe ugotoviti ustrezne vrste paketnega sistema"
 
@@ -2710,25 +2718,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "V sources.list morate vstaviti URI-je z viri"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Ni mogoe odprti ali razleniti seznama paketov ali datoteke stanja."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "e elite odpraviti teave, poskusite zagnati apt-get update."
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Napaen zapis v datoteki z nastavitvami. Ni glave paketa"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Ni mogoe razumeti vrste zaponke %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Prioriteta zaponke ni doloena ali pa je ni."
 
@@ -2818,33 +2826,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Ni mogoe doloiti seznama izvornih paketov %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Zbiranje dobaviteljev datotek"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Napaka IO pri shranjevanju predpomnilnika virov"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "preimenovanje spodletelo, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Neujemanje vsote MD5"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "Neujemanje vsote MD5"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr ""
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2853,7 +2886,7 @@
 "Ni bilo mogoe najti datoteke za paket %s. Morda boste morali rono "
 "popraviti ta paket (zaradi manjkajoega arhiva)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2862,7 +2895,7 @@
 "Ni bilo mogoe najti datoteke za paket %s. Morda boste morali rono "
 "popraviti ta paket."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2870,25 +2903,35 @@
 "Datoteke s kazali paketov so pokvarjene. Brez imena datotek: polje alu paket "
 "%s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Neujemanje velikosti"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Ni mogoe razleniti paketne datoteke %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Opomba: izbran %s namesto %s \n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Napana vrstica v datoteki z odklonom: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Ni mogoe razleniti paketne datoteke %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2982,153 +3025,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Izvorni vnosi za ta medij so:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Zapisal %i zapisov.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Zapisal %i zapisov z %i manjkajoimi datotekami.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Zapisal %i zapisov z %i neujemajoimi datotekami.\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Zapisal %i zapisov z %i manjkajoimi datotekami in %i neujemajoimi "
 "datotekami.\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Odpiranje nastavitvene datoteke %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Neujemanje vsote MD5"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Opomba: izbran %s namesto regex '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Izbrana razliica %s (%s) za %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "  Nameen: "
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, fuzzy, c-format
 msgid "Configuring %s"
 msgstr "Povezujem se z %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, fuzzy, c-format
 msgid "Removing %s"
 msgstr "Odpiram %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Odstranitev %s ni uspela"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "Manjka imenik s seznami %spartial."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Ne morem odpreti datoteke %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, fuzzy, c-format
 msgid "Preparing %s"
 msgstr "Odpiram %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, fuzzy, c-format
 msgid "Unpacking %s"
 msgstr "Odpiram %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, fuzzy, c-format
 msgid "Preparing to configure %s"
 msgstr "Odpiranje nastavitvene datoteke %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, fuzzy, c-format
 msgid "Installed %s"
 msgstr "  Nameen: "
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, fuzzy, c-format
 msgid "Removed %s"
 msgstr "Priporoa"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, fuzzy, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Odpiranje nastavitvene datoteke %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, fuzzy, c-format
 msgid "Completely removed %s"
 msgstr "Odstranitev %s ni uspela"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Imenika seznamov ni mogoe zakleniti"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3143,7 +3269,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Povezava se je prezgodaj zaprla"
 

=== modified file 'po/sv.po'
--- po/sv.po	2010-05-25 16:01:42 +0000
+++ po/sv.po	2010-06-10 14:02:22 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-03-03 23:15+0100\n"
 "Last-Translator: Daniel Nylander <po@danielnylander.se>\n"
 "Language-Team: Swedish <debian-l10n-swedish@debian.org>\n"
@@ -15,148 +15,146 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr ""
 "Paketet %s med versionen %s har ett beroende som inte kan tillfredsställas:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Kunde inte hitta paketet %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Totalt antal paketnamn: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Totalt antal paketnamn: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normala paket: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Rent virtuella paket: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Enstaka virtuella paket: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Blandade virtuella paket: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Saknade: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Totalt antal olika versioner: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Totalt antal olika beskrivningar: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Totalt antal beroenden: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Totalt antal version/filrelationer: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Totalt antal beskrivning/filrelationer: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Totalt antal tillhandahållningsmarkeringar: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Totalt antal sökmönstersträngar: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Totalt utrymme för versionsberoenden: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Totalt bortkastat utrymme: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Totalt utrymme som kan redogöras för: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Paketfilen %s är inte synkroniserad."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Du måste ange exakt ett mönster"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Inga paket hittades"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Kunde inte hitta paketet %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "\"Package\"-filer:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Cachen är inte synkroniserad, kan inte korsreferera en paketfil"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Fastnålade paket:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(hittades inte)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Installerad: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidat: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ingen)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Paketnålning: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Versionstabell:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s för %s kompilerad den %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -311,12 +309,12 @@
 "  -c=? Läs denna konfigurationsfil.\n"
 "  -o=? Ställ in en godtycklig konfigurationsflagga, t.ex -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Kunde inte skriva till %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Kan inte ta reda på debconf-version. Är debconf installerat?"
 
@@ -657,79 +655,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Misslyckades med att byta namn på %s till %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "J"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Fel vid kompilering av reguljärt uttryck - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Följande paket har beroenden som inte kan tillfredsställas:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "men %s är installerat"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "men %s kommer att installeras"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "men det kan inte installeras"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "men det är ett virtuellt paket"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "men det är inte installerat"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "men det kommer inte att installeras"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " eller"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Följande NYA paket kommer att installeras:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Följande paket kommer att TAS BORT:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Följande paket har hållits tillbaka:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Följande paket kommer att uppgraderas:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Följande paket kommer att NEDGRADERAS:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Följande tillbakahållna paket kommer att ändras:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (på grund av %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -737,144 +735,144 @@
 "VARNING: Följande systemkritiska paket kommer att tas bort.\n"
 "Detta bör INTE genomföras såvida du inte vet exakt vad du gör!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu att uppgradera, %lu att nyinstallera, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu att installera om, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu att nedgradera, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu att ta bort och %lu att inte uppgradera.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu är inte helt installerade eller borttagna.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Korrigerar beroenden...."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " misslyckades."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Kunde inte korrigera beroenden"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Kunde inte minimera uppgraderingsuppsättningen"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Färdig"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 "Du kan möjligen rätta till dessa genom att köra \"apt-get -f install\"."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Otillfredsställda beroenden. Prova med -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "VARNING: Följande paket kunde inte autentiseras!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Autentiseringsvarning åsidosatt.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Installera dessa paket utan verifiering [j/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Några av paketen kunde inte autentiseras"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Problem har uppstått och -y användes utan --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Internt fel. InstallPackages anropades med trasiga paket!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Paketen måste tas bort men \"Remove\" är inaktiverat."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Internt fel. Sorteringen färdigställdes inte"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Listan över källor kunde inte läsas."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Konstigt.. storlekarna stämde inte överens, skicka e-post till apt@packages."
 "debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Behöver hämta %sB/%sB arkiv.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Behöver hämta %sB arkiv.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "Efter denna åtgärd kommer ytterligare %sB utrymme användas på disken.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Efter denna åtgärd kommer %sB att frigöras på disken.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Kunde inte fastställa ledigt utrymme i %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Du har inte tillräckligt mycket ledigt utrymme i %s"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "\"Trivial Only\" angavs, men detta är inte en trivial handling."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Ja, gör som jag säger!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -886,28 +884,28 @@
 " ?] "
 
 # Visas då man svarar nej
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Avbryter."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Vill du fortsätta [J/n]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Misslyckades med att hämta %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Misslyckades med att hämta vissa filer"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Hämtningen färdig i \"endast-hämta\"-läge"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -915,19 +913,19 @@
 "Vissa arkiv kunte inte hämtas. Prova att köra \"apt-get update\" eller med --"
 "fix-missing."
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing och mediabyte stöds inte för tillfället"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Kunde inte korrigera saknade paket."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Avbryter installationen."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -937,51 +935,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Observera, väljer %s istället för %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Hoppar över %s, det är redan installerat och uppgradering har inte valts.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Hoppar över %s, det är redan installerat och uppgradering har inte valts.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Paketet %s är inte installerat, så det tas inte bort\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Paketet %s är ett virtuellt paket som tillhandahålls av:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Installerat]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Kandiderande versioner"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Du bör uttryckligen ange ett att installera."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -992,66 +990,66 @@
 "Det kan betyda att paketet saknas, har blivit föråldrat eller endast\n"
 "är tillgängligt från andra källor\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Dock kan följande paket ersätta det:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Paketet %s har ingen installationskandidat"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Ominstallation av %s är inte möjlig, det kan inte hämtas.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s är redan den senaste versionen.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Utgåvan \"%s\" för \"%s\" hittades inte"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Version \"%s\" för \"%s\" hittades inte"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Vald version %s (%s) för %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Kunde inte ta status på källkodspaketlistan %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Uppdateringskommandot tar inga argument"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 "Det är inte meningen att vi ska ta bort något, kan inte starta AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1063,7 +1061,7 @@
 msgstr[1] ""
 "Följande paket har installerats automatiskt och är inte längre nödvändiga:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1073,11 +1071,11 @@
 msgstr[1] ""
 "Följande paket har installerats automatiskt och är inte längre nödvändiga:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Använd \"apt-get autoremove\" för att ta bort dem."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1095,44 +1093,39 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Följande information kan vara till hjälp för att lösa situationen:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Internt fel, AutoRemover förstörde något"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Internt fel, AllUpgrade förstörde något"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Kunde inte hitta funktionen %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Kunde inte hitta paketet %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Observera, väljer %s för det reguljära uttrycket \"%s\"\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s är satt till manuellt installerad.\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 "Du kan möjligen rätta till detta genom att köra \"apt-get -f install\":"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1140,7 +1133,7 @@
 "Otillfredsställda beroenden. Prova med \"apt-get -f install\" utan paket "
 "(eller ange en lösning)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1152,124 +1145,139 @@
 "att några nödvändiga paket ännu inte har skapats eller flyttats\n"
 "ut från \"Incoming\"."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Trasiga paket"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Följande ytterligare paket kommer att installeras:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Föreslagna paket:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Rekommenderade paket:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s är satt till manuellt installerad.\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Beräknar uppgradering... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Misslyckades"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Färdig"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Internt fel, problemlösaren förstörde någonting"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Kunde inte låsa hämtningskatalogen"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Du måste ange minst ett paket att hämta källkod för"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Kunde inte hitta något källkodspaket för %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Hoppar över redan hämtade filen \"%s\"\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Du har inte tillräckligt mycket ledigt utrymme i %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Behöver hämta %sB/%sB källkodsarkiv.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Behöver hämta %sB källkodsarkiv.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Hämtar källkoden %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Misslyckades med att hämta vissa arkiv."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Packar inte upp redan uppackad källkod i %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Uppackningskommandot \"%s\" misslyckades.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Försäkra dig om att paketet \"dpkg-dev\" är installerat.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Byggkommandot \"%s\" misslyckades.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Barnprocessen misslyckades"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "Du måste ange minst ett paket att kontrollera byggberoenden för"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Kunde inte hämta information om byggberoenden för %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s har inga byggberoenden.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1278,7 +1286,7 @@
 "%s-beroendet på %s kan inte tillfredsställas eftersom paketet %s inte kan "
 "hittas"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1287,32 +1295,32 @@
 "%s-beroendet på %s kan inte tillfredsställas eftersom inga tillgängliga "
 "versioner av paketet %s tillfredsställer versionskraven"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Misslyckades med att tillfredsställa %s-beroendet för %s: Det installerade "
 "paketet %s är för nytt"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Misslyckades med att tillfredsställa %s-beroendet för %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Byggberoenden för %s kunde inte tillfredsställas."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Misslyckades med att behandla byggberoenden"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Moduler som stöds:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1653,8 +1661,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Kunde inte läsa %s"
@@ -1683,10 +1692,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Katalogerna info och temp måste vara på samma filsystem"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Läser paketlistor"
 
@@ -1903,176 +1911,176 @@
 msgid "Write error"
 msgstr "Skrivfel"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Kunde inte skapa ett uttag (socket)"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Kunde inte ansluta datauttaget (socket), inget svar inom tidsgräns"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Kunde inte ansluta passivt uttag (socket)."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo kunde inte få tag i ett lyssnande uttag (socket)"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Kunde inte binda ett uttag (socket)"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Kunde inte lyssna på uttaget (socket)"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Kunde inte fastställa uttagets namn (socket)"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Kunde inte sända PORT-kommando"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Okänd adressfamilj %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT misslyckades, servern sade: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Anslutet datauttag (socket) fick inte svar inom tidsgränsen"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Kunde inte ta emot anslutningen"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problem med att lägga filen till hashtabellen"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Kunde inte hämta filen, servern sade \"%s\""
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Datauttag (socket) fick inte svar inom tidsgränsen"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Dataöverföringen misslyckades, servern sade \"%s\""
 
 # Statusmeddelande, byter från substantiv till verb
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Frågar"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Kunde inte starta "
 
 # Felmeddelande för misslyckad chdir
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Ansluter till %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
 # [f]amilj, [t]yp, [p]rotokoll
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Kunde inte skapa ett uttag (socket) för %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Kunde inte initiera anslutningen till %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Kunde inte ansluta till %s:%s (%s), anslutningen överskred tidsgräns"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Kunde inte ansluta till %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Ansluter till %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Kunde inte slå upp \"%s\""
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Temporärt fel vid uppslagning av \"%s\""
 
 # Okänd felkod; %i = koden
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Något konstigt hände när \"%s:%s\" slogs upp (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Kunde inte ansluta till %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Avbryter installationen."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Internt fel: Korrekt signatur men kunde inte fastställa nyckelns "
 "fingeravtryck?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Minst en ogiltig signatur träffades på."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Kunde inte köra \"%s\" för att verifiera signatur (är gpgv installerad?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Okänt fel vid körning av gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Följande signaturer är ogiltiga:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2152,19 +2160,19 @@
 msgid "Error reading from server"
 msgstr "Fel vid läsning från server"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Misslyckades med att kapa av filen"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Felaktiga data i huvud"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Anslutningen misslyckades"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Internt fel"
 
@@ -2232,7 +2240,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Valet %s hittades inte"
@@ -2357,6 +2365,7 @@
 # Felmeddelande för misslyckad chdir
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Kunde inte byta till %s"
@@ -2543,7 +2552,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Misslyckades med att skriva temporär StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2678,7 +2687,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Kunde inte korrigera problemen, du har hållt tillbaka trasiga paket."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2729,13 +2738,13 @@
 msgstr ""
 "Mata in skivan med etiketten \"%s\" i enheten \"%s\" och tryck på Enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Paketsystemet \"%s\" stöds inte"
 
 #
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Kunde inte fastställa en lämplig paketsystemstyp"
 
@@ -2748,26 +2757,26 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Du måste lägga till några \"source\"-URI:er i din sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Paketlistan eller statusfilen kunde inte tolkas eller öppnas."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Du kan möjligen rätta till problemet genom att köra \"apt-get update\""
 
 # "Package" är en sträng i konfigurationsfilen
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Ogiltig post i konfigurationsfilen, \"Package\"-rubriken saknas"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Förstod inte nåltypen %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Prioritet ej angiven (eller noll) för nål"
 
@@ -2859,32 +2868,57 @@
 msgstr "Kunde inte ta status på källkodspaketlistan %s"
 
 # Bättre ord?
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Samlar filtillhandahållningar"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "In-/utfel vid lagring av källcache"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "namnbyte misslyckades, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5-kontrollsumman stämmer inte"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash-kontrollsumman stämmer inte"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Det finns ingen öppen nyckel tillgänglig för följande nyckel-id:n:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2893,7 +2927,7 @@
 "Jag kunde inte hitta någon fil för paketet %s. Detta kan betyda att du "
 "manuellt måste reparera detta paket (på grund av saknad arkitektur)."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2902,31 +2936,41 @@
 "Jag kunde inte hitta någon fil för paketet %s. Detta kan betyda att du "
 "manuellt måste reparera detta paket."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "Paketindexfilerna är skadede. Inget \"Filename:\"-fält för paketet %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Storleken stämmer inte"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Kunde inte tolka paketfilen %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Observera, väljer %s istället för %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Felaktig rad i omdirigeringsfilen: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Kunde inte tolka paketfilen %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3021,152 +3065,235 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Poster i källistan för denna skiva:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Skrev %i poster.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Skrev %i poster med %i saknade filer.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Skrev %i poster med %i filer som inte stämmer\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Skrev %i poster med %i saknade filer och %i filer som inte stämmer\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Öppnar konfigurationsfilen %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash-kontrollsumman stämmer inte"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Observera, väljer %s för det reguljära uttrycket \"%s\"\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Vald version %s (%s) för %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Installerar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Konfigurerar %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Tar bort %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Tog bort hela %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Kör efterinstallationsutlösare %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Katalogen \"%s\" saknas"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Kunde inte öppna filen %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Förbereder %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Packar upp %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Förbereder konfigurering av %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Installerade %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Förbereder borttagning av %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Tog bort %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Förbereder borttagning av hela %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Tog bort hela %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Kan inte skriva loggfil, openpty() misslyckades (/dev/pts inte monterad?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Kunde inte låsa listkatalogen"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3181,7 +3308,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Anslutningen stängdes i förtid"
 

=== modified file 'po/th.po'
--- po/th.po	2010-05-25 16:01:42 +0000
+++ po/th.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-11-06 15:54+0700\n"
 "Last-Translator: Theppitak Karoonboonyanan <thep@linux.thai.net>\n"
 "Language-Team: Thai <thai-l10n@googlegroups.com>\n"
@@ -16,147 +16,145 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "แพกเกจ %s รุ่น %s ขาดแพกเกจที่ต้องใช้:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "ไม่พบแพกเกจ %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "จำนวนชื่อแพกเกจทั้งหมด : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "จำนวนชื่อแพกเกจทั้งหมด : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  แพกเกจปกติ: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  แพกเกจเสมือนแท้ๆ: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  แพกเกจเสมือนที่มีแพกเกจจริงเดียว: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  แพกเกจเสมือนผสม: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  แพกเกจที่ขาดหาย: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "จำนวนรุ่นที่แตกต่างกันทั้งหมด: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "จำนวนคำบรรยายแพกเกจที่แตกต่างกันทั้งหมด: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "จำนวนการเชื่อมโยงระหว่างแพกเกจทั้งหมด: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "จำนวนความสัมพันธ์ รุ่น/แฟ้ม ทั้งหมด: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "จำนวนความสัมพันธ์ คำบรรยาย/แฟ้ม ทั้งหมด: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "จำนวนผังการตระเตรียมทั้งหมด: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "จำนวนสตริงทั้งหมด: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "ขนาดของพื้นที่ความเชื่อมโยงระหว่างแพกเกจทั้งหมด: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "พื้นที่สำรองทั้งหมด: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "พื้นที่ที่นับรวมทั้งหมด: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "ข้อมูลแฟ้ม Package %s ไม่ตรงกับความเป็นจริง"
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "คุณต้องระบุแพตเทิร์นด้วย"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "ไม่พบแพกเกจ"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "ไม่พบแพกเกจ %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "แฟ้มแพกเกจ:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "ข้อมูลแคชไม่ตรงกับความเป็นจริงแล้ว ไม่สามารถอ้างอิงไขว้ระหว่างแฟ้มแพกเกจ"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "แพกเกจที่ถูกตรึง:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(ไม่พบ)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  ที่ติดตั้งอยู่: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  รุ่นที่ติดตั้งได้: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(ไม่มี)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  การตรึงแพกเกจ: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  ตารางรุ่น:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s สำหรับ %s คอมไพล์เมื่อ %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -311,12 +309,12 @@
 "  -c=?  อ่านแฟ้มค่าตั้งนี้\n"
 "  -o=?  กำหนดตัวเลือกค่าตั้งเป็นรายตัว เช่น -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "ไม่สามารถเขียนลงแฟ้ม %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "ไม่สามารถอ่านรุ่นของ debconf ได้ ได้ติดตั้ง debconf ไว้หรือไม่?"
 
@@ -646,79 +644,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "ไม่สามารถเปลี่ยนชื่อ %s ไปเป็น %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "คอมไพล์นิพจน์เรกิวลาร์ไม่สำเร็จ - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "แพกเกจต่อไปนี้ขาดแพกเกจที่ต้องใช้:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "แต่รุ่นที่ติดตั้งไว้คือ %s"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "แต่รุ่นที่จะติดตั้งคือ %s"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "แต่ไม่สามารถติดตั้งได้"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "แต่แพกเกจนี้เป็นแพกเกจเสมือน"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "แต่ได้ติดตั้งไว้"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "แต่แพกเกจนี้จะไม่ถูกติดตั้ง"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " หรือ"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "จะติดตั้งแพกเกจ *ใหม่* ต่อไปนี้:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "จะ *ลบ* แพกเกจต่อไปนี้:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "จะคงรุ่นแพกเกจต่อไปนี้:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "จะปรับรุ่นแพกเกจต่อไปนี้ขึ้น:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "จะปรับรุ่นแพกเกจต่อไปนี้ *ลง*:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "จะเปลี่ยนแปลงรายการคงรุ่นแพกเกจต่อไปนี้:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (เนื่องจาก %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -726,140 +724,140 @@
 "*คำเตือน*: แพกเกจที่จำเป็นต่อไปนี้จะถูกถอดถอน\n"
 "คุณ *ไม่ควร* ทำเช่นนี้ นอกจากคุณเข้าใจสิ่งที่จะทำ!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "ปรับรุ่นขึ้น %lu, ติดตั้งใหม่ %lu, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "ติดตั้งซ้ำ %lu, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "ปรับรุ่นลง %lu, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "ถอดถอน %lu และไม่ปรับรุ่น %lu\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "ติดตั้งหรือถอดถอนไม่ครบ %lu\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "กำลังแก้ปัญหาความขึ้นต่อกันระหว่างแพกเกจ..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " ล้มเหลว"
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "ไม่สามารถแก้ปัญหาความขึ้นต่อกันระหว่างแพกเกจได้"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "ไม่สามารถจำกัดรายการปรับรุ่นให้น้อยที่สุดได้"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " เสร็จแล้ว"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "คุณอาจต้องเรียก 'apt-get -f install' เพื่อแก้ปัญหาเหล่านี้"
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "รายการแพกเกจที่ต้องใช้ไม่ครบ กรุณาลองใช้ตัวเลือก -f"
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "*คำเตือน*: แพกเกจต่อไปนี้ไม่สามารถยืนยันแหล่งต้นตอได้!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "จะข้ามการเตือนเกี่ยวกับการยืนยันแหล่งต้นตอ\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "จะติดตั้งแพกเกจเหล่านี้โดยไม่ตรวจสอบหรือไม่ [y/N]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "มีบางแพกเกจไม่สามารถยืนยันแหล่งต้นตอได้"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "มีปัญหาบางประการ และมีการใช้ -y โดยไม่ระบุ --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "เกิดข้อผิดพลาดภายใน: มีการเรียก InstallPackages ด้วยแพกเกจที่เสีย!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "มีแพกเกจที่จำเป็นต้องถอดถอน แต่ถูกห้ามการถอดถอนไว้"
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "ข้อผิดพลาดภายใน: การเรียงลำดับไม่เสร็จสิ้น"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "ไม่สามารถอ่านรายชื่อแหล่งแพกเกจได้"
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "แปลกประหลาด.. ขนาดไม่ตรงกัน กรุณาอีเมลแจ้ง apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "ต้องดาวน์โหลดแพกเกจ %sB/%sB\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "ต้องดาวน์โหลดแพกเกจ %sB\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "หลังจากการกระทำนี้ ต้องใช้เนื้อที่บนดิสก์อีก %sB\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "หลังจากการกระทำนี้ เนื้อที่บนดิสก์จะว่างเพิ่มอีก %sB\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "ไม่สามารถคำนวณพื้นที่ว่างใน %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "คุณมีพื้นที่ว่างเหลือไม่พอใน %s"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Trivial Only ถูกกำหนดไว้ แต่คำสั่งนี้ไม่ใช่คำสั่งเล็กน้อย"
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Yes, do as I say!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -870,28 +868,28 @@
 "หากต้องการดำเนินการต่อ ให้พิมพ์ประโยค '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "เลิกทำ"
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "คุณต้องการจะดำเนินการต่อไปหรือไม่ [Y/n]?"
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "ไม่สามารถดาวน์โหลด %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "ดาวน์โหลดบางแฟ้มไม่สำเร็จ"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "ดาวน์โหลดสำเร็จแล้ว และอยู่ในโหมดดาวน์โหลดอย่างเดียว"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -899,19 +897,19 @@
 "ดาวน์โหลดบางแพกเกจไม่สำเร็จ บางที การเรียก apt-get update หรือลองใช้ตัวเลือก --fix-"
 "missing อาจช่วยได้"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "ยังไม่รองรับ --fix-missing พร้อมกับการเปลี่ยนแผ่น"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "ไม่สามารถแก้ปัญหาแพกเกจที่ขาดหายได้"
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "จะล้มเลิกการติดตั้ง"
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -921,49 +919,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "หมายเหตุ: จะเลือก %s แทน %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "จะข้าม %s เนื่องจากแพกเกจติดตั้งไว้แล้ว และไม่มีการกำหนดให้ปรับรุ่น\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "จะข้าม %s เนื่องจากแพกเกจติดตั้งไว้แล้ว และไม่มีการกำหนดให้ปรับรุ่น\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "แพกเกจ %s ไม่ได้ติดตั้งไว้ จึงไม่มีการถอดถอน\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "แพกเกจ %s เป็นแพกเกจเสมือนที่ตระเตรียมโดย:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [ติดตั้งอยู่]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "รุ่นแพกเกจที่มี"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "คุณควรเจาะจงเลือกแพกเกจใดแพกเกจหนึ่งเพื่อติดตั้ง"
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -973,65 +971,65 @@
 "ไม่มีแพกเกจ %s ให้ใช้ติดตั้ง แต่ถูกอ้างถึงโดยแพกเกจอื่น\n"
 "แพกเกจนี้อาจขาดหายไป หรือตกรุ่นไปแล้ว หรืออยู่ในแหล่งอื่น\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "อย่างไรก็ดี แพกเกจต่อไปนี้ได้แทนที่แพกเกจดังกล่าวไปแล้ว:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "แพกเกจ %s ไม่มีรุ่นที่จะใช้ติดตั้ง"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "ไม่สามารถติดตั้ง %s ซ้ำได้ เนื่องจากไม่สามารถดาวน์โหลดได้\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s เป็นรุ่นใหม่ล่าสุดอยู่แล้ว\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "ไม่พบรุ่นย่อย '%s' ของ '%s'"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "ไม่พบรุ่น '%s' ของ '%s'"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "เลือกรุ่น %s (%s) สำหรับ %s แล้ว\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "ไม่สามารถ stat รายการแพกเกจซอร์ส %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "คำสั่ง update ไม่รับอาร์กิวเมนต์เพิ่ม"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "apt ถูกกำหนดไม่ให้มีการลบใดๆ จึงไม่สามารถดำเนินการถอดถอนอัตโนมัติได้"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1041,7 +1039,7 @@
 msgstr[0] "แพกเกจต่อไปนี้ถูกติดตั้งแบบอัตโนมัติไว้ และไม่ต้องใช้อีกต่อไปแล้ว:"
 msgstr[1] "แพกเกจต่อไปนี้ถูกติดตั้งแบบอัตโนมัติไว้ และไม่ต้องใช้อีกต่อไปแล้ว:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1049,11 +1047,11 @@
 msgstr[0] "แพกเกจต่อไปนี้ถูกติดตั้งแบบอัตโนมัติไว้ และไม่ต้องใช้อีกต่อไปแล้ว:"
 msgstr[1] "แพกเกจต่อไปนี้ถูกติดตั้งแบบอัตโนมัติไว้ และไม่ต้องใช้อีกต่อไปแล้ว:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "ใช้ 'apt-get autoremove' เพื่อลบแพกเกจดังกล่าวได้"
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1071,43 +1069,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "ข้อมูลต่อไปนี้อาจช่วยแก้ปัญหาได้:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "เกิดข้อผิดพลาดภายใน: AutoRemover ทำความเสียหาย"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "เกิดข้อผิดพลาดภายใน: AllUpgrade ทำความเสียหาย"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "ไม่พบงาน %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "ไม่พบแพกเกจ %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "หมายเหตุ: จะเลือก %s สำหรับนิพจน์เรกิวลาร์ '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "กำหนด %s ให้เป็นการติดตั้งแบบเลือกเองแล้ว\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "คุณอาจเรียก 'apt-get -f install' เพื่อแก้ปัญหานี้ได้:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1115,7 +1108,7 @@
 "มีปัญหาความขึ้นต่อกันระหว่างแพกเกจ กรุณาลองใช้ 'apt-get -f install' โดยไม่ระบุแพกเกจ "
 "(หรือจะระบุทางแก้ก็ได้)"
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1126,131 +1119,146 @@
 "หรือถ้าคุณกำลังใช้รุ่น unstable ก็เป็นไปได้ว่าแพกเกจที่จำเป็นบางรายการ\n"
 "ยังไม่ถูกสร้างขึ้น หรือถูกย้ายออกจาก Incoming"
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "แพกเกจมีปัญหา"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "จะติดตั้งแพกเกจเพิ่มเติมต่อไปนี้:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "แพกเกจที่แนะนำ:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "แพกเกจที่ควรใช้ร่วมกัน:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "กำหนด %s ให้เป็นการติดตั้งแบบเลือกเองแล้ว\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "กำลังคำนวณการปรับรุ่น... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "ล้มเหลว"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "เสร็จแล้ว"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "เกิดข้อผิดพลาดภายใน: กลไกการแก้ปัญหาทำความเสียหาย"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "ไม่สามารถล็อคไดเรกทอรีดาวน์โหลด"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "ต้องระบุแพกเกจอย่างน้อยหนึ่งแพกเกจที่จะดาวน์โหลดซอร์สโค้ด"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "ไม่พบแพกเกจซอร์สโค้ดสำหรับ %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "จะข้ามแฟ้ม '%s' ที่ดาวน์โหลดไว้แล้ว\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "คุณมีพื้นที่ว่างเหลือไม่พอใน %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "ต้องดาวน์โหลดซอร์สโค้ด %sB/%sB\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "ต้องดาวน์โหลดซอร์สโค้ด %sB\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "ดาวน์โหลดซอร์ส %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "ไม่สามารถดาวน์โหลดบางแฟ้ม"
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "จะข้ามการแตกซอร์สของซอร์สที่แตกไว้แล้วใน %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "คำสั่งแตกแฟ้ม '%s' ล้มเหลว\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "กรุณาตรวจสอบว่าได้ติดตั้งแพกเกจ 'dpkg-dev' แล้ว\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "คำสั่ง build '%s' ล้มเหลว\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "โพรเซสลูกล้มเหลว"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "ต้องระบุแพกเกจอย่างน้อยหนึ่งแพกเกจที่จะตรวจสอบสิ่งที่ต้องการสำหรับการ build"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "ไม่สามารถอ่านข้อมูลสิ่งที่ต้องการสำหรับการ build ของ %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s ไม่ต้องการสิ่งใดสำหรับ build\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "ไม่สามารถติดตั้งสิ่งเชื่อมโยง %s สำหรับ %s ได้ เพราะไม่พบแพกเกจ %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1259,30 +1267,30 @@
 "ไม่สามารถติดตั้งสิ่งเชื่อมโยง %s สำหรับ %s ได้ เพราะไม่มีแพกเกจ %s "
 "รุ่นที่จะสอดคล้องกับความต้องการรุ่นของแพกเกจได้"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr "ไม่สามารถติดตั้งสิ่งเชื่อมโยง %s สำหรับ %s ได้: แพกเกจ %s ที่ติดตั้งไว้ใหม่เกินไป"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "ไม่สามารถติดตั้งสิ่งเชื่อมโยง %s สำหรับ %s ได้: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "ไม่สามารถติดตั้งสิ่งที่จำเป็นสำหรับการ build ของ %s ได้"
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "ติดตั้งสิ่งที่จำเป็นสำหรับการ build ไม่สำเร็จ"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "มอดูลที่รองรับ:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1615,8 +1623,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "ไม่สามารถอ่าน %s"
@@ -1645,10 +1654,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "ไดเรกทอรี info และ temp ต้องอยู่ในระบบแฟ้มเดียวกัน"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "กำลังอ่านรายชื่อแพกเกจ"
 
@@ -1860,169 +1868,169 @@
 msgid "Write error"
 msgstr "การเขียนข้อมูลผิดพลาด"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "ไม่สามารถสร้างซ็อกเก็ต"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "ไม่สามารถเชื่อมต่อซ็อกเก็ตข้อมูล เนื่องจากหมดเวลาคอย"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "ไม่สามารถเชื่อมต่อซ็อกเกตแบบ passive"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo ไม่สามารถนำซ็อกเก็ตที่รอรับการเชื่อมต่อมาใช้"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "ไม่สามารถ bind ซ็อกเก็ต"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "ไม่สามารถ listen ที่ซ็อกเก็ต"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "ไม่สามารถระบุชื่อซ็อกเก็ต"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "ไม่สามารถส่งคำสั่ง PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "ไม่รู้จักตระกูลที่อยู่ %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT ล้มเหลว เซิร์ฟเวอร์ตอบว่า: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "หมดเวลารอเชื่อมต่อซ็อกเก็ตข้อมูล"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "ไม่สามารถรับการเชื่อมต่อ"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "เกิดปัญหาขณะคำนวณค่าแฮชของแฟ้ม"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "ไม่สามารถดาวน์โหลดแฟ้ม เซิร์ฟเวอร์ตอบว่า: '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "หมดเวลาคอยที่ซ็อกเก็ตข้อมูล"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "ถ่ายโอนข้อมูลไม่สำเร็จ เซิร์ฟเวอร์ตอบว่า '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "สอบถาม"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "ไม่สามารถเรียก "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "เชื่อมต่อไปยัง %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "ไม่สามารถสร้างซ็อกเก็ตสำหรับ %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "ไม่สามารถเริ่มการเชื่อมต่อไปยัง %s:%s (%s)"
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "ไม่สามารถเชื่อมต่อไปยัง %s:%s (%s) เนื่องจากหมดเวลาคอย"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "ไม่สามารถเชื่อมต่อไปยัง %s:%s (%s)"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "เชื่อมต่อไปยัง %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "ไม่สามารถเปิดหาที่อยู่ '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "เกิดข้อผิดพลาดชั่วคราวขณะเปิดหาที่อยู่ '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "เกิดปัญหาร้ายแรงบางอย่างขณะเปิดหาที่อยู่ '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "ไม่สามารถเชื่อมต่อไปยัง %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "จะล้มเลิกการติดตั้ง"
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "ข้อผิดพลาดภายใน: ลายเซ็นใช้การได้ แต่ไม่สามารถระบุลายนิ้วมือของกุญแจ?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "พบลายเซ็นที่ใช้การไม่ได้อย่างน้อยหนึ่งรายการ"
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "ไม่สามารถเรียก '%s' เพื่อตรวจสอบลายเซ็น (ได้ติดตั้ง gpgv ไว้หรือไม่?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "เกิดข้อผิดพลาดไม่ทราบสาเหตุขณะเรียก gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "ลายเซ็นต่อไปนี้ใช้การไม่ได้:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2099,19 +2107,19 @@
 msgid "Error reading from server"
 msgstr "เกิดข้อผิดพลาดขณะอ่านข้อมูลจากเซิร์ฟเวอร์"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "ไม่สามารถตัดท้ายแฟ้ม"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "ข้อมูลส่วนหัวผิดพลาด"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "เชื่อมต่อไม่สำเร็จ"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "ข้อผิดพลาดภายใน"
 
@@ -2177,7 +2185,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "ไม่พบรายการเลือก %s"
@@ -2300,6 +2308,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "ไม่สามารถเปลี่ยนไดเรกทอรีไปยัง %s"
@@ -2483,7 +2492,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "ไม่สามารถเขียนแฟ้มสถานะชั่วคราว %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2617,7 +2626,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "ไม่สามารถแก้ปัญหาได้ คุณได้คงรุ่นแพกเกจที่เสียอยู่ไว้"
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2665,12 +2674,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "กรุณาใส่แผ่นชื่อ: '%s' ลงในไดรว์ '%s' แล้วกด enter"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "ไม่รองรับระบบแพกเกจ '%s'"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "ไม่สามารถระบุชนิดของระบบแพกเกจที่เหมาะสมได้"
 
@@ -2683,25 +2692,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "คุณต้องเพิ่ม URI ชนิด 'source' ใน sources.list ของคุณด้วย"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "ไม่สามารถแจงหรือเปิดรายชื่อแพกเกจหรือสถานะแพกเกจได้"
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "คุณอาจเรียก `apt-get update' เพื่อแก้ปัญหาเหล่านี้ได้"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "ระเบียนผิดรูปแบบในแฟ้มค่าปรับแต่ง: ไม่มีข้อมูลส่วนหัว 'Package'"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "ไม่เข้าใจชนิดการตรึง %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "ไม่ได้ระบุลำดับความสำคัญ (หรือค่าศูนย์) สำหรับการตรึง"
 
@@ -2790,70 +2799,105 @@
 msgid "Couldn't stat source package list %s"
 msgstr "ไม่สามารถ stat รายการแพกเกจซอร์ส %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "กำลังเก็บข้อมูลแฟ้มที่ตระเตรียมให้"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "เกิดข้อผิดพลาด IO ขณะบันทึกแคชของซอร์ส"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "เปลี่ยนชื่อไม่สำเร็จ: %s (%s -> %s)"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum ไม่ตรงกัน"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "ผลรวมแฮชไม่ตรงกัน"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "ไม่มีกุญแจสาธารณะสำหรับกุญแจหมายเลขต่อไปนี้:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
 "to manually fix this package. (due to missing arch)"
 msgstr "ไม่พบแฟ้มสำหรับแพกเกจ %s คุณอาจต้องแก้ปัญหาแพกเกจนี้เอง (ไม่มี arch)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
 "manually fix this package."
 msgstr "ไม่พบแฟ้มสำหรับแพกเกจ %s คุณอาจต้องแก้ปัญหาแพกเกจนี้เอง"
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "แฟ้มดัชนีแพกเกจเสียหาย ไม่มีข้อมูล Filename: (ชื่อแฟ้ม) สำหรับแพกเกจ %s"
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "ขนาดไม่ตรงกัน"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "ไม่สามารถแจงแฟ้มแพกเกจ %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "หมายเหตุ: จะเลือก %s แทน %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "ข้อมูลผิดพลาดในแฟ้ม diversion: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "ไม่สามารถแจงแฟ้มแพกเกจ %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2948,153 +2992,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "บรรทัดรายชื่อแหล่งแพกเกจสำหรับแผ่นนี้คือ:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "เขียนแล้ว %i ระเบียน\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "เขียนแล้ว %i ระเบียน โดยมีแฟ้มขาดหาย %i แฟ้ม\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "เขียนแล้ว %i ระเบียน โดยมีแฟ้มผิดขนาด %i แฟ้ม\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "เขียนแล้ว %i ระเบียน โดยมีแฟ้มขาดหาย %i แฟ้ม และแฟ้มผิดขนาด %i แฟ้ม\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "ขณะเปิดแฟ้มค่าตั้ง %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "ผลรวมแฮชไม่ตรงกัน"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "หมายเหตุ: จะเลือก %s สำหรับนิพจน์เรกิวลาร์ '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "เลือกรุ่น %s (%s) สำหรับ %s แล้ว\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "กำลังติดตั้ง %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "กำลังตั้งค่า %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "กำลังถอดถอน %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "ถอดถอน %s อย่างสมบูรณ์แล้ว"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "กำลังเรียกการสะกิด %s หลังการติดตั้ง"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "ไม่มีไดเรกทอรี '%s'"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "ไม่สามารถเปิดแฟ้ม %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "กำลังเตรียม %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "กำลังแตกแพกเกจ %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "กำลังเตรียมตั้งค่า %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "ติดตั้ง %s แล้ว"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "กำลังเตรียมถอดถอน %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "ถอดถอน %s แล้ว"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "กำลังเตรียมถอดถอน %s อย่างสมบูรณ์"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "ถอดถอน %s อย่างสมบูรณ์แล้ว"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "ไม่สามารถเขียนบันทึกปฏิบัติการ เนื่องจาก openpty() ล้มเหลว (ไม่ได้เมานท์ /dev/pts "
 "หรือเปล่า?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "ไม่สามารถล็อคไดเรกทอรีรายชื่อแพกเกจ"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3109,7 +3236,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "การเชื่อมต่อถูกปิดก่อนเวลาอันควร"
 

=== modified file 'po/tl.po'
--- po/tl.po	2010-05-25 16:01:42 +0000
+++ po/tl.po	2010-06-10 14:02:22 +0000
@@ -10,7 +10,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2007-03-29 21:36+0800\n"
 "Last-Translator: Eric Pareja <xenos@upm.edu.ph>\n"
 "Language-Team: Tagalog <debian-tl@banwa.upm.edu.ph>\n"
@@ -19,149 +19,147 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n>1;\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Paketeng %s bersyon %s ay may kulang na dep:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Hindi mahanap ang paketeng %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Kabuuan ng mga Pakete : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Kabuuan ng mga Pakete : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Normal na Pakete: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Purong Birtwual na Pakete: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Nag-iisang Birtwal na Pakete: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Halong Birtwal na Pakete: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Kulang/Nawawala: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Kabuuan ng Natatanging mga Bersyon: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "Kabuuan ng Natatanging mga Bersyon: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Kabuuan ng mga Dependensiya: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Kabuuan ng ugnayang Ber/Talaksan: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "Kabuuan ng ugnayang Ber/Talaksan: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Kabuuan ng Mapping ng Provides: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Kabuuan ng Globbed String: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Kabuuan ng gamit na puwang ng Dependensiyang Bersyon: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Kabuuan ng Hindi Nagamit na puwang: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Kabuuan ng puwang na napag-tuosan: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Wala sa sync ang talaksan ng paketeng %s."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Kailangan niyong magbigay ng isa lamang na pattern"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Walang nahanap na mga pakete"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Hindi mahanap ang paketeng %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Talaksang Pakete:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Wala sa sync ang cache, hindi ma-x-ref ang talaksang pakete"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Mga naka-Pin na Pakete:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(hindi nahanap)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Nakaluklok: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Kandidato: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(wala)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Naka-Pin na Pakete: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Talaang Bersyon:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s para sa %s %s kinompile noong %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -319,12 +317,12 @@
 "  -c=? Basahin ang talaksang pagkaayos na ito\n"
 "  -o=? Itakda ang isang optiong pagkaayos, hal. -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Hindi makapagsulat sa %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Hindi makuha ang bersyon ng debconf. Nakaluklok ba ang debconf?"
 
@@ -664,79 +662,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Bigo ang pagpangalan muli ng %s tungong %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "O"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Error sa pag-compile ng regex - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Ang sumusunod na mga pakete ay may kulang na dependensiya:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "ngunit ang %s ay nakaluklok"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "ngunit ang %s ay iluluklok"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "ngunit hindi ito maaaring iluklok"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "ngunit ito ay birtwal na pakete"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "ngunit ito ay hindi nakaluklok"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "ngunit ito ay hindi iluluklok"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " o"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Ang sumusunod na mga paketeng BAGO ay iluluklok:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Ang sumusunod na mga pakete ay TATANGGALIN:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Ang sumusunod na mga pakete ay hinayaang maiwanan:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Ang susunod na mga pakete ay iu-upgrade:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Ang susunod na mga pakete ay ida-DOWNGRADE:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Ang susunod na mga hinawakang mga pakete ay babaguhin:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (dahil sa %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -744,147 +742,147 @@
 "BABALA: Ang susunod na mga paketeng esensyal ay tatanggalin.\n"
 "HINDI ito dapat gawin kung hindi niyo alam ng husto ang inyong ginagawa!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu na nai-upgrade, %lu na bagong luklok, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu iniluklok muli, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu nai-downgrade, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu na tatanggalin at %lu na hindi inupgrade\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu na hindi lubos na nailuklok o tinanggal.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Inaayos ang mga dependensiya..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " ay bigo."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Hindi maayos ang mga dependensiya"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Hindi mai-minimize ang upgrade set"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Tapos"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Maaari ninyong patakbuhin ang 'apt-get -f install' upang ayusin ito."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "May mga kulang na dependensiya. Subukan niyong gamitin ang -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr ""
 "BABALA: Ang susunod na mga pakete ay hindi matiyak ang pagka-awtentiko!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr ""
 "Ipina-walang-bisa ang babala tungkol sa pagka-awtentiko ng mga pakete.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Iluklok ang mga paketeng ito na walang beripikasyon [o/H]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "May mga paketeng hindi matiyak ang pagka-awtentiko"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "May mga problema at -y ay ginamit na walang --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 "Error na internal, tinawagan ang InstallPackages na may sirang mga pakete!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr ""
 "May mga paketeng kailangang tanggalin ngunit naka-disable ang Tanggal/Remove."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Error na internal, hindi natapos ang pagsaayos na pagkasunud-sunod"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Hindi mabasa ang talaan ng pagkukunan (sources)."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Nakapagtataka.. Hindi magkatugma ang laki, mag-email sa apt@packages.debian."
 "org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Kailangang kumuha ng %sB/%sB ng arkibo.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Kailangang kumuha ng %sB ng arkibo.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr ""
 "Matapos magbuklat ay %sB na karagdagang puwang sa disk ang magagamit.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Matapos magbuklat ay %sB na puwang sa disk ang mapapalaya.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Hindi matantsa ang libreng puwang sa %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Kulang kayo ng libreng puwang sa %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "Tinakdang Trivial Only ngunit hindi ito operasyong trivial."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Oo, gawin ang sinasabi ko!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -895,28 +893,28 @@
 "Upang magpatuloy, ibigay ang pariralang '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Abort."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Nais niyo bang magpatuloy [O/h]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Bigo sa pagkuha ng %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "May mga talaksang hindi nakuha"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Kumpleto ang pagkakuha ng mga talaksan sa modong pagkuha lamang"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -924,19 +922,19 @@
 "Hindi nakuha ang ilang mga arkibo, maaaring patakbuhin ang apt-get update o "
 "subukang may --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing at pagpalit ng media ay kasalukuyang hindi suportado"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Hindi maayos ang mga kulang na pakete."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Ina-abort ang pag-instol."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -946,51 +944,51 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Paunawa, pinili ang %s imbes na %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Linaktawan ang %s, ito'y nakaluklok na at hindi nakatakda ang upgrade.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Linaktawan ang %s, ito'y nakaluklok na at hindi nakatakda ang upgrade.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Hindi nakaluklok ang paketeng %s, kaya't hindi ito tinanggal\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Ang paketeng %s ay paketeng birtwal na bigay ng:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Nakaluklok]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Bersyong Kandidato"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Dapat kayong mamili ng isa na iluluklok."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -1001,65 +999,65 @@
 "Maaaring nawawala ang pakete, ito'y laos na, o ito'y makukuha lamang\n"
 "sa ibang pinagmulan.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Gayunpaman, ang sumusunod na mga pakete ay humahalili sa kanya:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Ang paketeng %s ay walang kandidatong maaaring instolahin"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Ang pagluklok muli ng %s ay hindi maaari, hindi ito makuha.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s ay pinakabagong bersyon na.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Release '%s' para sa '%s' ay hindi nahanap"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Bersyon '%s' para sa '%s' ay hindi nahanap"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Ang napiling bersyon %s (%s) para sa %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Hindi ma-stat ang talaan ng pagkukunan ng pakete %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Ang utos na update ay hindi tumatanggap ng mga argumento"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1069,7 +1067,7 @@
 msgstr[0] "Ang sumusunod na mga paketeng BAGO ay iluluklok:"
 msgstr[1] "Ang sumusunod na mga paketeng BAGO ay iluluklok:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1077,11 +1075,11 @@
 msgstr[0] "Ang sumusunod na mga paketeng BAGO ay iluluklok:"
 msgstr[1] "Ang sumusunod na mga paketeng BAGO ay iluluklok:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr ""
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1097,46 +1095,41 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr ""
 "Ang sumusunod na impormasyon ay maaaring makatulong sa pag-ayos ng problema:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Error na internal, may nasira ang problem resolver"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Internal error, nakasira ng bagay-bagay ang AllUpgrade"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "Hindi mahanap ang paketeng %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Hindi mahanap ang paketeng %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Paunawa, pinili ang %s para sa regex '%s'\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "ngunit ang %s ay iluluklok"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 "Maaaring patakbuhin niyo ang 'apt-get -f install' upang ayusin ang mga ito:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1144,7 +1137,7 @@
 "May mga dependensiyang kulang. Subukan ang 'apt-get -f install' na walang "
 "mga pakete (o magtakda ng solusyon)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1155,124 +1148,139 @@
 "o kung kayo'y gumagamit ng pamudmod na unstable ay may ilang mga paketeng\n"
 "kailangan na hindi pa nalikha o linipat mula sa Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Sirang mga pakete"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Ang mga sumusunod na extra na pakete ay luluklokin:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Mga paketeng mungkahi:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Mga paketeng rekomendado:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "ngunit ang %s ay iluluklok"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Sinusuri ang pag-upgrade... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Bigo"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Tapos"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Error na internal, may nasira ang problem resolver"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Hindi maaldaba ang directory ng download"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Kailangang magtakda ng kahit isang pakete na kunan ng source"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Hindi mahanap ang paketeng source para sa %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Linaktawan ang nakuha na na talaksan '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Kulang kayo ng libreng puwang sa %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Kailangang kumuha ng %sB/%sB ng arkibong source.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Kailangang kumuha ng %sB ng arkibong source.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Kunin ang Source %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Bigo sa pagkuha ng ilang mga arkibo."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Linaktawan ang pagbuklat ng nabuklat na na source sa %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Bigo ang utos ng pagbuklat '%s'.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Paki-siguro na nakaluklok ang paketeng 'dpkg-dev'.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Utos na build '%s' ay bigo.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Bigo ang prosesong anak"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "Kailangang magtakda ng kahit isang pakete na susuriin ang builddeps"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Hindi makuha ang impormasyong build-dependency para sa %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "Walang build depends ang %s.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1281,7 +1289,7 @@
 "Dependensiyang %s para sa %s ay hindi mabuo dahil ang paketeng %s ay hindi "
 "mahanap"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1290,32 +1298,32 @@
 "Dependensiyang %s para sa %s ay hindi mabuo dahil walang magamit na bersyon "
 "ng paketeng %s na tumutugon sa kinakailangang bersyon"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Bigo sa pagbuo ng dependensiyang %s para sa %s: Ang naka-instol na paketeng %"
 "s ay bagong-bago pa lamang."
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Bigo sa pagbuo ng dependensiyang %s para sa %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Hindi mabuo ang build-dependencies para sa %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Bigo sa pagproseso ng build dependencies"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Suportadong mga Module:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1651,8 +1659,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Hindi mabasa ang %s"
@@ -1681,10 +1690,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Ang info at temp directory ay kailangang nasa parehong filesystem"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Binabasa ang Listahan ng mga Pakete"
 
@@ -1901,172 +1909,172 @@
 msgid "Write error"
 msgstr "Error sa pagsulat"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Hindi maka-likha ng socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Hindi maka-konekta sa socket ng datos, nag-time-out ang koneksyon"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Hindi maka-konekta sa socket na passive."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "di makakuha ang getaddrinfo ng socket na nakikinig"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Hindi maka-bind ng socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Hindi makarinig sa socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Hindi malaman ang pangalan ng socket"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Hindi makapagpadala ng utos na PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Di kilalang pamilya ng address %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Bigo ang EPRT, sabi ng server ay: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Nag-timeout ang socket ng datos"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Hindi makatanggap ng koneksyon"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Problema sa pag-hash ng talaksan"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Hindi makakuha ng talaksan, sabi ng server ay '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Nag-timeout ang socket ng datos"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Bigo ang paglipat ng datos, sabi ng server ay '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Tanong"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Hindi ma-invoke "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Kumokonekta sa %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Hindi makalikha ng socket para sa %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Hindi maumpisahan ang koneksyon sa %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Hindi maka-konekta sa %s:%s (%s), nag-timeout ang koneksyon"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Hindi maka-konekta sa %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Kumokonekta sa %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Hindi maresolba ang '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Pansamantalang kabiguan sa pagresolba ng '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "May naganap na kababalaghan sa pagresolba ng '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Hindi maka-konekta sa %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Ina-abort ang pag-instol."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Error na internal: Tanggap na lagda, ngunit hindi malaman ang key "
 "fingerprint?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Hindi kukulang sa isang hindi tanggap na lagda ang na-enkwentro."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Hindi maitakbo ang '%s' upang maberipika ang lagda (nakaluklok ba ang gpgv?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Hindi kilalang error sa pag-execute ng gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Ang sumusunod na mga lagda ay imbalido:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2145,20 +2153,20 @@
 msgid "Error reading from server"
 msgstr "Error sa pagbasa mula sa server"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Bigo sa pagsulat ng talaksang %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Maling datos sa panimula"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Bigo ang koneksyon"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Internal na error"
 
@@ -2224,7 +2232,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Piniling %s ay hindi nahanap"
@@ -2351,6 +2359,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Di makalipat sa %s"
@@ -2538,7 +2547,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Bigo sa pagsulat ng talaksang %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2675,7 +2684,7 @@
 msgstr ""
 "Hindi maayos ang mga problema, mayroon kayong sirang mga pakete na naka-hold."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2726,12 +2735,12 @@
 msgstr ""
 "Ikasa ang disk na may pangalang: '%s' sa drive '%s' at pindutin ang enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Hindi suportado ang sistema ng paketeng '%s'"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Hindi matuklasan ang akmang uri ng sistema ng pakete "
 
@@ -2744,28 +2753,28 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Kailangan niyong maglagay ng 'source' URIs sa inyong sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr ""
 "Hindi ma-parse o mabuksan ang talaan ng mga pakete o ng talaksang estado."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Maaaring patakbuhin niyo ang apt-get update upang ayusin ang mga problemang "
 "ito"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Di tanggap na record sa talaksang pagtatangi, walang Package header"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Hindi naintindihan ang uri ng pin %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Walang prioridad (o sero) na nakatakda para sa pin"
 
@@ -2857,33 +2866,58 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Hindi ma-stat ang talaan ng pagkukunan ng pakete %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Kinukuha ang Talaksang Provides"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "IO Error sa pag-imbak ng source cache"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "pagpalit ng pangalan ay bigo, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Di tugmang MD5Sum"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "Di tugmang MD5Sum"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Walang public key na magamit para sa sumusunod na key ID:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2892,7 +2926,7 @@
 "Hindi ko mahanap ang talaksan para sa paketeng %s. Maaaring kailanganin "
 "niyong ayusin ng de kamay ang paketeng ito. (dahil sa walang arch)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2901,7 +2935,7 @@
 "Hindi ko mahanap ang talaksan para sa paketeng %s. Maaaring kailanganin "
 "niyong ayusin ng de kamay ang paketeng ito."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2909,25 +2943,35 @@
 "Sira ang talaksang index ng mga pakete. Walang Filename: field para sa "
 "paketeng %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Di tugmang laki"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Hindi ma-parse ang talaksang pakete %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Paunawa, pinili ang %s imbes na %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Di tanggap na linya sa talaksang diversion: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Hindi ma-parse ang talaksang pakete %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3023,153 +3067,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Mga nakatala sa Listahan ng Source para sa Disc na ito ay:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Nagsulat ng %i na record.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Nagsulat ng %i na record na may %i na talaksang kulang.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Nagsulat ng %i na record na may %i na talaksang mismatch\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Nagsulat ng %i na record na may %i na talaksang kulang at %i na talaksang "
 "mismatch\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Binubuksan ang talaksang pagsasaayos %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Di tugmang MD5Sum"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Paunawa, pinili ang %s para sa regex '%s'\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Ang napiling bersyon %s (%s) para sa %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "Iniluklok ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Isasaayos ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Tinatanggal ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Natanggal ng lubusan ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "Nawawala ang directory ng talaan %spartial."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Hindi mabuksan ang talaksang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Hinahanda ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Binubuklat ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Hinahanda ang %s upang isaayos"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Iniluklok ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Naghahanda para sa pagtanggal ng %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Tinanggal ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Naghahanda upang tanggalin ng lubusan ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Natanggal ng lubusan ang %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Hindi maaldaba ang directory ng talaan"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3184,7 +3311,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Nagsara ng maaga ang koneksyon"
 

=== modified file 'po/uk.po'
--- po/uk.po	2010-05-25 16:01:42 +0000
+++ po/uk.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: apt-all\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2006-07-29 15:57+0300\n"
 "Last-Translator: Artem Bondarenko <artem.brz@gmail.com>\n"
 "Language-Team: Українська <uk@li.org>\n"
@@ -15,149 +15,147 @@
 "Content-Transfer-Encoding: 8bit\n"
 "X-Generator: KBabel 1.11.1\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Пакунок %s версії %s має незадоволену залежність:\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Не можу знайти пакунок %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Всього імен пакунків : "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Всього імен пакунків : "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Нормальних пакунків: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Чисто віртуальних пакунків: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Окремих віртуальних пакунків: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr " Змішаних віртуальних пакунків: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Пропущено: "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Всього унікальних версій: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 #, fuzzy
 msgid "Total distinct descriptions: "
 msgstr "Всього унікальних версій: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Всього залежностей: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Всього відносин Версія/Файл: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 #, fuzzy
 msgid "Total Desc/File relations: "
 msgstr "Всього відносин Версія/Файл: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Всього відносин Provides: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Всього розгорнутих рядків: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Всього інформації про залежності: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Порожнього місця в кеші: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Загальний простір полічений для: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Перелік пакунків %s розсинхронізований."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Ви повинні задати рівно один шаблон"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Не знайдено жодного пакунка"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Не можу знайти пакунок %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Переліки пакунків:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "Кеш не синхронізований, неможливо знайти посилання на перелік пакунків"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Зафіксовані пакунки:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(не знайдено)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Встановлено: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Кандидат: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(відсутній)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Фіксатор(pin) пакунка: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Таблиця версій:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, fuzzy, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s для %s %s скомпільовано %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -312,12 +310,12 @@
 "  -c=? Читати зазначений конфігураційний файл\n"
 "  -o=? Вказати довільну опцію, наприклад, -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Неможливо записати в %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Неможливо визначити версію debconf. Він встановлений?"
 
@@ -662,79 +660,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Не вдалося перейменувати %s в %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Т"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Помилка компіляції регулярного виразу - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Пакунки, що мають незадоволені залежності:"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "але %s вже встановлений"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "але %s буде встановлений"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "але він не може бути встановлений"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "але це віртуальний пакунок"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "але він не встановлений"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "але він не буде встановлений"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " чи"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "НОВІ пакунки, які будуть встановлені:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Пакунки, які будуть ВИДАЛЕНІ:"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Пакунки, які будуть залишені в незмінному вигляді:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Пакунки, які будуть ОНОВЛЕНІ:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Пакунки, будуть замінені на більш СТАРІ версії:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Пакунки, які повинні були б залишитися без змін, але будуть замінені:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (внаслідок %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -742,147 +740,147 @@
 "УВАГА: Ці істотно важливі пакунки будуть вилучені.\n"
 "НЕ РОБІТЬ цього, якщо ви НЕ уявляєте собі всі можливі наслідки!"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "оновлено %lu, встановлено %lu нових пакунків, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr " %lu перевстановлено, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu пакунків замінено на старі версії, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "для видалення відмічено %lu пакунків, і %lu пакунків не оновлено.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "не встановлено до кінця чи видалено %lu пакунків.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Виправлення залежностей..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " невдача."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Неможливо скоригувати залежності"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Неможливо мінімізувати набір оновлень"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Виконано"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr ""
 "Можливо, для виправлення цих помилок ви захочете скористатися 'apt-get -f "
 "install'."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "Незадоволені залежності. Спробуйте використати -f."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "УВАГА: Наступні пакунки неможливо автентифікувати!"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Автентифікаційне попередження не прийнято до уваги.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Встановити ці пакунки без перевірки [т/Н]? "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Деякі пакунки неможливо автентифікувати"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Існують проблеми, а опція -y використана без --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr ""
 "Внутрішня помилка, InstallPackages була викликана з непрацездатними "
 "пакунками!"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Пакунки необхідно видалити, але видалення заборонене."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Внутрішня помилка, Ordering не завершилася"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Неможливо прочитати перелік джерел."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "Дивно.. Розбіжність розмірів, напишіть на apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Необхідно завантажити %sB/%sB архівів.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Необхідно завантажити %sB архівів.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, fuzzy, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Після розпакування об'єм зайнятого дискового простору зросте на %sB.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, fuzzy, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr ""
 "Після розпакування об'єм зайнятого дискового простору зменшиться на %sB.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Не вдалося визначити кількість вільного місця в %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Недостатньо вільного місця в %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "Запитане виконання тільки тривіальних операцій, але це не тривіальна "
 "операція."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Так, робити, як я скажу!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -893,28 +891,28 @@
 "Щоб продовжити, введіть фразу: '%s'\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Перервано."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Бажаєте продовжити [Т/н]? "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Не вдалося завантажити %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Деякі файли не вдалося завантажити"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Вказано режим \"тільки завантаження\", і завантаження завершено"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -922,19 +920,19 @@
 "Неможливо завантажити деякі архіви, імовірно треба виконати apt-get update "
 "або спробувати повторити запуск з ключем --fix-missing?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "--fix-missing і зміна носія в даний момент не підтримується"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Неможливо виправити втрачені пакунки."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Переривається встановлення."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -944,53 +942,53 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Помітьте, замість %2$s вибирається %1$s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr ""
 "Пропускається %s - пакунок вже встановлений, і опція upgrade не "
 "встановлена.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr ""
 "Пропускається %s - пакунок вже встановлений, і опція upgrade не "
 "встановлена.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Пакунок %s не встановлений, тому не може бути видалений\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Пакунок %s - віртуальний, його функції надаються пакунками:\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Встановлено]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Версії кандидатів"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Ви повинні явно вказати, який саме ви хочете встановити."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -1002,65 +1000,65 @@
 "Це може означати, що пакунок відсутній, застарів, або доступний з джерел, не "
 "згаданих в sources.list\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Однак наступні пакунки можуть його замінити:"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Для пакунка %s не знайдені кандидати на встановлення"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Перевстановлення %s неможливе, бо він не може бути завантаженим.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "Вже встановлена найновіша версія %s.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Реліз '%s' для '%s' не знайдений"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Версія '%s' для '%s' не знайдена"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Обрана версія %s (%s) для %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Не вдалося прочитати атрибути переліку вихідних текстів%s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Команді update не потрібні аргументи"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr ""
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1070,7 +1068,7 @@
 msgstr[0] "НОВІ пакунки були встановлені автоматично і більше не потрібні:"
 msgstr[1] "НОВІ пакунки були встановлені автоматично і більше не потрібні:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1078,11 +1076,11 @@
 msgstr[0] "НОВІ пакунки були встановлені автоматично і більше не потрібні:"
 msgstr[1] "НОВІ пакунки були встановлені автоматично і більше не потрібні:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Використовуйте 'apt-get autoremove' щоб видалити їх."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1100,46 +1098,41 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Наступна інформація можливо допоможе Вам:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 #, fuzzy
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Внутрішня помилка, вирішувач проблем все поламав"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Внутрішня помилка, AllUpgrade все поламав"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, fuzzy, c-format
 msgid "Couldn't find task %s"
 msgstr "Не можу знайти пакунок %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Не можу знайти пакунок %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Помітьте, регулярний вираз %2$s призводить до вибору %1$s\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, fuzzy, c-format
 msgid "%s set to manually installed.\n"
 msgstr "але %s буде встановлений"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr ""
 "Можливо, для виправлення цих помилок Ви захочете скористатися 'apt-get -f "
 "install':"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1147,7 +1140,7 @@
 "Незадоволені залежності. Спробуйте виконати 'apt-get -f install', не "
 "вказуючи імені пакунка (або знайдіть інше рішення)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1158,130 +1151,145 @@
 "або ж використаєте нестабільний дистрибутив, і запитані Вами пакунки\n"
 "ще не створені або були вилучені з Incoming."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Зламані пакунки"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Будуть встановлені наступні додаткові пакунки:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Пропоновані пакунки:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Рекомендовані пакунки:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "але %s буде встановлений"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Обчислення оновлень... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Невдача"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Виконано"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Внутрішня помилка, вирішувач проблем все поламав"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Неможливо заблокувати теку для завантаження"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr ""
 "Вкажіть як мінімум один пакунок, для якого необхідно завантажити вихідні "
 "тексти"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Неможливо знайти пакунок з вихідними текстами для %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Пропускаємо вже завантажений файл '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Недостатньо місця в %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Необхідно завантажити %sB/%sB з архівів вихідних текстів.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Потрібно завантажити %sB архівів з вихідними текстами.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Завантаження вихідних текстів %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Деякі архіви не вдалося завантажити."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr ""
 "Розпакування вихідних текстів пропущено, тому що в %s вже перебувають "
 "розпаковані вихідні тексти\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Команда розпакування '%s' завершилася невдало.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Перевірте, чи встановлений пакунок 'dpkg-dev'.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Команда побудови '%s' закінчилася невдало.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Породжений процес завершився невдало"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Для перевірки залежностей для побудови необхідно вказати як мінімум один "
 "пакунок"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Неможливо одержати інформацію про залежності для побудови %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s не має залежностей для побудови.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
@@ -1289,7 +1297,7 @@
 msgstr ""
 "Залежність типу %s для %s не може бути задоволена, бо пакунок %s не знайдено"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1298,32 +1306,32 @@
 "Залежність типу %s для %s не може бути задоволена, бо ні одна з версій "
 "пакунка %s не задовольняє умови"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Не вдалося задовольнити залежність типу %s для пакунка %s: Встановлений "
 "пакунок %s новіше, аніж треба"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Неможливо задовольнити залежність типу %s для пакунка %s: %s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Залежності для побудови %s не можуть бути задоволені."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Обробка залежностей для побудови закінчилася невдало"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Підтримувані модулі:"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1665,8 +1673,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Неможливо прочитати %s"
@@ -1695,10 +1704,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "Теки info і temp повинні бути на тій самій файловій системі"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Читання переліків пакетів"
 
@@ -1917,173 +1925,173 @@
 msgid "Write error"
 msgstr "Помилка запису"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Неможливо створити сокет (socket)"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Неможливо під'єднати сокет (socket) з даними, час з'єднання вичерпався"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Неможливо під'єднати пасивний сокет (passive socket)."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 #, fuzzy
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "Виклик getaddrinfo не зміг отримати сокет"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Неможливо приєднатися до сокета"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 #, fuzzy
 msgid "Could not listen on the socket"
 msgstr "Не можливо утримувати з'єднання на сокеті"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Не вдалося визначити назву сокета"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Неможливо відіслати команду PORT"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Невідоме адресове сімейство %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT невдало, сервер мовив: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Час з'єднання з сокетом даних вичерпався"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Неможливо прийняти з'єднання"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Проблема хешування файла"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Неможливо завантажити файл, сервер мовив: '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Час з'єднання з сокетом (socket) з даними вичерпався"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Передача даних обірвалася, сервер мовив '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Черга"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Неможливо викликати "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "З'єднання з %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Неможливо створити сокет для %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Неможливо ініціалізувати з'єднання з %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Неможливо з'єднатися з %s:%s (%s), час з'єднання вичерпався"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Не можливо під'єднатися до %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "З'єднання з %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Не можу знайти IP адрес для %s"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Тимчасова помилка при отриманні IP адреси '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Сталося щось дивне при спробі отримати IP адрес для '%s:%s' (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Не можливо під'єднатися до %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Переривається встановлення."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr ""
 "Внутрішня помилка: Вірний підпис (signature), але не можливо визначити його "
 "відбиток?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Знайдено як мінімум один невірний підпис."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "Неможливо виконати '%s' для перевірки підпису, gpgv встановлено?"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Невідома помилка виконання gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Слідуючі підписи були невірними:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2164,20 +2172,20 @@
 msgid "Error reading from server"
 msgstr "Помилка читання з сервера"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 #, fuzzy
 msgid "Failed to truncate file"
 msgstr "Не вдалося записати файл %s"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Погана заголовкова інформація"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "З'єднання не вдалося"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Внутрішня помилка"
 
@@ -2243,7 +2251,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Вибір %s не знайдено"
@@ -2370,6 +2378,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Неможливо зробити зміни у %s"
@@ -2559,7 +2568,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Не вдалося записати файл %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2697,7 +2706,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Неможливо усунути проблеми, Ви маєте поламані зафіксовані пакунки."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2748,12 +2757,12 @@
 msgstr ""
 "Будь-ласка, вставте диск з поміткою: '%s' в CD привід '%s' і натисніть Enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Система пакування '%s' не підтримується"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Неможливо визначити тип необхідної системи пакування "
 
@@ -2766,25 +2775,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "Ви повинні записати певні 'source' посилання в твій sources.list"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Не можу обробити чи відкрити перелік пакунків чи status файл."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "Можливо, для виправлення цих помилок Ви захочете запустити apt-get"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "Невірний запис в preferences файлі, відсутній заголовок Package"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Не зрозумів тип %s для pin"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Не встановлено пріоритету (або встановлено 0) для pin"
 
@@ -2874,35 +2883,60 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Не вдалося прочитати атрибути переліку вихідних текстів%s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 #, fuzzy
 msgid "Collecting File Provides"
 msgstr "Збирання інформації про  файлів "
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Помилка IO під час збереження джерельного кешу"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "Не вдалося перейменувати, %s (%s -> %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "Невідповідність MD5Sum"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 #, fuzzy
 msgid "Hash Sum mismatch"
 msgstr "Невідповідність MD5Sum"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 #, fuzzy
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Відсутній публічний ключ для заданих ID ключа:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2911,7 +2945,7 @@
 "Я не можу знайти файл для пакунку %s. Можливо, Ви захочете власноруч "
 "виправити цей пакунок. (due to missing arch)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2920,32 +2954,42 @@
 "Я не можу знайти файл для пакунку %s. Можливо, Ви захочете власноруч "
 "виправити цей пакунок."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr ""
 "Індексні файли пакунків пошкоджені. Немає поля Filename для пакунку %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Невідповідність розміру"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Неможливо обробити файл %s пакунку (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Помітьте, замість %2$s вибирається %1$s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Невірна лінія в файлі diversions: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Неможливо обробити файл %s пакунку (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3039,152 +3083,235 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Перелік джерел для цього диску:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Записано %i записів.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Записано %i записів з %i відсутніми файлами.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Записано %i записів з %i невідповідними файлам\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "Записано %i записів з %i відсутніми і %i невідповідними файлами\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Відкривається конфігураційний файл %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Невідповідність MD5Sum"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Помітьте, регулярний вираз %2$s призводить до вибору %1$s\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Обрана версія %s (%s) для %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, fuzzy, c-format
 msgid "Installing %s"
 msgstr "Встановлено %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Конфігурація %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Видаляється %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Повністю видалено %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, fuzzy, c-format
 msgid "Directory '%s' missing"
 msgstr "Lists тека %spartial відсутня."
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Не можливо відкрити файл %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Підготовка %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Розпакування %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Підготовка до конфігурації %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Встановлено %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Підготовка до видалення %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Видалено %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Підготовка до повного видалення %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Повністю видалено %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr ""
 "Неможливо записати в лог, проблема з openpty() (не змонтовано /dev/pts?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Неможливо заблокувати теку з переліками пакунків"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3199,7 +3326,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "З'єднання завершено передчасно"
 

=== modified file 'po/vi.po'
--- po/vi.po	2010-05-25 16:01:42 +0000
+++ po/vi.po	2010-06-10 14:02:22 +0000
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: apt 0.7.14\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2008-12-22 19:04+1030\n"
 "Last-Translator: Clytie Siddall <clytie@riverland.net.au>\n"
 "Language-Team: Vietnamese <vi-VN@googlegroups.com>\n"
@@ -16,148 +16,146 @@
 "Plural-Forms: nplurals=1; plural=0;\n"
 "X-Generator: LocFactoryEditor 1.8\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "Gói %s phiên bản %s phụ thuộc vào phần mềm chưa có :\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "Không thể định vị gói %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "Tổng số tên gói: "
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "Tổng số tên gói: "
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  Gói chuẩn: "
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  Gói ảo nguyên chất: "
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  Gói ảo đơn: "
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  Gói ảo hỗn hợp: "
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  Thiếu : "
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "Tổng phiên bản riêng: "
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "Tổng mô tả riêng: "
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "Tổng đồ phụ thuộc: "
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "Tổng liên quan phiên bản và tập tin: "
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "Tổng liên quan mô tả/tập tin: "
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "Tổng ảnh xạ Miễn là: "
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Tổng chuỗi mở rộng mẫu tìm kiếm: "
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "Tổng chỗ phiên bản phụ thuộc: "
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Tổng chỗ nghỉ: "
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "Tổng chỗ đã tính: "
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "Tập tin gói %s không đồng bộ được."
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "Bạn phải đưa ra đúng một mẫu"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "Không tìm thấy gói"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "Không thể định vị gói %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "Tập tin gói:"
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr ""
 "Bộ nhớ tạm không đồng bộ được nên không thể tham chiếu chéo tập tin gói"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "Các gói đã ghim:"
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(không tìm thấy)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  Đã cài đặt: "
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  Ứng cử: "
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(không có)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  Ghim gói: "
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  Bảng phiên bản:"
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s cho %s được biên dịch trên %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -325,12 +323,12 @@
 "  -c=? \t\tĐọc tập tin cấu hình này\n"
 "  -o=? \t\tLập một tùy chọn cấu hình nhiệm ý, v.d. « -o dir::cache=/tmp »\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "Không thể ghi vào %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "Không thể lấy phiên bản debconf. Debconf có được cài đặt chưa?"
 
@@ -681,79 +679,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "Việc đổi tên %s thành %s bị lỗi"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "C"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "Lỗi biên dich biểu thức chính quy - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "Những gói theo đây phụ thuộc vào phần mềm chưa có :"
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "nhưng mà %s đã được cài đặt"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "nhưng mà %s sẽ được cài đặt"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "nhưng mà nó không có khả năng cài đặt"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "nhưng mà nó là gói ảo"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "nhưng mà nó chưa được cài đặt"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "nhưng mà nó sẽ không được cài đặt"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " hay"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "Theo đây có những gói MỚI sẽ được cài đặt:"
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "Theo đây có những gói sẽ bị GỠ BỎ :"
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "Theo đây có những gói đã được giữ lại:"
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "Theo đây có những gói sẽ được nâng cấp:"
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "Theo đây có những gói sẽ được HẠ CẤP:"
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "Theo đây có những gói sẽ được thay đổi:"
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (do %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -761,144 +759,144 @@
 "CẢNH BÁO : theo đây có những gói chủ yếu sẽ bị gỡ bỏ.\n"
 "ĐỪNG làm như thế trừ khi bạn biết làm gì ở đây nó một cách chính xác."
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "%lu đã nâng cấp, %lu mới được cài đặt, "
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "%lu được cài đặt lại, "
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "%lu được hạ cấp, "
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "%lu cần gỡ bỏ, và %lu chưa được nâng cấp.\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu chưa được cài đặt toàn bộ hay được gỡ bỏ.\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "Đang sửa cách phụ thuộc..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " đã thất bại."
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "Không thể sửa cách phụ thuộc"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "Không thể cực tiểu hóa bộ nâng cấp"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " Đã xong"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "Có lẽ bạn hãy chay lệnh « apt-get -f install » để sửa hết."
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr ""
 "Còn có cách phụ thuộc vào phần mềm chưa có. Như thế thì bạn hãy cố dùng tùy "
 "chọn « -f »."
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "CẢNH BÁO : không thể xác thực những gói theo đây."
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "Cảnh báo xác thực bị đè.\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "Cài đặt những gói này mà không kiểm chứng không? [y/N] [c/K] "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "Một số gói không thể được xác thực"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "Gập lỗi và đã dùng tùy chọn « -y » mà không có  « --force-yes »"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "Lỗi nội bộ: InstallPackages (cài đặt gói) được gọi với gói bị hỏng."
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "Cần phải gỡ bỏ một số gói, nhưng mà khả năng Gỡ bỏ (Remove) đã bị tắt."
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "Gặp lỗi nội bộ: tiến trình Sắp xếp chưa xong"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "Không thể đọc danh sách nguồn."
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr ""
 "Lạ... Hai kích cỡ không khớp được. Hãy gởi thư cho <apt@packages.debian.org>"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "Cần phải lấy %sB/%sB kho.\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "Cần phải lấy %sB kho.\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "Sau thao tác này, %sB sức chứa đĩa thêm sẽ được chiếm.\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "Sau thao tác này, %sB sức chứa đĩa thêm sẽ được giải phóng.\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "Không thể quyết định chỗ rảnh trong %s"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "Bạn chưa có đủ sức chức còn rảnh trong %s."
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr ""
 "Xác đinh « Chỉ không đáng kể » (Trivial Only) nhưng mà thao tác này đáng kể."
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Có, làm đi."
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -909,28 +907,28 @@
 "Để tiếp tục thì hãy gõ cụm từ « %s »\n"
 "?]"
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "Hủy bỏ."
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "Bạn có muốn tiếp tục không? [Y/n] [C/k] "
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "Việc gói %s bị lỗi  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "Một số tập tin không tải về được"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "Mới tải về xong và trong chế độ chỉ tải về"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -938,21 +936,21 @@
 "Không thể lấy một số kho, có lẽ hãy chạy lệnh « apt-get update » (apt lấy cập "
 "nhật) hay cố với « --fix-missing » (sửa các điều còn thiếu) không?"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr ""
 "Chưa hô trợ tùy chọn « --fix-missing » (sửa khi thiếu điều) và trao đổi "
 "phương tiện."
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "Không thể sửa những gói còn thiếu."
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "Đang hủy bỏ cài đặt."
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -961,49 +959,49 @@
 "all files have been overwritten by other packages:"
 msgstr[0] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "Ghi chú : đang chọn %s thay vì %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "Đang bỏ qua %s vì nó đã được cài đặt và chưa lập tùy chọn Nâng cấp.\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "Đang bỏ qua %s vì nó đã được cài đặt và chưa lập tùy chọn Nâng cấp.\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "Chưa cài đặt gói %s nên không thể gỡ bỏ nó\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "Gói %s là gói ảo được cung cấp do :\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [Đã cài đặt]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "Phiên bản ứng cử"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "Bạn nên chọn một cách dứt khoát gói cần cài."
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -1014,65 +1012,65 @@
 "đã tham chiếu đến nó. Có lẽ có nghĩa là gói còn thiếu,\n"
 "đã trở thành cũ, hay chỉ sẵn sàng từ nguồn khác.\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "Tuy nhiên, những gói theo đây thay thế nó :"
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "Gói %s không có ứng cử cài đặt"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "Không thể cài đặt lại %s vì không thể tải về nó.\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s là phiên bản mơi nhất.\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "Không tìm thấy bản phát hành « %s » cho « %s »"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "Không tìm thấy phiên bản « %s » cho « %s »"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "Đã chọn phiên bản %s (%s) cho %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "Không thể lấy các thông tin về danh sách gói nguồn %s"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "Lệnh cập nhật không chấp nhật đối số"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "Không nên xoá gì thì không thể khởi chạy Bộ Gỡ bỏ Tự động"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1082,7 +1080,7 @@
 msgstr[0] ""
 "Theo đây có những gói đã được cài đặt tự động nên không còn cần thiết lại:"
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1090,11 +1088,11 @@
 msgstr[0] ""
 "Theo đây có những gói đã được cài đặt tự động nên không còn cần thiết lại:"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "Hãy sử dụng lệnh « apt-get autoremove » để gỡ bỏ chúng."
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1112,43 +1110,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "Có lẽ thông tin theo đây sẽ giúp đỡ quyết định trường hợp:"
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "Lỗi nội bộ : Bộ Gỡ bỏ Tự động đã làm hư gì."
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "Lỗi nội bộ: AllUpgrade (toàn bộ nâng cấp) đã ngắt gì"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "Không tìm thấy tác vụ %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "Không tìm thấy gói %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "Ghi chú : đang chọn %s cho biểu thức chính quy « %s »\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s được đặt thành « được cài đặt bằng tay ».\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "Có lẽ bạn hãy chạy lênh « apt-get -f install » để sửa hết:"
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1156,7 +1149,7 @@
 "Gói còn phụ thuộc vào phần mềm chưa có. Hãy cố chạy lệnh « apt-get -f install "
 "» mà không có gói nào (hoặc ghi rõ cách quyết định)."
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1168,132 +1161,147 @@
 "bất định, có lẽ chưa tạo một số gói cần thiết,\n"
 "hoặc chưa di chuyển chúng ra phần Incoming (Đến)."
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "Gói bị ngắt"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "Những gói thêm theo đây sẽ được cài đặt:"
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "Gói được đệ nghị:"
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "Gói được khuyên:"
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s được đặt thành « được cài đặt bằng tay ».\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "Đang tính nâng cấp... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "Bị lỗi"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "Xong"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "Lỗi nội bộ: bộ tháo gỡ vấn đề đã ngắt gì"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "Không thể khóa thư mục tải về"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "Phải ghi rõ ít nhất một gói cần lấy nguồn cho nó"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "Không tìm thấy gói nguồn cho %s"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "Đang bỏ qua tập tin đã được tải về « %s »\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "Không đủ sức chứa còn rảnh trong %s"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "Cần phải lấy %sB/%sB kho nguồn.\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "Cần phải lấy %sB kho nguồn.\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "Lấy nguồn %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "Việc lấy một số kho bị lỗi."
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "Đang bỏ qua giải nén nguồn đã giải nén trong %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "Lệnh giải nén « %s » bị lỗi.\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "Hãy kiểm tra xem gói « dpkg-dev » có được cài đặt chưa.\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "Lệnh xây dụng « %s » bị lỗi.\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "Tiến trình con bị lỗi"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr ""
 "Phải ghi rõ ít nhất một gói cần kiểm tra cách phụ thuộc khi xây dụng cho nó"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "Không thể lấy thông tin về cách phụ thuộc khi xây dụng cho %s"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s không phụ thuộc vào gì khi xây dụng.\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "cách phụ thuộc %s cho %s không thể được thỏa vì không tìm thấy gọi %s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1302,31 +1310,31 @@
 "cách phụ thuộc %s cho %s không thể được thỏa vì không có phiên bản sẵn sàng "
 "của gói %s có thể thỏa điều kiện phiên bản."
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr ""
 "Việc cố thỏa cách phụ thuộc %s cho %s bị lỗi vì gói đã cài đặt %s quá mới"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "Việc cố thỏa cách phụ thuộc %s cho %s bị lỗi: %s."
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "Không thể thỏa cách phụ thuộc khi xây dụng cho %s."
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "Việc xử lý cách phụ thuộc khi xây dụng bị lỗi"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "Mô-đun đã hỗ trợ :"
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1673,8 +1681,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "Không thể đọc %s"
@@ -1705,10 +1714,9 @@
 "Những thư mục info (thông tin) và temp (tạm thời) cần phải trong cùng một hệ "
 "thống tập tin"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "Đang đọc các danh sách gói..."
 
@@ -1926,170 +1934,170 @@
 msgid "Write error"
 msgstr "Lỗi ghi"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "Không thể tạo ổ cắm"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "Không thể kết nối ổ cắm dữ liệu, kết nối đã quá giờ"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "Không thể kết nối ổ cắm bị động."
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo (lấy thông tin địa chỉ) không thể lấy ổ cắm lắng nghe"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "Không thể đóng kết ổ cắm"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "Không thể lắng nghe trên ổ cắm đó"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "Không thể quyết định tên ổ cắm đó"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "Không thể gởi lệnh PORT (cổng)"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "Không biết nhóm địa chỉ %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "Lệnh EPRT (thông báo lỗi) đã thất bại: máy phục vụ nói: %s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Kết nối ổ cắm dữ liệu đã quá giờ"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "Không thể chấp nhận kết nối"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "Gặp khó khăn băm tập tin"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "Không thể lấy tập tin: máy phục vụ nói « %s »"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Ổ cắm dữ liệu đã quá giờ"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "Việc truyền dữ liệu bị lỗi: máy phục vụ nói « %s »"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "Truy vấn"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "Không thể gọi "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "Đang kết nối đến %s (%s)..."
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[Địa chỉ IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "Không thể tạo ổ cắm cho %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "Không thể sở khởi kết nối đến %s:%s (%s)."
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "Không thể kết nối đến %s:%s (%s), kết nối đã quá giờ"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "Không thể kết nối đến %s:%s (%s)."
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "Đang kết nối đến %s..."
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "Không thể tháo gỡ « %s »"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "Việc tháo gỡ « %s » bị lỗi tạm thời"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "Gặp lỗi nghiệm trọng khi tháo gỡ « %s:%s » (%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "Không thể kết nối đến %s %s:"
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "Đang hủy bỏ cài đặt."
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "Lỗi nội bộ: chữ ký đúng, nhưng không thể quyết định vân tay khóa ?!"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "Gặp ít nhất một chữ ký không hợp lệ."
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr ""
 "Không thể thực hiện « %s » để kiểm chứng chữ ký (gpgv có được cài đặt chưa?)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "Gặp lỗi lạ khi thực hiện gpgv"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "Những chữ ký theo đây là không hợp lệ:\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2171,19 +2179,19 @@
 msgid "Error reading from server"
 msgstr "Gặp lỗi khi đọc từ máy phục vụ"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "Lỗi cắt ngắn tập tin"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "Dữ liệu dòng đầu sai"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "Kết nối bị ngắt"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "Gặp lỗi nội bộ"
 
@@ -2249,7 +2257,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "Không tìm thấy vùng chọn %s"
@@ -2372,6 +2380,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "Không thể chuyển đổi sang %s"
@@ -2555,7 +2564,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "Lỗi ghi tập tin tình trạng StateFile tạm thời %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2696,7 +2705,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "Không thể sửa vấn đề, bạn đã giữ lại một số gói bị ngắt."
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2746,12 +2755,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "Hãy nạp đĩa có nhãn « %s » vào ổ « %s » và bấm nút Enter."
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "Không hỗ trợ hệ thống đóng gói « %s »"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "Không thể quyết định kiểu hệ thống đóng gói thích hợp"
 
@@ -2765,28 +2774,28 @@
 msgstr ""
 "Bạn phải để một số địa chỉ URI « nguồn » vào « sources.list » (danh sách nguồn)"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "Không thể phân tích hay mở danh sách gói hay tâp tin trạng thái."
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr ""
 "Có lẽ bạn muốn chạy « apt-get update » (lấy cập nhật) để sửa các vấn đề này"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr ""
 "Gặp mục ghi không hợp lệ trong tập tin tùy thích: không có phần đầu Package "
 "(Gói)."
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "Không hiểu kiểu ghim %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "Chưa ghi rõ ưu tiên (hay số không) cho ghim"
 
@@ -2877,32 +2886,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "Không thể lấy các thông tin về danh sách gói nguồn %s"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "Đang tập hợp các trường hợp « tập tin miễn là »"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "Lỗi nhập/xuất khi lưu bộ nhớ tạm nguồn"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "việc thay đổi tên bị lỗi, %s (%s → %s)."
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum (tổng kiểm) không khớp được"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Sai khớp tổng băm (hash sum)"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "Không có khóa công sẵn sàng cho những ID khóa theo đây:\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2911,7 +2945,7 @@
 "Không tìm thấy tập tin liên quan đến gói %s. Có lẽ bạn cần phải tự sửa gói "
 "này, do thiếu kiến trúc."
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2920,7 +2954,7 @@
 "Không tìm thấy tập tin liên quan đến gói %s. Có lẽ bạn cần phải tự sửa gói "
 "này."
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
@@ -2928,25 +2962,35 @@
 "Các tập tin chỉ mục của gói này bị hỏng. Không có trường Filename: (Tên tập "
 "tin:) cho gói %s."
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "Kích cỡ không khớp được"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, fuzzy, c-format
 msgid "Unable to parse Release file %s"
 msgstr "Không thể phân tách tập tin gói %s (1)"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, fuzzy, c-format
 msgid "No sections in Release file %s"
 msgstr "Ghi chú : đang chọn %s thay vì %s\n"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr ""
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "Gặp dòng không hợp lệ trong tập tin trệch đi: %s"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "Không thể phân tách tập tin gói %s (1)"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -3040,153 +3084,236 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "Các mục nhập danh sách nguồn cho đĩa này:\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "Mới ghi %i mục ghi.\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "Mới ghi %i mục ghi với %i tập tin còn thiếu.\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "Mới ghi %i mục ghi với %i tập tin không khớp với nhau\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr ""
 "Mới ghi %i mục ghi với %i tập tin còn thiếu và %i tập tin không khớp với "
 "nhau\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "Đang mở tập tin cấu hình %s..."
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Sai khớp tổng băm (hash sum)"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "Ghi chú : đang chọn %s cho biểu thức chính quy « %s »\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "Đã chọn phiên bản %s (%s) cho %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "Đang cài đặt %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "Đang cấu hình %s..."
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "Đang gỡ bỏ %s..."
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "Mới gỡ bỏ hoàn toàn %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "Đang chạy bộ gây nên tiến trình cuối cùng cài đặt %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "Thiếu thư mục « %s »"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "Không thể mở tập tin %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "Đang chuẩn bị %s..."
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "Đang mở gói %s..."
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "Đang chuẩn bị cấu hình %s..."
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "Đã cài đặt %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "Đang chuẩn bị gỡ bỏ %s..."
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "Đã gỡ bỏ %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "Đang chuẩn bị gỡ bỏ hoàn toàn %s..."
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "Mới gỡ bỏ hoàn toàn %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "Không thể ghi lưu, openpty() bị lỗi (« /dev/pts » chưa lắp ?)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "Không thể khóa thư mục danh sách"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3201,7 +3328,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "Kết nối bị đóng quá sớm."
 

=== modified file 'po/zh_CN.po'
--- po/zh_CN.po	2010-05-25 16:01:42 +0000
+++ po/zh_CN.po	2010-06-10 14:02:22 +0000
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: apt\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-12-02 01:00+0800\n"
 "Last-Translator: Aron Xu <happyaron.xu@gmail.com>\n"
 "Language-Team: Debian Chinese [GB] <debian-chinese-gb@lists.debian.org>\n"
@@ -17,147 +17,145 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "版本为 %2$s 的软件包 %1$s 有未满足的依赖关系：\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "未发现软件包 %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "软件包名称总数："
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "软件包名称总数："
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  普通软件包："
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  完全虚拟软件包："
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  单虚拟软件包："
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  混合虚拟软件包："
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  缺失："
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "按版本共计："
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "按不同的说明共计："
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "按依赖关系共计："
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "按版本/文件关系共计："
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "按说明/文件关系共计："
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "提供映射共计："
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "Glob 字串共计："
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "依赖关系版本名所占空间共计："
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "Slack 空间共计："
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "总占用空间："
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "软件包文件 %s 尚未同步。"
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "您必须明确地给出一个表达式"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "没有发现匹配的软件包"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "未发现软件包 %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "软件包文件："
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "缓存尚未同步，无法交差引证(x-ref)一个软件包文件"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "被锁定的软件包："
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(没有找到)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  已安装："
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  候选软件包："
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(无)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  软件包锁："
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  版本列表："
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s，用于 %s 构架，编译于 %s %s\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -311,12 +309,12 @@
 "  -c=? 读指定的配置文件\n"
 "  -o=? 设置任意指定的配置选项，例如 -o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "无法写入 %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "无法获得 debconf 的版本。您安装了 debconf 吗？"
 
@@ -650,79 +648,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "无法将 %s 重命名为 %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "编译正则表达式时出错 - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "下列软件包有未满足的依赖关系："
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "但是 %s 已经安装"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "但是 %s 正要被安装"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "但无法安装它"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "但是它是虚拟软件包"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "但是它还没有被安装"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "但是它将不会被安装"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr " 或"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "下列【新】软件包将被安装："
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "下列软件包将被【卸载】："
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "下列软件包的版本将保持不变："
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "下列软件包将被升级："
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "下列软件包将被【降级】："
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "下列被要求保持版本不变的软件包将被改变："
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s (是由于 %s) "
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -730,140 +728,140 @@
 "【警告】：下列基础软件包将被卸载。\n"
 "请勿尝试，除非您确实知道您在做什么！"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "升级了 %lu 个软件包，新安装了 %lu 个软件包，"
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "重新安装了 %lu 个软件包，"
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "降级了 %lu 个软件包，"
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "要卸载 %lu 个软件包，有 %lu 个软件包未被升级。\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "有 %lu 个软件包没有被完全安装或卸载。\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "正在更正依赖关系..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " 失败。"
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "无法更正依赖关系"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "无法最小化要升级的软件包集合"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " 完成"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "您也许需要运行“apt-get -f install”来修正上面的错误。"
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "不能满足依赖关系。不妨试一下 -f 选项。"
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "【警告】：下列软件包不能通过验证！"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "忽略了认证警告。\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "不经验证就安装这些软件包吗？[y/N] "
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "有些软件包不能通过验证"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "碰到了一些问题，您使用了 -y 选项，但是没有用 --force-yes"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "内部错误，InstallPackages 被用在了无法安装的软件包上！"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "有软件包需要被卸载，但是卸载动作被程序设置所禁止。"
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "内部错误，Ordering 未能完成"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "无法读取源列表。"
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "怪了……文件大小不符，请发信给 apt@packages.debian.org 吧"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "需要下载 %sB/%sB 的软件包。\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "需要下载 %sB 的软件包。\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "解压缩后会消耗掉 %sB 的额外空间。\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "解压缩后将会空出 %sB 的空间。\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "无法获知您在 %s 上的可用空间"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "您在 %s 上没有足够的可用空间。"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "虽然您指定了仅执行常规操作，但这不是个常规操作。"
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "是，按我说的做！"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -874,28 +872,28 @@
 "若还想继续的话，就输入下面的短句“%s”\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "中止执行。"
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "您希望继续执行吗？[Y/n]"
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "无法下载 %s  %s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "有一些文件无法下载"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "下载完毕，目前是“仅下载”模式"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -903,19 +901,19 @@
 "有几个软件包无法下载，您可以运行 apt-get update 或者加上 --fix-missing 的选项"
 "再试试？"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "目前还不支持 --fix-missing 和介质交换"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "无法更正缺少的软件包。"
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "中止安装。"
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -925,49 +923,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "注意，选取 %s 而非 %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "忽略了 %s，它已经被安装而且没有指定要升级。\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "忽略了 %s，它已经被安装而且没有指定要升级。\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "软件包 %s 还未安装，因而不会被卸载\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "软件包 %s 是一个由下面的软件包提供的虚拟软件包：\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr " [已安装]"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "候选版本"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "请您明确地选择一个来进行安装。"
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -978,65 +976,65 @@
 "这可能意味着这个缺失的软件包可能已被废弃，\n"
 "或者只能在其他发布源中找到\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "可是下列软件包取代了它："
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "软件包 %s 还没有可供安装的候选者"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "不能重新安装 %s，因为无法下载它。\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s 已经是最新的版本了。\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "未找到“%2$s”的“%1$s”发布版本"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "未找到“%2$s”的“%1$s”版本"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "选定了版本为 %s (%s) 的 %s\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "无法获取源软件包列表 %s 的状态"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr " update 命令不需要参数"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "我们不应该进行删除，无法启动自动删除器"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1046,7 +1044,7 @@
 msgstr[0] "下列软件包是自动安装的并且现在不需要了："
 msgstr[1] "下列软件包是自动安装的并且现在不需要了："
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1054,11 +1052,11 @@
 msgstr[0] "%lu 个自动安装的的软件包现在不需要了\n"
 msgstr[1] "%lu 个自动安装的的软件包现在不需要了\n"
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "使用'apt-get autoremove'来删除它们"
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1074,43 +1072,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "下列信息可能会对解决问题有所帮助："
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "内部错误，自动删除工具坏事了"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "内部错误，全部升级工具坏事了"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "无法找到任务 %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "无法找到软件包 %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "注意，根据正则表达式“%2$s”选中了 %1$s\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s 被设置为手动安装。\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "您可能需要运行“apt-get -f install”来纠正下列错误："
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1118,7 +1111,7 @@
 "有未能满足的依赖关系。请尝试不指明软件包的名字来运行“apt-get -f install”(也可"
 "以指定一个解决办法)。"
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1129,131 +1122,146 @@
 "因为系统无法达到您要求的状态造成的。该版本中可能会有一些您需要的软件\n"
 "包尚未被创建或是它们已被从新到(Incoming)目录移出。"
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "破损的软件包"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "将会安装下列额外的软件包："
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "建议安装的软件包："
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "推荐安装的软件包："
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s 被设置为手动安装。\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "正在对升级进行计算... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "失败"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "完成"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "内部错误，问题解决工具坏事了"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "无法锁定下载目录"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "要下载源代码，必须指定至少一个对应的软件包"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "无法找到与 %s 对应的源代码包"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "忽略已下载过的文件“%s”\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "您在 %s 上没有足够的可用空间"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "需要下载 %sB/%sB 的源代码包。\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "需要下载 %sB 的源代码包。\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "下载源代码 %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "有一些包文件无法下载。"
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "忽略已经被解包到 %s 目录的源代码包\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "运行解包的命令“%s”出错。\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "请检查是否安装了“dpkg-dev”软件包。\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "执行构造软件包命令“%s”失败。\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "子进程出错"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "要检查生成软件包的构建依赖关系，必须指定至少一个软件包"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "无法获得 %s 的构建依赖关系信息"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr " %s 没有构建依赖关系信息。\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "由于无法找到软件包 %3$s ，因此不能满足 %2$s 所要求的 %1$s 依赖关系"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1262,30 +1270,30 @@
 "由于无法找到符合要求的软件包 %3$s 的可用版本，因此不能满足 %2$s 所要求的 %1"
 "$s 依赖关系"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr "无法满足 %2$s 所要求 %1$s 依赖关系：已安装的软件包 %3$s 太新"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "无法满足 %2$s 所要求 %1$s 依赖关系：%3$s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "不能满足软件包 %s 所要求的构建依赖关系。"
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "无法处理构建依赖关系"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "支持的模块："
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1619,8 +1627,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "无法读取 %s"
@@ -1649,10 +1658,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "info 和 temp 目录要求处于同一文件系统之下"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "正在读取软件包列表"
 
@@ -1866,169 +1874,169 @@
 msgid "Write error"
 msgstr "写出错"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "无法创建套接字"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "无法连接上数据套接字，连接超时"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "无法连接被动模式的套接字。"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo 无法得到监听套接字"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "无法绑定套接字"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "无法在套接字上监听"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "无法确定套接字的名字"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "无法发出 PORT 指令"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "无法识别的地址族 %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT 指令出错，服务器响应信息为：%s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "数据套接字连接超时"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "无法接受连接"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "把文件加入哈希表时出错"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "无法获取文件，服务器响应信息为“%s”"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "数据套接字超时"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "数据传送出错，服务器响应信息为“%s”"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "查询"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "无法调用 "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "正在连接 %s (%s)"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "无法为 %s 创建套接字(f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "无法发起与 %s:%s (%s) 的连接"
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "无法连接上 %s:%s (%s)，连接超时"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "无法连接上 %s:%s (%s)。"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "正在连接 %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "无法解析域名“%s”"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "暂时不能解析域名“%s”"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "解析“%s:%s”时，出现了某些故障(%i)"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "不能连接到 %s：%s："
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "中止安装。"
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "内部错误：签名正确无误，但是无法确认密钥指纹？！"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "至少发现一个无效的签名。"
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "无法运行“%s”以验证签名(您安装了 gpgv 吗？)"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "运行 gpgv 时发生未知错误"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "下列签名无效：\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2105,19 +2113,19 @@
 msgid "Error reading from server"
 msgstr "从服务器读取数据出错"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "无法截断文件"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "错误的报头数据"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "连接失败"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "内部错误"
 
@@ -2185,7 +2193,7 @@
 msgid "%lis"
 msgstr "%li秒"
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "找不到您选则的 %s"
@@ -2308,6 +2316,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "无法切换工作目录到 %s"
@@ -2491,7 +2500,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "无法写入临时状态文件 %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2626,7 +2635,7 @@
 "无法修正错误，因为您要求某些软件包保持现状，就是它们破坏了软件包间的依赖关"
 "系。"
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2675,12 +2684,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "请把标有“%s”的盘片插入驱动器“%s”再按回车键。"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "不支持“%s”打包系统"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "无法确定适合的打包系统类型"
 
@@ -2693,25 +2702,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "您必须在您的 sources.list 写入一些“软件源”的 URI"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "无法解析或打开软件包的列表或是状态文件。"
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "您可能需要运行 apt-get update 来解决这些问题"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "首选项文件 %s 中发现有无效的记录，无 Package 字段头"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "无法识别锁定的类型 %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "没有为版本锁定指定优先级(或为零)"
 
@@ -2800,32 +2809,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "无法获取源软件包列表 %s 的状态"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "正在收集文件所提供的软件包"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "无法读取或写入软件源缓存"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "无法重命名文件，%s (%s -> %s)。"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5 校验和不符"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash 校验和不符"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "以下 ID 的密钥没有可用的公钥：\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2834,7 +2868,7 @@
 "我无法找到一个对应 %s 软件包的文件。在这种情况下可能需要您手动修正这个软件"
 "包。(缘于架构缺失)"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
@@ -2842,31 +2876,41 @@
 msgstr ""
 "我无法找到对应 %s 软件包的文件。在这种情况下您可能需要手动修正这个软件包。"
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "软件包的索引文件已损坏。找不到对应软件包 %s 的 Filename: 字段。"
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "大小不符"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "无法解析软件包仓库 Release 文件 %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "软件包仓库 Release 文件 %s 内无组件章节信息"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "软件包仓库 Release 文件 %s 内无哈希条目"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "软件包仓库 Release 文件 %s 内无哈希条目"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "软件包仓库 Release 文件 %s 内无哈希条目"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2963,151 +3007,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "对应于该盘片的软件源设置项是：\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "已写入 %i 条记录。\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "已写入 %i 条记录，并有 %i 个文件缺失。\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "已写入 %i 条记录，并有 %i 个文件不匹配\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "已写入 %i 条记录，并有 %i 个缺失，以及 %i 个文件不匹配\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "正在打开配置文件 %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash 校验和不符"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "注意，根据正则表达式“%2$s”选中了 %1$s\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "选定了版本为 %s (%s) 的 %s\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "正在安装 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "正在配置 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "正在删除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "完全删除了 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "执行安装后执行的触发器 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "目录 %s 不见了"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "无法打开文件 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "正在准备 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "正在解压缩 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "正在准备配置 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "已安装 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "正在准备 %s 的删除操作"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "已删除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "正在准备完全删除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "完全删除了 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "无法写入日志。 openpty() 失败(没有挂载 /dev/pts ？)\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr "正在运行 dpkg"
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr "无法锁定管理目录(%s)，是否有其他进程正占用它？"
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "无法对状态列表目录加锁(%s)，请查看您是否正以 root 用户运行？"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, fuzzy, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr "dpkg 被中断，您必须手工运行 'dpkg --configure -a' 解决此问题。"
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr "未锁定"
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3122,7 +3249,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "连接被永久关闭"
 

=== modified file 'po/zh_TW.po'
--- po/zh_TW.po	2010-05-25 16:01:42 +0000
+++ po/zh_TW.po	2010-06-10 14:02:22 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: 0.5.4\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-25 21:55+0200\n"
+"POT-Creation-Date: 2010-06-10 14:13+0200\n"
 "PO-Revision-Date: 2009-01-28 10:41+0800\n"
 "Last-Translator: Tetralet <tetralet@gmail.com>\n"
 "Language-Team: Debian-user in Chinese [Big5] <debian-chinese-big5@lists."
@@ -17,147 +17,145 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: cmdline/apt-cache.cc:143
+#: cmdline/apt-cache.cc:133
 #, c-format
 msgid "Package %s version %s has an unmet dep:\n"
 msgstr "套件 %s 版本 %s 未能滿足相依性：\n"
 
-#: cmdline/apt-cache.cc:183 cmdline/apt-cache.cc:554 cmdline/apt-cache.cc:648
-#: cmdline/apt-cache.cc:801 cmdline/apt-cache.cc:1025
-#: cmdline/apt-cache.cc:1453 cmdline/apt-cache.cc:1548
-#: cmdline/apt-cache.cc:1631
-#, c-format
-msgid "Unable to locate package %s"
-msgstr "找不到套件 %s"
-
-#: cmdline/apt-cache.cc:247
+#: cmdline/apt-cache.cc:258
 msgid "Total package names: "
 msgstr "套件名稱合計："
 
-#: cmdline/apt-cache.cc:249
+#: cmdline/apt-cache.cc:260
 #, fuzzy
 msgid "Total package structures: "
 msgstr "套件名稱合計："
 
-#: cmdline/apt-cache.cc:289
+#: cmdline/apt-cache.cc:300
 msgid "  Normal packages: "
 msgstr "  一般套件："
 
-#: cmdline/apt-cache.cc:290
+#: cmdline/apt-cache.cc:301
 msgid "  Pure virtual packages: "
 msgstr "  完全虛擬套件："
 
-#: cmdline/apt-cache.cc:291
+#: cmdline/apt-cache.cc:302
 msgid "  Single virtual packages: "
 msgstr "  單一虛擬套件："
 
-#: cmdline/apt-cache.cc:292
+#: cmdline/apt-cache.cc:303
 msgid "  Mixed virtual packages: "
 msgstr "  混合虛擬套件："
 
-#: cmdline/apt-cache.cc:293
+#: cmdline/apt-cache.cc:304
 msgid "  Missing: "
 msgstr "  找不到："
 
-#: cmdline/apt-cache.cc:295
+#: cmdline/apt-cache.cc:306
 msgid "Total distinct versions: "
 msgstr "個別版本合計："
 
-#: cmdline/apt-cache.cc:297
+#: cmdline/apt-cache.cc:308
 msgid "Total distinct descriptions: "
 msgstr "個別版本類別合計："
 
-#: cmdline/apt-cache.cc:299
+#: cmdline/apt-cache.cc:310
 msgid "Total dependencies: "
 msgstr "相依關係合計："
 
-#: cmdline/apt-cache.cc:302
+#: cmdline/apt-cache.cc:313
 msgid "Total ver/file relations: "
 msgstr "版本/檔案關聯合計："
 
-#: cmdline/apt-cache.cc:304
+#: cmdline/apt-cache.cc:315
 msgid "Total Desc/File relations: "
 msgstr "類別/檔案關聯合計："
 
-#: cmdline/apt-cache.cc:306
+#: cmdline/apt-cache.cc:317
 msgid "Total Provides mappings: "
 msgstr "提供者對應合計："
 
-#: cmdline/apt-cache.cc:318
+#: cmdline/apt-cache.cc:329
 msgid "Total globbed strings: "
 msgstr "所有字串合計："
 
-#: cmdline/apt-cache.cc:332
+#: cmdline/apt-cache.cc:343
 msgid "Total dependency version space: "
 msgstr "相依版本空間合計："
 
-#: cmdline/apt-cache.cc:337
+#: cmdline/apt-cache.cc:348
 msgid "Total slack space: "
 msgstr "間暇空間合計："
 
-#: cmdline/apt-cache.cc:345
+#: cmdline/apt-cache.cc:356
 msgid "Total space accounted for: "
 msgstr "統計後的空間合計："
 
-#: cmdline/apt-cache.cc:473 cmdline/apt-cache.cc:1225
+#: cmdline/apt-cache.cc:487 cmdline/apt-cache.cc:1217
 #, c-format
 msgid "Package file %s is out of sync."
 msgstr "套件檔 %s 未同步。"
 
-#: cmdline/apt-cache.cc:1301
-msgid "You must give exactly one pattern"
+#: cmdline/apt-cache.cc:1296
+#, fuzzy
+msgid "You must give at least one search pattern"
 msgstr "您必須明確得給定一個樣式"
 
-#: cmdline/apt-cache.cc:1482 cmdline/apt-cache.cc:1554
+#: cmdline/apt-cache.cc:1450 cmdline/apt-cache.cc:1526
 msgid "No packages found"
 msgstr "未找到套件"
 
-#: cmdline/apt-cache.cc:1573
+#: cmdline/apt-cache.cc:1520 apt-pkg/cacheset.cc:147
+#, c-format
+msgid "Unable to locate package %s"
+msgstr "找不到套件 %s"
+
+#: cmdline/apt-cache.cc:1550
 msgid "Package files:"
 msgstr "套件檔："
 
-#: cmdline/apt-cache.cc:1580 cmdline/apt-cache.cc:1682
+#: cmdline/apt-cache.cc:1557 cmdline/apt-cache.cc:1654
 msgid "Cache is out of sync, can't x-ref a package file"
 msgstr "快取資料未同步，無法 x-ref 套件檔"
 
 #. Show any packages have explicit pins
-#: cmdline/apt-cache.cc:1594
+#: cmdline/apt-cache.cc:1571
 msgid "Pinned packages:"
 msgstr "鎖定的套件："
 
-#: cmdline/apt-cache.cc:1606 cmdline/apt-cache.cc:1662
+#: cmdline/apt-cache.cc:1583 cmdline/apt-cache.cc:1634
 msgid "(not found)"
 msgstr "(未找到)"
 
-#: cmdline/apt-cache.cc:1615
+#: cmdline/apt-cache.cc:1592
 msgid "  Installed: "
 msgstr "  已安裝："
 
-#: cmdline/apt-cache.cc:1616
+#: cmdline/apt-cache.cc:1593
 msgid "  Candidate: "
 msgstr "  候選："
 
-#: cmdline/apt-cache.cc:1644 cmdline/apt-cache.cc:1652
+#: cmdline/apt-cache.cc:1616 cmdline/apt-cache.cc:1624
 msgid "(none)"
 msgstr "(無)"
 
-#: cmdline/apt-cache.cc:1659
+#: cmdline/apt-cache.cc:1631
 msgid "  Package pin: "
 msgstr "  套件鎖定："
 
 #. Show the priority tables
-#: cmdline/apt-cache.cc:1668
+#: cmdline/apt-cache.cc:1640
 msgid "  Version table:"
 msgstr "  版本列表："
 
-#: cmdline/apt-cache.cc:1779 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
+#: cmdline/apt-cache.cc:1747 cmdline/apt-cdrom.cc:197 cmdline/apt-config.cc:70
 #: cmdline/apt-extracttemplates.cc:225 ftparchive/apt-ftparchive.cc:584
-#: cmdline/apt-get.cc:2796 cmdline/apt-sortpkgs.cc:144
+#: cmdline/apt-get.cc:2797 cmdline/apt-sortpkgs.cc:144
 #, c-format
 msgid "%s %s for %s compiled on %s %s\n"
 msgstr "%s %s 是用於 %s 並在 %s %s 上編譯的\n"
 
-#: cmdline/apt-cache.cc:1786
+#: cmdline/apt-cache.cc:1754
 #, fuzzy
 msgid ""
 "Usage: apt-cache [options] command\n"
@@ -312,12 +310,12 @@
 "  -c=? 讀取指定的設定檔\n"
 "  -o=? 指定任意的設定選項，例如:-o dir::cache=/tmp\n"
 
-#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1030
+#: cmdline/apt-extracttemplates.cc:267 apt-pkg/pkgcachegen.cc:1036
 #, c-format
 msgid "Unable to write to %s"
 msgstr "無法寫入 %s"
 
-#: cmdline/apt-extracttemplates.cc:310
+#: cmdline/apt-extracttemplates.cc:309
 msgid "Cannot get debconf version. Is debconf installed?"
 msgstr "無法取得 debconf 版本。是否有安裝 debconf？"
 
@@ -649,79 +647,79 @@
 msgid "Failed to rename %s to %s"
 msgstr "無法將 %s 更名為 %s"
 
-#: cmdline/apt-get.cc:127
+#: cmdline/apt-get.cc:128
 msgid "Y"
 msgstr "Y"
 
-#: cmdline/apt-get.cc:149 cmdline/apt-get.cc:1803
+#: cmdline/apt-get.cc:150 apt-pkg/cacheset.cc:48
 #, c-format
 msgid "Regex compilation error - %s"
 msgstr "編譯正規表示式時發生錯誤 - %s"
 
-#: cmdline/apt-get.cc:244
+#: cmdline/apt-get.cc:245
 msgid "The following packages have unmet dependencies:"
 msgstr "下列的套件有未滿足的相依關係："
 
-#: cmdline/apt-get.cc:334
+#: cmdline/apt-get.cc:335
 #, c-format
 msgid "but %s is installed"
 msgstr "但 %s 卻已安裝"
 
-#: cmdline/apt-get.cc:336
+#: cmdline/apt-get.cc:337
 #, c-format
 msgid "but %s is to be installed"
 msgstr "但 %s 卻將被安裝"
 
-#: cmdline/apt-get.cc:343
+#: cmdline/apt-get.cc:344
 msgid "but it is not installable"
 msgstr "但它卻無法安裝"
 
-#: cmdline/apt-get.cc:345
+#: cmdline/apt-get.cc:346
 msgid "but it is a virtual package"
 msgstr "但它是虛擬套件"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not installed"
 msgstr "但它卻尚未安裝"
 
-#: cmdline/apt-get.cc:348
+#: cmdline/apt-get.cc:349
 msgid "but it is not going to be installed"
 msgstr "但它卻將不會被安裝"
 
-#: cmdline/apt-get.cc:353
+#: cmdline/apt-get.cc:354
 msgid " or"
 msgstr "或"
 
-#: cmdline/apt-get.cc:384
+#: cmdline/apt-get.cc:385
 msgid "The following NEW packages will be installed:"
 msgstr "下列【新】套件將會被安裝："
 
-#: cmdline/apt-get.cc:412
+#: cmdline/apt-get.cc:413
 msgid "The following packages will be REMOVED:"
 msgstr "下列套件將會被【移除】："
 
-#: cmdline/apt-get.cc:434
+#: cmdline/apt-get.cc:435
 msgid "The following packages have been kept back:"
 msgstr "下列套件將會維持其原有版本："
 
-#: cmdline/apt-get.cc:457
+#: cmdline/apt-get.cc:458
 msgid "The following packages will be upgraded:"
 msgstr "下列套件將會被升級："
 
-#: cmdline/apt-get.cc:480
+#: cmdline/apt-get.cc:481
 msgid "The following packages will be DOWNGRADED:"
 msgstr "下列套件將會被【降級】："
 
-#: cmdline/apt-get.cc:500
+#: cmdline/apt-get.cc:501
 msgid "The following held packages will be changed:"
 msgstr "下列被保留 (hold) 的套件將會被更改："
 
-#: cmdline/apt-get.cc:553
+#: cmdline/apt-get.cc:554
 #, c-format
 msgid "%s (due to %s) "
 msgstr "%s（因為 %s）"
 
-#: cmdline/apt-get.cc:561
+#: cmdline/apt-get.cc:562
 msgid ""
 "WARNING: The following essential packages will be removed.\n"
 "This should NOT be done unless you know exactly what you are doing!"
@@ -729,140 +727,140 @@
 "【警告】：下列的基本套件都將被移除。\n"
 "除非您很清楚您在做什麼，否則請勿輕易嘗試！"
 
-#: cmdline/apt-get.cc:595
+#: cmdline/apt-get.cc:596
 #, c-format
 msgid "%lu upgraded, %lu newly installed, "
 msgstr "升級 %lu 個，新安裝 %lu 個，"
 
-#: cmdline/apt-get.cc:599
+#: cmdline/apt-get.cc:600
 #, c-format
 msgid "%lu reinstalled, "
 msgstr "重新安裝 %lu 個，"
 
-#: cmdline/apt-get.cc:601
+#: cmdline/apt-get.cc:602
 #, c-format
 msgid "%lu downgraded, "
 msgstr "降級 %lu 個，"
 
-#: cmdline/apt-get.cc:603
+#: cmdline/apt-get.cc:604
 #, c-format
 msgid "%lu to remove and %lu not upgraded.\n"
 msgstr "移除 %lu 個，有 %lu 個未被升級。\n"
 
-#: cmdline/apt-get.cc:607
+#: cmdline/apt-get.cc:608
 #, c-format
 msgid "%lu not fully installed or removed.\n"
 msgstr "%lu 個沒有完整得安裝或移除。\n"
 
-#: cmdline/apt-get.cc:680
+#: cmdline/apt-get.cc:681
 msgid "Correcting dependencies..."
 msgstr "正在修正相依關係..."
 
-#: cmdline/apt-get.cc:683
+#: cmdline/apt-get.cc:684
 msgid " failed."
 msgstr " 失敗。"
 
-#: cmdline/apt-get.cc:686
+#: cmdline/apt-get.cc:687
 msgid "Unable to correct dependencies"
 msgstr "無法修正相依關係"
 
-#: cmdline/apt-get.cc:689
+#: cmdline/apt-get.cc:690
 msgid "Unable to minimize the upgrade set"
 msgstr "無法將升級計劃最小化"
 
-#: cmdline/apt-get.cc:691
+#: cmdline/apt-get.cc:692
 msgid " Done"
 msgstr " 完成"
 
-#: cmdline/apt-get.cc:695
+#: cmdline/apt-get.cc:696
 msgid "You might want to run 'apt-get -f install' to correct these."
 msgstr "您也許得執行 'apt-get -f install' 以修正這些問題。"
 
-#: cmdline/apt-get.cc:698
+#: cmdline/apt-get.cc:699
 msgid "Unmet dependencies. Try using -f."
 msgstr "未能滿足相依關係。試試 -f 選項。"
 
-#: cmdline/apt-get.cc:723
+#: cmdline/apt-get.cc:724
 msgid "WARNING: The following packages cannot be authenticated!"
 msgstr "【警告】：無法驗證下列套件！"
 
-#: cmdline/apt-get.cc:727
+#: cmdline/apt-get.cc:728
 msgid "Authentication warning overridden.\n"
 msgstr "忽略了驗證警告。\n"
 
-#: cmdline/apt-get.cc:734
+#: cmdline/apt-get.cc:735
 msgid "Install these packages without verification [y/N]? "
 msgstr "是否不經驗證就安裝這些套件？[y/N]"
 
-#: cmdline/apt-get.cc:736
+#: cmdline/apt-get.cc:737
 msgid "Some packages could not be authenticated"
 msgstr "有部份套件無法驗證"
 
-#: cmdline/apt-get.cc:745 cmdline/apt-get.cc:900
+#: cmdline/apt-get.cc:746 cmdline/apt-get.cc:901
 msgid "There are problems and -y was used without --force-yes"
 msgstr "發生了問題，且 -y 並沒有和 --force-yes 搭配使用"
 
-#: cmdline/apt-get.cc:786
+#: cmdline/apt-get.cc:787
 msgid "Internal error, InstallPackages was called with broken packages!"
 msgstr "內部錯誤，在損毀的套件上執行 InstallPackages！"
 
-#: cmdline/apt-get.cc:795
+#: cmdline/apt-get.cc:796
 msgid "Packages need to be removed but remove is disabled."
 msgstr "有套件需要被移除，但卻被禁止移除。"
 
-#: cmdline/apt-get.cc:806
+#: cmdline/apt-get.cc:807
 msgid "Internal error, Ordering didn't finish"
 msgstr "內部錯誤，排序未能完成"
 
-#: cmdline/apt-get.cc:831 cmdline/apt-get.cc:2272 cmdline/apt-get.cc:2536
-#: apt-pkg/cachefile.cc:65
+#: cmdline/apt-get.cc:832 cmdline/apt-get.cc:2246 cmdline/apt-get.cc:2537
+#: apt-pkg/cachefile.cc:106
 msgid "The list of sources could not be read."
 msgstr "無法讀取來源列表。"
 
-#: cmdline/apt-get.cc:846
+#: cmdline/apt-get.cc:847
 msgid "How odd.. The sizes didn't match, email apt@packages.debian.org"
 msgstr "怪哉... 檔案大小不符，請發信給 apt@packages.debian.org"
 
-#: cmdline/apt-get.cc:851
+#: cmdline/apt-get.cc:852
 #, c-format
 msgid "Need to get %sB/%sB of archives.\n"
 msgstr "需要下載 %sB/%sB 的套件檔。\n"
 
-#: cmdline/apt-get.cc:854
+#: cmdline/apt-get.cc:855
 #, c-format
 msgid "Need to get %sB of archives.\n"
 msgstr "需要下載 %sB 的套件檔。\n"
 
-#: cmdline/apt-get.cc:859
+#: cmdline/apt-get.cc:860
 #, c-format
 msgid "After this operation, %sB of additional disk space will be used.\n"
 msgstr "此操作完成之後，會多佔用 %sB 的磁碟空間。\n"
 
-#: cmdline/apt-get.cc:862
+#: cmdline/apt-get.cc:863
 #, c-format
 msgid "After this operation, %sB disk space will be freed.\n"
 msgstr "此操作完成之後，會空出 %sB 的磁碟空間。\n"
 
-#: cmdline/apt-get.cc:877 cmdline/apt-get.cc:880 cmdline/apt-get.cc:2374
-#: cmdline/apt-get.cc:2377
+#: cmdline/apt-get.cc:878 cmdline/apt-get.cc:881 cmdline/apt-get.cc:2375
+#: cmdline/apt-get.cc:2378
 #, c-format
 msgid "Couldn't determine free space in %s"
 msgstr "無法確認 %s 的未使用空間"
 
-#: cmdline/apt-get.cc:890
+#: cmdline/apt-get.cc:891
 #, c-format
 msgid "You don't have enough free space in %s."
 msgstr "在 %s 裡沒有足夠的的未使用空間。"
 
-#: cmdline/apt-get.cc:906 cmdline/apt-get.cc:926
+#: cmdline/apt-get.cc:907 cmdline/apt-get.cc:927
 msgid "Trivial Only specified but this is not a trivial operation."
 msgstr "雖然指定了 Trivial Only（自動答 NO）選項，但這並不是 trivial 操作。"
 
-#: cmdline/apt-get.cc:908
+#: cmdline/apt-get.cc:909
 msgid "Yes, do as I say!"
 msgstr "Yes, do as I say!"
 
-#: cmdline/apt-get.cc:910
+#: cmdline/apt-get.cc:911
 #, c-format
 msgid ""
 "You are about to do something potentially harmful.\n"
@@ -873,28 +871,28 @@
 "請輸入 '%s' 這個句子以繼續進行\n"
 " ?] "
 
-#: cmdline/apt-get.cc:916 cmdline/apt-get.cc:935
+#: cmdline/apt-get.cc:917 cmdline/apt-get.cc:936
 msgid "Abort."
 msgstr "放棄執行。"
 
-#: cmdline/apt-get.cc:931
+#: cmdline/apt-get.cc:932
 msgid "Do you want to continue [Y/n]? "
 msgstr "是否繼續進行 [Y/n]？"
 
-#: cmdline/apt-get.cc:1003 cmdline/apt-get.cc:2430 apt-pkg/algorithms.cc:1435
+#: cmdline/apt-get.cc:1004 cmdline/apt-get.cc:2431 apt-pkg/algorithms.cc:1434
 #, c-format
 msgid "Failed to fetch %s  %s\n"
 msgstr "無法取得 %s，%s\n"
 
-#: cmdline/apt-get.cc:1021
+#: cmdline/apt-get.cc:1022
 msgid "Some files failed to download"
 msgstr "有部份檔案無法下載"
 
-#: cmdline/apt-get.cc:1022 cmdline/apt-get.cc:2439
+#: cmdline/apt-get.cc:1023 cmdline/apt-get.cc:2440
 msgid "Download complete and in download only mode"
 msgstr "下載完成，且這是『僅下載』模式"
 
-#: cmdline/apt-get.cc:1028
+#: cmdline/apt-get.cc:1029
 msgid ""
 "Unable to fetch some archives, maybe run apt-get update or try with --fix-"
 "missing?"
@@ -902,19 +900,19 @@
 "有部份套件檔無法取得，試著執行 apt-get update 或者試著加上 --fix-missing 選"
 "項？"
 
-#: cmdline/apt-get.cc:1032
+#: cmdline/apt-get.cc:1033
 msgid "--fix-missing and media swapping is not currently supported"
 msgstr "目前尚未支援 --fix-missing 和媒體抽換"
 
-#: cmdline/apt-get.cc:1037
+#: cmdline/apt-get.cc:1038
 msgid "Unable to correct missing packages."
 msgstr "無法修正欠缺的套件。"
 
-#: cmdline/apt-get.cc:1038
+#: cmdline/apt-get.cc:1039
 msgid "Aborting install."
 msgstr "放棄安裝。"
 
-#: cmdline/apt-get.cc:1066
+#: cmdline/apt-get.cc:1067
 msgid ""
 "The following package disappeared from your system as\n"
 "all files have been overwritten by other packages:"
@@ -924,49 +922,49 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cmdline/apt-get.cc:1070
+#: cmdline/apt-get.cc:1071
 msgid "Note: This is done automatic and on purpose by dpkg."
 msgstr ""
 
-#: cmdline/apt-get.cc:1113
+#: cmdline/apt-get.cc:1114
 #, c-format
 msgid "Note, selecting %s instead of %s\n"
 msgstr "注意，選擇了以 %s 替代 %s\n"
 
-#: cmdline/apt-get.cc:1124
+#: cmdline/apt-get.cc:1125
 #, c-format
 msgid "Skipping %s, it is already installed and upgrade is not set.\n"
 msgstr "忽略 %s，它已被安裝且沒有計劃要進行升級。\n"
 
-#: cmdline/apt-get.cc:1134
+#: cmdline/apt-get.cc:1135
 #, fuzzy, c-format
 msgid "Skipping %s, it is not installed and only upgrades are requested.\n"
 msgstr "忽略 %s，它已被安裝且沒有計劃要進行升級。\n"
 
-#: cmdline/apt-get.cc:1152
+#: cmdline/apt-get.cc:1153
 #, c-format
 msgid "Package %s is not installed, so not removed\n"
 msgstr "套件 %s 並沒有被安裝，所以也不會被移除\n"
 
-#: cmdline/apt-get.cc:1163
+#: cmdline/apt-get.cc:1164
 #, c-format
 msgid "Package %s is a virtual package provided by:\n"
 msgstr "套件 %s 是虛擬套件，提供者為：\n"
 
-#: cmdline/apt-get.cc:1176
+#: cmdline/apt-get.cc:1177
 msgid " [Installed]"
 msgstr "【已安裝】"
 
-#: cmdline/apt-get.cc:1185
+#: cmdline/apt-get.cc:1186
 #, fuzzy
 msgid " [Not candidate version]"
 msgstr "候選版本"
 
-#: cmdline/apt-get.cc:1187
+#: cmdline/apt-get.cc:1188
 msgid "You should explicitly select one to install."
 msgstr "請您明確地選擇一個來進行安裝。"
 
-#: cmdline/apt-get.cc:1192
+#: cmdline/apt-get.cc:1193
 #, c-format
 msgid ""
 "Package %s is not available, but is referred to by another package.\n"
@@ -976,65 +974,65 @@
 "無法取得套件 %s，但它卻被其它的套件引用了。\n"
 "這意味著這個套件可能已經消失了、被廢棄了，或是只能由其他的來源取得\n"
 
-#: cmdline/apt-get.cc:1211
+#: cmdline/apt-get.cc:1212
 msgid "However the following packages replace it:"
 msgstr "然而，下列的套件取代了它："
 
-#: cmdline/apt-get.cc:1214
+#: cmdline/apt-get.cc:1215
 #, c-format
 msgid "Package %s has no installation candidate"
 msgstr "套件 %s 沒有可安裝的候選版本"
 
-#: cmdline/apt-get.cc:1234
+#: cmdline/apt-get.cc:1235
 #, c-format
 msgid "Reinstallation of %s is not possible, it cannot be downloaded.\n"
 msgstr "無法重新安裝 %s，因為它無法下載。\n"
 
-#: cmdline/apt-get.cc:1242
+#: cmdline/apt-get.cc:1243
 #, c-format
 msgid "%s is already the newest version.\n"
 msgstr "%s 已經是最新版本了。\n"
 
-#: cmdline/apt-get.cc:1271
+#: cmdline/apt-get.cc:1272 apt-pkg/cacheset.cc:183
 #, c-format
 msgid "Release '%s' for '%s' was not found"
 msgstr "找不到 '%2$s' 的 '%1$s' 發行版"
 
-#: cmdline/apt-get.cc:1273
+#: cmdline/apt-get.cc:1274 apt-pkg/cacheset.cc:186
 #, c-format
 msgid "Version '%s' for '%s' was not found"
 msgstr "找不到 '%s' 版的 '%s'"
 
-#: cmdline/apt-get.cc:1279
+#: cmdline/apt-get.cc:1280
 #, c-format
 msgid "Selected version %s (%s) for %s\n"
 msgstr "選定的版本為 %3$s 的 %1$s (%2$s)\n"
 
-#: cmdline/apt-get.cc:1384
+#: cmdline/apt-get.cc:1385
 #, c-format
 msgid "Ignore unavailable target release '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1416
+#: cmdline/apt-get.cc:1417
 #, fuzzy, c-format
 msgid "Picking '%s' as source package instead of '%s'\n"
 msgstr "無法取得來源套件列表 %s 的狀態"
 
 #. if (VerTag.empty() == false && Last == 0)
-#: cmdline/apt-get.cc:1454
+#: cmdline/apt-get.cc:1455
 #, c-format
 msgid "Ignore unavailable version '%s' of package '%s'"
 msgstr ""
 
-#: cmdline/apt-get.cc:1470
+#: cmdline/apt-get.cc:1471
 msgid "The update command takes no arguments"
 msgstr "update 指令不需任何參數"
 
-#: cmdline/apt-get.cc:1535
+#: cmdline/apt-get.cc:1536
 msgid "We are not supposed to delete stuff, can't start AutoRemover"
 msgstr "我們沒有計劃要刪除任何東西，無法啟動 AutoRemover"
 
-#: cmdline/apt-get.cc:1583
+#: cmdline/apt-get.cc:1584
 #, fuzzy
 msgid ""
 "The following package is automatically installed and is no longer required:"
@@ -1044,7 +1042,7 @@
 msgstr[0] "以下套件是被自動安裝進來的，且已不再會被用到了："
 msgstr[1] "以下套件是被自動安裝進來的，且已不再會被用到了："
 
-#: cmdline/apt-get.cc:1587
+#: cmdline/apt-get.cc:1588
 #, fuzzy, c-format
 msgid "%lu package was automatically installed and is no longer required.\n"
 msgid_plural ""
@@ -1052,11 +1050,11 @@
 msgstr[0] "以下套件是被自動安裝進來的，且已不再會被用到了："
 msgstr[1] "以下套件是被自動安裝進來的，且已不再會被用到了："
 
-#: cmdline/apt-get.cc:1589
+#: cmdline/apt-get.cc:1590
 msgid "Use 'apt-get autoremove' to remove them."
 msgstr "使用 'apt-get autoremove' 來將其移除。"
 
-#: cmdline/apt-get.cc:1594
+#: cmdline/apt-get.cc:1595
 msgid ""
 "Hmm, seems like the AutoRemover destroyed something which really\n"
 "shouldn't happen. Please file a bug report against apt."
@@ -1074,43 +1072,38 @@
 #. "that package should be filed.") << endl;
 #. }
 #.
-#: cmdline/apt-get.cc:1597 cmdline/apt-get.cc:1892
+#: cmdline/apt-get.cc:1598 cmdline/apt-get.cc:1866
 msgid "The following information may help to resolve the situation:"
 msgstr "以下的資訊或許有助於解決當前的情況："
 
-#: cmdline/apt-get.cc:1601
+#: cmdline/apt-get.cc:1602
 msgid "Internal Error, AutoRemover broke stuff"
 msgstr "內部錯誤，AutoRemover 處理失敗"
 
-#: cmdline/apt-get.cc:1620
+#: cmdline/apt-get.cc:1621
 msgid "Internal error, AllUpgrade broke stuff"
 msgstr "內部錯誤，AllUpgrade 造成了損壞"
 
-#: cmdline/apt-get.cc:1675
+#: cmdline/apt-get.cc:1676
 #, c-format
 msgid "Couldn't find task %s"
 msgstr "無法找到主題 %s"
 
-#: cmdline/apt-get.cc:1790 cmdline/apt-get.cc:1829 cmdline/apt-get.cc:2056
+#: cmdline/apt-get.cc:1786 cmdline/apt-get.cc:1803 cmdline/apt-get.cc:2030
 #, c-format
 msgid "Couldn't find package %s"
 msgstr "無法找到套件 %s"
 
-#: cmdline/apt-get.cc:1816
-#, c-format
-msgid "Note, selecting %s for regex '%s'\n"
-msgstr "注意，根據正規表示式 '%2$s' 而選擇了 %1$s\n"
-
-#: cmdline/apt-get.cc:1849 cmdline/apt-get.cc:2061
+#: cmdline/apt-get.cc:1823 cmdline/apt-get.cc:2035
 #, c-format
 msgid "%s set to manually installed.\n"
 msgstr "%s 被設定為手動安裝。\n"
 
-#: cmdline/apt-get.cc:1862
+#: cmdline/apt-get.cc:1836
 msgid "You might want to run 'apt-get -f install' to correct these:"
 msgstr "您也許得執行 'apt-get -f install' 以修正這些問題："
 
-#: cmdline/apt-get.cc:1865
+#: cmdline/apt-get.cc:1839
 msgid ""
 "Unmet dependencies. Try 'apt-get -f install' with no packages (or specify a "
 "solution)."
@@ -1118,7 +1111,7 @@
 "未能滿足相依關係。請試著不指定套件來執行 'apt-get -f install'（或採取其它的解"
 "決方案）。"
 
-#: cmdline/apt-get.cc:1877
+#: cmdline/apt-get.cc:1851
 msgid ""
 "Some packages could not be installed. This may mean that you have\n"
 "requested an impossible situation or if you are using the unstable\n"
@@ -1128,131 +1121,146 @@
 "有些套件無法安裝。這可能意謂著您的要求難以解決，或是若您使用的是\n"
 "unstable 發行版，可能有些必要的套件尚未建立，或是被移出 Incoming 了。"
 
-#: cmdline/apt-get.cc:1895
+#: cmdline/apt-get.cc:1869
 msgid "Broken packages"
 msgstr "損毀的套件"
 
-#: cmdline/apt-get.cc:1924
+#: cmdline/apt-get.cc:1898
 msgid "The following extra packages will be installed:"
 msgstr "下列的額外套件將被安裝："
 
-#: cmdline/apt-get.cc:2014
+#: cmdline/apt-get.cc:1988
 msgid "Suggested packages:"
 msgstr "建議套件："
 
-#: cmdline/apt-get.cc:2015
+#: cmdline/apt-get.cc:1989
 msgid "Recommended packages:"
 msgstr "推薦套件："
 
-#: cmdline/apt-get.cc:2063
+#: cmdline/apt-get.cc:2037
 #, fuzzy, c-format
 msgid "%s set to automatically installed.\n"
 msgstr "%s 被設定為手動安裝。\n"
 
-#: cmdline/apt-get.cc:2084
+#: cmdline/apt-get.cc:2058
 msgid "Calculating upgrade... "
 msgstr "籌備升級中... "
 
-#: cmdline/apt-get.cc:2087 methods/ftp.cc:708 methods/connect.cc:112
+#: cmdline/apt-get.cc:2061 methods/ftp.cc:707 methods/connect.cc:111
 msgid "Failed"
 msgstr "失敗"
 
-#: cmdline/apt-get.cc:2092
+#: cmdline/apt-get.cc:2066
 msgid "Done"
 msgstr "完成"
 
-#: cmdline/apt-get.cc:2159 cmdline/apt-get.cc:2167
+#: cmdline/apt-get.cc:2133 cmdline/apt-get.cc:2141
 msgid "Internal error, problem resolver broke stuff"
 msgstr "內部錯誤，問題排除器造成了損壞"
 
-#: cmdline/apt-get.cc:2191 cmdline/apt-get.cc:2224
+#: cmdline/apt-get.cc:2165 cmdline/apt-get.cc:2198
 msgid "Unable to lock the download directory"
 msgstr "無法鎖定下載目錄"
 
-#: cmdline/apt-get.cc:2267
+#: cmdline/apt-get.cc:2241
 msgid "Must specify at least one package to fetch source for"
 msgstr "在取得原始碼時必須至少指定一個套件"
 
-#: cmdline/apt-get.cc:2307 cmdline/apt-get.cc:2556
+#: cmdline/apt-get.cc:2281 cmdline/apt-get.cc:2557
 #, c-format
 msgid "Unable to find a source package for %s"
 msgstr "無法找到 %s 的原始碼套件"
 
-#: cmdline/apt-get.cc:2352
+#: cmdline/apt-get.cc:2297
+#, c-format
+msgid ""
+"NOTICE: '%s' packaging is maintained in the '%s' version control system at:\n"
+"%s\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2302
+#, c-format
+msgid ""
+"Please use:\n"
+"bzr get %s\n"
+"to retrieve the latest (possibly unreleased) updates to the package.\n"
+msgstr ""
+
+#: cmdline/apt-get.cc:2353
 #, c-format
 msgid "Skipping already downloaded file '%s'\n"
 msgstr "略過已下載的檔案 '%s'\n"
 
-#: cmdline/apt-get.cc:2387
+#: cmdline/apt-get.cc:2388
 #, c-format
 msgid "You don't have enough free space in %s"
 msgstr "在 %s 裡沒有足夠的的未使用空間"
 
-#: cmdline/apt-get.cc:2393
+#: cmdline/apt-get.cc:2394
 #, c-format
 msgid "Need to get %sB/%sB of source archives.\n"
 msgstr "需要下載 %sB/%sB 的原始套件檔。\n"
 
-#: cmdline/apt-get.cc:2396
+#: cmdline/apt-get.cc:2397
 #, c-format
 msgid "Need to get %sB of source archives.\n"
 msgstr "需要下載 %sB 的原始套件檔。\n"
 
-#: cmdline/apt-get.cc:2402
+#: cmdline/apt-get.cc:2403
 #, c-format
 msgid "Fetch source %s\n"
 msgstr "取得原始碼 %s\n"
 
-#: cmdline/apt-get.cc:2435
+#: cmdline/apt-get.cc:2436
 msgid "Failed to fetch some archives."
 msgstr "無法取得某些套件檔。"
 
-#: cmdline/apt-get.cc:2465
+#: cmdline/apt-get.cc:2466
 #, c-format
 msgid "Skipping unpack of already unpacked source in %s\n"
 msgstr "不解開，因原始碼已解開至 %s\n"
 
-#: cmdline/apt-get.cc:2477
+#: cmdline/apt-get.cc:2478
 #, c-format
 msgid "Unpack command '%s' failed.\n"
 msgstr "解開指令 '%s' 失敗。\n"
 
-#: cmdline/apt-get.cc:2478
+#: cmdline/apt-get.cc:2479
 #, c-format
 msgid "Check if the 'dpkg-dev' package is installed.\n"
 msgstr "請檢查是否已安裝了 'dpkg-dev' 套件。\n"
 
-#: cmdline/apt-get.cc:2495
+#: cmdline/apt-get.cc:2496
 #, c-format
 msgid "Build command '%s' failed.\n"
 msgstr "編譯指令 '%s' 失敗。\n"
 
-#: cmdline/apt-get.cc:2515
+#: cmdline/apt-get.cc:2516
 msgid "Child process failed"
 msgstr "子程序失敗"
 
-#: cmdline/apt-get.cc:2531
+#: cmdline/apt-get.cc:2532
 msgid "Must specify at least one package to check builddeps for"
 msgstr "在檢查編譯相依關係時必須至少指定一個套件"
 
-#: cmdline/apt-get.cc:2561
+#: cmdline/apt-get.cc:2562
 #, c-format
 msgid "Unable to get build-dependency information for %s"
 msgstr "無法取得 %s 的編譯相依關係資訊"
 
-#: cmdline/apt-get.cc:2581
+#: cmdline/apt-get.cc:2582
 #, c-format
 msgid "%s has no build depends.\n"
 msgstr "%s 沒有編譯相依關係。\n"
 
-#: cmdline/apt-get.cc:2633
+#: cmdline/apt-get.cc:2634
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because the package %s cannot be "
 "found"
 msgstr "無法滿足 %2$s 所要求的 %1$s 相依關係，因為找不到套件 %3$s"
 
-#: cmdline/apt-get.cc:2686
+#: cmdline/apt-get.cc:2687
 #, c-format
 msgid ""
 "%s dependency for %s cannot be satisfied because no available versions of "
@@ -1260,30 +1268,30 @@
 msgstr ""
 "無法滿足 %2$s 所要求的 %1$s 相依關係，因為套件 %3$s 沒有版本符合其版本需求"
 
-#: cmdline/apt-get.cc:2722
+#: cmdline/apt-get.cc:2723
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: Installed package %s is too new"
 msgstr "無法滿足 %2$s 的相依關係 %1$s：已安裝的套件 %3$s 太新了"
 
-#: cmdline/apt-get.cc:2749
+#: cmdline/apt-get.cc:2750
 #, c-format
 msgid "Failed to satisfy %s dependency for %s: %s"
 msgstr "無法滿足 %2$s 的相依關係 %1$s：%3$s"
 
-#: cmdline/apt-get.cc:2765
+#: cmdline/apt-get.cc:2766
 #, c-format
 msgid "Build-dependencies for %s could not be satisfied."
 msgstr "無法滿足套件 %s 的編譯相依關係。"
 
-#: cmdline/apt-get.cc:2770
+#: cmdline/apt-get.cc:2771
 msgid "Failed to process build dependencies"
 msgstr "無法處理編譯相依關係"
 
-#: cmdline/apt-get.cc:2801
+#: cmdline/apt-get.cc:2802
 msgid "Supported modules:"
 msgstr "已支援模組："
 
-#: cmdline/apt-get.cc:2842
+#: cmdline/apt-get.cc:2843
 #, fuzzy
 msgid ""
 "Usage: apt-get [options] command\n"
@@ -1615,8 +1623,9 @@
 #. Only warn if there is no sources.list file.
 #: apt-inst/extract.cc:464 apt-pkg/contrib/cdromutl.cc:166
 #: apt-pkg/contrib/fileutl.cc:287 apt-pkg/sourcelist.cc:204
-#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:92
-#: apt-pkg/init.cc:100 apt-pkg/clean.cc:33 apt-pkg/policy.cc:296
+#: apt-pkg/sourcelist.cc:210 apt-pkg/acquire.cc:471 apt-pkg/init.cc:93
+#: apt-pkg/init.cc:101 apt-pkg/clean.cc:33 apt-pkg/policy.cc:306
+#: methods/mirror.cc:87
 #, c-format
 msgid "Unable to read %s"
 msgstr "無法讀取 %s"
@@ -1645,10 +1654,9 @@
 msgid "The info and temp directories need to be on the same filesystem"
 msgstr "資料目錄與暫存目錄需位於同一檔案系統中"
 
-#. Build the status cache
-#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:947
-#: apt-pkg/pkgcachegen.cc:1032 apt-pkg/pkgcachegen.cc:1037
-#: apt-pkg/pkgcachegen.cc:1181
+#: apt-inst/deb/dpkgdb.cc:135 apt-pkg/pkgcachegen.cc:948
+#: apt-pkg/pkgcachegen.cc:1039 apt-pkg/pkgcachegen.cc:1045
+#: apt-pkg/pkgcachegen.cc:1192
 msgid "Reading package lists"
 msgstr "正在讀取套件清單"
 
@@ -1861,169 +1869,169 @@
 msgid "Write error"
 msgstr "寫入錯誤"
 
-#: methods/ftp.cc:693 methods/ftp.cc:699 methods/ftp.cc:735
+#: methods/ftp.cc:692 methods/ftp.cc:698 methods/ftp.cc:734
 msgid "Could not create a socket"
 msgstr "無法建立 Socket"
 
-#: methods/ftp.cc:704
+#: methods/ftp.cc:703
 msgid "Could not connect data socket, connection timed out"
 msgstr "無法和 data socket 連線，連線逾時"
 
-#: methods/ftp.cc:710
+#: methods/ftp.cc:709
 msgid "Could not connect passive socket."
 msgstr "無法和 passive socket 連線。"
 
-#: methods/ftp.cc:728
+#: methods/ftp.cc:727
 msgid "getaddrinfo was unable to get a listening socket"
 msgstr "getaddrinfo 無法取得監聽 socket"
 
-#: methods/ftp.cc:742
+#: methods/ftp.cc:741
 msgid "Could not bind a socket"
 msgstr "無法 bind 至 socket"
 
-#: methods/ftp.cc:746
+#: methods/ftp.cc:745
 msgid "Could not listen on the socket"
 msgstr "無法監聽 socket"
 
-#: methods/ftp.cc:753
+#: methods/ftp.cc:752
 msgid "Could not determine the socket's name"
 msgstr "無法解析 socket 名稱"
 
-#: methods/ftp.cc:785
+#: methods/ftp.cc:784
 msgid "Unable to send PORT command"
 msgstr "無法送出 PORT 指令"
 
-#: methods/ftp.cc:795
+#: methods/ftp.cc:794
 #, c-format
 msgid "Unknown address family %u (AF_*)"
 msgstr "未知的地址家族 %u (AF_*)"
 
-#: methods/ftp.cc:804
+#: methods/ftp.cc:803
 #, c-format
 msgid "EPRT failed, server said: %s"
 msgstr "EPRT 指令失敗，伺服器回應：%s"
 
-#: methods/ftp.cc:824
+#: methods/ftp.cc:823
 msgid "Data socket connect timed out"
 msgstr "Data socket 連線逾時"
 
-#: methods/ftp.cc:831
+#: methods/ftp.cc:830
 msgid "Unable to accept connection"
 msgstr "無法接受連線"
 
-#: methods/ftp.cc:870 methods/http.cc:997 methods/rsh.cc:303
+#: methods/ftp.cc:869 methods/http.cc:1000 methods/rsh.cc:302
 msgid "Problem hashing file"
 msgstr "有問題的雜湊檔"
 
-#: methods/ftp.cc:883
+#: methods/ftp.cc:882
 #, c-format
 msgid "Unable to fetch file, server said '%s'"
 msgstr "無法取得檔案，伺服器回應 '%s'"
 
-#: methods/ftp.cc:898 methods/rsh.cc:322
+#: methods/ftp.cc:897 methods/rsh.cc:321
 msgid "Data socket timed out"
 msgstr "Data socket 連線逾時"
 
-#: methods/ftp.cc:928
+#: methods/ftp.cc:927
 #, c-format
 msgid "Data transfer failed, server said '%s'"
 msgstr "資料傳輸失敗，伺服器回應 '%s'"
 
 #. Get the files information
-#: methods/ftp.cc:1005
+#: methods/ftp.cc:1004
 msgid "Query"
 msgstr "查詢"
 
-#: methods/ftp.cc:1117
+#: methods/ftp.cc:1116
 msgid "Unable to invoke "
 msgstr "無法 invoke "
 
-#: methods/connect.cc:70
+#: methods/connect.cc:71
 #, c-format
 msgid "Connecting to %s (%s)"
 msgstr "正和 %s (%s) 連線"
 
-#: methods/connect.cc:81
+#: methods/connect.cc:82
 #, c-format
 msgid "[IP: %s %s]"
 msgstr "[IP: %s %s]"
 
-#: methods/connect.cc:90
+#: methods/connect.cc:89
 #, c-format
 msgid "Could not create a socket for %s (f=%u t=%u p=%u)"
 msgstr "無法建立 socket 指向 %s (f=%u t=%u p=%u)"
 
-#: methods/connect.cc:96
+#: methods/connect.cc:95
 #, c-format
 msgid "Cannot initiate the connection to %s:%s (%s)."
 msgstr "無法初始和 %s:%s (%s) 的連線。"
 
-#: methods/connect.cc:104
+#: methods/connect.cc:103
 #, c-format
 msgid "Could not connect to %s:%s (%s), connection timed out"
 msgstr "無法和 %s:%s (%s) 連線，連線逾時"
 
-#: methods/connect.cc:122
+#: methods/connect.cc:121
 #, c-format
 msgid "Could not connect to %s:%s (%s)."
 msgstr "無法和 %s:%s (%s) 連線。"
 
 #. We say this mainly because the pause here is for the
 #. ssh connection that is still going
-#: methods/connect.cc:150 methods/rsh.cc:425
+#: methods/connect.cc:149 methods/rsh.cc:424
 #, c-format
 msgid "Connecting to %s"
 msgstr "正連線至 %s"
 
-#: methods/connect.cc:169 methods/connect.cc:188
+#: methods/connect.cc:168 methods/connect.cc:187
 #, c-format
 msgid "Could not resolve '%s'"
 msgstr "無法解析 '%s'"
 
-#: methods/connect.cc:194
+#: methods/connect.cc:193
 #, c-format
 msgid "Temporary failure resolving '%s'"
 msgstr "暫時無法解析 '%s'"
 
-#: methods/connect.cc:197
+#: methods/connect.cc:196
 #, fuzzy, c-format
 msgid "Something wicked happened resolving '%s:%s' (%i - %s)"
 msgstr "在解析 '%s:%s' (%i) 時出了怪事"
 
-#: methods/connect.cc:244
+#: methods/connect.cc:243
 #, fuzzy, c-format
 msgid "Unable to connect to %s:%s:"
 msgstr "無法連線至 %s %s："
 
 #. TRANSLATOR: %s is the trusted keyring parts directory
-#: methods/gpgv.cc:80
+#: methods/gpgv.cc:71
 #, fuzzy, c-format
 msgid "No keyring installed in %s."
 msgstr "放棄安裝。"
 
-#: methods/gpgv.cc:229
+#: methods/gpgv.cc:163
 msgid ""
 "Internal error: Good signature, but could not determine key fingerprint?!"
 msgstr "內部錯誤：簽章無誤，但卻無法辨識密鑰的指紋碼？！"
 
-#: methods/gpgv.cc:234
+#: methods/gpgv.cc:168
 msgid "At least one invalid signature was encountered."
 msgstr "至少發現一個無效的簽章。"
 
-#: methods/gpgv.cc:238
-#, c-format
-msgid "Could not execute '%s' to verify signature (is gpgv installed?)"
+#: methods/gpgv.cc:172
+#, fuzzy
+msgid "Could not execute 'gpgv' to verify signature (is gpgv installed?)"
 msgstr "無法執行 '%s' 來驗證簽章（gpgv 是否安裝了？）"
 
-#: methods/gpgv.cc:243
+#: methods/gpgv.cc:177
 msgid "Unknown error executing gpgv"
 msgstr "在執行 gpgv 時發生未知的錯誤"
 
-#: methods/gpgv.cc:277 methods/gpgv.cc:284
+#: methods/gpgv.cc:211 methods/gpgv.cc:218
 msgid "The following signatures were invalid:\n"
 msgstr "以下簽名無效：\n"
 
-#: methods/gpgv.cc:291
+#: methods/gpgv.cc:225
 msgid ""
 "The following signatures couldn't be verified because the public key is not "
 "available:\n"
@@ -2100,19 +2108,19 @@
 msgid "Error reading from server"
 msgstr "在讀取伺服器時發生錯誤"
 
-#: methods/http.cc:982 apt-pkg/contrib/mmap.cc:281
+#: methods/http.cc:985 apt-pkg/contrib/mmap.cc:281
 msgid "Failed to truncate file"
 msgstr "無法截短檔案"
 
-#: methods/http.cc:1151
+#: methods/http.cc:1154
 msgid "Bad header data"
 msgstr "錯誤的標頭資料"
 
-#: methods/http.cc:1168 methods/http.cc:1223
+#: methods/http.cc:1171 methods/http.cc:1226
 msgid "Connection failed"
 msgstr "連線失敗"
 
-#: methods/http.cc:1315
+#: methods/http.cc:1318
 msgid "Internal error"
 msgstr "內部錯誤"
 
@@ -2180,7 +2188,7 @@
 msgid "%lis"
 msgstr ""
 
-#: apt-pkg/contrib/strutl.cc:1083
+#: apt-pkg/contrib/strutl.cc:1119
 #, c-format
 msgid "Selection %s not found"
 msgstr "選項 %s 找不到"
@@ -2303,6 +2311,7 @@
 
 #: apt-pkg/contrib/cdromutl.cc:162 apt-pkg/contrib/cdromutl.cc:196
 #: apt-pkg/acquire.cc:477 apt-pkg/acquire.cc:502 apt-pkg/clean.cc:39
+#: methods/mirror.cc:93
 #, c-format
 msgid "Unable to change to %s"
 msgstr "無法切換至 %s"
@@ -2486,7 +2495,7 @@
 msgid "Failed to write temporary StateFile %s"
 msgstr "無法寫入暫存的 StateFile %s"
 
-#: apt-pkg/depcache.cc:852
+#: apt-pkg/depcache.cc:921
 #, c-format
 msgid "Internal error, group '%s' has no installable pseudo package"
 msgstr ""
@@ -2618,7 +2627,7 @@
 msgid "Unable to correct problems, you have held broken packages."
 msgstr "無法修正問題，您保留 (hold) 了損毀的套件。"
 
-#: apt-pkg/algorithms.cc:1461 apt-pkg/algorithms.cc:1463
+#: apt-pkg/algorithms.cc:1460 apt-pkg/algorithms.cc:1462
 msgid ""
 "Some index files failed to download, they have been ignored, or old ones "
 "used instead."
@@ -2666,12 +2675,12 @@
 msgid "Please insert the disc labeled: '%s' in the drive '%s' and press enter."
 msgstr "請把標籤為 '%s' 的光碟放入 '%s' 裝置中，然後按下 [Enter] 鍵。"
 
-#: apt-pkg/init.cc:135
+#: apt-pkg/init.cc:136
 #, c-format
 msgid "Packaging system '%s' is not supported"
 msgstr "不支援的套件包裝系統 '%s'"
 
-#: apt-pkg/init.cc:151
+#: apt-pkg/init.cc:152
 msgid "Unable to determine a suitable packaging system type"
 msgstr "無法確認合適的套件包裝系統類型"
 
@@ -2684,25 +2693,25 @@
 msgid "You must put some 'source' URIs in your sources.list"
 msgstr "在 sources.list 中必須包含一些 'source' URI"
 
-#: apt-pkg/cachefile.cc:71
+#: apt-pkg/cachefile.cc:84
 msgid "The package lists or status file could not be parsed or opened."
 msgstr "無法分析或開啟套件清單或狀況檔。"
 
-#: apt-pkg/cachefile.cc:75
+#: apt-pkg/cachefile.cc:88
 msgid "You may want to run apt-get update to correct these problems"
 msgstr "您也許得執行 apt-get update 以修正這些問題"
 
-#: apt-pkg/policy.cc:333
+#: apt-pkg/policy.cc:343
 #, fuzzy, c-format
 msgid "Invalid record in the preferences file %s, no Package header"
 msgstr "個人設定檔中有些不正確資料，沒有以 Package 開頭"
 
-#: apt-pkg/policy.cc:355
+#: apt-pkg/policy.cc:365
 #, c-format
 msgid "Did not understand pin type %s"
 msgstr "無法分析鎖定類型 %s"
 
-#: apt-pkg/policy.cc:363
+#: apt-pkg/policy.cc:373
 msgid "No priority (or zero) specified for pin"
 msgstr "銷定並沒有優先順序之分（或零）"
 
@@ -2791,32 +2800,57 @@
 msgid "Couldn't stat source package list %s"
 msgstr "無法取得來源套件列表 %s 的狀態"
 
-#: apt-pkg/pkgcachegen.cc:962
+#: apt-pkg/pkgcachegen.cc:965
 msgid "Collecting File Provides"
 msgstr "正在收集檔案提供者"
 
-#: apt-pkg/pkgcachegen.cc:1122 apt-pkg/pkgcachegen.cc:1129
+#: apt-pkg/pkgcachegen.cc:1130 apt-pkg/pkgcachegen.cc:1137
 msgid "IO Error saving source cache"
 msgstr "在儲存來源快取時 IO 錯誤"
 
-#: apt-pkg/acquire-item.cc:128
+#: apt-pkg/acquire-item.cc:136
 #, c-format
 msgid "rename failed, %s (%s -> %s)."
 msgstr "無法重新命名，%s (%s -> %s)。"
 
-#: apt-pkg/acquire-item.cc:432
+#: apt-pkg/acquire-item.cc:484
 msgid "MD5Sum mismatch"
 msgstr "MD5Sum 不符"
 
-#: apt-pkg/acquire-item.cc:693 apt-pkg/acquire-item.cc:1469
+#: apt-pkg/acquire-item.cc:744 apt-pkg/acquire-item.cc:1550
 msgid "Hash Sum mismatch"
 msgstr "Hash Sum 不符"
 
-#: apt-pkg/acquire-item.cc:1150
+#: apt-pkg/acquire-item.cc:1220
 msgid "There is no public key available for the following key IDs:\n"
 msgstr "無法取得以下的密鑰 ID 的公鑰：\n"
 
-#: apt-pkg/acquire-item.cc:1260
+#. TRANSLATOR: The first %s is the URL of the bad Release file, the second is
+#. the time since then the file is invalid - formated in the same way as in
+#. the download progress display (e.g. 7d 3h 42min 1s)
+#: apt-pkg/acquire-item.cc:1257
+#, fuzzy, c-format
+msgid "Release file expired, ignoring %s (invalid since %s)"
+msgstr "Release 檔已過期，略過 %s（有效期限 %s）"
+
+#: apt-pkg/acquire-item.cc:1278
+#, c-format
+msgid "Conflicting distribution: %s (expected %s but got %s)"
+msgstr "發行版本衝突：%s（應當是 %s 但卻得到 %s）"
+
+#: apt-pkg/acquire-item.cc:1304
+#, c-format
+msgid ""
+"A error occurred during the signature verification. The repository is not "
+"updated and the previous index files will be used.GPG error: %s: %s\n"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1313
+#, c-format
+msgid "GPG error: %s: %s"
+msgstr ""
+
+#: apt-pkg/acquire-item.cc:1341
 #, c-format
 msgid ""
 "I wasn't able to locate a file for the %s package. This might mean you need "
@@ -2825,38 +2859,48 @@
 "找不到 %s 套件的某個檔案。這意味著您可能要手動修復這個套件。（因為找不到平"
 "台）"
 
-#: apt-pkg/acquire-item.cc:1319
+#: apt-pkg/acquire-item.cc:1400
 #, c-format
 msgid ""
 "I wasn't able to locate file for the %s package. This might mean you need to "
 "manually fix this package."
 msgstr "找不到 %s 套件的某個檔案。這意味著您可能要手動修復這個套件。"
 
-#: apt-pkg/acquire-item.cc:1374
+#: apt-pkg/acquire-item.cc:1455
 #, c-format
 msgid ""
 "The package index files are corrupted. No Filename: field for package %s."
 msgstr "這個套件的索引檔損壞了。沒有套件 %s 的 Filename: 欄位。"
 
-#: apt-pkg/acquire-item.cc:1461
+#: apt-pkg/acquire-item.cc:1542
 msgid "Size mismatch"
 msgstr "大小不符"
 
-#: apt-pkg/indexrecords.cc:40
+#: apt-pkg/indexrecords.cc:53
 #, c-format
 msgid "Unable to parse Release file %s"
 msgstr "無法辨別 Release 檔 %s"
 
-#: apt-pkg/indexrecords.cc:47
+#: apt-pkg/indexrecords.cc:60
 #, c-format
 msgid "No sections in Release file %s"
 msgstr "在 Release 檔 %s 裡沒有區段"
 
-#: apt-pkg/indexrecords.cc:81
+#: apt-pkg/indexrecords.cc:94
 #, c-format
 msgid "No Hash entry in Release file %s"
 msgstr "在 Release 檔 %s 裡沒有 Hash 項目"
 
+#: apt-pkg/indexrecords.cc:107
+#, fuzzy, c-format
+msgid "Invalid 'Valid-Until' entry in Release file %s"
+msgstr "在 Release 檔 %s 裡沒有 Hash 項目"
+
+#: apt-pkg/indexrecords.cc:122
+#, fuzzy, c-format
+msgid "Invalid 'Date' entry in Release file %s"
+msgstr "在 Release 檔 %s 裡沒有 Hash 項目"
+
 #: apt-pkg/vendorlist.cc:66
 #, c-format
 msgid "Vendor block %s contains no fingerprint"
@@ -2949,151 +2993,234 @@
 msgid "Source list entries for this disc are:\n"
 msgstr "該碟片的來源列表項目為：\n"
 
-#: apt-pkg/indexcopy.cc:263 apt-pkg/indexcopy.cc:835
+#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:902
 #, c-format
 msgid "Wrote %i records.\n"
 msgstr "寫入 %i 筆紀錄。\n"
 
-#: apt-pkg/indexcopy.cc:265 apt-pkg/indexcopy.cc:837
+#: apt-pkg/indexcopy.cc:267 apt-pkg/indexcopy.cc:904
 #, c-format
 msgid "Wrote %i records with %i missing files.\n"
 msgstr "寫入 %i 筆紀綠，其中有 %i 個檔案遺失了。\n"
 
-#: apt-pkg/indexcopy.cc:268 apt-pkg/indexcopy.cc:840
+#: apt-pkg/indexcopy.cc:270 apt-pkg/indexcopy.cc:907
 #, c-format
 msgid "Wrote %i records with %i mismatched files\n"
 msgstr "寫入 %i 筆紀綠，其中有 %i 個檔案不符\n"
 
-#: apt-pkg/indexcopy.cc:271 apt-pkg/indexcopy.cc:843
+#: apt-pkg/indexcopy.cc:273 apt-pkg/indexcopy.cc:910
 #, c-format
 msgid "Wrote %i records with %i missing files and %i mismatched files\n"
 msgstr "寫入 %i 筆紀綠，其中有 %i 個檔案遺失了，有 %i 個檔案不符\n"
 
-#: apt-pkg/indexcopy.cc:530
+#: apt-pkg/indexcopy.cc:532
 #, fuzzy, c-format
 msgid "Skipping nonexistent file %s"
 msgstr "開啟設定檔 %s"
 
-#: apt-pkg/indexcopy.cc:536
+#: apt-pkg/indexcopy.cc:538
 #, c-format
 msgid "Can't find authentication record for: %s"
 msgstr ""
 
-#: apt-pkg/indexcopy.cc:542
+#: apt-pkg/indexcopy.cc:544
 #, fuzzy, c-format
 msgid "Hash mismatch for: %s"
 msgstr "Hash Sum 不符"
 
-#: apt-pkg/deb/dpkgpm.cc:49
+#: apt-pkg/cacheset.cc:68
+#, c-format
+msgid "Note, selecting %s for regex '%s'\n"
+msgstr "注意，根據正規表示式 '%2$s' 而選擇了 %1$s\n"
+
+#: apt-pkg/cacheset.cc:194
+#, fuzzy, c-format
+msgid "Selected version '%s' (%s) for '%s'\n"
+msgstr "選定的版本為 %3$s 的 %1$s (%2$s)\n"
+
+#: apt-pkg/cacheset.cc:213
+#, c-format
+msgid "Can't select versions from package '%s' as it purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:234 apt-pkg/cacheset.cc:245
+#, c-format
+msgid ""
+"Can't select installed nor candidate version from package '%s' as it has "
+"neither of them"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:253
+#, c-format
+msgid "Can't select newest version from package '%s' as it is purely virtual"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:268
+#, c-format
+msgid "Can't select candidate version from package %s as it has no candidate"
+msgstr ""
+
+#: apt-pkg/cacheset.cc:276
+#, c-format
+msgid "Can't select installed version from package %s as it is not installed"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:52
 #, c-format
 msgid "Installing %s"
 msgstr "正在安裝 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:50 apt-pkg/deb/dpkgpm.cc:742
+#: apt-pkg/deb/dpkgpm.cc:53 apt-pkg/deb/dpkgpm.cc:814
 #, c-format
 msgid "Configuring %s"
 msgstr "正在設定 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:51 apt-pkg/deb/dpkgpm.cc:749
+#: apt-pkg/deb/dpkgpm.cc:54 apt-pkg/deb/dpkgpm.cc:821
 #, c-format
 msgid "Removing %s"
 msgstr "正在移除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:52
+#: apt-pkg/deb/dpkgpm.cc:55
 #, fuzzy, c-format
 msgid "Completely removing %s"
 msgstr "已完整移除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:53
+#: apt-pkg/deb/dpkgpm.cc:56
 #, c-format
 msgid "Noting disappearance of %s"
 msgstr ""
 
-#: apt-pkg/deb/dpkgpm.cc:54
+#: apt-pkg/deb/dpkgpm.cc:57
 #, c-format
 msgid "Running post-installation trigger %s"
 msgstr "正在執行安裝後套件後續處理程式 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:586
+#: apt-pkg/deb/dpkgpm.cc:643
 #, c-format
 msgid "Directory '%s' missing"
 msgstr "找不到 '%s' 目錄"
 
-#: apt-pkg/deb/dpkgpm.cc:601 apt-pkg/deb/dpkgpm.cc:614
+#: apt-pkg/deb/dpkgpm.cc:658 apt-pkg/deb/dpkgpm.cc:671
 #, fuzzy, c-format
 msgid "Could not open file '%s'"
 msgstr "無法開啟檔案 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:735
+#: apt-pkg/deb/dpkgpm.cc:807
 #, c-format
 msgid "Preparing %s"
 msgstr "正在準備 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:736
+#: apt-pkg/deb/dpkgpm.cc:808
 #, c-format
 msgid "Unpacking %s"
 msgstr "正在解開 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:741
+#: apt-pkg/deb/dpkgpm.cc:813
 #, c-format
 msgid "Preparing to configure %s"
 msgstr "正在準備設定 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:743
+#: apt-pkg/deb/dpkgpm.cc:815
 #, c-format
 msgid "Installed %s"
 msgstr "已安裝 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:748
+#: apt-pkg/deb/dpkgpm.cc:820
 #, c-format
 msgid "Preparing for removal of %s"
 msgstr "正在準備移除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:750
+#: apt-pkg/deb/dpkgpm.cc:822
 #, c-format
 msgid "Removed %s"
 msgstr "已移除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:755
+#: apt-pkg/deb/dpkgpm.cc:827
 #, c-format
 msgid "Preparing to completely remove %s"
 msgstr "正在準備完整移除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:756
+#: apt-pkg/deb/dpkgpm.cc:828
 #, c-format
 msgid "Completely removed %s"
 msgstr "已完整移除 %s"
 
-#: apt-pkg/deb/dpkgpm.cc:962
+#: apt-pkg/deb/dpkgpm.cc:1034
 msgid "Can not write log, openpty() failed (/dev/pts not mounted?)\n"
 msgstr "無法寫入記錄檔，openpty() 失敗（/dev/pts 未掛載？）\n"
 
-#: apt-pkg/deb/dpkgpm.cc:993
+#: apt-pkg/deb/dpkgpm.cc:1065
 msgid "Running dpkg"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:70
+#: apt-pkg/deb/dpkgpm.cc:1268
+msgid "No apport report written because MaxReports is reached already"
+msgstr ""
+
+#. check if its not a follow up error
+#: apt-pkg/deb/dpkgpm.cc:1273
+msgid "dependency problems - leaving unconfigured"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1275
+msgid ""
+"No apport report written because the error message indicates its a followup "
+"error from a previous failure."
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1281
+msgid ""
+"No apport report written because the error message indicates a disk full "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1287
+msgid ""
+"No apport report written because the error message indicates a out of memory "
+"error"
+msgstr ""
+
+#: apt-pkg/deb/dpkgpm.cc:1294
+msgid ""
+"No apport report written because the error message indicates a dpkg I/O error"
+msgstr ""
+
+#: apt-pkg/deb/debsystem.cc:69
 #, c-format
 msgid ""
 "Unable to lock the administration directory (%s), is another process using "
 "it?"
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:73
+#: apt-pkg/deb/debsystem.cc:72
 #, fuzzy, c-format
 msgid "Unable to lock the administration directory (%s), are you root?"
 msgstr "無法鎖定列表目錄"
 
-#: apt-pkg/deb/debsystem.cc:82
+#. TRANSLATORS: the %s contains the recovery command, usually
+#. dpkg --configure -a
+#: apt-pkg/deb/debsystem.cc:88
+#, c-format
 msgid ""
-"dpkg was interrupted, you must manually run 'dpkg --configure -a' to correct "
-"the problem. "
+"dpkg was interrupted, you must manually run '%s' to correct the problem. "
 msgstr ""
 
-#: apt-pkg/deb/debsystem.cc:100
+#: apt-pkg/deb/debsystem.cc:106
 msgid "Not locked"
 msgstr ""
 
+#. FIXME: fallback to a default mirror here instead
+#. and provide a config option to define that default
+#: methods/mirror.cc:200
+#, c-format
+msgid "No mirror file '%s' found "
+msgstr ""
+
+#: methods/mirror.cc:343
+#, c-format
+msgid "[Mirror: %s]"
+msgstr ""
+
 #: methods/rred.cc:465
 #, c-format
 msgid ""
@@ -3108,7 +3235,7 @@
 "to be corrupt."
 msgstr ""
 
-#: methods/rsh.cc:330
+#: methods/rsh.cc:329
 msgid "Connection closed prematurely"
 msgstr "連線突然終止"
 
@@ -3132,9 +3259,3 @@
 
 #~ msgid "Processing triggers for %s"
 #~ msgstr "正在進行 %s 的觸發程式"
-
-#~ msgid "Release file expired, ignoring %s (valid until %s)"
-#~ msgstr "Release 檔已過期，略過 %s（有效期限 %s）"
-
-#~ msgid "Conflicting distribution: %s (expected %s but got %s)"
-#~ msgstr "發行版本衝突：%s（應當是 %s 但卻得到 %s）"

=== added directory 'test/authReliability'
=== added directory 'test/authReliability/lists'
=== added file 'test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Packages'
--- test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Packages	1970-01-01 00:00:00 +0000
+++ test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Packages	2010-06-10 14:02:22 +0000
@@ -0,0 +1,25 @@
+Package: libglib2.0-data
+Priority: optional
+Section: misc
+Installed-Size: 2288
+Maintainer: Ubuntu Desktop Team <ubuntu-desktop@lists.ubuntu.com>
+Original-Maintainer: Loic Minier <lool@dooz.org>
+Architecture: all
+Source: glib2.0
+Version: 2.13.6-1ubuntu1
+Replaces: libglib1.3, libglib1.3-data
+Depends: libglib2.0-0 (>= 2.13.6-1ubuntu1)
+Conflicts: libglib1.3-data
+Filename: ./libglib2.0-data_2.13.6-1ubuntu1_all.deb
+Size: 958
+MD5sum: 803fc5e2e31a4345b3e9c771e1eae49f
+SHA1: 75b2c62b21bae60c58e694dd40ed6d4df946e304
+SHA256: 142d8466eac252f06bc957d76fe1bb87f86f2d3512b99c8d4b08c1ad79fbe59e
+Description: Common files for GLib library
+ GLib is a library containing many useful C routines for things such
+ as trees, hashes, lists, and strings.  It is a useful general-purpose
+ C library used by projects such as GTK+, GIMP, and GNOME.
+ .
+ This package is needed for the runtime libraries to display messages in
+ languages other than English.
+

=== added file 'test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Release'
--- test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Release	1970-01-01 00:00:00 +0000
+++ test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Release	2010-06-10 14:02:22 +0000
@@ -0,0 +1,13 @@
+Date: Fri, 27 Jul 2007 14:39:41 UTC
+MD5Sum:
+ 4672dadea6a144839f823c9f3d5fd44b              934 Packages
+ 82ebcf09a8d78a2b9cf7759349da4936              603 Packages.gz
+ d41d8cd98f00b204e9800998ecf8427e                0 Release
+SHA1:
+ fa0f294aa30789529371066b10e9497be1284d26              934 Packages
+ f4032808663b2810d87b4a4dab6f5ae4a1e8fa8e              603 Packages.gz
+ da39a3ee5e6b4b0d3255bfef95601890afd80709                0 Release
+SHA256:
+ 92c9b605480dc74e6be79c0ddc24738bfcbd6dd3148af531acd68717de528049              934 Packages
+ 659ccc0d07ff21f0247f9fa5abe149221c90d5e17da52c7afddb035b93c23d39              603 Packages.gz
+ e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855                0 Release

=== added file 'test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Release.gpg'
--- test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Release.gpg	1970-01-01 00:00:00 +0000
+++ test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Release.gpg	2010-06-10 14:02:22 +0000
@@ -0,0 +1,7 @@
+-----BEGIN PGP SIGNATURE-----
+Version: GnuPG v1.4.6 (GNU/Linux)
+
+iD8DBQBGqgOwliSD4VZixzQRAs6jAJ9p7Aiob9gzkUNCtoW8UPrBo0E/YwCdEaz0
+CQJszU6fRYX5jGWXSWzfc5c=
+=ugH0
+-----END PGP SIGNATURE-----

=== added file 'test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Packages'
--- test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Packages	1970-01-01 00:00:00 +0000
+++ test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Packages	2010-06-10 14:02:22 +0000
@@ -0,0 +1,25 @@
+Package: libglib2.0-data
+Priority: optional
+Section: misc
+Installed-Size: 2288
+Maintainer: Ubuntu Desktop Team <ubuntu-desktop@lists.ubuntu.com>
+Original-Maintainer: Loic Minier <lool@dooz.org>
+Architecture: all
+Source: glib2.0
+Version: 2.13.6-1ubuntu1
+Replaces: libglib1.3, libglib1.3-data
+Depends: libglib2.0-0 (>= 2.13.6-1ubuntu1)
+Conflicts: libglib1.3-data
+Filename: ./libglib2.0-data_2.13.6-1ubuntu1_all.deb
+Size: 958
+MD5sum: 803fc5e2e31a4345b3e9c771e1eae49f
+SHA1: 75b2c62b21bae60c58e694dd40ed6d4df946e304
+SHA256: 142d8466eac252f06bc957d76fe1bb87f86f2d3512b99c8d4b08c1ad79fbe59e
+Description: Common files for GLib library
+ GLib is a library containing many useful C routines for things such
+ as trees, hashes, lists, and strings.  It is a useful general-purpose
+ C library used by projects such as GTK+, GIMP, and GNOME.
+ .
+ This package is needed for the runtime libraries to display messages in
+ languages other than English.
+

=== added file 'test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release'
--- test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release	1970-01-01 00:00:00 +0000
+++ test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release	2010-06-10 14:02:22 +0000
@@ -0,0 +1,13 @@
+Date: Fri, 27 Jul 2007 14:39:41 UTC
+MD5Sum:
+ 4672dadea6a144839f823c9f3d5fd44b              934 Packages
+ 82ebcf09a8d78a2b9cf7759349da4936              603 Packages.gz
+ d41d8cd98f00b204e9800998ecf8427e                0 Release
+SHA1:
+ fa0f294aa30789529371066b10e9497be1284d26              934 Packages
+ f4032808663b2810d87b4a4dab6f5ae4a1e8fa8e              603 Packages.gz
+ da39a3ee5e6b4b0d3255bfef95601890afd80709                0 Release
+SHA256:
+ 92c9b605480dc74e6be79c0ddc24738bfcbd6dd3148af531acd68717de528049              934 Packages
+ 659ccc0d07ff21f0247f9fa5abe149221c90d5e17da52c7afddb035b93c23d39              603 Packages.gz
+ e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855                0 Release

=== added file 'test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release.gpg'
--- test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release.gpg	1970-01-01 00:00:00 +0000
+++ test/authReliability/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release.gpg	2010-06-10 14:02:22 +0000
@@ -0,0 +1,7 @@
+-----BEGIN PGP SIGNATURE-----
+Version: GnuPG v1.4.6 (GNU/Linux)
+
+iD8DBQBGqgOwliSD4VZixzQRAs6jAJ9p7Aiob9gzkUNCtoW8UPrBo0E/YwCdEaz0
+CQJszU6fRYX5jGWXSWzfc5c=
+=ugH0
+-----END PGP SIGNATURE-----

=== added file 'test/authReliability/sources.list.failure'
--- test/authReliability/sources.list.failure	1970-01-01 00:00:00 +0000
+++ test/authReliability/sources.list.failure	2010-06-10 14:02:22 +0000
@@ -0,0 +1,2 @@
+deb http://people.ubuntu.com/~mvo/apt/auth-test-suit/gpg-package-broken/ /
+

=== added file 'test/authReliability/sources.list.good'
--- test/authReliability/sources.list.good	1970-01-01 00:00:00 +0000
+++ test/authReliability/sources.list.good	2010-06-10 14:02:22 +0000
@@ -0,0 +1,2 @@
+deb http://people.ubuntu.com/~mvo/apt/auth-test-suit/gpg-package-ok/ /
+

=== added file 'test/libapt/getarchitectures_test.cc'
--- test/libapt/getarchitectures_test.cc	1970-01-01 00:00:00 +0000
+++ test/libapt/getarchitectures_test.cc	2010-06-10 14:02:22 +0000
@@ -0,0 +1,61 @@
+#include <apt-pkg/aptconfiguration.h>
+#include <apt-pkg/configuration.h>
+
+#include "assert.h"
+#include <string>
+#include <vector>
+
+#include <iostream>
+
+// simple helper to quickly output a vector of strings
+void dumpVector(std::vector<std::string> vec) {
+	for (std::vector<std::string>::const_iterator v = vec.begin();
+	     v != vec.end(); v++)
+		std::cout << *v << std::endl;
+}
+
+int main(int argc,char *argv[])
+{
+	std::vector<std::string> vec;
+
+	_config->Set("APT::Architectures::1", "i386");
+	_config->Set("APT::Architectures::2", "amd64");
+	vec = APT::Configuration::getArchitectures(false);
+	equals(vec.size(), 2);
+	equals(vec[0], "i386");
+	equals(vec[1], "amd64");
+
+	_config->Set("APT::Architecture", "i386");
+	vec = APT::Configuration::getArchitectures(false);
+	equals(vec.size(), 2);
+	equals(vec[0], "i386");
+	equals(vec[1], "amd64");
+
+	_config->Set("APT::Architectures::2", "");
+	vec = APT::Configuration::getArchitectures(false);
+	equals(vec.size(), 1);
+	equals(vec[0], "i386");
+
+	_config->Set("APT::Architecture", "armel");
+	vec = APT::Configuration::getArchitectures(false);
+	equals(vec.size(), 2);
+	equals(vec[0], "i386");
+	equals(vec[1], "armel");
+
+	_config->Set("APT::Architectures::2", "amd64");
+	_config->Set("APT::Architectures::3", "i386");
+	_config->Set("APT::Architectures::4", "armel");
+	_config->Set("APT::Architectures::5", "i386");
+	_config->Set("APT::Architectures::6", "amd64");
+	_config->Set("APT::Architectures::7", "armel");
+	_config->Set("APT::Architectures::8", "armel");
+	_config->Set("APT::Architectures::9", "amd64");
+	_config->Set("APT::Architectures::10", "amd64");
+	vec = APT::Configuration::getArchitectures(false);
+	equals(vec.size(), 3);
+	equals(vec[0], "i386");
+	equals(vec[1], "amd64");
+	equals(vec[2], "armel");
+
+	return 0;
+}

=== modified file 'test/libapt/makefile'
--- test/libapt/makefile	2010-04-01 17:30:43 +0000
+++ test/libapt/makefile	2010-06-10 14:02:22 +0000
@@ -12,6 +12,11 @@
 SOURCE = getlanguages_test.cc
 include $(PROGRAM_H)
 
+PROGRAM = getArchitectures${BASENAME}
+SLIBS = -lapt-pkg
+SOURCE = getarchitectures_test.cc
+include $(PROGRAM_H)
+
 # Program for testing ParseDepends
 PROGRAM = ParseDepends${BASENAME}
 SLIBS = -lapt-pkg

=== modified file 'test/libapt/run-tests.sh'
--- test/libapt/run-tests.sh	2010-02-18 22:07:23 +0000
+++ test/libapt/run-tests.sh	2010-06-10 14:02:22 +0000
@@ -2,6 +2,7 @@
 set -e
 
 echo "Compiling the tests ..."
+test -d '../../build/obj/test/libapt/' || mkdir -p '../../build/obj/test/libapt/'
 make
 echo "Running all testcases ..."
 LDPATH=$(pwd)/../../build/bin

=== modified file 'test/pre-upload-check.py'
--- test/pre-upload-check.py	2010-02-18 22:07:23 +0000
+++ test/pre-upload-check.py	2010-06-10 14:02:22 +0000
@@ -4,6 +4,8 @@
 import os
 import glob
 import os.path
+import shutil
+import time
 from subprocess import call, PIPE
 
 import unittest
@@ -11,7 +13,102 @@
 stdout = os.open("/dev/null",0) #sys.stdout
 stderr = os.open("/dev/null",0) # sys.stderr
 
-apt_args = []  # ["-o","Debug::pkgAcquire::Auth=true"]
+apt_args = [] 
+#apt_args = ["-o","Debug::pkgAcquire::Auth=true"]
+
+class testAptAuthenticationReliability(unittest.TestCase):
+    """
+    test if the spec https://wiki.ubuntu.com/AptAuthenticationReliability 
+    is properly implemented
+    """
+    #apt = "../bin/apt-get"
+    apt = "apt-get"
+
+    def setUp(self):
+        if os.path.exists("/tmp/autFailure"):
+            os.unlink("/tmp/authFailure");
+        if os.path.exists("/tmp/autFailure2"):
+            os.unlink("/tmp/authFailure2");
+    def testRepositorySigFailure(self):
+        """
+        test if a repository that used to be authenticated and fails on
+        apt-get update refuses to update and uses the old state
+        """
+        # copy valid signatures into lists (those are ok, even
+        # if the name is "-broken-" ...
+        for f in glob.glob("./authReliability/lists/*"):
+            shutil.copy(f,"/var/lib/apt/lists")
+            # ensure we do *not* get a I-M-S hit
+            os.utime("/var/lib/apt/lists/%s" % os.path.basename(f), (0,0))
+        res = call([self.apt,
+                    "update",
+                    "-o","Dir::Etc::sourcelist=./authReliability/sources.list.failure", 
+                    "-o",'APT::Update::Auth-Failure::=touch /tmp/authFailure',
+                   ] + apt_args,
+                   stdout=stdout, stderr=stderr)
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Release.gpg"),
+                     "The gpg file disappeared, this should not happen")
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Packages"),
+                     "The Packages file disappeared, this should not happen")
+        self.assert_(os.path.exists("/tmp/authFailure"),
+                     "The APT::Update::Auth-Failure script did not run (1)")
+        # the same with i-m-s hit this time
+        for f in glob.glob("./authReliability/lists/*"):
+            shutil.copy(f,"/var/lib/apt/lists")
+            os.utime("/var/lib/apt/lists/%s" % os.path.basename(f), (time.time(),time.time()))
+        res = call([self.apt,
+                    "update",
+                    "-o","Dir::Etc::sourcelist=./authReliability/sources.list.failure",
+                    "-o",'APT::Update::Auth-Failure::=touch /tmp/authFailure2',
+                   ] + apt_args,
+                   stdout=stdout, stderr=stderr)
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Release.gpg"),
+                     "The gpg file disappeared, this should not happen")
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-broken_Packages"),
+                     "The Packages file disappeared, this should not happen")
+        self.assert_(os.path.exists("/tmp/authFailure2"),
+                     "The APT::Update::Auth-Failure script did not run (2)")
+    def testRepositorySigGood(self):
+        """
+        test that a regular repository with good data stays good
+        """
+        res = call([self.apt,
+                    "update",
+                    "-o","Dir::Etc::sourcelist=./authReliability/sources.list.good"
+                   ] + apt_args,
+                   stdout=stdout, stderr=stderr)
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release.gpg"),
+                     "The gpg file disappeared after a regular download, this should not happen")
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Packages"),
+                     "The Packages file disappeared, this should not happen")
+        # test good is still good after non I-M-S hit and a previous files in lists/
+        for f in glob.glob("./authReliability/lists/*"):
+            shutil.copy(f,"/var/lib/apt/lists")
+            # ensure we do *not* get a I-M-S hit
+            os.utime("/var/lib/apt/lists/%s" % os.path.basename(f), (0,0))
+        res = call([self.apt,
+                    "update",
+                    "-o","Dir::Etc::sourcelist=./authReliability/sources.list.good"
+                   ] + apt_args,
+                   stdout=stdout, stderr=stderr)
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release.gpg"),
+                     "The gpg file disappeared after a I-M-S hit, this should not happen")
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Packages"),
+                     "The Packages file disappeared, this should not happen")
+        # test good is still good after I-M-S hit
+        for f in glob.glob("./authReliability/lists/*"):
+            shutil.copy(f,"/var/lib/apt/lists")
+            # ensure we do get a I-M-S hit
+            os.utime("/var/lib/apt/lists/%s" % os.path.basename(f), (time.time(),time.time()))
+        res = call([self.apt,
+                    "update",
+                    "-o","Dir::Etc::sourcelist=./authReliability/sources.list.good"
+                   ] + apt_args,
+                   stdout=stdout, stderr=stderr)
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Release.gpg"),
+                     "The gpg file disappeared, this should not happen")
+        self.assert_(os.path.exists("/var/lib/apt/lists/people.ubuntu.com_%7emvo_apt_auth-test-suit_gpg-package-ok_Packages"),
+                     "The Packages file disappeared, this should not happen")
 
 
 class testAuthentication(unittest.TestCase):
@@ -95,6 +192,20 @@
                 self.assert_(len(glob.glob("/var/lib/apt/lists/partial/*")) == 0,
                              "partial/ dir has leftover files: %s" % glob.glob("/var/lib/apt/lists/partial/*"))
 
+    def testValid(self):
+        for f in glob.glob("testsources.list/sources.list*validuntil*"):
+            self._cleanup()
+            (prefix, testtype, result) = f.split("-")
+            expected_res = self._expectedRes(result)
+            cmd = ["update"]
+            res = call([self.apt,"-o","Dir::Etc::sourcelist=./%s" % f]+cmd+apt_args,
+                       stdout=stdout, stderr=stderr)
+            self.assert_(res == expected_res,
+                         "test '%s' failed (got %s expected %s" % (f,res,expected_res))
+            if expected_res == 0:
+                self.assert_(len(glob.glob("/var/lib/apt/lists/partial/*")) == 0,
+                             "partial/ dir has leftover files: %s" % glob.glob("/var/lib/apt/lists/partial/*"))
+
 
 class testLocalRepositories(unittest.TestCase):
     " test local repository regressions "
@@ -149,6 +260,7 @@
     if len(sys.argv) > 1 and sys.argv[1] == "-v":
         stdout = sys.stdout
         stderr = sys.stderr
+    
+    # run only one for now
+    #unittest.main(defaultTest="testAptAuthenticationReliability")
     unittest.main()
-
-

=== added file 'test/testsources.list/sources.list.all-validuntil-broken'
--- test/testsources.list/sources.list.all-validuntil-broken	1970-01-01 00:00:00 +0000
+++ test/testsources.list/sources.list.all-validuntil-broken	2010-06-10 14:02:22 +0000
@@ -0,0 +1,1 @@
+deb http://people.ubuntu.com/~mvo/apt/auth-test-suit/all-validuntil-broken/ /

